(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4356719,     179364]*)
(*NotebookOutlinePosition[   4357399,     179387]*)
(*  CellTagsIndexPosition[   4357355,     179383]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING WITH A BOUND STATE", "Text",
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  ",
    FontSize->12],
  StyleBox["is located on the entire ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0, ",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" any real number, is in the nonhomogeneity and needs to be \
specified. \n\nThe potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly negative. It corresponds to a \
reflectionless potential with one bound state of norming constant, c>0.\n\n\
The transmission coefficient, left reflection coefficient, and right \
reflection coefficient, respectively, are denoted by  T[k],  L[k],  R[k].\n\n\
The tail of the wave is denoted by  g[x,t].\n\nThe focusing moment is chosen \
as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, x0, g, c];\)\), "\[IndentingNewLine]", 
    \(\(v[
          x_] = \(-\ 
            16\)\ c^2\ E^\((2\ x)\)/\((2\ E^\((2\ x)\) + 
                  c^2)\)^2\ ;\)\), "\n", 
    \(\(T[k_] = \((k + I\ )\)/\((k - I)\);\)\), "\n", 
    \(\(L[k_] = 0;\)\), "\n", 
    \(\(R[k_] = 0;\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the focusing location  x0, any real number, and the norming \
constant c, a positive number, next:\
\>", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\(c = 1\) \)\(;\)\(\ \)\(\(x0 = \(-1\)\) \)\(;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(g[x_, t_] = 
        UnitStep[\(-x\) + x0 + 
              t]\ \((4\ c^2\ E^\((x + x0)\)\ \((E^t - 
                    E^\((\(-t\))\))\))\)/\((\((2\ E^\((2\ x)\) + 
                    c^2)\) \((2\ E^\((2\ x0)\) + c^2)\))\);\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-5\), \ 
              2.5}, \ PlotRange -> {\(-3\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]Plot[{10\ UnitStep[
                  x - x0 - t]}, \ {x, \ \(-5\), \ 2.5}, \ 
            PlotStyle\  \[Rule] \ Hue[0.9], \ 
            PlotRange -> {\(-3\), 4}], \ \[IndentingNewLine]Plot[{g[x, 
                t]}, \ {x, \ \(-5\), \ 2.5}, 
            PlotStyle\  \[Rule] \ 
              Hue[ .6], \ \ PlotRange -> {\(-3\), 
                4}]}, \ \[IndentingNewLine]{t, \ \(-3.8\), \ 2.2, 0.1}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.03279 .26487 L
.04262 .26487 L
.04517 .26487 L
.04758 .26487 L
.04822 .26487 L
.04891 .26487 L
s
.04891 .26487 m
.04921 .61803 L
s
0 .4 1 r
.02381 .23409 m
.03279 .23184 L
.04262 .22918 L
.04517 .22846 L
.04758 .22776 L
.04822 .22757 L
.04891 .22737 L
.04966 .26487 L
.05035 .26487 L
.05288 .26487 L
.06244 .26487 L
.10458 .26487 L
.14241 .26487 L
.1827 .26487 L
.22147 .26487 L
.2627 .26487 L
.30241 .26487 L
.3406 .26487 L
.38125 .26487 L
.42038 .26487 L
.46196 .26487 L
.50202 .26487 L
.54057 .26487 L
.58158 .26487 L
.62107 .26487 L
.65904 .26487 L
.69946 .26487 L
.73837 .26487 L
.77973 .26487 L
.81958 .26487 L
.85791 .26487 L
.89869 .26487 L
.93795 .26487 L
.97571 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool01000001Vo`1Vo`1V
oaWoool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0000co`0c
o`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Oooo`@00000
0oooo`1Vo`1Vo`02000000@0I_ooooooool0I_lCoooo100000;oool010000?ooooooo`0001Ooool4
00001Oooo`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J
<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000H
oooo00<0003oooooool00_ooo`0306Kooooooooo01Soool00`000?ooo`00000Moooo00@0003ooooo
ool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol0
00<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<00002oooo00<0I_ooooooool06Ooo
o`80000Noooo0P0001_oool500007S?o0080000L<ol000<0000co`0co`0073?o00800008<ol01000
01?oool200009oooo`007Oooo`0306Kooooooooo05Coool20000@C?o00030000<ol0<ol002Xco`03
0000>Oooo`007Oooo`0306Kooooooooo053oool40000@c?o0080000^<ol00P0003Ooool001goool0
0`1Vooooooooo`1;oooo1@0004Lco`000`0003?o03?o000_<ol0100003?oool001goool00`1Voooo
ooooo`11oooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool001goool00`1Vooooooooo`0f
oooo2`0005Hco`000`0003?o03?o000m<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool04_ooo`005_ooo`030000oooooooo00Coool00ol0VOooooooo`0Foooo00<0
003oooooool07_ooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`007Oooo`03o`2I
oooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo
06Koool001goool00ol0VOooooooo`2Goooo0P0006Ooool001goool00ol0VOooooooo`2Goooo00<0
003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o
09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo0P0006Ooool0
01goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool0
0`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool0
0ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool20000Iooo
o`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uooo
o`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Ooo
o`03o`2Ioooooooo09Ooool20000Ioooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1V
oooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2?
oooo1@0000?oool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0TOooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0TOooo`030000oooooooo00?oool3
0000I_ooo`007Oooo`03o`2Ioooooooo097oool00`000?ooooooo`03oooo00<0003oooooool0I_oo
o`007Oooo`03o`2Ioooooooo097oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`007Ooo
o`03o`2Ioooooooo093oool200001Oooo`030000oooooooo06Koool001goool00ol0VOooooooo`2G
oooo0P0006Ooool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2I
oooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo
06Koool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo
09Ooool20000Ioooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o
09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0003ooooo
ool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool20000Ioooo`007Oooo`03o`2Ioooooooo09Ooool0
0`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool0
0ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool00`000?oo
ooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`80001Woooo000Moooo00?o09Woooooool0Uooo
o`030000oooooooo06Koool001goool00ol0VOooooooo`2?oooo100000Coool00`000?ooooooo`1V
oooo000Moooo00?o09Woooooool0Soooo`030000oooooooo00Goool00`000?ooooooo`1Voooo000M
oooo00?o09Woooooool0T?ooo`030000oooooooo00Coool30000I_ooo`007Oooo`03o`2Ioooooooo
097oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo08ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0T?ooo`800005
oooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool20000Ioooo`007Oooo`03o`2I
oooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo
06Koool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo
09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`80001Woooo000Moooo00?o
09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0003ooooo
ool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Wooooo
ool0Uoooo`80001Woooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool0
0ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool00`000?oo
ooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOoo
ooooo`2Goooo0P0006Ooool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Ooo
o`03o`2Ioooooooo093oool200001Oooo`030000oooooooo06Koool001goool00ol0VOooooooo`2?
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo097oool0
0`000?ooooooo`03oooo0`0006Koool001goool00ol0VOooooooo`2Boooo00<0003oooooool00_oo
o`030000oooooooo06Koool001goool00ol0VOooooooo`2?oooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`007Oooo`03o`2Ioooooooo093oool200001Oooo`030000oooooooo06Koool0
01goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool2
0000Ioooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Wooooo
ool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_oo
o`007Oooo`03o`2Ioooooooo09Ooool20000Ioooo`007Oooo`03o`2Ioooooooo09Ooool00`000?oo
ooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOoo
ooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2Ioooooooo09Ooool00`000?ooooooo`1V
oooo000Moooo00?o09Woooooool0Uoooo`80001Woooo000Moooo00?o09Woooooool0Uoooo`030000
oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0003oooooool0I_ooo`007Oooo`03o`2I
oooooooo09Ooool00`000?ooooooo`1Voooo000Moooo00?o09Woooooool0Uoooo`80001Woooo000M
oooo00?o09Woooooool0Uoooo`030000oooooooo06Koool001goool00ol0VOooooooo`2Goooo00<0
003oooooool0I_ooo`007Oooo`03o`2Ioooooooo097oool300000oooo`030000oooooooo06Koool0
01goool00ol0VOooooooo`2Boooo00<0003oooooool00_ooo`030000oooooooo06Koool001goool0
0ol0VOooooooo`2?oooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?oo
o`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005Oooo`030000oooooooo00Ooool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.03279 .26487 L
.04262 .26487 L
.04758 .26487 L
.05288 .26487 L
.05546 .26487 L
.05789 .26487 L
.06007 .26487 L
.06131 .26487 L
s
.06131 .26487 m
.06176 .61803 L
s
0 .4 1 r
.02381 .23703 m
.03279 .23499 L
.04262 .23258 L
.04758 .2313 L
.05288 .22986 L
.05546 .22915 L
.05789 .22846 L
.06007 .22782 L
.06131 .22746 L
.06244 .26487 L
.06371 .26487 L
.06487 .26487 L
.06747 .26487 L
.07218 .26487 L
.0829 .26487 L
.10458 .26487 L
.14429 .26487 L
.18248 .26487 L
.22313 .26487 L
.26226 .26487 L
.30384 .26487 L
.34391 .26487 L
.38246 .26487 L
.42346 .26487 L
.46295 .26487 L
.50092 .26487 L
.54134 .26487 L
.58025 .26487 L
.62161 .26487 L
.66146 .26487 L
.69979 .26487 L
.74057 .26487 L
.77984 .26487 L
.81759 .26487 L
.85779 .26487 L
.89648 .26487 L
.93762 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool010000?oooooooooo
o`<0I_lFoooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000
<ol0<ol001Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool4
00000oooo`8000001?ooo`1Vo`1Vo`1Vo`;oool00`1Vooooooooo`0>oooo100000;oool010000?oo
ooooo`0001Ooool400001Oooo`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`00
0`0003?o03?o000J<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?oo
ooooo`0Uoooo000Foooo0P1Vo`03000006Ko06Ko00Goool00`1Vooooooooo`0Eoooo00<0003oool0
00007Oooo`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol0
01dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Soool300001Ooo
o`0306Kooooooooo01Koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool0023oool00`1Vooooooooo`1Aoooo0P00044co`00
0`0003?o03?o000Z<ol00`0003Woool0023oool00`1Vooooooooo`1=oooo100004<co`020000;S?o
0080000goooo000Poooo00<0I_ooooooool0B?ooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo000Poooo00<0I_ooooooool0?_ooo`X0001<<ol000<0000co`0co`00<c?o00X0000Yoooo000P
oooo00<0I_ooooooool0<oooo`/0001F<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00
017oool001Koool00`000?ooooooo`04oooo00@0003ooooooooo09T2oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool04_ooo`005_ooo`030000oooooooo00Ooool0
0ol0VOooooooo`0Coooo00<0003oooooool07_ooo`030000oooooooo01goool00`000?ooooooo`0M
oooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003ooooo
ool09Oooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Wooooo
ool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo0P0006Ooool0023oool0
0ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool00`000?oo
ooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOoo
ooooo`2Doooo0P0006Ooool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?oo
o`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000
oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2I
oooooooo09Coool20000Ioooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000P
oooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0
003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool20000Ioooo`008?ooo`03o`2Ioooooooo
09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0
023oool00ol0VOooooooo`2<oooo1@0000?oool00`000?ooooooo`1Voooo000Poooo00?o09Wooooo
ool0S_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0S_oo
o`030000oooooooo00?oool30000I_ooo`008?ooo`03o`2Ioooooooo08koool00`000?ooooooo`03
oooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo08koool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`008?ooo`03o`2Ioooooooo08goool200001Oooo`030000oooooooo06Koool0
023oool00ol0VOooooooo`2Doooo0P0006Ooool0023oool00ol0VOooooooo`2Doooo00<0003ooooo
ool0I_ooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Wooooo
ool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_oo
o`008?ooo`03o`2Ioooooooo09Coool20000Ioooo`008?ooo`03o`2Ioooooooo09Coool00`000?oo
ooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOoo
ooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool20000Ioooo`008?oo
o`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000
oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2I
oooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`80001Woooo000P
oooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2<oooo1000
00Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0S?ooo`030000oooooooo00Goool0
0`000?ooooooo`1Voooo000Poooo00?o09Woooooool0SOooo`030000oooooooo00Coool30000I_oo
o`008?ooo`03o`2Ioooooooo08koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`008?oo
o`03o`2Ioooooooo08coool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000Poooo00?o
09Woooooool0SOooo`800005oooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool2
0000Ioooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Wooooo
ool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_oo
o`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?oo
o`80001Woooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOoo
ooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1V
oooo000Poooo00?o09Woooooool0U?ooo`80001Woooo000Poooo00?o09Woooooool0U?ooo`030000
oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2I
oooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo
06Koool0023oool00ol0VOooooooo`2Doooo0P0006Ooool0023oool00ol0VOooooooo`2Doooo00<0
003oooooool0I_ooo`008?ooo`03o`2Ioooooooo08goool200001Oooo`030000oooooooo06Koool0
023oool00ol0VOooooooo`2<oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`008?oo
o`03o`2Ioooooooo08koool00`000?ooooooo`03oooo0`0006Koool0023oool00ol0VOooooooo`2?
oooo00<0003oooooool00_ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2<oooo00@0
003oooooool00004oooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo08goool200001Ooo
o`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?oo
o`03o`2Ioooooooo09Coool20000Ioooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1V
oooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2D
oooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo09Coool20000Ioooo`008?ooo`03o`2I
oooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo
06Koool0023oool00ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo
09Coool00`000?ooooooo`1Voooo000Poooo00?o09Woooooool0U?ooo`80001Woooo000Poooo00?o
09Woooooool0U?ooo`030000oooooooo06Koool0023oool00ol0VOooooooo`2Doooo00<0003ooooo
ool0I_ooo`008?ooo`03o`2Ioooooooo09Coool00`000?ooooooo`1Voooo000Poooo00?o09Wooooo
ool0U?ooo`80001Woooo000Poooo00?o09Woooooool0U?ooo`030000oooooooo06Koool0023oool0
0ol0VOooooooo`2Doooo00<0003oooooool0I_ooo`008?ooo`03o`2Ioooooooo08koool300000ooo
o`030000oooooooo06Koool0023oool00ol0VOooooooo`2?oooo00<0003oooooool00_ooo`030000
oooooooo06Koool0023oool00ol0VOooooooo`2<oooo1@0000?oool30000I_ooo`00[oooo`040000
oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
01Goool00`000?ooooooo`09oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooo
oooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`800009oooo100000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.04262 .26487 L
.06244 .26487 L
.06747 .26487 L
.07024 .26487 L
.0716 .26487 L
.07286 .26487 L
.07404 .26487 L
s
.07404 .26487 m
.07454 .61803 L
s
0 .4 1 r
.02381 .23968 m
.04262 .23566 L
.06244 .23072 L
.06747 .22934 L
.07024 .22856 L
.0716 .22817 L
.07286 .22781 L
.07404 .22746 L
.07529 .26487 L
.07655 .26487 L
.07793 .26487 L
.08255 .26487 L
.10458 .26487 L
.14487 .26487 L
.18364 .26487 L
.22486 .26487 L
.26457 .26487 L
.30277 .26487 L
.34341 .26487 L
.38254 .26487 L
.42412 .26487 L
.46419 .26487 L
.50274 .26487 L
.54374 .26487 L
.58323 .26487 L
.6212 .26487 L
.66163 .26487 L
.70054 .26487 L
.7419 .26487 L
.78174 .26487 L
.82007 .26487 L
.86085 .26487 L
.90012 .26487 L
.93787 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`04
oooo0`1Voa?oool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0000Coool306Ko0_ooo`0306Kooooooooo00_oool400000_ooo`040000oooooooo
00005oooo`@00005oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`00001Vo`1Vo`0306Ko1Oooo`0306Kooooooooo01;oool00`000?ooo`00000M
oooo00@0003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o
00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`005_ooo`80I_l300002?oo
o`0306Kooooooooo01?oool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool002?oool00`1Vooooooooo`1>oooo0P00044co`00
0`0003?o03?o000Z<ol00`0003Woool002?oool00`1Vooooooooo`1:oooo100004<co`020000;S?o
0080000goooo000Soooo00<0I_ooooooool0AOooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo000Soooo00<0I_ooooooool0>oooo`X0001<<ol000<0000co`0co`00<c?o00X0000Yoooo000S
oooo00<0I_ooooooool0<?ooo`/0001F<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00
017oool001Koool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`0:oooo00?o
09Woooooool04?ooo`030000oooooooo01koool00`000?ooooooo`0Moooo00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo
02Goool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo
097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`80001Woooo000Soooo00?o
09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo00<0003ooooo
ool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Wooooo
ool0TOooo`80001Woooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool0
0ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?oo
ooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOoo
ooooo`2Aoooo0P0006Ooool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008ooo
o`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000
oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo0P0006Ooool002?oool00ol0VOooooooo`2A
oooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000S
oooo00?o09Woooooool0ROooo`D00003oooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo
08_oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo08_oool0
0`000?ooooooo`03oooo0`0006Koool002?oool00ol0VOooooooo`2;oooo00<0003oooooool00ooo
o`030000oooooooo06Koool002?oool00ol0VOooooooo`2;oooo00<0003oooooool00oooo`030000
oooooooo06Koool002?oool00ol0VOooooooo`2:oooo0P0000Goool00`000?ooooooo`1Voooo000S
oooo00?o09Woooooool0TOooo`80001Woooo000Soooo00?o09Woooooool0TOooo`030000oooooooo
06Koool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo
097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool0
02?oool00ol0VOooooooo`2Aoooo0P0006Ooool002?oool00ol0VOooooooo`2Aoooo00<0003ooooo
ool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Wooooo
ool0TOooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo0P0006Ooool002?oool0
0ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?oo
ooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOoo
ooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool20000Ioooo`008ooo
o`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0ROooo`@00004
oooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo08Woool00`000?ooooooo`05oooo00<0
003oooooool0I_ooo`008oooo`03o`2Ioooooooo08[oool00`000?ooooooo`04oooo0`0006Koool0
02?oool00ol0VOooooooo`2;oooo00<0003oooooool00oooo`030000oooooooo06Koool002?oool0
0ol0VOooooooo`29oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`008oooo`03o`2I
oooooooo08[oool200001Oooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo0P00
06Ooool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo
097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool0
02?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool2
0000Ioooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Wooooo
ool0TOooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_oo
o`008oooo`03o`2Ioooooooo097oool20000Ioooo`008oooo`03o`2Ioooooooo097oool00`000?oo
ooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOoo
ooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1V
oooo000Soooo00?o09Woooooool0TOooo`80001Woooo000Soooo00?o09Woooooool0TOooo`030000
oooooooo06Koool002?oool00ol0VOooooooo`2:oooo0P0000Goool00`000?ooooooo`1Voooo000S
oooo00?o09Woooooool0ROooo`040000oooooooo00001?ooo`030000oooooooo06Koool002?oool0
0ol0VOooooooo`2;oooo00<0003oooooool00oooo`<0001Voooo000Soooo00?o09Woooooool0S?oo
o`030000oooooooo00;oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0ROooo`040000
oooooooo00001?ooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2:oooo0P0000Goool0
0`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool0
0ol0VOooooooo`2Aoooo0P0006Ooool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_oo
o`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOoo
o`030000oooooooo06Koool002?oool00ol0VOooooooo`2Aoooo0P0006Ooool002?oool00ol0VOoo
ooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1V
oooo000Soooo00?o09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2A
oooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo097oool20000Ioooo`008oooo`03o`2I
oooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o09Woooooool0TOooo`030000oooooooo
06Koool002?oool00ol0VOooooooo`2Aoooo00<0003oooooool0I_ooo`008oooo`03o`2Ioooooooo
097oool20000Ioooo`008oooo`03o`2Ioooooooo097oool00`000?ooooooo`1Voooo000Soooo00?o
09Woooooool0TOooo`030000oooooooo06Koool002?oool00ol0VOooooooo`2;oooo0`0000?oool0
0`000?ooooooo`1Voooo000Soooo00?o09Woooooool0S?ooo`030000oooooooo00;oool00`000?oo
ooooo`1Voooo000Soooo00?o09Woooooool0ROooo`D00003oooo0`0006Koool00:ooool010000?oo
ooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Goool0
0`000?ooooooo`06oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.04262 .26487 L
.06244 .26487 L
.07216 .26487 L
.0775 .26487 L
.08255 .26487 L
.08542 .26487 L
.0862 .26487 L
.08703 .26487 L
s
.08703 .26487 m
.08732 .61803 L
s
0 .4 1 r
.02381 .24208 m
.04262 .23844 L
.06244 .23398 L
.07216 .23152 L
.0775 .23009 L
.08255 .22868 L
.08542 .22785 L
.0862 .22763 L
.08703 .22738 L
.08774 .26487 L
.08852 .26487 L
.09396 .26487 L
.10458 .26487 L
.14487 .26487 L
.18364 .26487 L
.22486 .26487 L
.26457 .26487 L
.30277 .26487 L
.34341 .26487 L
.38254 .26487 L
.42412 .26487 L
.46419 .26487 L
.50274 .26487 L
.54374 .26487 L
.58323 .26487 L
.6212 .26487 L
.66163 .26487 L
.70054 .26487 L
.7419 .26487 L
.78174 .26487 L
.82007 .26487 L
.86085 .26487 L
.90012 .26487 L
.93787 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`07
oooo0`1Voa3oool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0000Goool506Ko0_ooo`0306Kooooooooo00Soool400000_ooo`040000oooooooo
00005oooo`@00005oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`000?ooooooo`02oooo0P1Vo`Ooool00`1Vooooooooo`0?oooo00<0003oool0
00007Oooo`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol0
01dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Koool206Ko0`00
0080I_l9oooo00<0I_ooooooool04?ooo`80000Noooo0P0001_oool500007S?o0080000L<ol000<0
000co`0co`0073?o00800008<ol0100001?oool200009oooo`009_ooo`0306Kooooooooo04_oool2
0000@C?o00030000<ol0<ol002Xco`030000>Oooo`009_ooo`0306Kooooooooo04Ooool40000@c?o
0080000^<ol00P0003Ooool002Koool00`1Vooooooooo`12oooo1@0004Lco`000`0003?o03?o000_
<ol0100003?oool002Koool00`1Vooooooooo`0hoooo2P0004`co`000`0003?o03?o000c<ol02P00
02Woool002Koool00`1Vooooooooo`0]oooo2`0005Hco`000`0003?o03?o000m<ol03`0001[oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00@0003ooooo
oooo09T3oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo00goool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01koool0
0`000?ooooooo`0Uoooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool0
0ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool20000Iooo
o`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_oo
o`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_oo
o`03o`2Ioooooooo08koool20000Ioooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1V
oooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>
oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000V
oooo00?o09Woooooool0S_ooo`80001Woooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo
06Koool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo
08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`80001Woooo000Voooo00?o
09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0003ooooo
ool0I_ooo`009_ooo`03o`2Ioooooooo08Koool500000oooo`030000oooooooo06Koool002Koool0
0ol0VOooooooo`28oooo00<0003oooooool00oooo`030000oooooooo06Koool002Koool00ol0VOoo
ooooo`28oooo00<0003oooooool00oooo`<0001Voooo000Voooo00?o09Woooooool0R?ooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0R?ooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0Qoooo`800005oooo00<0003ooooo
ool0I_ooo`009_ooo`03o`2Ioooooooo08koool20000Ioooo`009_ooo`03o`2Ioooooooo08koool0
0`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool0
0ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?oo
ooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`80001Woooo000Voooo00?o09Woooooool0S_oo
o`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_oo
o`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`80001W
oooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>
oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000V
oooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo0P00
06Ooool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo
08Koool400001?ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`26oooo00<0003ooooo
ool01Oooo`030000oooooooo06Koool002Koool00ol0VOooooooo`27oooo00<0003oooooool01?oo
o`<0001Voooo000Voooo00?o09Woooooool0R?ooo`030000oooooooo00?oool00`000?ooooooo`1V
oooo000Voooo00?o09Woooooool0Q_ooo`040000oooooooo00001?ooo`030000oooooooo06Koool0
02Koool00ol0VOooooooo`27oooo0P0000Goool00`000?ooooooo`1Voooo000Voooo00?o09Wooooo
ool0S_ooo`80001Woooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool0
0ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?oo
ooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOoo
ooooo`2>oooo0P0006Ooool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_oo
o`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`030000
oooooooo06Koool002Koool00ol0VOooooooo`2>oooo0P0006Ooool002Koool00ol0VOooooooo`2>
oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000V
oooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0
003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool20000Ioooo`009_ooo`03o`2Ioooooooo
08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0Qoooo`800005oooo00<0003ooooo
ool0I_ooo`009_ooo`03o`2Ioooooooo08Koool010000?ooooooo`0000Coool00`000?ooooooo`1V
oooo000Voooo00?o09Woooooool0R?ooo`030000oooooooo00?oool30000I_ooo`009_ooo`03o`2I
oooooooo08Woool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo
08Koool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0Qooo
o`800005oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1V
oooo000Voooo00?o09Woooooool0S_ooo`80001Woooo000Voooo00?o09Woooooool0S_ooo`030000
oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2I
oooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`80001Woooo000V
oooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo00<0
003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o
09Woooooool0S_ooo`030000oooooooo06Koool002Koool00ol0VOooooooo`2>oooo0P0006Ooool0
02Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08koool0
0`000?ooooooo`1Voooo000Voooo00?o09Woooooool0S_ooo`030000oooooooo06Koool002Koool0
0ol0VOooooooo`2>oooo0P0006Ooool002Koool00ol0VOooooooo`2>oooo00<0003oooooool0I_oo
o`009_ooo`03o`2Ioooooooo08koool00`000?ooooooo`1Voooo000Voooo00?o09Woooooool0R?oo
o`<00003oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08Woool00`000?ooooooo`02
oooo00<0003oooooool0I_ooo`009_ooo`03o`2Ioooooooo08Koool500000oooo`<0001Voooo002_
oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005Oooo`030000oooooooo00Ooool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.04262 .26487 L
.06244 .26487 L
.08255 .26487 L
.08806 .26487 L
.09396 .26487 L
.09682 .26487 L
.09822 .26487 L
.09952 .26487 L
s
.09952 .26487 m
.09999 .61803 L
s
0 .4 1 r
.02381 .24425 m
.04262 .24096 L
.06244 .23692 L
.08255 .23213 L
.08806 .23068 L
.09396 .22906 L
.09682 .22824 L
.09822 .22783 L
.09952 .22745 L
.1007 .26487 L
.10195 .26487 L
.10458 .26487 L
.14241 .26487 L
.1827 .26487 L
.22147 .26487 L
.2627 .26487 L
.30241 .26487 L
.3406 .26487 L
.38125 .26487 L
.42038 .26487 L
.46196 .26487 L
.50202 .26487 L
.54057 .26487 L
.58158 .26487 L
.62107 .26487 L
.65904 .26487 L
.69946 .26487 L
.73837 .26487 L
.77973 .26487 L
.81958 .26487 L
.85791 .26487 L
.89869 .26487 L
.93795 .26487 L
.97571 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0;
oooo0P1Vo`goool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0000Woool506Ko00?oool0I_ooool01_ooo`@00002oooo00@0003oooooool0000G
oooo100000Goool00`000?ooooooo`0Doooo100000Coool300005C?o00@00004<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Ooo
o`006?ooo`030000oooooooo00?oool506Ko1_ooo`0306Kooooooooo00coool00`000?ooo`00000M
oooo00@0003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o
00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000306Ko2ooo
o`0306Kooooooooo00goool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool001Koool306Ko4?ooo`0306Kooooooooo04Soool2
0000@C?o00030000<ol0<ol002Xco`030000>Oooo`00:_ooo`0306Kooooooooo04?oool40000@c?o
0080000^<ol00P0003Ooool002[oool00`1Vooooooooo`0noooo1@0004Lco`000`0003?o03?o000_
<ol0100003?oool002[oool00`1Vooooooooo`0doooo2P0004`co`000`0003?o03?o000c<ol02P00
02Woool002[oool00`1Vooooooooo`0Yoooo2`0005Hco`000`0003?o03?o000m<ol03`0001[oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`03o`2I0000oooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool04_ooo`005_ooo`030000oooooooo
013oool00ol0VOooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01goool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0
003oooooool09Oooo`00:Oooo`03o`2Ioooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o
09Woooooool0Roooo`030000oooooooo06Koool002Woool00ol0VOooooooo`2;oooo0P0006Ooool0
02Woool00ol0VOooooooo`2;oooo00<0003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08_oool0
0`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Roooo`030000oooooooo06Koool002Woool0
0ol0VOooooooo`2;oooo0P0006Ooool002Woool00ol0VOooooooo`2;oooo00<0003oooooool0I_oo
o`00:Oooo`03o`2Ioooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Rooo
o`030000oooooooo06Koool002Woool00ol0VOooooooo`2;oooo00<0003oooooool0I_ooo`00:Ooo
o`03o`2Ioooooooo08_oool20000Ioooo`00:Oooo`03o`2Ioooooooo08_oool00`000?ooooooo`1V
oooo000Yoooo00?o09Woooooool0Roooo`030000oooooooo06Koool002Woool00ol0VOooooooo`2;
oooo00<0003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08_oool20000Ioooo`00:Oooo`03o`2I
oooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Roooo`030000oooooooo
06Koool002Woool00ol0VOooooooo`23oooo1@0000?oool00`000?ooooooo`1Voooo000Yoooo00?o
09Woooooool0QOooo`030000oooooooo00?oool00`000?ooooooo`1Voooo000Yoooo00?o09Wooooo
ool0QOooo`030000oooooooo00?oool30000I_ooo`00:Oooo`03o`2Ioooooooo08Goool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08Goool00`000?ooooooo`03
oooo00<0003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08Coool200001Oooo`030000oooooooo
06Koool002Woool00ol0VOooooooo`2;oooo0P0006Ooool002Woool00ol0VOooooooo`2;oooo00<0
003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o
09Woooooool0Roooo`030000oooooooo06Koool002Woool00ol0VOooooooo`2;oooo00<0003ooooo
ool0I_ooo`00:Oooo`03o`2Ioooooooo08_oool20000Ioooo`00:Oooo`03o`2Ioooooooo08_oool0
0`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Roooo`030000oooooooo06Koool002Woool0
0ol0VOooooooo`2;oooo00<0003oooooool0I_ooo`00:Oooo`03o`2Ioooooooo08_oool20000Iooo
o`00:Oooo`03o`2Ioooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Rooo
o`030000oooooooo06Koool002Woool00ol0VOooooooo`2;oooo00<0003oooooool0I_ooo`00:Ooo
o`03o`2Ioooooooo08_oool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Roooo`80001W
oooo000Yoooo00?o09Woooooool0Roooo`030000oooooooo06Koool002Woool00ol0VOooooooo`23
oooo100000Coool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Poooo`030000oooooooo
00Goool00`000?ooooooo`1Voooo000Yoooo00?o09Woooooool0Q?ooo`030000oooooooo00Coool3
0000I_ooo`00:_ooo`03o`2Ioooooooo08Coool00`000?ooooooo`03oooo00<0003oooooool0I_oo
o`00:_ooo`03o`2Ioooooooo08;oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000Z
oooo00?o09Woooooool0Poooo`800005oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo
08[oool20000Ioooo`00:_ooo`03o`2Ioooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o
09Woooooool0R_ooo`030000oooooooo06Koool002[oool00ol0VOooooooo`2:oooo00<0003ooooo
ool0I_ooo`00:_ooo`03o`2Ioooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o09Wooooo
ool0R_ooo`80001Woooo000Zoooo00?o09Woooooool0R_ooo`030000oooooooo06Koool002[oool0
0ol0VOooooooo`2:oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08[oool00`000?oo
ooooo`1Voooo000Zoooo00?o09Woooooool0R_ooo`80001Woooo000Zoooo00?o09Woooooool0R_oo
o`030000oooooooo06Koool002[oool00ol0VOooooooo`2:oooo00<0003oooooool0I_ooo`00:_oo
o`03o`2Ioooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o09Woooooool0R_ooo`030000
oooooooo06Koool002[oool00ol0VOooooooo`2:oooo0P0006Ooool002[oool00ol0VOooooooo`2:
oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08?oool200001Oooo`030000oooooooo
06Koool002[oool00ol0VOooooooo`22oooo00@0003oooooool00004oooo00<0003oooooool0I_oo
o`00:_ooo`03o`2Ioooooooo08Coool00`000?ooooooo`03oooo0`0006Koool002[oool00ol0VOoo
ooooo`25oooo00<0003oooooool00_ooo`030000oooooooo06Koool002[oool00ol0VOooooooo`22
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08?oool2
00001Oooo`030000oooooooo06Koool002[oool00ol0VOooooooo`2:oooo00<0003oooooool0I_oo
o`00:_ooo`03o`2Ioooooooo08[oool20000Ioooo`00:_ooo`03o`2Ioooooooo08[oool00`000?oo
ooooo`1Voooo000Zoooo00?o09Woooooool0R_ooo`030000oooooooo06Koool002[oool00ol0VOoo
ooooo`2:oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08[oool20000Ioooo`00:_oo
o`03o`2Ioooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o09Woooooool0R_ooo`030000
oooooooo06Koool002[oool00ol0VOooooooo`2:oooo00<0003oooooool0I_ooo`00:_ooo`03o`2I
oooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o09Woooooool0R_ooo`80001Woooo000Z
oooo00?o09Woooooool0R_ooo`030000oooooooo06Koool002[oool00ol0VOooooooo`2:oooo00<0
003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08[oool00`000?ooooooo`1Voooo000Zoooo00?o
09Woooooool0R_ooo`80001Woooo000Zoooo00?o09Woooooool0R_ooo`030000oooooooo06Koool0
02[oool00ol0VOooooooo`2:oooo00<0003oooooool0I_ooo`00:_ooo`03o`2Ioooooooo08Coool3
00000oooo`030000oooooooo06Koool002[oool00ol0VOooooooo`25oooo00<0003oooooool00_oo
o`030000oooooooo06Koool002[oool00ol0VOooooooo`22oooo1@0000?oool30000I_ooo`00[ooo
o`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00D0003oooooooooool00000N_oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`D00003
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Eoooo00<0003oooooool01_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000_oool200000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.08255 .26487 L
.0932 .26487 L
.09905 .26487 L
.10458 .26487 L
.10972 .26487 L
.11113 .26487 L
.1119 .26487 L
.11263 .26487 L
s
.11263 .26487 m
.11314 .61803 L
s
0 .4 1 r
.02381 .24622 m
.06244 .23959 L
.08255 .23525 L
.0932 .23267 L
.09905 .23115 L
.10458 .22965 L
.10972 .22819 L
.11113 .22778 L
.1119 .22756 L
.11263 .22734 L
.1139 .26487 L
.11458 .26487 L
.11531 .26487 L
.12507 .26487 L
.14415 .26487 L
.18538 .26487 L
.22508 .26487 L
.26328 .26487 L
.30392 .26487 L
.34305 .26487 L
.38463 .26487 L
.4247 .26487 L
.46325 .26487 L
.50426 .26487 L
.54374 .26487 L
.58171 .26487 L
.62214 .26487 L
.66105 .26487 L
.70241 .26487 L
.74225 .26487 L
.78058 .26487 L
.82137 .26487 L
.86063 .26487 L
.89838 .26487 L
.93859 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0>
oooo0`1Vo`Woool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0000goool406Ko0_ooo`0406Kooooooooooooo100000;oool010000?ooooooo`00
01Ooool400001Oooo`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o
03?o000J<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0U
oooo000Hoooo00<0003oooooool02?ooo`@0I_l6oooo00<0I_ooooooool02?ooo`030000oooo0000
01goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M
<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`000003oooo
06Ko06Ko00D0I_l:oooo00<0I_ooooooool02Oooo`80000Noooo0P0001_oool500007S?o0080000L
<ol000<0000co`0co`0073?o00800008<ol0100001?oool200009oooo`005_ooo`H0I_lAoooo00<0
I_ooooooool0A?ooo`800011<ol000<0000co`0co`00:S?o00<0000ioooo000]oooo00<0I_oooooo
ool0@?ooo`@00013<ol00P0002hco`020000=oooo`00;Oooo`0306Kooooooooo03_oool50000Ac?o
00030000<ol0<ol002lco`040000<oooo`00;Oooo`0306Kooooooooo037oool:0000C3?o00030000
<ol0<ol003<co`0:0000:Oooo`00;Oooo`0306Kooooooooo02Koool;0000ES?o00030000<ol0<ol0
03dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00@0003ooooooooo09T2oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo01;oool0
01Koool00`000?ooooooo`0Doooo00?o09Woooooool01_ooo`030000oooooooo01koool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0
003oooooool07_ooo`030000oooooooo02Goool002goool00ol0VOooooooo`27oooo00<0003ooooo
ool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Wooooo
ool0Qoooo`80001Woooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool0
0ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?oo
ooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`80001Woooo000]oooo00?o09Woooooool0Qooo
o`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Ooo
o`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000
oooooooo06Koool002goool00ol0VOooooooo`27oooo0P0006Ooool002goool00ol0VOooooooo`27
oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]
oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo0P00
06Ooool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo
08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Ooooo`D00003oooo00<0003ooooo
ool0I_ooo`00;Oooo`03o`2Ioooooooo087oool00`000?ooooooo`03oooo00<0003oooooool0I_oo
o`00;Oooo`03o`2Ioooooooo087oool00`000?ooooooo`03oooo0`0006Koool002goool00ol0VOoo
ooooo`21oooo00<0003oooooool00oooo`030000oooooooo06Koool002goool00ol0VOooooooo`21
oooo00<0003oooooool00oooo`030000oooooooo06Koool002goool00ol0VOooooooo`20oooo0P00
00Goool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`80001Woooo000]oooo00?o
09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003ooooo
ool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Wooooo
ool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo0P0006Ooool002goool0
0ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?oo
ooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOoo
ooooo`27oooo0P0006Ooool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Ooo
o`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000
oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2I
oooooooo08Ooool20000Ioooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]
oooo00?o09Woooooool0Ooooo`@00004oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo
07ooool00`000?ooooooo`05oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo083oool0
0`000?ooooooo`04oooo0`0006Koool002goool00ol0VOooooooo`21oooo00<0003oooooool00ooo
o`030000oooooooo06Koool002goool00ol0VOooooooo`1ooooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo083oool200001Oooo`030000oooooooo06Koool0
02goool00ol0VOooooooo`27oooo0P0006Ooool002goool00ol0VOooooooo`27oooo00<0003ooooo
ool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Wooooo
ool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_oo
o`00;Oooo`03o`2Ioooooooo08Ooool20000Ioooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?oo
ooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOoo
ooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool20000Ioooo`00;Ooo
o`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000
oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2I
oooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`80001Woooo000]
oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`20oooo0P00
00Goool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Ooooo`040000oooooooo00001?oo
o`030000oooooooo06Koool002goool00ol0VOooooooo`21oooo00<0003oooooool00oooo`<0001V
oooo000]oooo00?o09Woooooool0P_ooo`030000oooooooo00;oool00`000?ooooooo`1Voooo000]
oooo00?o09Woooooool0Ooooo`040000oooooooo00001?ooo`030000oooooooo06Koool002goool0
0ol0VOooooooo`20oooo0P0000Goool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qooo
o`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo0P0006Ooool002goool00ol0VOoo
ooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1V
oooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27
oooo0P0006Ooool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2I
oooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo
06Koool002goool00ol0VOooooooo`27oooo00<0003oooooool0I_ooo`00;Oooo`03o`2Ioooooooo
08Ooool20000Ioooo`00;Oooo`03o`2Ioooooooo08Ooool00`000?ooooooo`1Voooo000]oooo00?o
09Woooooool0Qoooo`030000oooooooo06Koool002goool00ol0VOooooooo`27oooo00<0003ooooo
ool0I_ooo`00;Oooo`03o`2Ioooooooo08Ooool20000Ioooo`00;Oooo`03o`2Ioooooooo08Ooool0
0`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Qoooo`030000oooooooo06Koool002goool0
0ol0VOooooooo`21oooo0`0000?oool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0P_oo
o`030000oooooooo00;oool00`000?ooooooo`1Voooo000]oooo00?o09Woooooool0Ooooo`D00003
oooo0`0006Koool00:ooool010000?ooooooo`0006goool00;3oool00`000?ooo`00001]oooo002a
oooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Eoooo00<0003oooooool02Oooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.08255 .26487 L
.10458 .26487 L
.11448 .26487 L
.11992 .26487 L
.1226 .26487 L
.12377 .26487 L
.12507 .26487 L
s
.12507 .26487 m
.12555 .61803 L
s
0 .4 1 r
.02381 .248 m
.06244 .242 L
.08255 .23808 L
.10458 .23301 L
.11448 .23043 L
.11992 .22892 L
.1226 .22815 L
.12377 .22781 L
.12507 .22743 L
.12627 .26487 L
.12739 .26487 L
.12986 .26487 L
.13506 .26487 L
.14415 .26487 L
.18292 .26487 L
.22415 .26487 L
.26386 .26487 L
.30205 .26487 L
.34269 .26487 L
.38182 .26487 L
.42341 .26487 L
.46347 .26487 L
.50202 .26487 L
.54303 .26487 L
.58251 .26487 L
.62049 .26487 L
.66091 .26487 L
.69982 .26487 L
.74118 .26487 L
.78103 .26487 L
.81936 .26487 L
.86014 .26487 L
.8994 .26487 L
.93715 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0@
oooo101Vo`Koool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0000ooool406Ko0oooo`0306Ko0000000000800002oooo00@0003oooooool0000G
oooo100000Goool00`000?ooooooo`0Doooo100000Coool300005C?o00@00004<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Ooo
o`006?ooo`030000oooooooo00Soool606Ko1oooo`0306Kooooooooo00Goool00`000?ooo`00000M
oooo00@0003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o
00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<00003oooo1@1V
o`goool00`1Vooooooooo`06oooo0P0001koool200006oooo`D0000N<ol00P0001`co`000`0003?o
03?o000L<ol00P0000Pco`0400004oooo`80000Woooo000Ioooo1@1Voa;oool00`1Vooooooooo`11
oooo0P00044co`000`0003?o03?o000Z<ol00`0003Woool001Koool306Ko5oooo`0306Kooooooooo
03goool40000@c?o0080000^<ol00P0003Ooool0033oool00`1Vooooooooo`0hoooo1@0004Lco`00
0`0003?o03?o000_<ol0100003?oool0033oool00`1Vooooooooo`0^oooo2P0004`co`000`0003?o
03?o000c<ol02P0002Woool0033oool00`1Vooooooooo`0Soooo2`0005Hco`000`0003?o03?o000m
<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool04_ooo`005_oo
o`030000oooooooo01Ooool00ol0VOooooooo`03oooo00<0003oooooool07_ooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Noooo00<0003oooooool09Oooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1V
oooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24
oooo0P0006Ooool0033oool00ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2I
oooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo
06Koool0033oool00ol0VOooooooo`24oooo0P0006Ooool0033oool00ol0VOooooooo`24oooo00<0
003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o
09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0003ooooo
ool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool20000Ioooo`00<?ooo`03o`2Ioooooooo08Coool0
0`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool0
0ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool20000Iooo
o`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?oo
o`030000oooooooo06Koool0033oool00ol0VOooooooo`1loooo1@0000?oool00`000?ooooooo`1V
oooo000`oooo00?o09Woooooool0O_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo000`
oooo00?o09Woooooool0O_ooo`030000oooooooo00?oool30000I_ooo`00<?ooo`03o`2Ioooooooo
07koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo07koool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo07goool200001Ooo
o`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo0P0006Ooool0033oool00ol0VOoo
ooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1V
oooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24
oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool20000Ioooo`00<?ooo`03o`2I
oooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo
06Koool0033oool00ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo
08Coool20000Ioooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o
09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0003ooooo
ool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Wooooo
ool0Q?ooo`80001Woooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool0
0ol0VOooooooo`1loooo100000Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0O?oo
o`030000oooooooo00Goool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0OOooo`030000
oooooooo00Coool30000I_ooo`00<?ooo`03o`2Ioooooooo07koool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo07coool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo000`oooo00?o09Woooooool0OOooo`800005oooo00<0003oooooool0I_ooo`00<?oo
o`03o`2Ioooooooo08Coool20000Ioooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1V
oooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24
oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`
oooo00?o09Woooooool0Q?ooo`80001Woooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo
06Koool0033oool00ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo
08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?ooo`80001Woooo000`oooo00?o
09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0003ooooo
ool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Wooooo
ool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo0P0006Ooool0033oool0
0ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo07goool200001Ooo
o`030000oooooooo06Koool0033oool00ol0VOooooooo`1loooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo07koool00`000?ooooooo`03oooo0`0006Koool0
033oool00ol0VOooooooo`1ooooo00<0003oooooool00_ooo`030000oooooooo06Koool0033oool0
0ol0VOooooooo`1loooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00<?ooo`03o`2I
oooooooo07goool200001Oooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0
003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool20000Ioooo`00<?ooo`03o`2Ioooooooo
08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0
033oool00ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool2
0000Ioooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Wooooo
ool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0003oooooool0I_oo
o`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1Voooo000`oooo00?o09Woooooool0Q?oo
o`80001Woooo000`oooo00?o09Woooooool0Q?ooo`030000oooooooo06Koool0033oool00ol0VOoo
ooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2Ioooooooo08Coool00`000?ooooooo`1V
oooo000`oooo00?o09Woooooool0Q?ooo`80001Woooo000`oooo00?o09Woooooool0Q?ooo`030000
oooooooo06Koool0033oool00ol0VOooooooo`24oooo00<0003oooooool0I_ooo`00<?ooo`03o`2I
oooooooo07koool300000oooo`030000oooooooo06Koool0033oool00ol0VOooooooo`1ooooo00<0
003oooooool00_ooo`030000oooooooo06Koool0033oool00ol0VOooooooo`1loooo1@0000?oool3
0000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool2
0000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003ooooo
ool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Eoooo00<0003oooooool02?ooo`030000oooooooo00;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.08255 .26487 L
.10458 .26487 L
.11448 .26487 L
.12507 .26487 L
.1302 .26487 L
.13273 .26487 L
.13506 .26487 L
.13615 .26487 L
.13718 .26487 L
s
.13718 .26487 m
.1376 .61803 L
s
0 .4 1 r
.02381 .24961 m
.06244 .24419 L
.08255 .24064 L
.10458 .23605 L
.11448 .23372 L
.12507 .23101 L
.1302 .22961 L
.13273 .22891 L
.13506 .22824 L
.13615 .22792 L
.13718 .22762 L
.13824 .26487 L
.13942 .26487 L
.14415 .26487 L
.18292 .26487 L
.22415 .26487 L
.26386 .26487 L
.30205 .26487 L
.34269 .26487 L
.38182 .26487 L
.42341 .26487 L
.46347 .26487 L
.50202 .26487 L
.54303 .26487 L
.58251 .26487 L
.62049 .26487 L
.66091 .26487 L
.69982 .26487 L
.74118 .26487 L
.78103 .26487 L
.81936 .26487 L
.86014 .26487 L
.8994 .26487 L
.93715 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0D
oooo0`1Vo`?oool500007_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001?oool406Ko100000;oool010000?ooooooo`0001Ooool400001Oooo`030000
oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0c
o`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003ooooo
ool03_ooo`@0I_l6oooo00<0I_ooooooool00_ooo`030000oooo000001goool010000?ooooooo`00
01coool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0000co`0co`000c?o
00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`0000Soool606Ko2_ooo`0306Kooooooooo
00?oool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool001coool706Ko4?ooo`0306Kooooooooo03koool20000@C?o00030000
<ol0<ol002Xco`030000>Oooo`005_ooo`H0I_lGoooo00<0I_ooooooool0>_ooo`@00013<ol00P00
02hco`020000=oooo`00<oooo`0306Kooooooooo03Goool50000Ac?o00030000<ol0<ol002lco`04
0000<oooo`00<oooo`0306Kooooooooo02_oool:0000C3?o00030000<ol0<ol003<co`0:0000:Ooo
o`00<oooo`0306Kooooooooo023oool;0000ES?o00030000<ol0<ol003dco`0?00006_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`040000ooooooooo`2I0_ooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`0J
oooo00Co09Woooooool0000Poooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo000c
oooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0
003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool20000Ioooo`00<oooo`03o`2Ioooooooo
087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POooo`030000oooooooo06Koool0
03?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool2
0000Ioooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Wooooo
ool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_oo
o`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POoo
o`80001Woooo000coooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOoo
ooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1V
oooo000coooo00?o09Woooooool0POooo`80001Woooo000coooo00?o09Woooooool0POooo`030000
oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2I
oooooooo07Woool500000oooo`030000oooooooo06Koool003?oool00ol0VOooooooo`1koooo00<0
003oooooool00oooo`030000oooooooo06Koool003?oool00ol0VOooooooo`1koooo00<0003ooooo
ool00oooo`<0001Voooo000coooo00?o09Woooooool0Noooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo000coooo00?o09Woooooool0Noooo`030000oooooooo00?oool00`000?ooooooo`1V
oooo000coooo00?o09Woooooool0N_ooo`800005oooo00<0003oooooool0I_ooo`00<oooo`03o`2I
oooooooo087oool20000Ioooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000c
oooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0
003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o
09Woooooool0POooo`80001Woooo000coooo00?o09Woooooool0POooo`030000oooooooo06Koool0
03?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool0
0`000?ooooooo`1Voooo000coooo00?o09Woooooool0POooo`80001Woooo000coooo00?o09Wooooo
ool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_oo
o`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POoo
o`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo0P0006Ooool003?oool00ol0VOoo
ooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo07Woool400001?ooo`030000
oooooooo06Koool003?oool00ol0VOooooooo`1ioooo00<0003oooooool01Oooo`030000oooooooo
06Koool003?oool00ol0VOooooooo`1joooo00<0003oooooool01?ooo`<0001Voooo000coooo00?o
09Woooooool0Noooo`030000oooooooo00?oool00`000?ooooooo`1Voooo000coooo00?o09Wooooo
ool0NOooo`040000oooooooo00001?ooo`030000oooooooo06Koool003?oool00ol0VOooooooo`1j
oooo0P0000Goool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POooo`80001Woooo000c
oooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0
003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o
09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo0P0006Ooool0
03?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool0
0`000?ooooooo`1Voooo000coooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool0
0ol0VOooooooo`21oooo0P0006Ooool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_oo
o`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POoo
o`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<ooo
o`03o`2Ioooooooo087oool20000Ioooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1V
oooo000coooo00?o09Woooooool0N_ooo`800005oooo00<0003oooooool0I_ooo`00<oooo`03o`2I
oooooooo07Woool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000coooo00?o09Wooooo
ool0Noooo`030000oooooooo00?oool30000I_ooo`00<oooo`03o`2Ioooooooo07coool00`000?oo
ooooo`02oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo07Woool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0N_ooo`800005oooo00<0003ooooo
ool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Wooooo
ool0POooo`80001Woooo000coooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool0
0ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?oo
ooooo`1Voooo000coooo00?o09Woooooool0POooo`80001Woooo000coooo00?o09Woooooool0POoo
o`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<ooo
o`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0POooo`030000
oooooooo06Koool003?oool00ol0VOooooooo`21oooo0P0006Ooool003?oool00ol0VOooooooo`21
oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo087oool00`000?ooooooo`1Voooo000c
oooo00?o09Woooooool0POooo`030000oooooooo06Koool003?oool00ol0VOooooooo`21oooo0P00
06Ooool003?oool00ol0VOooooooo`21oooo00<0003oooooool0I_ooo`00<oooo`03o`2Ioooooooo
087oool00`000?ooooooo`1Voooo000coooo00?o09Woooooool0Noooo`<00003oooo00<0003ooooo
ool0I_ooo`00<oooo`03o`2Ioooooooo07coool00`000?ooooooo`02oooo00<0003oooooool0I_oo
o`00<oooo`03o`2Ioooooooo07Woool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]
oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00goool200001?ooo`800003oooo1@0000;oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo
00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Goool00`000?ooooooo`08
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.13506 .26487 L
.14415 .26487 L
.14635 .26487 L
.14868 .26487 L
.1499 .26487 L
.15059 .26487 L
s
.15059 .26487 m
.15085 .61803 L
s
0 .4 1 r
.02381 .25107 m
.06244 .24616 L
.10458 .23881 L
.12507 .23425 L
.13506 .23174 L
.14415 .22928 L
.14635 .22866 L
.14868 .22799 L
.1499 .22764 L
.15059 .22743 L
.15124 .26487 L
.15238 .26487 L
.1536 .26487 L
.16254 .26487 L
.18221 .26487 L
.22343 .26487 L
.26314 .26487 L
.30133 .26487 L
.34198 .26487 L
.38111 .26487 L
.42269 .26487 L
.46276 .26487 L
.50131 .26487 L
.54231 .26487 L
.5818 .26487 L
.61977 .26487 L
.6602 .26487 L
.6991 .26487 L
.74046 .26487 L
.78031 .26487 L
.81864 .26487 L
.85942 .26487 L
.89869 .26487 L
.93644 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0G
oooo0`1Vo`D0000Noooo00<0003oooooool07?ooo`040000oooooooooooo0P0001/co`000`0003?o
03?o000J<ol00P0001hco`00100003?o0000000001coool00`000?ooooooo`0Voooo000Aoooo1000
00?oool200005Oooo`80I_l4000000?oool0I_l000000_ooo`030000oooooooo01Goool400001Ooo
o`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0
000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0
003oooooool04_ooo`80I_l7oooo00D0I_ooool0003oool000007Oooo`040000oooooooo00007?oo
o`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`00
01Koool010000?ooooooo`0002Koool001Soool300002oooo`L0I_l9oooo00<0I_ooooooool00P00
01koool200006oooo`D0000N<ol00P0001`co`000`0003?o03?o000L<ol00P0000Pco`0400004ooo
o`80000Woooo000Noooo201Voa3oool00`1Vooooooooo`0koooo0P00044co`000`0003?o03?o000Z
<ol00`0003Woool001Woool506Ko6Oooo`0306Kooooooooo03Koool40000@c?o0080000^<ol00P00
03Ooool001Koool306Ko7_ooo`0306Kooooooooo037oool50000Ac?o00030000<ol0<ol002lco`04
0000<oooo`00=oooo`0306Kooooooooo02Ooool:0000C3?o00030000<ol0<ol003<co`0:0000:Ooo
o`00=oooo`0306Kooooooooo01coool;0000ES?o00030000<ol0<ol003dco`0?00006_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003oooooool07Ooo
o`030000oooooooo01koool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool003Koool0
0ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?oo
ooooo`1Voooo000foooo00?o09Woooooool0O_ooo`80001Woooo000foooo00?o09Woooooool0O_oo
o`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_oo
o`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`80001W
oooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1n
oooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000f
oooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo0P00
06Ooool003Koool00ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo
07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool0
03Koool00ol0VOooooooo`1noooo0P0006Ooool003Koool00ol0VOooooooo`1noooo00<0003ooooo
ool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Wooooo
ool0M_ooo`D00003oooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07Soool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07Soool00`000?ooooooo`03
oooo0`0006Koool003Koool00ol0VOooooooo`1hoooo00<0003oooooool00oooo`030000oooooooo
06Koool003Koool00ol0VOooooooo`1hoooo00<0003oooooool00oooo`030000oooooooo06Koool0
03Koool00ol0VOooooooo`1goooo0P0000Goool00`000?ooooooo`1Voooo000foooo00?o09Wooooo
ool0O_ooo`80001Woooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool0
0ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?oo
ooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOoo
ooooo`1noooo0P0006Ooool003Koool00ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_oo
o`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000
oooooooo06Koool003Koool00ol0VOooooooo`1noooo0P0006Ooool003Koool00ol0VOooooooo`1n
oooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000f
oooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo00<0
003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool20000Ioooo`00=_ooo`03o`2Ioooooooo
07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0M_ooo`@00004oooo00<0003ooooo
ool0I_ooo`00=_ooo`03o`2Ioooooooo07Koool00`000?ooooooo`05oooo00<0003oooooool0I_oo
o`00=_ooo`03o`2Ioooooooo07Ooool00`000?ooooooo`04oooo0`0006Koool003Koool00ol0VOoo
ooooo`1hoooo00<0003oooooool00oooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1f
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07Ooool2
00001Oooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo0P0006Ooool003Koool0
0ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?oo
ooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOoo
ooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool20000Ioooo`00=_oo
o`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000
oooooooo06Koool003Koool00ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2I
oooooooo07koool20000Ioooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000f
oooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo00<0
003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o
09Woooooool0O_ooo`80001Woooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool0
03Koool00ol0VOooooooo`1goooo0P0000Goool00`000?ooooooo`1Voooo000foooo00?o09Wooooo
ool0M_ooo`040000oooooooo00001?ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1h
oooo00<0003oooooool00oooo`<0001Voooo000foooo00?o09Woooooool0NOooo`030000oooooooo
00;oool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0M_ooo`040000oooooooo00001?oo
o`030000oooooooo06Koool003Koool00ol0VOooooooo`1goooo0P0000Goool00`000?ooooooo`1V
oooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1n
oooo0P0006Ooool003Koool00ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2I
oooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000oooooooo
06Koool003Koool00ol0VOooooooo`1noooo0P0006Ooool003Koool00ol0VOooooooo`1noooo00<0
003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o
09Woooooool0O_ooo`030000oooooooo06Koool003Koool00ol0VOooooooo`1noooo00<0003ooooo
ool0I_ooo`00=_ooo`03o`2Ioooooooo07koool20000Ioooo`00=_ooo`03o`2Ioooooooo07koool0
0`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_ooo`030000oooooooo06Koool003Koool0
0ol0VOooooooo`1noooo00<0003oooooool0I_ooo`00=_ooo`03o`2Ioooooooo07koool20000Iooo
o`00=_ooo`03o`2Ioooooooo07koool00`000?ooooooo`1Voooo000foooo00?o09Woooooool0O_oo
o`030000oooooooo06Koool003Koool00ol0VOooooooo`1hoooo0`0000?oool00`000?ooooooo`1V
oooo000foooo00?o09Woooooool0NOooo`030000oooooooo00;oool00`000?ooooooo`1Voooo000f
oooo00?o09Woooooool0M_ooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool0
0;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?oo
ooooo`0000Woool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
01Goool00`000?ooooooo`09oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000E
oooo00<0003oooooool01oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo01Ooool2
00002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.14415 .26487 L
.1536 .26487 L
.15825 .26487 L
.16029 .26487 L
.16137 .26487 L
.16254 .26487 L
s
.16254 .26487 m
.16303 .61803 L
s
0 .4 1 r
.02381 .25239 m
.06244 .24795 L
.10458 .2413 L
.12507 .23718 L
.14415 .23269 L
.1536 .23021 L
.15825 .22892 L
.16029 .22833 L
.16137 .22802 L
.16254 .22768 L
.16378 .26487 L
.16494 .26487 L
.16748 .26487 L
.17284 .26487 L
.18221 .26487 L
.22343 .26487 L
.26314 .26487 L
.30133 .26487 L
.34198 .26487 L
.38111 .26487 L
.42269 .26487 L
.46276 .26487 L
.50131 .26487 L
.54231 .26487 L
.5818 .26487 L
.61977 .26487 L
.6602 .26487 L
.6991 .26487 L
.74046 .26487 L
.78031 .26487 L
.81864 .26487 L
.85942 .26487 L
.89869 .26487 L
.93644 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo10000080I_l010000?ooo`1Vo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool04oooo`D0I_l5
oooo00<00000I_l000007Oooo`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool0
01Soool300003_ooo`D0I_l;oooo0P0001koool200006oooo`D0000N<ol00P0001`co`000`0003?o
03?o000L<ol00P0000Pco`0400004oooo`80000Woooo000Soooo1P1Voa3oool00`1Vooooooooo`0h
oooo0P00044co`000`0003?o03?o000Z<ol00`0003Woool001coool706Ko5oooo`0306Kooooooooo
03?oool40000@c?o0080000^<ol00P0003Ooool001Koool606Ko7_ooo`0306Kooooooooo02koool5
0000Ac?o00030000<ol0<ol002lco`040000<oooo`00>_ooo`0306Kooooooooo02Coool:0000C3?o
00030000<ol0<ol003<co`0:0000:Oooo`00>_ooo`0306Kooooooooo01Woool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
10000?ooooooool0V@?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Moooo00@0003ooooooooo09TMoooo00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01koool00`000?ooooooo`0Uoooo000ioooo00?o09Woooooool0Noooo`030000oooooooo06Koool0
03Woool00ol0VOooooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07_oool2
0000Ioooo`00>Oooo`03o`2Ioooooooo07_oool00`000?ooooooo`1Voooo000ioooo00?o09Wooooo
ool0Noooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1koooo00<0003oooooool0I_oo
o`00>Oooo`03o`2Ioooooooo07_oool20000Ioooo`00>Oooo`03o`2Ioooooooo07_oool00`000?oo
ooooo`1Voooo000ioooo00?o09Woooooool0Noooo`030000oooooooo06Koool003Woool00ol0VOoo
ooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07_oool00`000?ooooooo`1V
oooo000ioooo00?o09Woooooool0Noooo`80001Woooo000ioooo00?o09Woooooool0Noooo`030000
oooooooo06Koool003Woool00ol0VOooooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2I
oooooooo07_oool00`000?ooooooo`1Voooo000ioooo00?o09Woooooool0Noooo`80001Woooo000i
oooo00?o09Woooooool0Noooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1koooo00<0
003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07?oool500000oooo`030000oooooooo06Koool0
03Woool00ol0VOooooooo`1eoooo00<0003oooooool00oooo`030000oooooooo06Koool003Woool0
0ol0VOooooooo`1eoooo00<0003oooooool00oooo`<0001Voooo000ioooo00?o09Woooooool0MOoo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo000ioooo00?o09Woooooool0MOooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo000ioooo00?o09Woooooool0M?ooo`800005oooo00<0
003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07_oool20000Ioooo`00>Oooo`03o`2Ioooooooo
07_oool00`000?ooooooo`1Voooo000ioooo00?o09Woooooool0Noooo`030000oooooooo06Koool0
03Woool00ol0VOooooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07_oool0
0`000?ooooooo`1Voooo000ioooo00?o09Woooooool0Noooo`80001Woooo000ioooo00?o09Wooooo
ool0Noooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1koooo00<0003oooooool0I_oo
o`00>Oooo`03o`2Ioooooooo07_oool00`000?ooooooo`1Voooo000ioooo00?o09Woooooool0Nooo
o`80001Woooo000ioooo00?o09Woooooool0Noooo`030000oooooooo06Koool003Woool00ol0VOoo
ooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2Ioooooooo07_oool00`000?ooooooo`1V
oooo000ioooo00?o09Woooooool0Noooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1k
oooo0P0006Ooool003Woool00ol0VOooooooo`1koooo00<0003oooooool0I_ooo`00>Oooo`03o`2I
oooooooo07?oool400001?ooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1coooo00<0
003oooooool01Oooo`030000oooooooo06Koool003Woool00ol0VOooooooo`1doooo00<0003ooooo
ool01?ooo`<0001Voooo000joooo00?o09Woooooool0M?ooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo000joooo00?o09Woooooool0L_ooo`040000oooooooo00001?ooo`030000oooooooo
06Koool003[oool00ol0VOooooooo`1coooo0P0000Goool00`000?ooooooo`1Voooo000joooo00?o
09Woooooool0N_ooo`80001Woooo000joooo00?o09Woooooool0N_ooo`030000oooooooo06Koool0
03[oool00ol0VOooooooo`1joooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool0
0`000?ooooooo`1Voooo000joooo00?o09Woooooool0N_ooo`030000oooooooo06Koool003[oool0
0ol0VOooooooo`1joooo0P0006Ooool003[oool00ol0VOooooooo`1joooo00<0003oooooool0I_oo
o`00>_ooo`03o`2Ioooooooo07[oool00`000?ooooooo`1Voooo000joooo00?o09Woooooool0N_oo
o`030000oooooooo06Koool003[oool00ol0VOooooooo`1joooo0P0006Ooool003[oool00ol0VOoo
ooooo`1joooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool00`000?ooooooo`1V
oooo000joooo00?o09Woooooool0N_ooo`030000oooooooo06Koool003[oool00ol0VOooooooo`1j
oooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool20000Ioooo`00>_ooo`03o`2I
oooooooo07[oool00`000?ooooooo`1Voooo000joooo00?o09Woooooool0Loooo`800005oooo00<0
003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo000joooo00?o09Woooooool0M?ooo`030000oooooooo00?oool30000I_ooo`00>_oo
o`03o`2Ioooooooo07Goool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00>_ooo`03o`2I
oooooooo07;oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000joooo00?o09Wooooo
ool0Loooo`800005oooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool00`000?oo
ooooo`1Voooo000joooo00?o09Woooooool0N_ooo`80001Woooo000joooo00?o09Woooooool0N_oo
o`030000oooooooo06Koool003[oool00ol0VOooooooo`1joooo00<0003oooooool0I_ooo`00>_oo
o`03o`2Ioooooooo07[oool00`000?ooooooo`1Voooo000joooo00?o09Woooooool0N_ooo`80001W
oooo000joooo00?o09Woooooool0N_ooo`030000oooooooo06Koool003[oool00ol0VOooooooo`1j
oooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool00`000?ooooooo`1Voooo000j
oooo00?o09Woooooool0N_ooo`030000oooooooo06Koool003[oool00ol0VOooooooo`1joooo0P00
06Ooool003[oool00ol0VOooooooo`1joooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo
07[oool00`000?ooooooo`1Voooo000joooo00?o09Woooooool0N_ooo`030000oooooooo06Koool0
03[oool00ol0VOooooooo`1joooo0P0006Ooool003[oool00ol0VOooooooo`1joooo00<0003ooooo
ool0I_ooo`00>_ooo`03o`2Ioooooooo07[oool00`000?ooooooo`1Voooo000joooo00?o09Wooooo
ool0M?ooo`<00003oooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07Goool00`000?oo
ooooo`02oooo00<0003oooooool0I_ooo`00>_ooo`03o`2Ioooooooo07;oool500000oooo`<0001V
oooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool400000oooo`800003oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`0;oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05?ooo`030000
oooooooo00Woool300001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.14415 .26487 L
.16254 .26487 L
.16783 .26487 L
.17044 .26487 L
.17284 .26487 L
.17502 .26487 L
.17612 .26487 L
s
.17612 .26487 m
.1766 .61803 L
s
0 .4 1 r
.02381 .25359 m
.06244 .24957 L
.10458 .24356 L
.12507 .23983 L
.14415 .23577 L
.16254 .23124 L
.16783 .22981 L
.17044 .22909 L
.17284 .22841 L
.17502 .22778 L
.17612 .22746 L
.17733 .26487 L
.17854 .26487 L
.17985 .26487 L
.18221 .26487 L
.22343 .26487 L
.26314 .26487 L
.30133 .26487 L
.34198 .26487 L
.38111 .26487 L
.42269 .26487 L
.46276 .26487 L
.50131 .26487 L
.54231 .26487 L
.5818 .26487 L
.61977 .26487 L
.6602 .26487 L
.6991 .26487 L
.74046 .26487 L
.78031 .26487 L
.81864 .26487 L
.85942 .26487 L
.89869 .26487 L
.93644 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@000080I_lLoooo00<0003oooooool07?ooo`040000oooooooooooo0P0001/co`000`0003?o
03?o000J<ol00P0001hco`00100003?o0000000001coool00`000?ooooooo`0Voooo000Aoooo1000
00?oool200005oooo`@00002oooo00@00000I_l0I_l00002oooo00<0I_ooooooool04_ooo`@00005
oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol001Xco`00
0`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo02Goool001Soool0
0`000?ooooooo`0Hoooo1@1Vo`030000oooo000000;oool00`1Vooooooooo`0Hoooo00@0003ooooo
ool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol0
00<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Coooo1@1Vo`Koool200000_oo
o`0306Kooooooooo01Woool200006oooo`D0000N<ol00P0001`co`000`0003?o03?o000L<ol00P00
00Pco`0400004oooo`80000Woooo000Voooo201Vo`ooool00`1Vooooooooo`0doooo0P00044co`00
0`0003?o03?o000Z<ol00`0003Woool001coool:06Ko5oooo`0306Kooooooooo033oool40000@c?o
0080000^<ol00P0003Ooool001Koool606Ko8Oooo`0306Kooooooooo02_oool50000Ac?o00030000
<ol0<ol002lco`040000<oooo`00?Oooo`0306Kooooooooo027oool:0000C3?o00030000<ol0<ol0
03<co`0:0000:Oooo`00?Oooo`0306Kooooooooo01Koool;0000ES?o00030000<ol0<ol003dco`0?
00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0
003oooooool07Oooo`030000oooooooo00Coool00ol0VOooooooo`0Goooo00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01koool00`000?ooooooo`0Uoooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool0
03goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool2
0000Ioooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Wooooo
ool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_oo
o`00?Oooo`03o`2Ioooooooo07Ooool20000Ioooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?oo
ooooo`1Voooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOoo
ooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1V
oooo000moooo00?o09Woooooool0Moooo`80001Woooo000moooo00?o09Woooooool0Moooo`030000
oooooooo06Koool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2I
oooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`80001Woooo000m
oooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo00<0
003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo06ooool500000oooo`030000oooooooo06Koool0
03goool00ol0VOooooooo`1aoooo00<0003oooooool00oooo`030000oooooooo06Koool003goool0
0ol0VOooooooo`1aoooo00<0003oooooool00oooo`<0001Voooo000moooo00?o09Woooooool0LOoo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0LOooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0L?ooo`800005oooo00<0
003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool20000Ioooo`00?Oooo`03o`2Ioooooooo
07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool0
03goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool0
0`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`80001Woooo000moooo00?o09Wooooo
ool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_oo
o`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Mooo
o`80001Woooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOoo
ooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1V
oooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1g
oooo0P0006Ooool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2I
oooooooo06ooool400001?ooo`030000oooooooo06Koool003goool00ol0VOooooooo`1_oooo00<0
003oooooool01Oooo`030000oooooooo06Koool003goool00ol0VOooooooo`1`oooo00<0003ooooo
ool01?ooo`<0001Voooo000moooo00?o09Woooooool0LOooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo000moooo00?o09Woooooool0Koooo`040000oooooooo00001?ooo`030000oooooooo
06Koool003goool00ol0VOooooooo`1`oooo0P0000Goool00`000?ooooooo`1Voooo000moooo00?o
09Woooooool0Moooo`80001Woooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool0
03goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool0
0`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool0
0ol0VOooooooo`1goooo0P0006Ooool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_oo
o`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Mooo
o`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo0P0006Ooool003goool00ol0VOoo
ooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1V
oooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1g
oooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool20000Ioooo`00?Oooo`03o`2I
oooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0L?ooo`800005oooo00<0
003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo06ooool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo000moooo00?o09Woooooool0LOooo`030000oooooooo00?oool30000I_ooo`00?Ooo
o`03o`2Ioooooooo07;oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00?Oooo`03o`2I
oooooooo06ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo000moooo00?o09Wooooo
ool0L?ooo`800005oooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?oo
ooooo`1Voooo000moooo00?o09Woooooool0Moooo`80001Woooo000moooo00?o09Woooooool0Mooo
o`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Ooo
o`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`80001W
oooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1g
oooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000m
oooo00?o09Woooooool0Moooo`030000oooooooo06Koool003goool00ol0VOooooooo`1goooo0P00
06Ooool003goool00ol0VOooooooo`1goooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo
07Ooool00`000?ooooooo`1Voooo000moooo00?o09Woooooool0Moooo`030000oooooooo06Koool0
03goool00ol0VOooooooo`1goooo0P0006Ooool003goool00ol0VOooooooo`1goooo00<0003ooooo
ool0I_ooo`00?Oooo`03o`2Ioooooooo07Ooool00`000?ooooooo`1Voooo000moooo00?o09Wooooo
ool0LOooo`<00003oooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo07;oool00`000?oo
ooooo`02oooo00<0003oooooool0I_ooo`00?Oooo`03o`2Ioooooooo06ooool500000oooo`<0001V
oooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool400000oooo`800004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`09oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Doooo00<0
003oooooool02?ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.16408 .26487 L
.17277 .26487 L
.18221 .26487 L
.18475 .26487 L
.18614 .26487 L
.18744 .26487 L
.18855 .26487 L
s
.18855 .26487 m
.18902 .61803 L
s
0 .4 1 r
.02381 .25467 m
.06244 .25104 L
.10458 .2456 L
.14415 .23856 L
.16408 .2341 L
.17277 .23192 L
.18221 .22939 L
.18475 .22867 L
.18614 .22827 L
.18744 .2279 L
.18855 .22757 L
.18974 .26487 L
.19106 .26487 L
.19227 .26487 L
.20178 .26487 L
.22272 .26487 L
.26243 .26487 L
.30062 .26487 L
.34126 .26487 L
.38039 .26487 L
.42198 .26487 L
.46204 .26487 L
.50059 .26487 L
.5416 .26487 L
.58108 .26487 L
.61906 .26487 L
.65948 .26487 L
.69839 .26487 L
.73975 .26487 L
.77959 .26487 L
.81792 .26487 L
.85871 .26487 L
.89797 .26487 L
.93572 .26487 L
.97593 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0000;oool306Ko6Oooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooo06Ko00000`1Vo`;oool00`1Vooooooooo`0?
oooo100000Goool00`000?ooooooo`0Doooo100000Coool300005C?o00@00004<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Ooo
o`006?ooo`030000oooooooo01coool0101Vo`000?ooo`0000Goool00`1Vooooooooo`0Eoooo00@0
003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000
<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Foooo1P1Vo`;oool2
00001Oooo`0306Kooooooooo01Koool200006oooo`D0000N<ol00P0001`co`000`0003?o03?o000L
<ol00P0000Pco`0400004oooo`80000Woooo000Yoooo201Vo`ooool00`1Vooooooooo`0aoooo0P00
044co`000`0003?o03?o000Z<ol00`0003Woool002?oool606Ko5oooo`0306Kooooooooo02goool4
0000@c?o0080000^<ol00P0003Ooool001coool706Ko7Oooo`0306Kooooooooo02Soool50000Ac?o
00030000<ol0<ol002lco`040000<oooo`005_ooo`H0I_lToooo00<0I_ooooooool07_ooo`X0001<
<ol000<0000co`0co`00<c?o00X0000Yoooo0010oooo00<0I_ooooooool04oooo`/0001F<ol000<0
000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo00Coool010000?ooooooool0V@;oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`07oooo00?o09Woooooool05?oo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00@?ooo`03o`2Ioooooooo07Coool0
0`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool0
0ol0VOooooooo`1doooo0P0006Ooool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_oo
o`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?oo
o`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo0P0006Ooool0043oool00ol0VOoo
ooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1V
oooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1d
oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool20000Ioooo`00@?ooo`03o`2I
oooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo
06Koool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo
07Coool20000Ioooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o
09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1/oooo1@0000?oool0
0`000?ooooooo`1Voooo0010oooo00?o09Woooooool0K_ooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo0010oooo00?o09Woooooool0K_ooo`030000oooooooo00?oool30000I_ooo`00@?oo
o`03o`2Ioooooooo06koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00@?ooo`03o`2I
oooooooo06koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo
06goool200001Oooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo0P0006Ooool0
043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool0
0`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool0
0ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool20000Iooo
o`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?oo
o`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?oo
o`03o`2Ioooooooo07Coool20000Ioooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1V
oooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1d
oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010
oooo00?o09Woooooool0M?ooo`80001Woooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo
06Koool0043oool00ol0VOooooooo`1/oooo100000Coool00`000?ooooooo`1Voooo0010oooo00?o
09Woooooool0K?ooo`030000oooooooo00Goool00`000?ooooooo`1Voooo0010oooo00?o09Wooooo
ool0KOooo`030000oooooooo00Coool30000I_ooo`00@?ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo06coool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0KOooo`800005oooo00<0003ooooo
ool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool20000Ioooo`00@?ooo`03o`2Ioooooooo07Coool0
0`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool0
0ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool00`000?oo
ooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`80001Woooo0010oooo00?o09Woooooool0M?oo
o`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?oo
o`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`80001W
oooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1d
oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010
oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo0P00
06Ooool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo
06goool200001Oooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1/oooo00@0003ooooo
ool00004oooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo06koool00`000?ooooooo`03
oooo0`0006Koool0043oool00ol0VOooooooo`1_oooo00<0003oooooool00_ooo`030000oooooooo
06Koool0043oool00ol0VOooooooo`1/oooo00@0003oooooool00004oooo00<0003oooooool0I_oo
o`00@?ooo`03o`2Ioooooooo06goool200001Oooo`030000oooooooo06Koool0043oool00ol0VOoo
ooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool20000Ioooo`00@?oo
o`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`030000
oooooooo06Koool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2I
oooooooo07Coool20000Ioooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010
oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo00<0
003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool00`000?ooooooo`1Voooo0010oooo00?o
09Woooooool0M?ooo`80001Woooo0010oooo00?o09Woooooool0M?ooo`030000oooooooo06Koool0
043oool00ol0VOooooooo`1doooo00<0003oooooool0I_ooo`00@?ooo`03o`2Ioooooooo07Coool0
0`000?ooooooo`1Voooo0010oooo00?o09Woooooool0M?ooo`80001Woooo0010oooo00?o09Wooooo
ool0M?ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1doooo00<0003oooooool0I_oo
o`00@?ooo`03o`2Ioooooooo06koool300000oooo`030000oooooooo06Koool0043oool00ol0VOoo
ooooo`1_oooo00<0003oooooool00_ooo`030000oooooooo06Koool0043oool00ol0VOooooooo`1/
oooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo0000
06goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1000
00?oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05?ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002Ooo
o`@00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.16408 .26487 L
.18221 .26487 L
.18703 .26487 L
.19227 .26487 L
.19467 .26487 L
.19721 .26487 L
.19939 .26487 L
.20062 .26487 L
s
.20062 .26487 m
.20109 .61803 L
s
0 .4 1 r
.02381 .25565 m
.06244 .25237 L
.10458 .24745 L
.14415 .24109 L
.16408 .23705 L
.18221 .23279 L
.18703 .23156 L
.19227 .23016 L
.19467 .2295 L
.19721 .22878 L
.19939 .22816 L
.20062 .2278 L
.20178 .26487 L
.20307 .26487 L
.20448 .26487 L
.20705 .26487 L
.21187 .26487 L
.22272 .26487 L
.26336 .26487 L
.30249 .26487 L
.34407 .26487 L
.38414 .26487 L
.42269 .26487 L
.46369 .26487 L
.50318 .26487 L
.54115 .26487 L
.58158 .26487 L
.62049 .26487 L
.66185 .26487 L
.70169 .26487 L
.74002 .26487 L
.7808 .26487 L
.82007 .26487 L
.85782 .26487 L
.89802 .26487 L
.93671 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0000Goool306Ko5_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00000_ooo`@0I_l2oooo00<0I_oooooo
ool03?ooo`@00005oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`000?ooooooo`0Moooo00<00000I_l000000P1Vo`Koool00`1Vooooooooo`0B
oooo00@0003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o
00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Hoooo1@1V
o`03oooo0000000000Soool00`1Vooooooooo`0Coooo0P0001_oool500007S?o0080000L<ol000<0
000co`0co`0073?o00800008<ol0100001?oool200009oooo`00;_ooo`D0I_l@oooo00<0I_oooooo
ool0;_ooo`800011<ol000<0000co`0co`00:S?o00<0000ioooo000Voooo201VoaGoool00`1Voooo
ooooo`0Zoooo100004<co`020000;S?o0080000goooo000Loooo2P1Voagoool00`1Vooooooooo`0U
oooo1@0004Lco`000`0003?o03?o000_<ol0100003?oool001Koool606Ko9oooo`0306Kooooooooo
01_oool:0000C3?o00030000<ol0<ol003<co`0:0000:Oooo`00@oooo`0306Kooooooooo013oool;
0000ES?o00030000<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo00[oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0
003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo0013oooo00?o09Wooooo
ool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_oo
o`00@oooo`03o`2Ioooooooo077oool20000Ioooo`00@oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`1Voooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool004?oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool20000Ioooo`00@ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`030000
oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2I
oooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`80001Woooo0013
oooo00?o09Woooooool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0
003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o
09Woooooool0LOooo`80001Woooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool0
04?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo06Woool5
00000oooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1[oooo00<0003oooooool00ooo
o`030000oooooooo06Koool004?oool00ol0VOooooooo`1[oooo00<0003oooooool00oooo`<0001V
oooo0013oooo00?o09Woooooool0Joooo`030000oooooooo00?oool00`000?ooooooo`1Voooo0013
oooo00?o09Woooooool0Joooo`030000oooooooo00?oool00`000?ooooooo`1Voooo0013oooo00?o
09Woooooool0J_ooo`800005oooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool2
0000Ioooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Wooooo
ool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_oo
o`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOoo
o`80001Woooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool004?oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1V
oooo0013oooo00?o09Woooooool0LOooo`80001Woooo0013oooo00?o09Woooooool0LOooo`030000
oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2I
oooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`030000oooooooo
06Koool004?oool00ol0VOooooooo`1aoooo0P0006Ooool004?oool00ol0VOooooooo`1aoooo00<0
003oooooool0I_ooo`00@oooo`03o`2Ioooooooo06Woool400001?ooo`030000oooooooo06Koool0
04?oool00ol0VOooooooo`1Yoooo00<0003oooooool01Oooo`030000oooooooo06Koool004?oool0
0ol0VOooooooo`1Zoooo00<0003oooooool01?ooo`<0001Voooo0013oooo00?o09Woooooool0Jooo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0JOooo`040000
oooooooo00001?ooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1Zoooo0P0000Goool0
0`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`80001Woooo0013oooo00?o09Wooooo
ool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_oo
o`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOoo
o`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo0P0006Ooool004?oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1V
oooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1a
oooo0P0006Ooool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2I
oooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`030000oooooooo
06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo
077oool20000Ioooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o
09Woooooool0J_ooo`800005oooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo06Woool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0Joooo`030000
oooooooo00?oool30000I_ooo`00@oooo`03o`2Ioooooooo06coool00`000?ooooooo`02oooo00<0
003oooooool0I_ooo`00@oooo`03o`2Ioooooooo06Woool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo0013oooo00?o09Woooooool0J_ooo`800005oooo00<0003oooooool0I_ooo`00@ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`80001W
oooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1a
oooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013
oooo00?o09Woooooool0LOooo`80001Woooo0013oooo00?o09Woooooool0LOooo`030000oooooooo
06Koool004?oool00ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo
077oool00`000?ooooooo`1Voooo0013oooo00?o09Woooooool0LOooo`030000oooooooo06Koool0
04?oool00ol0VOooooooo`1aoooo0P0006Ooool004?oool00ol0VOooooooo`1aoooo00<0003ooooo
ool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?ooooooo`1Voooo0013oooo00?o09Wooooo
ool0LOooo`030000oooooooo06Koool004?oool00ol0VOooooooo`1aoooo0P0006Ooool004?oool0
0ol0VOooooooo`1aoooo00<0003oooooool0I_ooo`00@oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`1Voooo0013oooo00?o09Woooooool0Joooo`<00003oooo00<0003oooooool0I_ooo`00@ooo
o`03o`2Ioooooooo06coool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00@oooo`03o`2I
oooooooo06Woool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0
003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool400000oooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Doooo00<0003oooooool02?ooo`040000oooooooo00001?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P00
00[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20178 .26487 L
.20742 .26487 L
.21019 .26487 L
.2114 .26487 L
.21274 .26487 L
.21394 .26487 L
s
.21394 .26487 m
.21439 .61803 L
s
0 .4 1 r
.02381 .25654 m
.06244 .25357 L
.10458 .24913 L
.14415 .24338 L
.18221 .23588 L
.20178 .23107 L
.20742 .22954 L
.21019 .22876 L
.2114 .22841 L
.21274 .22803 L
.21394 .22768 L
.21506 .26487 L
.21625 .26487 L
.21753 .26487 L
.22272 .26487 L
.26394 .26487 L
.30365 .26487 L
.34184 .26487 L
.38249 .26487 L
.42162 .26487 L
.4632 .26487 L
.50327 .26487 L
.54182 .26487 L
.58282 .26487 L
.62231 .26487 L
.66028 .26487 L
.7007 .26487 L
.73961 .26487 L
.78097 .26487 L
.82082 .26487 L
.85915 .26487 L
.89993 .26487 L
.9392 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0000Woool206Ko4oooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00001_ooo`@0I_l00oooo`1Vooooo`0:
oooo100000Goool00`000?ooooooo`0Doooo100000Coool300005C?o00@00004<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Ooo
o`006?ooo`030000oooooooo01goool010000?ooo`000?ooo`D0I_l5oooo00<0I_ooooooool03ooo
o`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol001dco`00
0`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Soool300007Oooo`0406Ko
0000000006Ko2_ooo`0306Kooooooooo013oool200006oooo`D0000N<ol00P0001`co`000`0003?o
03?o000L<ol00P0000Pco`0400004oooo`80000Woooo000aoooo1`1Vo`koool00`1Vooooooooo`0[
oooo0P00044co`000`0003?o03?o000Z<ol00`0003Woool002Koool;06Ko5_ooo`0306Kooooooooo
02Koool40000@c?o0080000^<ol00P0003Ooool001coool:06Ko8Oooo`0306Kooooooooo027oool5
0000Ac?o00030000<ol0<ol002lco`040000<oooo`005_ooo`H0I_l[oooo00<0I_ooooooool05ooo
o`X0001<<ol000<0000co`0co`00<c?o00X0000Yoooo0017oooo00<0I_ooooooool03?ooo`/0001F
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00@0003ooooooooo09T3oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0=oooo00?o09Wooooo
ool03_ooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00A_ooo`03o`2Ioooooooo
06koool00`000?ooooooo`1Voooo0016oooo00?o09Woooooool0K_ooo`030000oooooooo06Koool0
04Koool00ol0VOooooooo`1^oooo0P0006Ooool004Koool00ol0VOooooooo`1^oooo00<0003ooooo
ool0I_ooo`00A_ooo`03o`2Ioooooooo06koool00`000?ooooooo`1Voooo0016oooo00?o09Wooooo
ool0K_ooo`030000oooooooo06Koool004Koool00ol0VOooooooo`1^oooo0P0006Ooool004Koool0
0ol0VOooooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`1Voooo0016oooo00?o09Woooooool0K_ooo`030000oooooooo06Koool004Koool00ol0VOoo
ooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2Ioooooooo06koool20000Ioooo`00A_oo
o`03o`2Ioooooooo06koool00`000?ooooooo`1Voooo0016oooo00?o09Woooooool0K_ooo`030000
oooooooo06Koool004Koool00ol0VOooooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2I
oooooooo06koool20000Ioooo`00A_ooo`03o`2Ioooooooo06koool00`000?ooooooo`1Voooo0016
oooo00?o09Woooooool0K_ooo`030000oooooooo06Koool004Koool00ol0VOooooooo`1Voooo1@00
00?oool00`000?ooooooo`1Voooo0016oooo00?o09Woooooool0J?ooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo0016oooo00?o09Woooooool0J?ooo`030000oooooooo00?oool30000I_oo
o`00A_ooo`03o`2Ioooooooo06Soool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00A_oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00A_ooo`03o`2I
oooooooo06Ooool200001Oooo`030000oooooooo06Koool004Koool00ol0VOooooooo`1^oooo0P00
06Ooool004Koool00ol0VOooooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2Ioooooooo
06koool00`000?ooooooo`1Voooo0016oooo00?o09Woooooool0K_ooo`030000oooooooo06Koool0
04Koool00ol0VOooooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2Ioooooooo06koool2
0000Ioooo`00A_ooo`03o`2Ioooooooo06koool00`000?ooooooo`1Voooo0016oooo00?o09Wooooo
ool0K_ooo`030000oooooooo06Koool004Koool00ol0VOooooooo`1^oooo00<0003oooooool0I_oo
o`00A_ooo`03o`2Ioooooooo06koool20000Ioooo`00A_ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`1Voooo0016oooo00?o09Woooooool0K_ooo`030000oooooooo06Koool004Koool00ol0VOoo
ooooo`1^oooo00<0003oooooool0I_ooo`00A_ooo`03o`2Ioooooooo06koool00`000?ooooooo`1V
oooo0016oooo00?o09Woooooool0K_ooo`80001Woooo0016oooo00?o09Woooooool0K_ooo`030000
oooooooo06Koool004Koool00ol0VOooooooo`1Voooo100000Coool00`000?ooooooo`1Voooo0016
oooo00?o09Woooooool0I_ooo`030000oooooooo00Goool00`000?ooooooo`1Voooo0016oooo00?o
09Woooooool0Ioooo`030000oooooooo00Coool30000I_ooo`00Aoooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06Goool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo0017oooo00?o09Woooooool0I_ooo`800005oooo00<0
003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06goool20000Ioooo`00Aoooo`03o`2Ioooooooo
06goool00`000?ooooooo`1Voooo0017oooo00?o09Woooooool0KOooo`030000oooooooo06Koool0
04Ooool00ol0VOooooooo`1]oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06goool0
0`000?ooooooo`1Voooo0017oooo00?o09Woooooool0KOooo`80001Woooo0017oooo00?o09Wooooo
ool0KOooo`030000oooooooo06Koool004Ooool00ol0VOooooooo`1]oooo00<0003oooooool0I_oo
o`00Aoooo`03o`2Ioooooooo06goool00`000?ooooooo`1Voooo0017oooo00?o09Woooooool0KOoo
o`80001Woooo0017oooo00?o09Woooooool0KOooo`030000oooooooo06Koool004Ooool00ol0VOoo
ooooo`1]oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06goool00`000?ooooooo`1V
oooo0017oooo00?o09Woooooool0KOooo`030000oooooooo06Koool004Ooool00ol0VOooooooo`1]
oooo0P0006Ooool004Ooool00ol0VOooooooo`1]oooo00<0003oooooool0I_ooo`00Aoooo`03o`2I
oooooooo06Koool200001Oooo`030000oooooooo06Koool004Ooool00ol0VOooooooo`1Uoooo00@0
003oooooool00004oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`03oooo0`0006Koool004Ooool00ol0VOooooooo`1Xoooo00<0003oooooool00_ooo`030000
oooooooo06Koool004Ooool00ol0VOooooooo`1Uoooo00@0003oooooool00004oooo00<0003ooooo
ool0I_ooo`00Aoooo`03o`2Ioooooooo06Koool200001Oooo`030000oooooooo06Koool004Ooool0
0ol0VOooooooo`1]oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06goool20000Iooo
o`00Aoooo`03o`2Ioooooooo06goool00`000?ooooooo`1Voooo0017oooo00?o09Woooooool0KOoo
o`030000oooooooo06Koool004Ooool00ol0VOooooooo`1]oooo00<0003oooooool0I_ooo`00Aooo
o`03o`2Ioooooooo06goool20000Ioooo`00Aoooo`03o`2Ioooooooo06goool00`000?ooooooo`1V
oooo0017oooo00?o09Woooooool0KOooo`030000oooooooo06Koool004Ooool00ol0VOooooooo`1]
oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo06goool00`000?ooooooo`1Voooo0017
oooo00?o09Woooooool0KOooo`80001Woooo0017oooo00?o09Woooooool0KOooo`030000oooooooo
06Koool004Ooool00ol0VOooooooo`1]oooo00<0003oooooool0I_ooo`00Aoooo`03o`2Ioooooooo
06goool00`000?ooooooo`1Voooo0017oooo00?o09Woooooool0KOooo`80001Woooo0017oooo00?o
09Woooooool0KOooo`030000oooooooo06Koool004Ooool00ol0VOooooooo`1]oooo00<0003ooooo
ool0I_ooo`00Aoooo`03o`2Ioooooooo06Ooool300000oooo`030000oooooooo06Koool004Ooool0
0ol0VOooooooo`1Xoooo00<0003oooooool00_ooo`030000oooooooo06Koool004Ooool00ol0VOoo
ooooo`1Uoooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000
oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<
oooo100000?oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00<0003ooooo
ool02Oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05?ooo`030000oooooooo00_oool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_oo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20342 .26487 L
.21345 .26487 L
.21786 .26487 L
.22037 .26487 L
.22272 .26487 L
.22496 .26487 L
.22623 .26487 L
s
.22623 .26487 m
.22669 .61803 L
s
0 .4 1 r
.02381 .25734 m
.06244 .25466 L
.10458 .25065 L
.14415 .24545 L
.18221 .23868 L
.20342 .23393 L
.21345 .2314 L
.21786 .23022 L
.22037 .22953 L
.22272 .22887 L
.22496 .22823 L
.22623 .22787 L
.22738 .26487 L
.22859 .26487 L
.22992 .26487 L
.23233 .26487 L
.24276 .26487 L
.26171 .26487 L
.30236 .26487 L
.34148 .26487 L
.38307 .26487 L
.42313 .26487 L
.46168 .26487 L
.50269 .26487 L
.54217 .26487 L
.58015 .26487 L
.62057 .26487 L
.65948 .26487 L
.70084 .26487 L
.74069 .26487 L
.77902 .26487 L
.8198 .26487 L
.85906 .26487 L
.89681 .26487 L
.93702 .26487 L
.97571 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0000_oool406Ko3oooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00002?ooo`@0I_l3oooo00<0I_oooooo
ool01Oooo`@00005oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`000?ooooooo`0Moooo00<0003oool000001Oooo`<0I_l7oooo00<0I_oooooo
ool02oooo`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol0
01dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Soool300007_oo
o`80000506Ko2_ooo`0306Kooooooooo00coool200006oooo`D0000N<ol00P0001`co`000`0003?o
03?o000L<ol00P0000Pco`0400004oooo`80000Woooo000coooo1`1Voa3oool00`1Vooooooooo`0W
oooo0P00044co`000`0003?o03?o000Z<ol00`0003Woool002koool506Ko5oooo`0306Kooooooooo
02?oool40000@c?o0080000^<ol00P0003Ooool002Koool806Ko7?ooo`0306Kooooooooo01koool5
0000Ac?o00030000<ol0<ol002lco`040000<oooo`005_oooa00I_lToooo00<0I_ooooooool05?oo
o`X0001<<ol000<0000co`0co`00<c?o00X0000Yoooo001:oooo00<0I_ooooooool02Oooo`/0001F
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool04Oooo`03o`2Ioooooooo
00[oool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool004[oool00ol0VOooooooo`1Z
oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:
oooo00?o09Woooooool0J_ooo`80001Woooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo
06Koool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo
06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`80001Woooo001:oooo00?o
09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo00<0003ooooo
ool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Wooooo
ool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo0P0006Ooool004[oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?oo
ooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOoo
ooooo`1Zoooo0P0006Ooool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_oo
o`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0H_ooo`D00003
oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06Coool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06Coool00`000?ooooooo`03oooo0`0006Koool0
04[oool00ol0VOooooooo`1Toooo00<0003oooooool00oooo`030000oooooooo06Koool004[oool0
0ol0VOooooooo`1Toooo00<0003oooooool00oooo`030000oooooooo06Koool004[oool00ol0VOoo
ooooo`1Soooo0P0000Goool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`80001W
oooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Z
oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:
oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo0P00
06Ooool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo
06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool0
04[oool00ol0VOooooooo`1Zoooo0P0006Ooool004[oool00ol0VOooooooo`1Zoooo00<0003ooooo
ool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Wooooo
ool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_oo
o`00B_ooo`03o`2Ioooooooo06[oool20000Ioooo`00B_ooo`03o`2Ioooooooo06[oool00`000?oo
ooooo`1Voooo001:oooo00?o09Woooooool0H_ooo`@00004oooo00<0003oooooool0I_ooo`00B_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`05oooo00<0003oooooool0I_ooo`00B_ooo`03o`2I
oooooooo06?oool00`000?ooooooo`04oooo0`0006Koool004[oool00ol0VOooooooo`1Toooo00<0
003oooooool00oooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Roooo00@0003ooooo
ool00004oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06?oool200001Oooo`030000
oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo0P0006Ooool004[oool00ol0VOooooooo`1Z
oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:
oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo00<0
003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool20000Ioooo`00B_ooo`03o`2Ioooooooo
06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool0
04[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool2
0000Ioooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Wooooo
ool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_oo
o`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_oo
o`80001Woooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOoo
ooooo`1Soooo0P0000Goool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0H_ooo`040000
oooooooo00001?ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Toooo00<0003ooooo
ool00oooo`<0001Voooo001:oooo00?o09Woooooool0IOooo`030000oooooooo00;oool00`000?oo
ooooo`1Voooo001:oooo00?o09Woooooool0H_ooo`040000oooooooo00001?ooo`030000oooooooo
06Koool004[oool00ol0VOooooooo`1Soooo0P0000Goool00`000?ooooooo`1Voooo001:oooo00?o
09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo0P0006Ooool0
04[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool0
0ol0VOooooooo`1Zoooo0P0006Ooool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_oo
o`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_oo
o`030000oooooooo06Koool004[oool00ol0VOooooooo`1Zoooo00<0003oooooool0I_ooo`00B_oo
o`03o`2Ioooooooo06[oool20000Ioooo`00B_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`1V
oooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo06Koool004[oool00ol0VOooooooo`1Z
oooo00<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo06[oool20000Ioooo`00B_ooo`03o`2I
oooooooo06[oool00`000?ooooooo`1Voooo001:oooo00?o09Woooooool0J_ooo`030000oooooooo
06Koool004[oool00ol0VOooooooo`1Toooo0`0000?oool00`000?ooooooo`1Voooo001:oooo00?o
09Woooooool0IOooo`030000oooooooo00;oool00`000?ooooooo`1Voooo001:oooo00?o09Wooooo
ool0H_ooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool00;3oool00`000?oo
o`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`@00003oooo0P0000Goool300000_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`030000oooooooo
00coool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
01Coool00`000?ooooooo`08oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001Coool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20342 .26487 L
.22272 .26487 L
.23233 .26487 L
.23496 .26487 L
.2364 .26487 L
.23775 .26487 L
.2389 .26487 L
s
.2389 .26487 m
.2394 .61803 L
s
0 .4 1 r
.02381 .25807 m
.06244 .25565 L
.10458 .25203 L
.14415 .24733 L
.18221 .24122 L
.20342 .23693 L
.22272 .23236 L
.23233 .22982 L
.23496 .22908 L
.2364 .22868 L
.23775 .22829 L
.2389 .22796 L
.24014 .26487 L
.24084 .26487 L
.24151 .26487 L
.24276 .26487 L
.26171 .26487 L
.2999 .26487 L
.34055 .26487 L
.37968 .26487 L
.42126 .26487 L
.46133 .26487 L
.49988 .26487 L
.54088 .26487 L
.58037 .26487 L
.61834 .26487 L
.65876 .26487 L
.69767 .26487 L
.73903 .26487 L
.77888 .26487 L
.81721 .26487 L
.85799 .26487 L
.89726 .26487 L
.93501 .26487 L
.97521 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0000ooool306Ko3?ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00003?ooo`@0I_l2oooo00<0I_oooooo
ool00_ooo`@00005oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`000?ooooooo`0Moooo00<0003oool000001oooo`D0I_l6oooo00<0I_oooooo
ool02?ooo`040000oooooooo00007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol0
01dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Soool300007_oo
o`8000000oooo`1Vo`1Vo`0406Ko2oooo`0306Kooooooooo00Woool200006oooo`D0000N<ol00P00
01`co`000`0003?o03?o000L<ol00P0000Pco`0400004oooo`80000Woooo000hoooo101Voa7oool0
0`1Vooooooooo`0Toooo0P00044co`000`0003?o03?o000Z<ol00`0003Woool0037oool706Ko5Ooo
o`0306Kooooooooo023oool40000@c?o0080000^<ol00P0003Ooool002Koool;06Ko7?ooo`0306Ko
oooooooo01_oool50000Ac?o00030000<ol0<ol002lco`040000<oooo`005_oooa00I_lWoooo00<0
I_ooooooool04Oooo`X0001<<ol000<0000co`0co`00<c?o00X0000Yoooo001=oooo00<0I_oooooo
ool01_ooo`/0001F<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`040000ooooooooo`2I0_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0D
oooo00?o09Woooooool01oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003ooooo
ool07Oooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00COoo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000
oooooooo06Koool004goool00ol0VOooooooo`1Woooo0P0006Ooool004goool00ol0VOooooooo`1W
oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=
oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo0P00
06Ooool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo
06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool0
04goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool2
0000Ioooo`00COooo`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Wooooo
ool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_oo
o`00COooo`03o`2Ioooooooo06Ooool20000Ioooo`00COooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOoo
ooooo`1Ooooo1@0000?oool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0HOooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0HOooo`030000oooooooo
00?oool30000I_ooo`00COooo`03o`2Ioooooooo067oool00`000?ooooooo`03oooo00<0003ooooo
ool0I_ooo`00COooo`03o`2Ioooooooo067oool00`000?ooooooo`03oooo00<0003oooooool0I_oo
o`00COooo`03o`2Ioooooooo063oool200001Oooo`030000oooooooo06Koool004goool00ol0VOoo
ooooo`1Woooo0P0006Ooool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COoo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000
oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2I
oooooooo06Ooool20000Ioooo`00COooo`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=
oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0
003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool20000Ioooo`00COooo`03o`2Ioooooooo
06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool0
04goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`80001Woooo001=oooo00?o09Wooooo
ool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Ooooo100000Coool00`000?oo
ooooo`1Voooo001=oooo00?o09Woooooool0Goooo`030000oooooooo00Goool00`000?ooooooo`1V
oooo001=oooo00?o09Woooooool0H?ooo`030000oooooooo00Coool30000I_ooo`00COooo`03o`2I
oooooooo067oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo
05ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0H?oo
o`800005oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool20000Ioooo`00COoo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000
oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2I
oooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`80001Woooo001=
oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0
003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o
09Woooooool0Ioooo`80001Woooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool0
04goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool0
0ol0VOooooooo`1Woooo0P0006Ooool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_oo
o`00COooo`03o`2Ioooooooo063oool200001Oooo`030000oooooooo06Koool004goool00ol0VOoo
ooooo`1Ooooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo
067oool00`000?ooooooo`03oooo0`0006Koool004goool00ol0VOooooooo`1Roooo00<0003ooooo
ool00_ooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Ooooo00@0003oooooool00004
oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo063oool200001Oooo`030000oooooooo
06Koool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo
06Ooool20000Ioooo`00COooo`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o
09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0003ooooo
ool0I_ooo`00COooo`03o`2Ioooooooo06Ooool20000Ioooo`00COooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool0
0ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`80001Woooo001=oooo00?o09Woooooool0Iooo
o`030000oooooooo06Koool004goool00ol0VOooooooo`1Woooo00<0003oooooool0I_ooo`00COoo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`1Voooo001=oooo00?o09Woooooool0Ioooo`80001W
oooo001=oooo00?o09Woooooool0Ioooo`030000oooooooo06Koool004goool00ol0VOooooooo`1W
oooo00<0003oooooool0I_ooo`00COooo`03o`2Ioooooooo067oool300000oooo`030000oooooooo
06Koool004goool00ol0VOooooooo`1Roooo00<0003oooooool00_ooo`030000oooooooo06Koool0
04goool00ol0VOooooooo`1Ooooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOoo
o`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0<oooo100000?oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003
oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool05?ooo`030000oooooooo00[oool00`000?ooooooo`03
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02_oo
o`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20342 .26487 L
.22272 .26487 L
.23233 .26487 L
.23739 .26487 L
.24276 .26487 L
.24745 .26487 L
.24873 .26487 L
.25012 .26487 L
.25142 .26487 L
s
.25142 .26487 m
.2519 .61803 L
s
0 .4 1 r
.02381 .25873 m
.06244 .25655 L
.10458 .25327 L
.14415 .24904 L
.18221 .24352 L
.20342 .23964 L
.22272 .23552 L
.23233 .23322 L
.23739 .23194 L
.24276 .23053 L
.24745 .22924 L
.24873 .22888 L
.25012 .22849 L
.25142 .22812 L
.25261 .26487 L
.25377 .26487 L
.25484 .26487 L
.25728 .26487 L
.26171 .26487 L
.30084 .26487 L
.34242 .26487 L
.38249 .26487 L
.42104 .26487 L
.46204 .26487 L
.50153 .26487 L
.5395 .26487 L
.57993 .26487 L
.61883 .26487 L
.6602 .26487 L
.70004 .26487 L
.73837 .26487 L
.77915 .26487 L
.81842 .26487 L
.85617 .26487 L
.89637 .26487 L
.93506 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001?oool206Ko2Oooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00004?ooo`@0I_l00oooo`1Vooooo`04
00001Oooo`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J
<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000H
oooo00<0003oooooool07Oooo`030000oooo000000coool406Ko1Oooo`0306Kooooooooo00Goool0
10000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0
000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`0001koool200001ooo
o`D0I_l9oooo00<0I_ooooooool01_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool003[oool806Ko3_ooo`0306Kooooooooo027oool2
0000@C?o00030000<ol0<ol002Xco`030000>Oooo`00<Oooo`T0I_lFoooo00<0I_ooooooool07Ooo
o`@00013<ol00P0002hco`020000=oooo`009_ooo`/0I_lOoooo00<0I_ooooooool06?ooo`D00017
<ol000<0000co`0co`00;c?o00@0000coooo000Loooo2P1Vob[oool00`1Vooooooooo`0>oooo2P00
04`co`000`0003?o03?o000c<ol02P0002Woool001Koool606Ko=?ooo`0306Kooooooooo00?oool;
0000ES?o00030000<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo01Ooool00ol0VOoo
ooooo`04oooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0
003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo001@oooo00?o09Wooooo
ool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_oo
o`00D?ooo`03o`2Ioooooooo06Coool20000Ioooo`00D?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0053oool00ol0VOoo
ooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool20000Ioooo`00D?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`030000
oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2I
oooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`80001Woooo001@
oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0
003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o
09Woooooool0I?ooo`80001Woooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0
053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo05coool5
00000oooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Noooo00<0003oooooool00ooo
o`030000oooooooo06Koool0053oool00ol0VOooooooo`1Noooo00<0003oooooool00oooo`<0001V
oooo001@oooo00?o09Woooooool0G_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001@
oooo00?o09Woooooool0G_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001@oooo00?o
09Woooooool0GOooo`800005oooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool2
0000Ioooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Wooooo
ool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_oo
o`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?oo
o`80001Woooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0053oool00ol0VOoo
ooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1V
oooo001@oooo00?o09Woooooool0I?ooo`80001Woooo001@oooo00?o09Woooooool0I?ooo`030000
oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2I
oooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo
06Koool0053oool00ol0VOooooooo`1Toooo0P0006Ooool0053oool00ol0VOooooooo`1Toooo00<0
003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo05coool400001?ooo`030000oooooooo06Koool0
053oool00ol0VOooooooo`1Loooo00<0003oooooool01Oooo`030000oooooooo06Koool0053oool0
0ol0VOooooooo`1Moooo00<0003oooooool01?ooo`<0001Voooo001@oooo00?o09Woooooool0G_oo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0G?ooo`040000
oooooooo00001?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Moooo0P0000Goool0
0`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`80001Woooo001@oooo00?o09Wooooo
ool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_oo
o`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?oo
o`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo0P0006Ooool0053oool00ol0VOoo
ooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1V
oooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1T
oooo0P0006Ooool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2I
oooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo
06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo
06Coool20000Ioooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o
09Woooooool0GOooo`800005oooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo05coool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0G_ooo`030000
oooooooo00?oool30000I_ooo`00D?ooo`03o`2Ioooooooo05ooool00`000?ooooooo`02oooo00<0
003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo05coool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo001@oooo00?o09Woooooool0GOooo`800005oooo00<0003oooooool0I_ooo`00D?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`80001W
oooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1T
oooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@
oooo00?o09Woooooool0I?ooo`80001Woooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo
06Koool0053oool00ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`1Voooo001@oooo00?o09Woooooool0I?ooo`030000oooooooo06Koool0
053oool00ol0VOooooooo`1Toooo0P0006Ooool0053oool00ol0VOooooooo`1Toooo00<0003ooooo
ool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`1Voooo001@oooo00?o09Wooooo
ool0I?ooo`030000oooooooo06Koool0053oool00ol0VOooooooo`1Toooo0P0006Ooool0053oool0
0ol0VOooooooo`1Toooo00<0003oooooool0I_ooo`00D?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`1Voooo001@oooo00?o09Woooooool0G_ooo`<00003oooo00<0003oooooool0I_ooo`00D?oo
o`03o`2Ioooooooo05ooool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00D?ooo`03o`2I
oooooooo05coool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0
003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool400000oooo`800003oooo100000?oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`09oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05?ooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.24141 .26487 L
.25127 .26487 L
.25666 .26487 L
.26171 .26487 L
.26301 .26487 L
.26425 .26487 L
.26493 .26487 L
s
.26493 .26487 m
.26523 .61803 L
s
0 .4 1 r
.02381 .25933 m
.06244 .25736 L
.10458 .25441 L
.14415 .25058 L
.18221 .2456 L
.22272 .23839 L
.24141 .23421 L
.25127 .23175 L
.25666 .23032 L
.26171 .22893 L
.26301 .22856 L
.26425 .22821 L
.26493 .22801 L
.26568 .26487 L
.26698 .26487 L
.27279 .26487 L
.28302 .26487 L
.30316 .26487 L
.3438 .26487 L
.38293 .26487 L
.42451 .26487 L
.46458 .26487 L
.50313 .26487 L
.54413 .26487 L
.58362 .26487 L
.62159 .26487 L
.66202 .26487 L
.70093 .26487 L
.74229 .26487 L
.78213 .26487 L
.82046 .26487 L
.86124 .26487 L
.90051 .26487 L
.93826 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001Goool306Ko1_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00004_ooo`@0I_l00oooo`0000000002
00001Oooo`030000oooooooo01Coool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J
<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000H
oooo00<0003oooooool07Oooo`030000oooo0000013oool206Ko1_ooo`0306Kooooooooo00;oool0
10000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0
000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`0001koool200002Ooo
o`L0I_l8oooo00<0I_ooooooool00oooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool003coool806Ko3oooo`0306Kooooooooo01koool2
0000@C?o00030000<ol0<ol002Xco`030000>Oooo`00>?ooo`@0I_lHoooo00<0I_ooooooool06Ooo
o`@00013<ol00P0002hco`020000=oooo`00<Oooo`L0I_lLoooo00<0I_ooooooool05?ooo`D00017
<ol000<0000co`0co`00;c?o00@0000coooo000Loooo5@1Vob?oool00`1Vooooooooo`0:oooo2P00
04`co`000`0003?o03?o000c<ol02P0002Woool001Koool606Ko>?ooo`0306Kooooo000000X0001F
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool010000?ooooooool0V@?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0Joooo00Go09Wooooo
ooooool000007oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Ooo
o`030000oooooooo01koool00`000?ooooooo`0Uoooo001Coooo00?o09Woooooool0HOooo`030000
oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2I
oooooooo067oool20000Ioooo`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001C
oooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0
003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool20000Ioooo`00Doooo`03o`2Ioooooooo
067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool0
05?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool0
0`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`80001Woooo001Coooo00?o09Wooooo
ool0HOooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_oo
o`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOoo
o`80001Woooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOoo
ooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo05Woool500000oooo`030000
oooooooo06Koool005?oool00ol0VOooooooo`1Koooo00<0003oooooool00oooo`030000oooooooo
06Koool005?oool00ol0VOooooooo`1Koooo00<0003oooooool00oooo`<0001Voooo001Coooo00?o
09Woooooool0Foooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Coooo00?o09Wooooo
ool0Foooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0F_oo
o`800005oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool20000Ioooo`00Dooo
o`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000
oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2I
oooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`80001Woooo001C
oooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0
003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o
09Woooooool0HOooo`80001Woooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool0
05?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool0
0`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool0
0ol0VOooooooo`1Qoooo0P0006Ooool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_oo
o`00Doooo`03o`2Ioooooooo05Woool400001?ooo`030000oooooooo06Koool005?oool00ol0VOoo
ooooo`1Ioooo00<0003oooooool01Oooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1J
oooo00<0003oooooool01?ooo`<0001Voooo001Coooo00?o09Woooooool0Foooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0FOooo`040000oooooooo00001?oo
o`030000oooooooo06Koool005?oool00ol0VOooooooo`1Joooo0P0000Goool00`000?ooooooo`1V
oooo001Coooo00?o09Woooooool0HOooo`80001Woooo001Coooo00?o09Woooooool0HOooo`030000
oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2I
oooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000oooooooo
06Koool005?oool00ol0VOooooooo`1Qoooo0P0006Ooool005?oool00ol0VOooooooo`1Qoooo00<0
003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o
09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo0P0006Ooool0
05?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool0
0`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool0
0ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool20000Iooo
o`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0F_oo
o`800005oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo05Woool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0Foooo`030000oooooooo00?oool3
0000I_ooo`00Doooo`03o`2Ioooooooo05coool00`000?ooooooo`02oooo00<0003oooooool0I_oo
o`00Doooo`03o`2Ioooooooo05Woool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001C
oooo00?o09Woooooool0F_ooo`800005oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo
067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`80001Woooo001Coooo00?o
09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo00<0003ooooo
ool0I_ooo`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Wooooo
ool0HOooo`80001Woooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool0
0ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool00`000?oo
ooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000oooooooo06Koool005?oool00ol0VOoo
ooooo`1Qoooo0P0006Ooool005?oool00ol0VOooooooo`1Qoooo00<0003oooooool0I_ooo`00Dooo
o`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001Coooo00?o09Woooooool0HOooo`030000
oooooooo06Koool005?oool00ol0VOooooooo`1Qoooo0P0006Ooool005?oool00ol0VOooooooo`1Q
oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo067oool00`000?ooooooo`1Voooo001C
oooo00?o09Woooooool0Foooo`<00003oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo
05coool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Doooo`03o`2Ioooooooo05Woool5
00000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOoo
o`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool400000ooo
o`800003oooo1@0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05?ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Doooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P00
00?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.24141 .26487 L
.26171 .26487 L
.26709 .26487 L
.27279 .26487 L
.27513 .26487 L
.27643 .26487 L
.27765 .26487 L
s
.27765 .26487 m
.27793 .61803 L
s
0 .4 1 r
.02381 .25987 m
.06244 .2581 L
.10458 .25543 L
.14415 .25199 L
.18221 .24749 L
.22272 .24099 L
.24141 .23722 L
.26171 .23246 L
.26709 .23107 L
.27279 .22953 L
.27513 .22888 L
.27643 .22851 L
.27765 .22816 L
.27835 .26487 L
.2791 .26487 L
.28042 .26487 L
.28302 .26487 L
.30316 .26487 L
.3438 .26487 L
.38293 .26487 L
.42451 .26487 L
.46458 .26487 L
.50313 .26487 L
.54413 .26487 L
.58362 .26487 L
.62159 .26487 L
.66202 .26487 L
.70093 .26487 L
.74229 .26487 L
.78213 .26487 L
.82046 .26487 L
.86124 .26487 L
.90051 .26487 L
.93826 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001Woool306Ko0_ooo`030000oooooooo01coool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00005_ooo`0306Ko0000000000800000
0oooo`1Vooooo`02oooo00<0003oooooool05?ooo`@00004oooo0`0001Dco`04000013?o00030000
<ol0<ol001Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo
02Goool001Soool00`000?ooooooo`0Moooo00<0003oool000004Oooo`D0I_l6oooo00D0I_l0003o
ooooool000007?ooo`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol001dco`000`0003?o
03?o0003<ol00`0001Koool010000?ooooooo`0002Koool001Soool300007_ooo`80000<oooo1@1V
o`_oool0101Vooooo`00000001_oool500007S?o0080000L<ol000<0000co`0co`0073?o00800008
<ol0100001?oool200009oooo`00@Oooo`H0I_l@oooo00<0I_ooooooool06_ooo`800011<ol000<0
000co`0co`00:S?o00<0000ioooo000joooo1`1VoaKoool00`1Vooooooooo`0Foooo100004<co`02
0000;S?o0080000goooo000aoooo2@1Voagoool00`1Vooooooooo`0Aoooo1@0004Lco`000`0003?o
03?o000_<ol0100003?oool002Koool;06Ko9_ooo`0306Kooooooooo00Ooool:0000C3?o00030000
<ol0<ol003<co`0:0000:Oooo`005_oooa00I_l`oooo00<00000I_l00000200005Hco`000`0003?o
03?o000m<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool04_oo
o`005_ooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01koool0
0`000?ooooooo`0Uoooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool0
0ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool20000Iooo
o`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOoo
o`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eooo
o`03o`2Ioooooooo05goool20000Ioooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1V
oooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1M
oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001G
oooo00?o09Woooooool0GOooo`80001Woooo001Goooo00?o09Woooooool0GOooo`030000oooooooo
06Koool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo
05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`80001Woooo001Goooo00?o
09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0003ooooo
ool0I_ooo`00Eoooo`03o`2Ioooooooo05Goool500000oooo`030000oooooooo06Koool005Ooool0
0ol0VOooooooo`1Goooo00<0003oooooool00oooo`030000oooooooo06Koool005Ooool00ol0VOoo
ooooo`1Goooo00<0003oooooool00oooo`<0001Voooo001Goooo00?o09Woooooool0Eoooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0Eoooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0E_ooo`800005oooo00<0003ooooo
ool0I_ooo`00Eoooo`03o`2Ioooooooo05goool20000Ioooo`00Eoooo`03o`2Ioooooooo05goool0
0`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool0
0ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?oo
ooooo`1Voooo001Goooo00?o09Woooooool0GOooo`80001Woooo001Goooo00?o09Woooooool0GOoo
o`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eooo
o`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`80001W
oooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1M
oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001G
oooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo0P00
06Ooool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo
05Goool400001?ooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Eoooo00<0003ooooo
ool01Oooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Foooo00<0003oooooool01?oo
o`<0001Voooo001Goooo00?o09Woooooool0Eoooo`030000oooooooo00?oool00`000?ooooooo`1V
oooo001Goooo00?o09Woooooool0EOooo`040000oooooooo00001?ooo`030000oooooooo06Koool0
05Ooool00ol0VOooooooo`1Foooo0P0000Goool00`000?ooooooo`1Voooo001Goooo00?o09Wooooo
ool0GOooo`80001Woooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool0
0ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?oo
ooooo`1Voooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOoo
ooooo`1Moooo0P0006Ooool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eooo
o`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`030000
oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo0P0006Ooool005Ooool00ol0VOooooooo`1M
oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001G
oooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0
003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool20000Ioooo`00Eoooo`03o`2Ioooooooo
05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0E_ooo`800005oooo00<0003ooooo
ool0I_ooo`00Eoooo`03o`2Ioooooooo05Goool010000?ooooooo`0000Coool00`000?ooooooo`1V
oooo001Goooo00?o09Woooooool0Eoooo`030000oooooooo00?oool30000I_ooo`00Eoooo`03o`2I
oooooooo05Soool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo
05Goool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0E_oo
o`800005oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1V
oooo001Goooo00?o09Woooooool0GOooo`80001Woooo001Goooo00?o09Woooooool0GOooo`030000
oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2I
oooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`80001Woooo001G
oooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo00<0
003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o
09Woooooool0GOooo`030000oooooooo06Koool005Ooool00ol0VOooooooo`1Moooo0P0006Ooool0
05Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05goool0
0`000?ooooooo`1Voooo001Goooo00?o09Woooooool0GOooo`030000oooooooo06Koool005Ooool0
0ol0VOooooooo`1Moooo0P0006Ooool005Ooool00ol0VOooooooo`1Moooo00<0003oooooool0I_oo
o`00Eoooo`03o`2Ioooooooo05goool00`000?ooooooo`1Voooo001Goooo00?o09Woooooool0Eooo
o`<00003oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05Soool00`000?ooooooo`02
oooo00<0003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo05Goool500000oooo`<0001Voooo002_
oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool400000oooo`800004oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00<0003oooooool02_ooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool05?ooo`030000oooooooo00[oool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0001Coool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`1koooo001l
oooo00<0003oooooool05oooo`800009oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.27193 .26487 L
.27731 .26487 L
.28302 .26487 L
.28542 .26487 L
.288 .26487 L
.28876 .26487 L
.28948 .26487 L
.29013 .26487 L
s
.29013 .26487 m
.29041 .61803 L
s
0 .4 1 r
.02381 .26037 m
.06244 .25877 L
.10458 .25637 L
.14415 .25326 L
.18221 .24921 L
.22272 .24335 L
.26171 .23567 L
.27193 .23324 L
.27731 .23188 L
.28302 .23038 L
.28542 .22973 L
.288 .22902 L
.28876 .22881 L
.28948 .2286 L
.29013 .22842 L
.29083 .26487 L
.2915 .26487 L
.29221 .26487 L
.29349 .26487 L
.30316 .26487 L
.34474 .26487 L
.3848 .26487 L
.42335 .26487 L
.46436 .26487 L
.50385 .26487 L
.54182 .26487 L
.58224 .26487 L
.62115 .26487 L
.66251 .26487 L
.70236 .26487 L
.74069 .26487 L
.78147 .26487 L
.82073 .26487 L
.85849 .26487 L
.89869 .26487 L
.93738 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001coool206Ko00<0003oooooool07?ooo`040000oooooooooooo0P0001/co`000`0003?o
03?o000J<ol00P0001hco`00100003?o0000000001coool00`000?ooooooo`0Voooo000Aoooo1000
00?oool200005oooo`@00002oooo00@0003oooooool0000Goooo10000080I_l2oooo00<0I_l0003o
ool05Oooo`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol001Xco`000`0003?o03?o000M
<ol000@0000co`0co`0co`0200006oooo`030000oooooooo02Goool001Soool00`000?ooooooo`0M
oooo00<0003oool000005_ooo`@0I_l3oooo00@0003oool0I_l0000Loooo100001hco`000`0003?o
03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol000<co`0300005_ooo`040000oooooooo
00009_ooo`006?ooo`<0000Noooo0P00017oool506Ko2?ooo`80000Koooo1@0001hco`02000073?o
00030000<ol0<ol001`co`02000023?o00@0000Coooo0P0002Ooool004Coool806Ko3_ooo`0306Ko
oooooooo01Ooool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00>_ooo`X0I_lFoooo00<0
I_ooooooool04oooo`@00013<ol00P0002hco`020000=oooo`00<Oooo`T0I_lPoooo00<0I_oooooo
ool03_ooo`D00017<ol000<0000co`0co`00;c?o00@0000coooo000Voooo2`1VobWoool00`1Voooo
ooooo`04oooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool001Koool@06Ko<?ooo`@00000
0`1Vo`00000000040000ES?o00030000<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000ooooooooo`2I0_oo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`0Moooo00<0003ooooo
ool07_ooo`040000ooooooooo`2I7?ooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0
003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo001Joooo00?o09Wooooo
ool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_oo
o`00F_ooo`03o`2Ioooooooo05[oool20000Ioooo`00F_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool005[oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool20000Ioooo`00F_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`030000
oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`80001Woooo001J
oooo00?o09Woooooool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0
003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o
09Woooooool0F_ooo`80001Woooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool0
05[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05;oool5
00000oooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Doooo00<0003oooooool00ooo
o`030000oooooooo06Koool005[oool00ol0VOooooooo`1Doooo00<0003oooooool00oooo`<0001V
oooo001Joooo00?o09Woooooool0E?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001J
oooo00?o09Woooooool0E?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Joooo00?o
09Woooooool0Doooo`800005oooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool2
0000Ioooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Wooooo
ool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_oo
o`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_oo
o`80001Woooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool005[oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1V
oooo001Joooo00?o09Woooooool0F_ooo`80001Woooo001Joooo00?o09Woooooool0F_ooo`030000
oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo
06Koool005[oool00ol0VOooooooo`1Joooo0P0006Ooool005[oool00ol0VOooooooo`1Joooo00<0
003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05;oool400001?ooo`030000oooooooo06Koool0
05[oool00ol0VOooooooo`1Boooo00<0003oooooool01Oooo`030000oooooooo06Koool005[oool0
0ol0VOooooooo`1Coooo00<0003oooooool01?ooo`<0001Voooo001Joooo00?o09Woooooool0E?oo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0D_ooo`040000
oooooooo00001?ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Coooo0P0000Goool0
0`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`80001Woooo001Joooo00?o09Wooooo
ool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_oo
o`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_oo
o`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo0P0006Ooool005[oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1V
oooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1J
oooo0P0006Ooool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo
06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo
05[oool20000Ioooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o
09Woooooool0Doooo`800005oooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05;oool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0E?ooo`030000
oooooooo00?oool30000I_ooo`00F_ooo`03o`2Ioooooooo05Goool00`000?ooooooo`02oooo00<0
003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo001Joooo00?o09Woooooool0Doooo`800005oooo00<0003oooooool0I_ooo`00F_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`80001W
oooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1J
oooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001J
oooo00?o09Woooooool0F_ooo`80001Woooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo
06Koool005[oool00ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo
05[oool00`000?ooooooo`1Voooo001Joooo00?o09Woooooool0F_ooo`030000oooooooo06Koool0
05[oool00ol0VOooooooo`1Joooo0P0006Ooool005[oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`1Voooo001Joooo00?o09Wooooo
ool0F_ooo`030000oooooooo06Koool005[oool00ol0VOooooooo`1Joooo0P0006Ooool005[oool0
0ol0VOooooooo`1Joooo00<0003oooooool0I_ooo`00F_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`1Voooo001Joooo00?o09Woooooool0E?ooo`<00003oooo00<0003oooooool0I_ooo`00F_oo
o`03o`2Ioooooooo05Goool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00F_ooo`03o`2I
oooooooo05;oool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0
003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool500000_ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?oo
ooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Soool300001?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:
oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.29205 .26487 L
.29779 .26487 L
.30059 .26487 L
.30182 .26487 L
.30246 .26487 L
.30316 .26487 L
s
.30316 .26487 m
.30366 .61803 L
s
0 .4 1 r
.02381 .26082 m
.06244 .25938 L
.10458 .25722 L
.14415 .25442 L
.18221 .25077 L
.22272 .2455 L
.26171 .23858 L
.28158 .23417 L
.29205 .23156 L
.29779 .23004 L
.30059 .22928 L
.30182 .22893 L
.30246 .22875 L
.30316 .22856 L
.30442 .26487 L
.3056 .26487 L
.30791 .26487 L
.31304 .26487 L
.32392 .26487 L
.34309 .26487 L
.38467 .26487 L
.42473 .26487 L
.46328 .26487 L
.50429 .26487 L
.54378 .26487 L
.58175 .26487 L
.62217 .26487 L
.66108 .26487 L
.70244 .26487 L
.74229 .26487 L
.78062 .26487 L
.8214 .26487 L
.86066 .26487 L
.89841 .26487 L
.93862 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool010000?ooo`1Vo`1Voa_oool010000?ooooooooooo`80000K<ol000<0000co`0c
o`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Oooo`@00003
oooo0P0001Ooool400000_ooo`040000oooooooo00005oooo`@000000oooo`1Vo`1Vo`0206Ko00<0
003oool0I_l05?ooo`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo02Goool001Soool00`000?oo
ooooo`0Moooo00<0003oool000006_ooo`80I_l01oooo`000?ooooooo`000?ooo`1Vo`0Joooo1000
01hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol000<co`0300005_oo
o`040000oooooooo00009_ooo`006?ooo`<0000Noooo0P0001Coool606Ko1?ooo`800002oooo00<0
I_ooooooool05_ooo`D0000N<ol00P0001`co`000`0003?o03?o000L<ol00P0000Pco`0400004ooo
o`80000Woooo0017oooo201Vo`koool00`1Vooooooooo`0Doooo0P00044co`000`0003?o03?o000Z
<ol00`0003Woool0047oool606Ko5_ooo`0306Kooooooooo013oool40000@c?o0080000^<ol00P00
03Ooool003[oool706Ko7?ooo`0306Kooooooooo00_oool50000Ac?o00030000<ol0<ol002lco`04
0000<oooo`009_oooa@0I_lSoooo00@0I_ooooooooooool:0000C3?o00030000<ol0<ol003<co`0:
0000:Oooo`005_oooa00I_l`oooo1`00000406Ko000000000000ES?o00030000<ol0<ol003dco`0?
00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0
003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`03oooo00?o09Woooooool05ooo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01koool00`000?ooooooo`0Uoooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool0
05goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool2
0000Ioooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Wooooo
ool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_oo
o`00GOooo`03o`2Ioooooooo05Ooool20000Ioooo`00GOooo`03o`2Ioooooooo05Ooool00`000?oo
ooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOoo
ooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1V
oooo001Moooo00?o09Woooooool0Eoooo`80001Woooo001Moooo00?o09Woooooool0Eoooo`030000
oooooooo06Koool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2I
oooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`80001Woooo001M
oooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo00<0
003oooooool0I_ooo`00GOooo`03o`2Ioooooooo04ooool500000oooo`030000oooooooo06Koool0
05goool00ol0VOooooooo`1Aoooo00<0003oooooool00oooo`030000oooooooo06Koool005goool0
0ol0VOooooooo`1Aoooo00<0003oooooool00oooo`<0001Voooo001Moooo00?o09Woooooool0DOoo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0DOooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0D?ooo`800005oooo00<0
003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool20000Ioooo`00GOooo`03o`2Ioooooooo
05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool0
05goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool0
0`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`80001Woooo001Moooo00?o09Wooooo
ool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_oo
o`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eooo
o`80001Woooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOoo
ooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1V
oooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1G
oooo0P0006Ooool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2I
oooooooo04ooool400001?ooo`030000oooooooo06Koool005goool00ol0VOooooooo`1?oooo00<0
003oooooool01Oooo`030000oooooooo06Koool005goool00ol0VOooooooo`1@oooo00<0003ooooo
ool01?ooo`<0001Voooo001Moooo00?o09Woooooool0DOooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo001Moooo00?o09Woooooool0Coooo`040000oooooooo00001?ooo`030000oooooooo
06Koool005goool00ol0VOooooooo`1@oooo0P0000Goool00`000?ooooooo`1Voooo001Moooo00?o
09Woooooool0Eoooo`80001Woooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool0
05goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool0
0`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool0
0ol0VOooooooo`1Goooo0P0006Ooool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_oo
o`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eooo
o`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo0P0006Ooool005goool00ol0VOoo
ooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1V
oooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1G
oooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool20000Ioooo`00GOooo`03o`2I
oooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0D?ooo`800005oooo00<0
003oooooool0I_ooo`00GOooo`03o`2Ioooooooo04ooool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo001Moooo00?o09Woooooool0DOooo`030000oooooooo00?oool30000I_ooo`00GOoo
o`03o`2Ioooooooo05;oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00GOooo`03o`2I
oooooooo04ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001Moooo00?o09Wooooo
ool0D?ooo`800005oooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?oo
ooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`80001Woooo001Moooo00?o09Woooooool0Eooo
o`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOoo
o`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`80001W
oooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1G
oooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001M
oooo00?o09Woooooool0Eoooo`030000oooooooo06Koool005goool00ol0VOooooooo`1Goooo0P00
06Ooool005goool00ol0VOooooooo`1Goooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo
05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Woooooool0Eoooo`030000oooooooo06Koool0
05goool00ol0VOooooooo`1Goooo0P0006Ooool005goool00ol0VOooooooo`1Goooo00<0003ooooo
ool0I_ooo`00GOooo`03o`2Ioooooooo05Ooool00`000?ooooooo`1Voooo001Moooo00?o09Wooooo
ool0DOooo`<00003oooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`02oooo00<0003oooooool0I_ooo`00GOooo`03o`2Ioooooooo04ooool500000oooo`<0001V
oooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.29205 .26487 L
.30316 .26487 L
.30791 .26487 L
.31054 .26487 L
.31304 .26487 L
.31444 .26487 L
.31523 .26487 L
s
.31523 .26487 m
.31553 .61803 L
s
0 .4 1 r
.02381 .26123 m
.06244 .25993 L
.10458 .25799 L
.14415 .25547 L
.18221 .2522 L
.22272 .24745 L
.26171 .24123 L
.28158 .23726 L
.29205 .23492 L
.30316 .23222 L
.30791 .23099 L
.31054 .2303 L
.31304 .22962 L
.31444 .22924 L
.31523 .22902 L
.31597 .26487 L
.31727 .26487 L
.31865 .26487 L
.32392 .26487 L
.34309 .26487 L
.38467 .26487 L
.42473 .26487 L
.46328 .26487 L
.50429 .26487 L
.54378 .26487 L
.58175 .26487 L
.62217 .26487 L
.66108 .26487 L
.70244 .26487 L
.74229 .26487 L
.78062 .26487 L
.8214 .26487 L
.86066 .26487 L
.89841 .26487 L
.93862 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`02oooo0P1VoaSoool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00005oooo`@00005oooo00H00000I_l0
I_l0I_ooool0I_lAoooo100000Coool300005C?o00@00004<ol000<0000co`0co`006S?o00030000
<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Oooo`006?ooo`030000
oooooooo01goool00`000?ooo`00000Koooo0P1Vo`04000006Ko06Ko00001?ooo`0306Kooooooooo
01Goool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0000co`0co`000c?o
00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`0001koool200005_ooo`D0I_l3oooo0P00
00Goool00`1Vooooooooo`0Coooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool004coool506Ko3oooo`0306Kooooooooo017oool20000@C?o00030000
<ol0<ol002Xco`030000>Oooo`00A?ooo`P0I_lDoooo00<0I_ooooooool03Oooo`@00013<ol00P00
02hco`020000=oooo`00>_ooo`X0I_lLoooo00<0I_ooooooool02?ooo`D00017<ol000<0000co`0c
o`00;c?o00@0000coooo000Voooo501VobKoool00`1Vo`00000000080000C3?o00030000<ol0<ol0
03<co`0:0000:Oooo`005_oooa00I_l`oooo2P00000306Ko<ol0<ol005@co`000`0003?o03?o000m
<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00@0003ooooooooo09T3oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000F
oooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`06oooo00?o09Wooooo
ool05?ooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000
oooooooo01koool00`000?ooooooo`0Uoooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo
06Koool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo
05Coool20000Ioooo`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o
09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1Doooo00<0003ooooo
ool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool20000Ioooo`00H?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool0
0ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`80001Woooo001Poooo00?o09Woooooool0E?oo
o`030000oooooooo06Koool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`80001W
oooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1D
oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo04coool500000oooo`030000oooooooo
06Koool0063oool00ol0VOooooooo`1>oooo00<0003oooooool00oooo`030000oooooooo06Koool0
063oool00ol0VOooooooo`1>oooo00<0003oooooool00oooo`<0001Voooo001Poooo00?o09Wooooo
ool0C_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0C_oo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0COooo`800005
oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool20000Ioooo`00H?ooo`03o`2I
oooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo
06Koool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`80001Woooo001Poooo00?o
09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1Doooo00<0003ooooo
ool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Wooooo
ool0E?ooo`80001Woooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool0
0ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOoo
ooooo`1Doooo0P0006Ooool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?oo
o`03o`2Ioooooooo04coool400001?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1<
oooo00<0003oooooool01Oooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1=oooo00<0
003oooooool01?ooo`<0001Voooo001Poooo00?o09Woooooool0C_ooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo001Poooo00?o09Woooooool0C?ooo`040000oooooooo00001?ooo`030000
oooooooo06Koool0063oool00ol0VOooooooo`1=oooo0P0000Goool00`000?ooooooo`1Voooo001P
oooo00?o09Woooooool0E?ooo`80001Woooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo
06Koool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0
063oool00ol0VOooooooo`1Doooo0P0006Ooool0063oool00ol0VOooooooo`1Doooo00<0003ooooo
ool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Wooooo
ool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1Doooo0P0006Ooool0063oool0
0ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOoo
ooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool20000Ioooo`00H?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0COooo`800005
oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo04coool010000?ooooooo`0000Coool0
0`000?ooooooo`1Voooo001Poooo00?o09Woooooool0C_ooo`030000oooooooo00?oool30000I_oo
o`00H?ooo`03o`2Ioooooooo04ooool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00H?oo
o`03o`2Ioooooooo04coool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001Poooo00?o
09Woooooool0COooo`800005oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`80001Woooo001Poooo00?o09Wooooo
ool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_oo
o`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?oo
o`80001Woooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOoo
ooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1V
oooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo06Koool0063oool00ol0VOooooooo`1D
oooo0P0006Ooool0063oool00ol0VOooooooo`1Doooo00<0003oooooool0I_ooo`00H?ooo`03o`2I
oooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o09Woooooool0E?ooo`030000oooooooo
06Koool0063oool00ol0VOooooooo`1Doooo0P0006Ooool0063oool00ol0VOooooooo`1Doooo00<0
003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`1Voooo001Poooo00?o
09Woooooool0C_ooo`<00003oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo04ooool0
0`000?ooooooo`02oooo00<0003oooooool0I_ooo`00H?ooo`03o`2Ioooooooo04coool500000ooo
o`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Ooo
o`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800005
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0001Coool00`000?ooooooo`0:oooo00D0003oooooooooool00000N_oo
o`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002Oooo`@00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.30316 .26487 L
.31323 .26487 L
.31875 .26487 L
.32392 .26487 L
.32617 .26487 L
.32728 .26487 L
.32831 .26487 L
s
.32831 .26487 m
.32878 .61803 L
s
0 .4 1 r
.02381 .2616 m
.06244 .26044 L
.10458 .25869 L
.14415 .25643 L
.18221 .25349 L
.22272 .24923 L
.26171 .24364 L
.28158 .24008 L
.30316 .23555 L
.31323 .23317 L
.31875 .23179 L
.32392 .23044 L
.32617 .22984 L
.32728 .22954 L
.32831 .22926 L
.32949 .26487 L
.33078 .26487 L
.33304 .26487 L
.34309 .26487 L
.38221 .26487 L
.4238 .26487 L
.46386 .26487 L
.50241 .26487 L
.54342 .26487 L
.5829 .26487 L
.62088 .26487 L
.6613 .26487 L
.70021 .26487 L
.74157 .26487 L
.78142 .26487 L
.81975 .26487 L
.86053 .26487 L
.89979 .26487 L
.93754 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`05oooo0P1VoaGoool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00005oooo`@00005oooo00@0003ooooo
ooooool306Ko00?oool0I_ooool03Oooo`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol0
01Xco`000`0003?o03?o000M<ol000@0000co`0co`0co`0200006oooo`030000oooooooo02Goool0
01Soool00`000?ooooooo`0Moooo00<0003oool000007Oooo`040000oooooooo00000`1Vo`Coool0
0`1Vooooooooo`0Boooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000
<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Noooo0P0001_oool3
06Ko0P0000Soool00`1Vooooooooo`0@oooo1@0001hco`02000073?o00030000<ol0<ol001`co`02
000023?o00@0000Coooo0P0002Ooool004ooool706Ko3Oooo`0306Kooooooooo00koool20000@C?o
00030000<ol0<ol002Xco`030000>Oooo`00A?ooo`/0I_lEoooo00<0I_ooooooool02Oooo`@00013
<ol00P0002hco`020000=oooo`00>_ooo`X0I_lPoooo00<0I_ooooooool01?ooo`D00017<ol000<0
000co`0co`00;c?o00@0000coooo000aoooo2@1VobOoool3000000<0I_l000000000100004`co`00
0`0003?o03?o000c<ol02P0002Woool001KooolK06Ko9Oooo`/00003<ol000<0I_lco`0co`00D3?o
00030000<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00?o
09T0003oool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`09
oooo00?o09Woooooool04Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003ooooo
ool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo001Soooo00?o09Woooooool0DOoo
o`030000oooooooo06Koool006?oool00ol0VOooooooo`1Aoooo00<0003oooooool0I_ooo`00Hooo
o`03o`2Ioooooooo057oool20000Ioooo`00Hoooo`03o`2Ioooooooo057oool00`000?ooooooo`1V
oooo001Soooo00?o09Woooooool0DOooo`030000oooooooo06Koool006?oool00ol0VOooooooo`1A
oooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo057oool20000Ioooo`00Hoooo`03o`2I
oooooooo057oool00`000?ooooooo`1Voooo001Soooo00?o09Woooooool0DOooo`030000oooooooo
06Koool006?oool00ol0VOooooooo`1Aoooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo
057oool00`000?ooooooo`1Voooo001Soooo00?o09Woooooool0DOooo`80001Woooo001Soooo00?o
09Woooooool0DOooo`030000oooooooo06Koool006?oool00ol0VOooooooo`1Aoooo00<0003ooooo
ool0I_ooo`00Hoooo`03o`2Ioooooooo057oool00`000?ooooooo`1Voooo001Soooo00?o09Wooooo
ool0DOooo`80001Woooo001Soooo00?o09Woooooool0DOooo`030000oooooooo06Koool006?oool0
0ol0VOooooooo`1Aoooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo04Woool500000ooo
o`030000oooooooo06Koool006?oool00ol0VOooooooo`1;oooo00<0003oooooool00oooo`030000
oooooooo06Koool006?oool00ol0VOooooooo`1;oooo00<0003oooooool00oooo`<0001Voooo001S
oooo00?o09Woooooool0Boooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Soooo00?o
09Woooooool0Boooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Soooo00?o09Wooooo
ool0B_ooo`800005oooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo057oool20000Iooo
o`00Hoooo`03o`2Ioooooooo057oool00`000?ooooooo`1Voooo001Soooo00?o09Woooooool0DOoo
o`030000oooooooo06Koool006?oool00ol0VOooooooo`1Aoooo00<0003oooooool0I_ooo`00Hooo
o`03o`2Ioooooooo057oool00`000?ooooooo`1Voooo001Soooo00?o09Woooooool0DOooo`80001W
oooo001Soooo00?o09Woooooool0DOooo`030000oooooooo06Koool006?oool00ol0VOooooooo`1A
oooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo057oool00`000?ooooooo`1Voooo001S
oooo00?o09Woooooool0DOooo`80001Woooo001Soooo00?o09Woooooool0DOooo`030000oooooooo
06Koool006?oool00ol0VOooooooo`1Aoooo00<0003oooooool0I_ooo`00Hoooo`03o`2Ioooooooo
057oool00`000?ooooooo`1Voooo001Soooo00?o09Woooooool0DOooo`030000oooooooo06Koool0
06?oool00ol0VOooooooo`1Aoooo0P0006Ooool006?oool00ol0VOooooooo`1Aoooo00<0003ooooo
ool0I_ooo`00Hoooo`03o`2Ioooooooo04Woool400001?ooo`030000oooooooo06Koool006?oool0
0ol0VOooooooo`19oooo00<0003oooooool01Oooo`030000oooooooo06Koool006?oool00ol0VOoo
ooooo`1:oooo00<0003oooooool01?ooo`<0001Voooo001Toooo00?o09Woooooool0B_ooo`030000
oooooooo00?oool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0B?ooo`040000oooooooo
00001?ooo`030000oooooooo06Koool006Coool00ol0VOooooooo`19oooo0P0000Goool00`000?oo
ooooo`1Voooo001Toooo00?o09Woooooool0D?ooo`80001Woooo001Toooo00?o09Woooooool0D?oo
o`030000oooooooo06Koool006Coool00ol0VOooooooo`1@oooo00<0003oooooool0I_ooo`00I?oo
o`03o`2Ioooooooo053oool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0D?ooo`030000
oooooooo06Koool006Coool00ol0VOooooooo`1@oooo0P0006Ooool006Coool00ol0VOooooooo`1@
oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo053oool00`000?ooooooo`1Voooo001T
oooo00?o09Woooooool0D?ooo`030000oooooooo06Koool006Coool00ol0VOooooooo`1@oooo0P00
06Ooool006Coool00ol0VOooooooo`1@oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo
053oool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0D?ooo`030000oooooooo06Koool0
06Coool00ol0VOooooooo`1@oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo053oool2
0000Ioooo`00I?ooo`03o`2Ioooooooo053oool00`000?ooooooo`1Voooo001Toooo00?o09Wooooo
ool0BOooo`800005oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo04Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0B_ooo`030000oooooooo
00?oool30000I_ooo`00I?ooo`03o`2Ioooooooo04_oool00`000?ooooooo`02oooo00<0003ooooo
ool0I_ooo`00I?ooo`03o`2Ioooooooo04Soool010000?ooooooo`0000Coool00`000?ooooooo`1V
oooo001Toooo00?o09Woooooool0BOooo`800005oooo00<0003oooooool0I_ooo`00I?ooo`03o`2I
oooooooo053oool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0D?ooo`80001Woooo001T
oooo00?o09Woooooool0D?ooo`030000oooooooo06Koool006Coool00ol0VOooooooo`1@oooo00<0
003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo053oool00`000?ooooooo`1Voooo001Toooo00?o
09Woooooool0D?ooo`80001Woooo001Toooo00?o09Woooooool0D?ooo`030000oooooooo06Koool0
06Coool00ol0VOooooooo`1@oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`1Voooo001Toooo00?o09Woooooool0D?ooo`030000oooooooo06Koool006Coool0
0ol0VOooooooo`1@oooo0P0006Ooool006Coool00ol0VOooooooo`1@oooo00<0003oooooool0I_oo
o`00I?ooo`03o`2Ioooooooo053oool00`000?ooooooo`1Voooo001Toooo00?o09Woooooool0D?oo
o`030000oooooooo06Koool006Coool00ol0VOooooooo`1@oooo0P0006Ooool006Coool00ol0VOoo
ooooo`1@oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo053oool00`000?ooooooo`1V
oooo001Toooo00?o09Woooooool0B_ooo`<00003oooo00<0003oooooool0I_ooo`00I?ooo`03o`2I
oooooooo04_oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00I?ooo`03o`2Ioooooooo
04Soool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool0
0000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool5
00000_ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool300001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.30316 .26487 L
.31323 .26487 L
.32392 .26487 L
.33304 .26487 L
.33554 .26487 L
.33823 .26487 L
.33953 .26487 L
.34076 .26487 L
s
.34076 .26487 m
.34121 .61803 L
s
0 .4 1 r
.02381 .26194 m
.06244 .2609 L
.10458 .25933 L
.14415 .25731 L
.18221 .25467 L
.22272 .25085 L
.26171 .24584 L
.28158 .24265 L
.30316 .23859 L
.31323 .23646 L
.32392 .23401 L
.33304 .23177 L
.33554 .23112 L
.33823 .23042 L
.33953 .23007 L
.34076 .22974 L
.34187 .26487 L
.34309 .26487 L
.38373 .26487 L
.42286 .26487 L
.46444 .26487 L
.50451 .26487 L
.54306 .26487 L
.58406 .26487 L
.62355 .26487 L
.66152 .26487 L
.70195 .26487 L
.74085 .26487 L
.78222 .26487 L
.82206 .26487 L
.86039 .26487 L
.90117 .26487 L
.94044 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`09oooo0P1Voa7oool010000?ooooooooooo`80000K<ol000<0
000co`0co`006S?o0080000N<ol000@0000co`000000000Loooo00<0003oooooool09_ooo`004Ooo
o`@00003oooo0P0001Ooool400000_ooo`040000oooooooo00005oooo`@00005oooo00<0003ooooo
ool01?ooo`@0I_l00oooo`1Vooooo`09oooo100000Coool300005C?o00@00004<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Ooo
o`006?ooo`030000oooooooo01goool00`000?ooo`00000Moooo00@0003oooooool00003oooo0`1V
o`Goool00`1Vooooooooo`0>oooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o
00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Noooo0P00
01koool20000101Vo`Soool00`1Vooooooooo`0<oooo1@0001hco`02000073?o00030000<ol0<ol0
01`co`02000023?o00@0000Coooo0P0002Ooool0057oool:06Ko3?ooo`0306Kooooooooo00[oool2
0000@C?o00030000<ol0<ol002Xco`030000>Oooo`00C?ooo`D0I_lFoooo00<0I_ooooooool01_oo
o`@00013<ol00P0002hco`020000=oooo`00A?ooo`P0I_lKoooo00@0I_ooooooooooool50000Ac?o
00030000<ol0<ol002lco`040000<oooo`00<Ooooa<0I_lMoooo1P00000406Ko000000000000C3?o
00030000<ol0<ol003<co`0:0000:Oooo`005_oooa/0I_lUoooo2`0000Hco`000`1Voc?o03?o001=
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
10000?ooooooool0V@;oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo00goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00Ioooo`03o`2Ioooooooo
04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool0
06Ooool00ol0VOooooooo`1=oooo0P0006Ooool006Ooool00ol0VOooooooo`1=oooo00<0003ooooo
ool0I_ooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001Woooo00?o09Wooooo
ool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo0P0006Ooool006Ooool0
0ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool00`000?oo
ooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOoo
ooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool20000Ioooo`00Iooo
o`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000
oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2I
oooooooo04goool20000Ioooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001W
oooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`15oooo1@00
00?oool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0Aoooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo001Woooo00?o09Woooooool0Aoooo`030000oooooooo00?oool30000I_oo
o`00Ioooo`03o`2Ioooooooo04Ooool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Iooo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Ioooo`03o`2I
oooooooo04Koool200001Oooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo0P00
06Ooool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo
04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool0
06Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool2
0000Ioooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001Woooo00?o09Wooooo
ool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_oo
o`00Ioooo`03o`2Ioooooooo04goool20000Ioooo`00Ioooo`03o`2Ioooooooo04goool00`000?oo
ooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOoo
ooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1V
oooo001Woooo00?o09Woooooool0COooo`80001Woooo001Woooo00?o09Woooooool0COooo`030000
oooooooo06Koool006Ooool00ol0VOooooooo`15oooo100000Coool00`000?ooooooo`1Voooo001W
oooo00?o09Woooooool0AOooo`030000oooooooo00Goool00`000?ooooooo`1Voooo001Woooo00?o
09Woooooool0A_ooo`030000oooooooo00Coool30000I_ooo`00Ioooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04Goool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0A_ooo`800005oooo00<0
003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool20000Ioooo`00Ioooo`03o`2Ioooooooo
04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool0
06Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool0
0`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`80001Woooo001Woooo00?o09Wooooo
ool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_oo
o`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COoo
o`80001Woooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOoo
ooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1V
oooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=
oooo0P0006Ooool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2I
oooooooo04Koool200001Oooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`15oooo00@0
003oooooool00004oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`03oooo0`0006Koool006Ooool00ol0VOooooooo`18oooo00<0003oooooool00_ooo`030000
oooooooo06Koool006Ooool00ol0VOooooooo`15oooo00@0003oooooool00004oooo00<0003ooooo
ool0I_ooo`00Ioooo`03o`2Ioooooooo04Koool200001Oooo`030000oooooooo06Koool006Ooool0
0ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool20000Iooo
o`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COoo
o`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Iooo
o`03o`2Ioooooooo04goool20000Ioooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1V
oooo001Woooo00?o09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=
oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo04goool00`000?ooooooo`1Voooo001W
oooo00?o09Woooooool0COooo`80001Woooo001Woooo00?o09Woooooool0COooo`030000oooooooo
06Koool006Ooool00ol0VOooooooo`1=oooo00<0003oooooool0I_ooo`00Ioooo`03o`2Ioooooooo
04goool00`000?ooooooo`1Voooo001Woooo00?o09Woooooool0COooo`80001Woooo001Woooo00?o
09Woooooool0COooo`030000oooooooo06Koool006Ooool00ol0VOooooooo`1=oooo00<0003ooooo
ool0I_ooo`00Ioooo`03o`2Ioooooooo04Ooool300000oooo`030000oooooooo06Koool006Ooool0
0ol0VOooooooo`18oooo00<0003oooooool00_ooo`030000oooooooo06Koool006Ooool00ol0VOoo
ooooo`15oooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000
oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<
oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.32392 .26487 L
.33304 .26487 L
.34309 .26487 L
.34772 .26487 L
.35028 .26487 L
.35154 .26487 L
.35271 .26487 L
.3538 .26487 L
s
.3538 .26487 m
.35427 .61803 L
s
0 .4 1 r
.02381 .26225 m
.06244 .26132 L
.10458 .25992 L
.14415 .25811 L
.18221 .25575 L
.22272 .25233 L
.26171 .24785 L
.30316 .24137 L
.32392 .23727 L
.33304 .23526 L
.34309 .23289 L
.34772 .23173 L
.35028 .23108 L
.35154 .23075 L
.35271 .23045 L
.3538 .23016 L
.35496 .26487 L
.35625 .26487 L
.35742 .26487 L
.36173 .26487 L
.3815 .26487 L
.42157 .26487 L
.46012 .26487 L
.50112 .26487 L
.54061 .26487 L
.57858 .26487 L
.619 .26487 L
.65791 .26487 L
.69927 .26487 L
.73912 .26487 L
.77745 .26487 L
.81823 .26487 L
.8575 .26487 L
.89525 .26487 L
.93545 .26487 L
.97414 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0=oooo00<0I_ooooooool03?ooo`040000oooooooooooo0P00
01/co`000`0003?o03?o000J<ol00P0001hco`00100003?o0000000001coool00`000?ooooooo`0V
oooo000Aoooo100000?oool200005oooo`@00002oooo00@0003oooooool0000Goooo100000Goool0
0`000?ooooooo`09oooo101Vo`Ooool400001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J
<ol000<0000co`0co`007C?o00040000<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000H
oooo00<0003oooooool07Oooo`030000oooo000001goool010000?ooooooo`0000Coool706Ko0ooo
o`0306Kooooooooo00_oool400007S?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0
000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`0001koool200007_oo
o`80000506Ko2_ooo`0306Kooooooooo00Woool500007S?o0080000L<ol000<0000co`0co`0073?o
00800008<ol0100001?oool200009oooo`00E_ooo`D0I_l?oooo00<0I_ooooooool01oooo`800011
<ol000<0000co`0co`00:S?o00<0000ioooo001?oooo1`1VoaCoool00`1Vooooooooo`03oooo1000
04<co`020000;S?o0080000goooo0014oooo2`1Voa_oool00`1Vo`00000000030000Ac?o00030000
<ol0<ol002lco`040000<oooo`00>_ooo`X0I_lMoooo2@00000306Ko<ol0<ol004Xco`000`0003?o
03?o000c<ol02P0002Woool001cooolN06Ko7?ooo`/00009<ol000<0I_lco`0co`00BS?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0@oooo00?o
09Woooooool02_ooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Ooo
o`030000oooooooo01koool00`000?ooooooo`0Uoooo001Zoooo00?o09Woooooool0B_ooo`030000
oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2I
oooooooo04[oool20000Ioooo`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Z
oooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0
003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool20000Ioooo`00J_ooo`03o`2Ioooooooo
04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool0
06[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`80001Woooo001Zoooo00?o09Wooooo
ool0B_ooo`030000oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_oo
o`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_oo
o`80001Woooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOoo
ooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04;oool500000oooo`030000
oooooooo06Koool006[oool00ol0VOooooooo`14oooo00<0003oooooool00oooo`030000oooooooo
06Koool006[oool00ol0VOooooooo`14oooo00<0003oooooool00oooo`<0001Voooo001Zoooo00?o
09Woooooool0A?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Zoooo00?o09Wooooo
ool0A?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0@ooo
o`800005oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool20000Ioooo`00J_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000
oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`80001Woooo001Z
oooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0
003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o
09Woooooool0B_ooo`80001Woooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool0
06[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool0
0ol0VOooooooo`1:oooo0P0006Ooool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_oo
o`00J_ooo`03o`2Ioooooooo04;oool400001?ooo`030000oooooooo06Koool006[oool00ol0VOoo
ooooo`12oooo00<0003oooooool01Oooo`030000oooooooo06Koool006[oool00ol0VOooooooo`13
oooo00<0003oooooool01?ooo`<0001Voooo001Zoooo00?o09Woooooool0A?ooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0@_ooo`040000oooooooo00001?oo
o`030000oooooooo06Koool006[oool00ol0VOooooooo`13oooo0P0000Goool00`000?ooooooo`1V
oooo001Zoooo00?o09Woooooool0B_ooo`80001Woooo001Zoooo00?o09Woooooool0B_ooo`030000
oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo
06Koool006[oool00ol0VOooooooo`1:oooo0P0006Ooool006[oool00ol0VOooooooo`1:oooo00<0
003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o
09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOooooooo`1:oooo0P0006Ooool0
06[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool0
0ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool20000Iooo
o`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0@ooo
o`800005oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04;oool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0A?ooo`030000oooooooo00?oool3
0000I_ooo`00J_ooo`03o`2Ioooooooo04Goool00`000?ooooooo`02oooo00<0003oooooool0I_oo
o`00J_ooo`03o`2Ioooooooo04;oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo001Z
oooo00?o09Woooooool0@oooo`800005oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo
04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`80001Woooo001Zoooo00?o
09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Wooooo
ool0B_ooo`80001Woooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool0
0ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000oooooooo06Koool006[oool00ol0VOoo
ooooo`1:oooo0P0006Ooool006[oool00ol0VOooooooo`1:oooo00<0003oooooool0I_ooo`00J_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Zoooo00?o09Woooooool0B_ooo`030000
oooooooo06Koool006[oool00ol0VOooooooo`1:oooo0P0006Ooool006[oool00ol0VOooooooo`1:
oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`1Voooo001Z
oooo00?o09Woooooool0A?ooo`<00003oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo
04Goool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00J_ooo`03o`2Ioooooooo04;oool5
00000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOoo
o`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_oo
o`800005oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`0:oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0
003oooooool01oooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000D
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooo000000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.32392 .26487 L
.34309 .26487 L
.35271 .26487 L
.36173 .26487 L
.36405 .26487 L
.3652 .26487 L
.36626 .26487 L
s
.36626 .26487 m
.36675 .61803 L
s
0 .4 1 r
.02381 .26253 m
.06244 .2617 L
.10458 .26045 L
.14415 .25884 L
.18221 .25673 L
.22272 .25369 L
.26171 .24969 L
.30316 .24391 L
.32392 .24026 L
.34309 .23635 L
.35271 .23417 L
.36173 .23199 L
.36405 .23141 L
.3652 .23111 L
.36626 .23084 L
.36748 .26487 L
.36812 .26487 L
.36881 .26487 L
.37114 .26487 L
.3815 .26487 L
.42308 .26487 L
.46315 .26487 L
.5017 .26487 L
.5427 .26487 L
.58219 .26487 L
.62016 .26487 L
.66059 .26487 L
.69949 .26487 L
.74085 .26487 L
.7807 .26487 L
.81903 .26487 L
.85981 .26487 L
.89908 .26487 L
.93683 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo00_oool5
06Ko1?ooo`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol001Xco`000`0003?o03?o000M
<ol000@0000co`0co`0co`0200006oooo`030000oooooooo02Goool001Soool00`000?ooooooo`0M
oooo00<0003oool000007Oooo`040000oooooooo00002Oooo`@0I_l4oooo00<0I_ooooooool02?oo
o`@0000N<ol000<0000co`0co`006S?o00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`00
01Koool010000?ooooooo`0002Koool001Soool300007_ooo`80000Noooo0P0000Goool506Ko2?oo
o`0306Kooooooooo00Koool500007S?o0080000L<ol000<0000co`0co`0073?o00800008<ol01000
01?oool200009oooo`00FOooo`L0I_l=oooo00<0I_ooooooool01?ooo`800011<ol000<0000co`0c
o`00:S?o00<0000ioooo001?oooo2P1VoaCoool00`1Vooooooooo`040000@c?o0080000^<ol00P00
03Ooool004Coool;06Ko7?ooo`8000000`1Vo`0000000017<ol000<0000co`0co`00;c?o00@0000c
oooo000joooo2P1Voagoool:00000S?o000306Ko<ol0<ol004Lco`000`0003?o03?o000c<ol02P00
02Woool001cooolN06Ko7?ooo`/0000<<ol000<0I_lco`0co`00Ac?o00030000<ol0<ol003dco`0?
00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`040000
ooooooooo`2I0_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo01;oool001Koool0
0`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo01?oool00ol0VOooooooo`07
oooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003ooooo
ool07_ooo`030000oooooooo02Goool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_oo
o`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aooo
o`80001Woooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOoo
ooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1V
oooo001]oooo00?o09Woooooool0Aoooo`80001Woooo001]oooo00?o09Woooooool0Aoooo`030000
oooooooo06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo
06Koool006goool00ol0VOooooooo`17oooo0P0006Ooool006goool00ol0VOooooooo`17oooo00<0
003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o
09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo0P0006Ooool0
06goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`1Voooo001]oooo00?o09Woooooool0?oooo`D00003oooo00<0003oooooool0I_oo
o`00KOooo`03o`2Ioooooooo047oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00KOoo
o`03o`2Ioooooooo047oool00`000?ooooooo`03oooo0`0006Koool006goool00ol0VOooooooo`11
oooo00<0003oooooool00oooo`030000oooooooo06Koool006goool00ol0VOooooooo`11oooo00<0
003oooooool00oooo`030000oooooooo06Koool006goool00ol0VOooooooo`10oooo0P0000Goool0
0`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`80001Woooo001]oooo00?o09Wooooo
ool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_oo
o`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aooo
o`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo0P0006Ooool006goool00ol0VOoo
ooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1V
oooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17
oooo0P0006Ooool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo
06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo
04Ooool20000Ioooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o
09Woooooool0?oooo`@00004oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`05oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo043oool00`000?oo
ooooo`04oooo0`0006Koool006goool00ol0VOooooooo`11oooo00<0003oooooool00oooo`030000
oooooooo06Koool006goool00ol0VOooooooo`0ooooo00@0003oooooool00004oooo00<0003ooooo
ool0I_ooo`00KOooo`03o`2Ioooooooo043oool200001Oooo`030000oooooooo06Koool006goool0
0ol0VOooooooo`17oooo0P0006Ooool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_oo
o`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aooo
o`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOoo
o`03o`2Ioooooooo04Ooool20000Ioooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1V
oooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17
oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool20000Ioooo`00KOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo
06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`80001Woooo001]oooo00?o
09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`10oooo0P0000Goool0
0`000?ooooooo`1Voooo001]oooo00?o09Woooooool0?oooo`040000oooooooo00001?ooo`030000
oooooooo06Koool006goool00ol0VOooooooo`11oooo00<0003oooooool00oooo`<0001Voooo001]
oooo00?o09Woooooool0@_ooo`030000oooooooo00;oool00`000?ooooooo`1Voooo001]oooo00?o
09Woooooool0?oooo`040000oooooooo00001?ooo`030000oooooooo06Koool006goool00ol0VOoo
ooooo`10oooo0P0000Goool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000
oooooooo06Koool006goool00ol0VOooooooo`17oooo0P0006Ooool006goool00ol0VOooooooo`17
oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]
oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo0P00
06Ooool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool0
06goool00ol0VOooooooo`17oooo00<0003oooooool0I_ooo`00KOooo`03o`2Ioooooooo04Ooool2
0000Ioooo`00KOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1Voooo001]oooo00?o09Wooooo
ool0Aoooo`030000oooooooo06Koool006goool00ol0VOooooooo`17oooo00<0003oooooool0I_oo
o`00KOooo`03o`2Ioooooooo04Ooool20000Ioooo`00KOooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`1Voooo001]oooo00?o09Woooooool0Aoooo`030000oooooooo06Koool006goool00ol0VOoo
ooooo`11oooo0`0000?oool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0@_ooo`030000
oooooooo00;oool00`000?ooooooo`1Voooo001]oooo00?o09Woooooool0?oooo`D00003oooo0`00
06Koool00:ooool010000?ooooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P00
06goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.32392 .26487 L
.34309 .26487 L
.36173 .26487 L
.37114 .26487 L
.37372 .26487 L
.37649 .26487 L
.37783 .26487 L
.3791 .26487 L
s
.3791 .26487 m
.37956 .61803 L
s
0 .4 1 r
.02381 .26279 m
.06244 .26205 L
.10458 .26094 L
.14415 .25951 L
.18221 .25764 L
.22272 .25493 L
.26171 .25138 L
.30316 .24624 L
.32392 .24299 L
.34309 .23952 L
.36173 .23565 L
.37114 .23349 L
.37372 .23288 L
.37649 .2322 L
.37783 .23187 L
.3791 .23155 L
.38025 .26487 L
.3815 .26487 L
.42214 .26487 L
.46127 .26487 L
.50286 .26487 L
.54292 .26487 L
.58147 .26487 L
.62248 .26487 L
.66196 .26487 L
.69994 .26487 L
.74036 .26487 L
.77927 .26487 L
.82063 .26487 L
.86048 .26487 L
.8988 .26487 L
.93959 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo013oool3
06Ko00?oool0000000000P0000Coool300005C?o00@00004<ol000<0000co`0co`006S?o00030000
<ol0<ol001dco`00100003?o03?o03?o0080000Koooo00<0003oooooool09Oooo`006?ooo`030000
oooooooo01goool00`000?ooo`00000Moooo00@0003oooooool0000>oooo101Vo`;oool00`1Voooo
ooooo`05oooo100001hco`000`0003?o03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol0
00<co`0300005_ooo`040000oooooooo00009_ooo`006?ooo`<0000Noooo0P0001koool200002_oo
o`D0I_l6oooo00<0I_ooooooool00oooo`D0000N<ol00P0001`co`000`0003?o03?o000L<ol00P00
00Pco`0400004oooo`80000Woooo001Koooo2P1Vo`_oool0101Vooooooooooooo`800011<ol000<0
000co`0co`00:S?o00<0000ioooo001Foooo1@1VoaGoool0101Vo`000000000004<co`020000;S?o
0080000goooo001?oooo1`1VoaGoool5000000<co`00I_lco`00A3?o00030000<ol0<ol002lco`04
0000<oooo`00>_oooaD0I_lBoooo2P0000Hco`000`1Voc?o03?o0013<ol000<0000co`0co`00<c?o
00X0000Yoooo000Voooo501Voacoool;000043?o000306Ko<ol0<ol004<co`000`0003?o03?o000m
<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool04_ooo`005_oo
o`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`03o`2Ioooooooo
00Coool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Noooo00<0003oooooool09Oooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1V
oooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14
oooo0P0006Ooool0073oool00ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2I
oooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo
06Koool0073oool00ol0VOooooooo`14oooo0P0006Ooool0073oool00ol0VOooooooo`14oooo00<0
003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o
09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0003ooooo
ool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool20000Ioooo`00L?ooo`03o`2Ioooooooo04Coool0
0`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool0
0ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool20000Iooo
o`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?oo
o`030000oooooooo06Koool0073oool00ol0VOooooooo`0loooo1@0000?oool00`000?ooooooo`1V
oooo001`oooo00?o09Woooooool0?_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo001`
oooo00?o09Woooooool0?_ooo`030000oooooooo00?oool30000I_ooo`00L?ooo`03o`2Ioooooooo
03koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo03koool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo03goool200001Ooo
o`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo0P0006Ooool0073oool00ol0VOoo
ooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1V
oooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14
oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool20000Ioooo`00L?ooo`03o`2I
oooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo
06Koool0073oool00ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo
04Coool20000Ioooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o
09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0003ooooo
ool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Wooooo
ool0A?ooo`80001Woooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool0
0ol0VOooooooo`0loooo100000Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0??oo
o`030000oooooooo00Goool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0?Oooo`030000
oooooooo00Coool30000I_ooo`00L?ooo`03o`2Ioooooooo03koool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo03coool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo001`oooo00?o09Woooooool0?Oooo`800005oooo00<0003oooooool0I_ooo`00L?oo
o`03o`2Ioooooooo04Coool20000Ioooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1V
oooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14
oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`
oooo00?o09Woooooool0A?ooo`80001Woooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo
06Koool0073oool00ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo
04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?ooo`80001Woooo001`oooo00?o
09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0003ooooo
ool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Wooooo
ool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo0P0006Ooool0073oool0
0ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo03goool200001Ooo
o`030000oooooooo06Koool0073oool00ol0VOooooooo`0loooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo03koool00`000?ooooooo`03oooo0`0006Koool0
073oool00ol0VOooooooo`0ooooo00<0003oooooool00_ooo`030000oooooooo06Koool0073oool0
0ol0VOooooooo`0loooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00L?ooo`03o`2I
oooooooo03goool200001Oooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0
003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool20000Ioooo`00L?ooo`03o`2Ioooooooo
04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0
073oool00ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool2
0000Ioooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Wooooo
ool0A?ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0003oooooool0I_oo
o`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1Voooo001`oooo00?o09Woooooool0A?oo
o`80001Woooo001`oooo00?o09Woooooool0A?ooo`030000oooooooo06Koool0073oool00ol0VOoo
ooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`1V
oooo001`oooo00?o09Woooooool0A?ooo`80001Woooo001`oooo00?o09Woooooool0A?ooo`030000
oooooooo06Koool0073oool00ol0VOooooooo`14oooo00<0003oooooool0I_ooo`00L?ooo`03o`2I
oooooooo03koool300000oooo`030000oooooooo06Koool0073oool00ol0VOooooooo`0ooooo00<0
003oooooool00_ooo`030000oooooooo06Koool0073oool00ol0VOooooooo`0loooo1@0000?oool3
0000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool2
0000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`030000oooooooo
00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.36136 .26487 L
.37176 .26487 L
.3815 .26487 L
.3864 .26487 L
.38881 .26487 L
.38999 .26487 L
.39106 .26487 L
s
.39106 .26487 m
.39155 .61803 L
s
0 .4 1 r
.02381 .26303 m
.06244 .26238 L
.10458 .2614 L
.14415 .26013 L
.18221 .25847 L
.22272 .25608 L
.26171 .25294 L
.30316 .24839 L
.34309 .24244 L
.36136 .23908 L
.37176 .23697 L
.3815 .23486 L
.3864 .23374 L
.38881 .23317 L
.38999 .2329 L
.39106 .23264 L
.3923 .26487 L
.39298 .26487 L
.39362 .26487 L
.39642 .26487 L
.40134 .26487 L
.42237 .26487 L
.46092 .26487 L
.50192 .26487 L
.54141 .26487 L
.57938 .26487 L
.6198 .26487 L
.65871 .26487 L
.70007 .26487 L
.73992 .26487 L
.77825 .26487 L
.81903 .26487 L
.8583 .26487 L
.89605 .26487 L
.93625 .26487 L
.97494 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001;oool406Ko00?oool0I_ooool00oooo`@0000N<ol000<0
000co`0co`006S?o00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`0001Koool010000?oo
ooooo`0002Koool001Soool300007_ooo`80000Noooo0P0000ooool406Ko1Oooo`0306Kooooooooo
00D0000N<ol00P0001`co`000`0003?o03?o000L<ol00P0000Pco`0400004oooo`80000Woooo001S
oooo1`1Vo`Woool00`1Vo`0000000011<ol000<0000co`0co`00:S?o00<0000ioooo001Ioooo2P1V
o`goool3000000<0I_lco`0co`00@C?o0080000^<ol00P0003Ooool004ooool:06Ko4_ooo`D00004
<ol000<0I_lco`0co`00@3?o00030000<ol0<ol002lco`040000<oooo`00A?ooo`/0I_lBoooo2P00
00Tco`000`1Voc?o03?o0010<ol000<0000co`0co`00<c?o00X0000Yoooo000Voooo7P1Voa;oool;
00004c?o000306Ko<ol0<ol0040co`000`0003?o03?o000m<ol03`0001[oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00@0003ooooo
oooo09T3oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000
oooooooo01koool00`000?ooooooo`0Ioooo00Go09Woooooooooool000007oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool007?oool0
0ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?oo
ooooo`1Voooo001coooo00?o09Woooooool0@Oooo`80001Woooo001coooo00?o09Woooooool0@Ooo
o`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Looo
o`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`80001W
oooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11
oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001c
oooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo0P00
06Ooool007?oool00ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo
047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool0
07?oool00ol0VOooooooo`11oooo0P0006Ooool007?oool00ol0VOooooooo`11oooo00<0003ooooo
ool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Wooooo
ool0>Oooo`D00003oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo03_oool00`000?ooooooo`03
oooo0`0006Koool007?oool00ol0VOooooooo`0koooo00<0003oooooool00oooo`030000oooooooo
06Koool007?oool00ol0VOooooooo`0koooo00<0003oooooool00oooo`030000oooooooo06Koool0
07?oool00ol0VOooooooo`0joooo0P0000Goool00`000?ooooooo`1Voooo001coooo00?o09Wooooo
ool0@Oooo`80001Woooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool0
0ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?oo
ooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOoo
ooooo`11oooo0P0006Ooool007?oool00ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Looo
o`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000
oooooooo06Koool007?oool00ol0VOooooooo`11oooo0P0006Ooool007?oool00ol0VOooooooo`11
oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001c
oooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo00<0
003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool20000Ioooo`00Loooo`03o`2Ioooooooo
047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0>Oooo`@00004oooo00<0003ooooo
ool0I_ooo`00Loooo`03o`2Ioooooooo03Woool00`000?ooooooo`05oooo00<0003oooooool0I_oo
o`00Loooo`03o`2Ioooooooo03[oool00`000?ooooooo`04oooo0`0006Koool007?oool00ol0VOoo
ooooo`0koooo00<0003oooooool00oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`0i
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo03[oool2
00001Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo0P0006Ooool007?oool0
0ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?oo
ooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOoo
ooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool20000Ioooo`00Looo
o`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000
oooooooo06Koool007?oool00ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2I
oooooooo047oool20000Ioooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001c
oooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo00<0
003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o
09Woooooool0@Oooo`80001Woooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool0
07?oool00ol0VOooooooo`0joooo0P0000Goool00`000?ooooooo`1Voooo001coooo00?o09Wooooo
ool0>Oooo`040000oooooooo00001?ooo`030000oooooooo06Koool007?oool00ol0VOooooooo`0k
oooo00<0003oooooool00oooo`<0001Voooo001coooo00?o09Woooooool0??ooo`030000oooooooo
00;oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0>Oooo`040000oooooooo00001?oo
o`030000oooooooo06Koool007?oool00ol0VOooooooo`0joooo0P0000Goool00`000?ooooooo`1V
oooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11
oooo0P0006Ooool007?oool00ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2I
oooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000oooooooo
06Koool007?oool00ol0VOooooooo`11oooo0P0006Ooool007?oool00ol0VOooooooo`11oooo00<0
003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o
09Woooooool0@Oooo`030000oooooooo06Koool007?oool00ol0VOooooooo`11oooo00<0003ooooo
ool0I_ooo`00Loooo`03o`2Ioooooooo047oool20000Ioooo`00Loooo`03o`2Ioooooooo047oool0
0`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Oooo`030000oooooooo06Koool007?oool0
0ol0VOooooooo`11oooo00<0003oooooool0I_ooo`00Loooo`03o`2Ioooooooo047oool20000Iooo
o`00Loooo`03o`2Ioooooooo047oool00`000?ooooooo`1Voooo001coooo00?o09Woooooool0@Ooo
o`030000oooooooo06Koool007?oool00ol0VOooooooo`0koooo0`0000?oool00`000?ooooooo`1V
oooo001coooo00?o09Woooooool0??ooo`030000oooooooo00;oool00`000?ooooooo`1Voooo001c
oooo00?o09Woooooool0>Oooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool0
0;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`D00002oooo0P0000?oool500000_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Ooo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00?oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Goooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.39174 .26487 L
.39675 .26487 L
.40134 .26487 L
.40252 .26487 L
.40381 .26487 L
s
.40381 .26487 m
.4043 .61803 L
s
0 .4 1 r
.02381 .26325 m
.06244 .26268 L
.10458 .26181 L
.14415 .2607 L
.18221 .25924 L
.22272 .25713 L
.26171 .25437 L
.30316 .25037 L
.34309 .24513 L
.3815 .23846 L
.39174 .23637 L
.39675 .23529 L
.40134 .23428 L
.40252 .23401 L
.40381 .23372 L
.40503 .26487 L
.40616 .26487 L
.41134 .26487 L
.42237 .26487 L
.4615 .26487 L
.50308 .26487 L
.54314 .26487 L
.58169 .26487 L
.6227 .26487 L
.66219 .26487 L
.70016 .26487 L
.74058 .26487 L
.77949 .26487 L
.82085 .26487 L
.8607 .26487 L
.89903 .26487 L
.93981 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00000P1Vo`;oool300005C?o00@00004<ol000<0000co`0co`006S?o00030000<ol0<ol001dco`00
100003?o03?o03?o0080000Koooo00<0003oooooool09Oooo`006?ooo`030000oooooooo01goool0
0`000?ooo`00000Moooo00@0003oooooool0000Goooo0`1Vo`03oooo06Ko000000<0000N<ol000<0
000co`0co`006S?o00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`0001Koool010000?oo
ooooo`0002Koool001Soool300007_ooo`80000Noooo0P0001;oool606Ko0oooo`03000006Ko0000
0080000N<ol00P0001`co`000`0003?o03?o000L<ol00P0000Pco`0400004oooo`80000Woooo001U
oooo201Vo`Ooool2000000<co`00I_lco`00?S?o00030000<ol0<ol002Xco`030000>Oooo`00H?oo
o`D0I_l;oooo100000<co`000`1Voc?o03?o000m<ol00P0002hco`020000=oooo`00FOooo`L0I_l;
oooo1@0000Lco`000`1Voc?o03?o000m<ol000<0000co`0co`00;c?o00@0000coooo0014oooo5@1V
o`Soool:000033?o000306Ko<ol0<ol003dco`000`0003?o03?o000c<ol02P0002Woool002KooolN
06Ko4_ooo`/0000F<ol000<0I_lco`0co`00?C?o00030000<ol0<ol003dco`0?00006_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003oooooool07Ooo
o`030000oooooooo01koool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool007Ooool0
0ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?oo
ooooo`1Voooo001goooo00?o09Woooooool0?Oooo`80001Woooo001goooo00?o09Woooooool0?Ooo
o`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Mooo
o`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`80001W
oooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0m
oooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001g
oooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo0P00
06Ooool007Ooool00ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo
03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool0
07Ooool00ol0VOooooooo`0moooo0P0006Ooool007Ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Wooooo
ool0=Oooo`D00003oooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03Ooool00`000?ooooooo`03
oooo0`0006Koool007Ooool00ol0VOooooooo`0goooo00<0003oooooool00oooo`030000oooooooo
06Koool007Ooool00ol0VOooooooo`0goooo00<0003oooooool00oooo`030000oooooooo06Koool0
07Ooool00ol0VOooooooo`0foooo0P0000Goool00`000?ooooooo`1Voooo001goooo00?o09Wooooo
ool0?Oooo`80001Woooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool0
0ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?oo
ooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOoo
ooooo`0moooo0P0006Ooool007Ooool00ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Mooo
o`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000
oooooooo06Koool007Ooool00ol0VOooooooo`0moooo0P0006Ooool007Ooool00ol0VOooooooo`0m
oooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001g
oooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo00<0
003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool20000Ioooo`00Moooo`03o`2Ioooooooo
03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0=Oooo`@00004oooo00<0003ooooo
ool0I_ooo`00Moooo`03o`2Ioooooooo03Goool00`000?ooooooo`05oooo00<0003oooooool0I_oo
o`00Moooo`03o`2Ioooooooo03Koool00`000?ooooooo`04oooo0`0006Koool007Ooool00ol0VOoo
ooooo`0goooo00<0003oooooool00oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0e
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03Koool2
00001Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo0P0006Ooool007Ooool0
0ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?oo
ooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOoo
ooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool20000Ioooo`00Mooo
o`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000
oooooooo06Koool007Ooool00ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2I
oooooooo03goool20000Ioooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001g
oooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo00<0
003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o
09Woooooool0?Oooo`80001Woooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool0
07Ooool00ol0VOooooooo`0foooo0P0000Goool00`000?ooooooo`1Voooo001goooo00?o09Wooooo
ool0=Oooo`040000oooooooo00001?ooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0g
oooo00<0003oooooool00oooo`<0001Voooo001goooo00?o09Woooooool0>?ooo`030000oooooooo
00;oool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0=Oooo`040000oooooooo00001?oo
o`030000oooooooo06Koool007Ooool00ol0VOooooooo`0foooo0P0000Goool00`000?ooooooo`1V
oooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0m
oooo0P0006Ooool007Ooool00ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2I
oooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000oooooooo
06Koool007Ooool00ol0VOooooooo`0moooo0P0006Ooool007Ooool00ol0VOooooooo`0moooo00<0
003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o
09Woooooool0?Oooo`030000oooooooo06Koool007Ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0I_ooo`00Moooo`03o`2Ioooooooo03goool20000Ioooo`00Moooo`03o`2Ioooooooo03goool0
0`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Oooo`030000oooooooo06Koool007Ooool0
0ol0VOooooooo`0moooo00<0003oooooool0I_ooo`00Moooo`03o`2Ioooooooo03goool20000Iooo
o`00Moooo`03o`2Ioooooooo03goool00`000?ooooooo`1Voooo001goooo00?o09Woooooool0?Ooo
o`030000oooooooo06Koool007Ooool00ol0VOooooooo`0goooo0`0000?oool00`000?ooooooo`1V
oooo001goooo00?o09Woooooool0>?ooo`030000oooooooo00;oool00`000?ooooooo`1Voooo001g
oooo00?o09Woooooool0=Oooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool0
0;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`D00002oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?oo
ooooo`08oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool02Oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500005?oo
o`030000oooooooo00Soool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000005ooo
o`030000oooooooo00Soool00`000?ooooooo`1koooo001loooo00<0003oooooool05oooo`800009
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40134 .26487 L
.41134 .26487 L
.41408 .26487 L
.4156 .26487 L
.41634 .26487 L
.41703 .26487 L
s
.41703 .26487 m
.41729 .61803 L
s
0 .4 1 r
.02381 .26346 m
.06244 .26295 L
.10458 .2622 L
.14415 .26123 L
.18221 .25995 L
.22272 .25811 L
.26171 .2557 L
.30316 .2522 L
.34309 .24763 L
.3815 .2418 L
.40134 .23815 L
.41134 .23612 L
.41408 .23554 L
.4156 .23522 L
.41634 .23506 L
.41703 .23491 L
.41768 .26487 L
.41837 .26487 L
.41982 .26487 L
.42237 .26487 L
.46395 .26487 L
.50401 .26487 L
.54257 .26487 L
.58357 .26487 L
.62306 .26487 L
.66103 .26487 L
.70145 .26487 L
.74036 .26487 L
.78172 .26487 L
.82157 .26487 L
.8599 .26487 L
.90068 .26487 L
.93994 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001Soool406Ko00@00000I_l0I_l0000N<ol000<0000co`0c
o`006S?o00030000<ol0<ol001dco`000`0003?o03?o0003<ol00`0001Koool010000?ooooooo`00
02Koool001Soool300007_ooo`80000Noooo0P0001Coool506Ko0_ooo`D0000N<ol00P0001`co`00
0`0003?o03?o000L<ol00P0000Pco`0400004oooo`80000Woooo001Zoooo1@1Vo`Goool2000013?o
000306Ko<ol0<ol003Xco`000`0003?o03?o000Z<ol00`0003Woool006?oool706Ko1_ooo`@00006
<ol000<0I_lco`0co`00>S?o0080000^<ol00P0003Ooool005Woool:06Ko2?ooo`D0000:<ol000<0
I_lco`0co`00>S?o00030000<ol0<ol002lco`040000<oooo`00Coooo`X0I_l8oooo2P0000lco`00
0`1Voc?o03?o000j<ol000<0000co`0co`00<c?o00X0000Yoooo000aoooo7P1Vo`Ooool;00006C?o
000306Ko<ol0<ol003Xco`000`0003?o03?o000m<ol03`0001[oool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`040000ooooooooo`2I0_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo
01koool00`000?ooooooo`0Moooo00@0003ooooooooo09TLoooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00N_ooo`03o`2Ioooooooo
03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool0
07[oool00ol0VOooooooo`0joooo0P0006Ooool007[oool00ol0VOooooooo`0joooo00<0003ooooo
ool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001joooo00?o09Wooooo
ool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo0P0006Ooool007[oool0
0ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool00`000?oo
ooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOoo
ooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool20000Ioooo`00N_oo
o`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000
oooooooo06Koool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2I
oooooooo03[oool20000Ioooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001j
oooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0boooo1@00
00?oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0=?ooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo001joooo00?o09Woooooool0=?ooo`030000oooooooo00?oool30000I_oo
o`00N_ooo`03o`2Ioooooooo03Coool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00N_oo
o`03o`2Ioooooooo03Coool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00N_ooo`03o`2I
oooooooo03?oool200001Oooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo0P00
06Ooool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo
03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool0
07[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool2
0000Ioooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001joooo00?o09Wooooo
ool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_oo
o`00N_ooo`03o`2Ioooooooo03[oool20000Ioooo`00N_ooo`03o`2Ioooooooo03[oool00`000?oo
ooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOoo
ooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1V
oooo001joooo00?o09Woooooool0>_ooo`80001Woooo001joooo00?o09Woooooool0>_ooo`030000
oooooooo06Koool007[oool00ol0VOooooooo`0boooo100000Coool00`000?ooooooo`1Voooo001j
oooo00?o09Woooooool0<_ooo`030000oooooooo00Goool00`000?ooooooo`1Voooo001joooo00?o
09Woooooool0<oooo`030000oooooooo00Coool30000I_ooo`00N_ooo`03o`2Ioooooooo03Coool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03;oool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0<oooo`800005oooo00<0
003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool20000Ioooo`00N_ooo`03o`2Ioooooooo
03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool0
07[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`80001Woooo001joooo00?o09Wooooo
ool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_oo
o`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_oo
o`80001Woooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOoo
ooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1V
oooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0j
oooo0P0006Ooool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2I
oooooooo03?oool200001Oooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0boooo00@0
003oooooool00004oooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03Coool00`000?oo
ooooo`03oooo0`0006Koool007[oool00ol0VOooooooo`0eoooo00<0003oooooool00_ooo`030000
oooooooo06Koool007[oool00ol0VOooooooo`0boooo00@0003oooooool00004oooo00<0003ooooo
ool0I_ooo`00N_ooo`03o`2Ioooooooo03?oool200001Oooo`030000oooooooo06Koool007[oool0
0ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool20000Iooo
o`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_oo
o`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_oo
o`03o`2Ioooooooo03[oool20000Ioooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1V
oooo001joooo00?o09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0j
oooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo03[oool00`000?ooooooo`1Voooo001j
oooo00?o09Woooooool0>_ooo`80001Woooo001joooo00?o09Woooooool0>_ooo`030000oooooooo
06Koool007[oool00ol0VOooooooo`0joooo00<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo
03[oool00`000?ooooooo`1Voooo001joooo00?o09Woooooool0>_ooo`80001Woooo001joooo00?o
09Woooooool0>_ooo`030000oooooooo06Koool007[oool00ol0VOooooooo`0joooo00<0003ooooo
ool0I_ooo`00N_ooo`03o`2Ioooooooo03Coool300000oooo`030000oooooooo06Koool007[oool0
0ol0VOooooooo`0eoooo00<0003oooooool00_ooo`030000oooooooo06Koool007[oool00ol0VOoo
ooooo`0boooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000
oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`<00004oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40095 .26487 L
.41127 .26487 L
.41696 .26487 L
.42237 .26487 L
.42482 .26487 L
.42744 .26487 L
.42821 .26487 L
.42894 .26487 L
.4296 .26487 L
s
.4296 .26487 m
.42988 .61803 L
s
0 .4 1 r
.02381 .26365 m
.06244 .26321 L
.10458 .26256 L
.14415 .26172 L
.18221 .26062 L
.22272 .25902 L
.26171 .25694 L
.30316 .25391 L
.34309 .24996 L
.3815 .24491 L
.40095 .24182 L
.41127 .24001 L
.41696 .23897 L
.42237 .23794 L
.42482 .23746 L
.42744 .23695 L
.42821 .2368 L
.42894 .23665 L
.4296 .23652 L
.43031 .26487 L
.43098 .26487 L
.4317 .26487 L
.43298 .26487 L
.44268 .26487 L
.46172 .26487 L
.49969 .26487 L
.54011 .26487 L
.57902 .26487 L
.62038 .26487 L
.66023 .26487 L
.69856 .26487 L
.73934 .26487 L
.77861 .26487 L
.81636 .26487 L
.85656 .26487 L
.89525 .26487 L
.93639 .26487 L
.97601 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400000P1Voa`co`000`0003?o03?o000J<ol000<0
000co`0co`007C?o00030000<ol0<ol000<co`0300005_ooo`040000oooooooo00009_ooo`006?oo
o`<0000Noooo0P0001koool200006Oooo`D0I_l200000S?o000306Ko<ol0<ol001Tco`02000073?o
00030000<ol0<ol001`co`02000023?o00@0000Coooo0P0002Ooool006goool706Ko0P0000Lco`00
0`1Voc?o03?o000g<ol000<0000co`0co`00:S?o00<0000ioooo001Soooo2P1Vo`?oool400002C?o
000306Ko<ol0<ol003Lco`020000;S?o0080000goooo001Ioooo2P1Vo`Soool500003C?o000306Ko
<ol0<ol003Lco`000`0003?o03?o000_<ol0100003?oool004ooool:06Ko2?ooo`X0000B<ol000<0
I_lco`0co`00=c?o00030000<ol0<ol003<co`0:0000:Oooo`00<Ooooah0I_l7oooo2`0001`co`00
0`1Voc?o03?o000g<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool07_oo
o`030000oooooooo01goool00`000?ooooooo`03oooo00?o09Woooooool05oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool007goool0
0ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`1Voooo001moooo00?o09Woooooool0=oooo`80001Woooo001moooo00?o09Woooooool0=ooo
o`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`80001W
oooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0g
oooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001m
oooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo0P00
06Ooool007goool00ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool0
07goool00ol0VOooooooo`0goooo0P0006Ooool007goool00ol0VOooooooo`0goooo00<0003ooooo
ool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Wooooo
ool0;oooo`D00003oooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo037oool00`000?oo
ooooo`03oooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo037oool00`000?ooooooo`03
oooo0`0006Koool007goool00ol0VOooooooo`0aoooo00<0003oooooool00oooo`030000oooooooo
06Koool007goool00ol0VOooooooo`0aoooo00<0003oooooool00oooo`030000oooooooo06Koool0
07goool00ol0VOooooooo`0`oooo0P0000Goool00`000?ooooooo`1Voooo001moooo00?o09Wooooo
ool0=oooo`80001Woooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool0
0ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOoo
ooooo`0goooo0P0006Ooool007goool00ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000
oooooooo06Koool007goool00ol0VOooooooo`0goooo0P0006Ooool007goool00ol0VOooooooo`0g
oooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001m
oooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo00<0
003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool20000Ioooo`00OOooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0;oooo`@00004oooo00<0003ooooo
ool0I_ooo`00OOooo`03o`2Ioooooooo02ooool00`000?ooooooo`05oooo00<0003oooooool0I_oo
o`00OOooo`03o`2Ioooooooo033oool00`000?ooooooo`04oooo0`0006Koool007goool00ol0VOoo
ooooo`0aoooo00<0003oooooool00oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0_
oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo033oool2
00001Oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo0P0006Ooool007goool0
0ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOoo
ooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool20000Ioooo`00OOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000
oooooooo06Koool007goool00ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2I
oooooooo03Ooool20000Ioooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001m
oooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo00<0
003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o
09Woooooool0=oooo`80001Woooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool0
07goool00ol0VOooooooo`0`oooo0P0000Goool00`000?ooooooo`1Voooo001moooo00?o09Wooooo
ool0;oooo`040000oooooooo00001?ooo`030000oooooooo06Koool007goool00ol0VOooooooo`0a
oooo00<0003oooooool00oooo`<0001Voooo001moooo00?o09Woooooool0<_ooo`030000oooooooo
00;oool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0;oooo`040000oooooooo00001?oo
o`030000oooooooo06Koool007goool00ol0VOooooooo`0`oooo0P0000Goool00`000?ooooooo`1V
oooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0g
oooo0P0006Ooool007goool00ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2I
oooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000oooooooo
06Koool007goool00ol0VOooooooo`0goooo0P0006Ooool007goool00ol0VOooooooo`0goooo00<0
003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o
09Woooooool0=oooo`030000oooooooo06Koool007goool00ol0VOooooooo`0goooo00<0003ooooo
ool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool20000Ioooo`00OOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`1Voooo001moooo00?o09Woooooool0=oooo`030000oooooooo06Koool007goool0
0ol0VOooooooo`0goooo00<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo03Ooool20000Iooo
o`00OOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1Voooo001moooo00?o09Woooooool0=ooo
o`030000oooooooo06Koool007goool00ol0VOooooooo`0aoooo0`0000?oool00`000?ooooooo`1V
oooo001moooo00?o09Woooooool0<_ooo`030000oooooooo00;oool00`000?ooooooo`1Voooo001m
oooo00?o09Woooooool0;oooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool0
0;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo
00002Oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40095 .26487 L
.42237 .26487 L
.43215 .26487 L
.43755 .26487 L
.44021 .26487 L
.44151 .26487 L
.44268 .26487 L
s
.44268 .26487 m
.44316 .61803 L
s
0 .4 1 r
.02381 .26383 m
.06244 .26346 L
.10458 .2629 L
.14415 .26218 L
.18221 .26124 L
.22272 .25988 L
.26171 .25809 L
.30316 .25551 L
.34309 .25213 L
.3815 .24783 L
.40095 .24518 L
.42237 .24187 L
.43215 .24021 L
.43755 .23926 L
.44021 .23879 L
.44151 .23855 L
.44268 .23834 L
.44387 .26487 L
.44498 .26487 L
.44744 .26487 L
.45262 .26487 L
.46172 .26487 L
.50027 .26487 L
.54127 .26487 L
.58076 .26487 L
.61873 .26487 L
.65915 .26487 L
.69806 .26487 L
.73942 .26487 L
.77927 .26487 L
.8176 .26487 L
.85838 .26487 L
.89765 .26487 L
.9354 .26487 L
.9756 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool4000013?o000306Ko<ol0<ol001Lco`000`0003?o
03?o000J<ol000<0000co`0co`007C?o00030000<ol0<ol000<co`0300005_ooo`040000oooooooo
00009_ooo`006?ooo`<0000Noooo0P0001koool200006oooo`D0000606Ko63?o0080000L<ol000<0
000co`0co`0073?o00800008<ol0100001?oool200009oooo`00M?ooo`D0I_l7<ol000<0I_lco`0c
o`00=3?o00030000<ol0<ol002Xco`030000>Oooo`00KOooo`L0I_l<<ol000<0I_lco`0co`00=3?o
0080000^<ol00P0003Ooool006?oool:06Ko0`00014co`000`1Voc?o03?o000c<ol000<0000co`0c
o`00;c?o00@0000coooo001Ioooo2P1Vo`P0000F<ol000<0I_lco`0co`00<c?o00030000<ol0<ol0
03<co`0:0000:Oooo`00>_oooal0I_l8000083?o000306Ko<ol0<ol003<co`000`0003?o03?o000m
<ol03`0001[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool010000?ooooooool0
V@?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo000F
oooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo01Coool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000
oooooooo01koool00`000?ooooooo`0Uoooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo
06Koool0083oool00ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo
03Coool20000Ioooo`00P?ooo`03o`2Ioooooooo03Coool00`000?ooooooo`1Voooo0020oooo00?o
09Woooooool0=?ooo`030000oooooooo06Koool0083oool00ol0VOooooooo`0doooo00<0003ooooo
ool0I_ooo`00P?ooo`03o`2Ioooooooo03Coool20000Ioooo`00P?ooo`03o`2Ioooooooo03Coool0
0`000?ooooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo06Koool0083oool0
0ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo03Coool00`000?oo
ooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`80001Woooo0020oooo00?o09Woooooool0=?oo
o`030000oooooooo06Koool0083oool00ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?oo
o`03o`2Ioooooooo03Coool00`000?ooooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`80001W
oooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo06Koool0083oool00ol0VOooooooo`0d
oooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo02coool500000oooo`030000oooooooo
06Koool0083oool00ol0VOooooooo`0^oooo00<0003oooooool00oooo`030000oooooooo06Koool0
083oool00ol0VOooooooo`0^oooo00<0003oooooool00oooo`<0001Voooo0020oooo00?o09Wooooo
ool0;_ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo0020oooo00?o09Woooooool0;_oo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo0020oooo00?o09Woooooool0;Oooo`800005
oooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo03Coool20000Ioooo`00P?ooo`03o`2I
oooooooo03Coool00`000?ooooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo
06Koool0083oool00ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo
03Coool00`000?ooooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`80001Woooo0020oooo00?o
09Woooooool0=?ooo`030000oooooooo06Koool0083oool00ol0VOooooooo`0doooo00<0003ooooo
ool0I_ooo`00P?ooo`03o`2Ioooooooo03Coool00`000?ooooooo`1Voooo0020oooo00?o09Wooooo
ool0=?ooo`80001Woooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo06Koool0083oool0
0ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo03Coool00`000?oo
ooooo`1Voooo0020oooo00?o09Woooooool0=?ooo`030000oooooooo06Koool0083oool00ol0VOoo
ooooo`0doooo0P0006Ooool0083oool00ol0VOooooooo`0doooo00<0003oooooool0I_ooo`00P?oo
o`03o`2Ioooooooo02coool400001?ooo`030000oooooooo06Koool0083oool00ol0VOooooooo`0/
oooo00<0003oooooool01Oooo`030000oooooooo06Koool0083oool00ol0VOooooooo`0]oooo00<0
003oooooool01?ooo`<0001Voooo0021oooo00?o09Woooooool0;Oooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo0021oooo00?o09Woooooool0:oooo`040000oooooooo00001?ooo`030000
oooooooo06Koool0087oool00ol0VOooooooo`0/oooo0P0000Goool00`000?ooooooo`1Voooo0021
oooo00?o09Woooooool0<oooo`80001Woooo0021oooo00?o09Woooooool0<oooo`030000oooooooo
06Koool0087oool00ol0VOooooooo`0coooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo
03?oool00`000?ooooooo`1Voooo0021oooo00?o09Woooooool0<oooo`030000oooooooo06Koool0
087oool00ol0VOooooooo`0coooo0P0006Ooool0087oool00ol0VOooooooo`0coooo00<0003ooooo
ool0I_ooo`00POooo`03o`2Ioooooooo03?oool00`000?ooooooo`1Voooo0021oooo00?o09Wooooo
ool0<oooo`030000oooooooo06Koool0087oool00ol0VOooooooo`0coooo0P0006Ooool0087oool0
0ol0VOooooooo`0coooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`1Voooo0021oooo00?o09Woooooool0<oooo`030000oooooooo06Koool0087oool00ol0VOoo
ooooo`0coooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo03?oool20000Ioooo`00POoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`1Voooo0021oooo00?o09Woooooool0;?ooo`800005
oooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo02_oool010000?ooooooo`0000Coool0
0`000?ooooooo`1Voooo0021oooo00?o09Woooooool0;Oooo`030000oooooooo00?oool30000I_oo
o`00POooo`03o`2Ioooooooo02koool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00POoo
o`03o`2Ioooooooo02_oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo0021oooo00?o
09Woooooool0;?ooo`800005oooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`1Voooo0021oooo00?o09Woooooool0<oooo`80001Woooo0021oooo00?o09Wooooo
ool0<oooo`030000oooooooo06Koool0087oool00ol0VOooooooo`0coooo00<0003oooooool0I_oo
o`00POooo`03o`2Ioooooooo03?oool00`000?ooooooo`1Voooo0021oooo00?o09Woooooool0<ooo
o`80001Woooo0021oooo00?o09Woooooool0<oooo`030000oooooooo06Koool0087oool00ol0VOoo
ooooo`0coooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo03?oool00`000?ooooooo`1V
oooo0021oooo00?o09Woooooool0<oooo`030000oooooooo06Koool0087oool00ol0VOooooooo`0c
oooo0P0006Ooool0087oool00ol0VOooooooo`0coooo00<0003oooooool0I_ooo`00POooo`03o`2I
oooooooo03?oool00`000?ooooooo`1Voooo0021oooo00?o09Woooooool0<oooo`030000oooooooo
06Koool0087oool00ol0VOooooooo`0coooo0P0006Ooool0087oool00ol0VOooooooo`0coooo00<0
003oooooool0I_ooo`00POooo`03o`2Ioooooooo03?oool00`000?ooooooo`1Voooo0021oooo00?o
09Woooooool0;Oooo`<00003oooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo02koool0
0`000?ooooooo`02oooo00<0003oooooool0I_ooo`00POooo`03o`2Ioooooooo02_oool500000ooo
o`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Ooo
o`80001]oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000N_ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`800009oooo1000
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40095 .26487 L
.42237 .26487 L
.43215 .26487 L
.44268 .26487 L
.44778 .26487 L
.45029 .26487 L
.45262 .26487 L
.45371 .26487 L
.45473 .26487 L
s
.45473 .26487 m
.4552 .61803 L
s
0 .4 1 r
.02381 .26399 m
.06244 .26368 L
.10458 .26322 L
.14415 .26261 L
.18221 .26182 L
.22272 .26068 L
.26171 .25918 L
.30316 .25701 L
.34309 .25418 L
.3815 .25056 L
.40095 .24834 L
.42237 .24557 L
.43215 .24418 L
.44268 .2426 L
.44778 .24181 L
.45029 .24141 L
.45262 .24104 L
.45371 .24087 L
.45473 .2407 L
.4559 .26487 L
.45697 .26487 L
.46172 .26487 L
.50027 .26487 L
.54127 .26487 L
.58076 .26487 L
.61873 .26487 L
.65915 .26487 L
.69806 .26487 L
.73942 .26487 L
.77927 .26487 L
.8176 .26487 L
.85838 .26487 L
.89765 .26487 L
.9354 .26487 L
.9756 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0000Lco`0206Ko5C?o0080000L<ol000<0000co`0co`0073?o
00800008<ol0100001?oool200009oooo`00M?ooo`800003<ol02@1Vo`03<ol006Ko<ol0038co`00
0`0003?o03?o000Z<ol00`0003Woool0073oool400001@1Vo`Xco`000`1Voc?o03?o000a<ol00P00
02hco`020000=oooo`00Joooo`80000706Ko3c?o000306Ko<ol0<ol0034co`000`0003?o03?o000_
<ol0100003?oool005WooolD06Ko5c?o000306Ko<ol0<ol0030co`000`0003?o03?o000c<ol02P00
02Woool003[ooolO06Ko200002<co`000`1Voc?o03?o000`<ol000<0000co`0co`00?C?o00l0000J
oooo000@ooooo`00017oool001Koool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`03o`2I
0000oooo00Coool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo01;oool001Koool00`000?oo
ooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo01goool00`000?ooooooo`09oooo00?o
09Woooooool04Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07_oo
o`030000oooooooo02Goool008?oool00ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Pooo
o`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023oooo00?o09Woooooool0<Oooo`80001W
oooo0023oooo00?o09Woooooool0<Oooo`030000oooooooo06Koool008?oool00ol0VOooooooo`0a
oooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023
oooo00?o09Woooooool0<Oooo`80001Woooo0023oooo00?o09Woooooool0<Oooo`030000oooooooo
06Koool008?oool00ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo
037oool00`000?ooooooo`1Voooo0023oooo00?o09Woooooool0<Oooo`030000oooooooo06Koool0
08?oool00ol0VOooooooo`0aoooo0P0006Ooool008?oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0I_ooo`00Poooo`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023oooo00?o09Wooooo
ool0<Oooo`030000oooooooo06Koool008?oool00ol0VOooooooo`0aoooo0P0006Ooool008?oool0
0ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo037oool00`000?oo
ooooo`1Voooo0023oooo00?o09Woooooool0:Oooo`D00003oooo00<0003oooooool0I_ooo`00Pooo
o`03o`2Ioooooooo02_oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Poooo`03o`2I
oooooooo02_oool00`000?ooooooo`03oooo0`0006Koool008?oool00ol0VOooooooo`0[oooo00<0
003oooooool00oooo`030000oooooooo06Koool008?oool00ol0VOooooooo`0[oooo00<0003ooooo
ool00oooo`030000oooooooo06Koool008?oool00ol0VOooooooo`0Zoooo0P0000Goool00`000?oo
ooooo`1Voooo0023oooo00?o09Woooooool0<Oooo`80001Woooo0023oooo00?o09Woooooool0<Ooo
o`030000oooooooo06Koool008?oool00ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Pooo
o`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023oooo00?o09Woooooool0<Oooo`030000
oooooooo06Koool008?oool00ol0VOooooooo`0aoooo0P0006Ooool008?oool00ol0VOooooooo`0a
oooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023
oooo00?o09Woooooool0<Oooo`030000oooooooo06Koool008?oool00ol0VOooooooo`0aoooo0P00
06Ooool008?oool00ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo
037oool00`000?ooooooo`1Voooo0023oooo00?o09Woooooool0<Oooo`030000oooooooo06Koool0
08?oool00ol0VOooooooo`0aoooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo037oool2
0000Ioooo`00Poooo`03o`2Ioooooooo037oool00`000?ooooooo`1Voooo0023oooo00?o09Wooooo
ool0:Oooo`@00004oooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`05oooo00<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo02[oool00`000?ooooooo`04
oooo0`0006Koool008Coool00ol0VOooooooo`0Zoooo00<0003oooooool00oooo`030000oooooooo
06Koool008Coool00ol0VOooooooo`0Xoooo00@0003oooooool00004oooo00<0003oooooool0I_oo
o`00Q?ooo`03o`2Ioooooooo02Woool200001Oooo`030000oooooooo06Koool008Coool00ol0VOoo
ooooo`0`oooo0P0006Ooool008Coool00ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?oo
o`03o`2Ioooooooo033oool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?ooo`030000
oooooooo06Koool008Coool00ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?ooo`03o`2I
oooooooo033oool20000Ioooo`00Q?ooo`03o`2Ioooooooo033oool00`000?ooooooo`1Voooo0024
oooo00?o09Woooooool0<?ooo`030000oooooooo06Koool008Coool00ol0VOooooooo`0`oooo00<0
003oooooool0I_ooo`00Q?ooo`03o`2Ioooooooo033oool20000Ioooo`00Q?ooo`03o`2Ioooooooo
033oool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?ooo`030000oooooooo06Koool0
08Coool00ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?ooo`03o`2Ioooooooo033oool0
0`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?ooo`80001Woooo0024oooo00?o09Wooooo
ool0<?ooo`030000oooooooo06Koool008Coool00ol0VOooooooo`0Yoooo0P0000Goool00`000?oo
ooooo`1Voooo0024oooo00?o09Woooooool0:?ooo`040000oooooooo00001?ooo`030000oooooooo
06Koool008Coool00ol0VOooooooo`0Zoooo00<0003oooooool00oooo`<0001Voooo0024oooo00?o
09Woooooool0:oooo`030000oooooooo00;oool00`000?ooooooo`1Voooo0024oooo00?o09Wooooo
ool0:?ooo`040000oooooooo00001?ooo`030000oooooooo06Koool008Coool00ol0VOooooooo`0Y
oooo0P0000Goool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?ooo`030000oooooooo
06Koool008Coool00ol0VOooooooo`0`oooo0P0006Ooool008Coool00ol0VOooooooo`0`oooo00<0
003oooooool0I_ooo`00Q?ooo`03o`2Ioooooooo033oool00`000?ooooooo`1Voooo0024oooo00?o
09Woooooool0<?ooo`030000oooooooo06Koool008Coool00ol0VOooooooo`0`oooo0P0006Ooool0
08Coool00ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?ooo`03o`2Ioooooooo033oool0
0`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?ooo`030000oooooooo06Koool008Coool0
0ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?ooo`03o`2Ioooooooo033oool20000Iooo
o`00Q?ooo`03o`2Ioooooooo033oool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0<?oo
o`030000oooooooo06Koool008Coool00ol0VOooooooo`0`oooo00<0003oooooool0I_ooo`00Q?oo
o`03o`2Ioooooooo033oool20000Ioooo`00Q?ooo`03o`2Ioooooooo033oool00`000?ooooooo`1V
oooo0024oooo00?o09Woooooool0<?ooo`030000oooooooo06Koool008Coool00ol0VOooooooo`0Z
oooo0`0000?oool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0:oooo`030000oooooooo
00;oool00`000?ooooooo`1Voooo0024oooo00?o09Woooooool0:?ooo`D00003oooo0`0006Koool0
0:ooool010000?ooooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P0006goool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002?ooo`<00004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.44268 .26487 L
.45262 .26487 L
.46172 .26487 L
.46388 .26487 L
.46618 .26487 L
.46687 .26487 L
.46751 .26487 L
s
.46751 .26487 m
.46799 .61803 L
s
0 .4 1 r
.02381 .26415 m
.06244 .2639 L
.10458 .26352 L
.14415 .26302 L
.18221 .26237 L
.22272 .26144 L
.26171 .26021 L
.30316 .25844 L
.34309 .25612 L
.3815 .25316 L
.42237 .24907 L
.44268 .24664 L
.45262 .24537 L
.46172 .24415 L
.46388 .24385 L
.46618 .24354 L
.46687 .24344 L
.46751 .24335 L
.46871 .26487 L
.46984 .26487 L
.47106 .26487 L
.47994 .26487 L
.49955 .26487 L
.54055 .26487 L
.58004 .26487 L
.61801 .26487 L
.65844 .26487 L
.69735 .26487 L
.73871 .26487 L
.77855 .26487 L
.81688 .26487 L
.85766 .26487 L
.89693 .26487 L
.93468 .26487 L
.97489 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool2000033?o00H0I_l_<ol000<0000co`0co`00:S?o00<0000i
oooo001`oooo100000<co`0;06Ko1C?o000306Ko<ol0<ol002dco`020000;S?o0080000goooo001[
oooo0P0000X0I_l@<ol000<0I_lco`0co`00;C?o00030000<ol0<ol002lco`040000<oooo`00HOoo
o`80000:06Ko6S?o000306Ko<ol0<ol002dco`000`0003?o03?o000c<ol02P0002Woool004CooolO
06Ko93?o000306Ko<ol0<ol002dco`000`0003?o03?o000m<ol03`0001[oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00@0003ooooooooo09T2oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000
oooooooo01koool00`000?ooooooo`0Moooo00<0003oooooool03Oooo`03o`2Ioooooooo00goool0
0`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0U
oooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]
oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool20000Ioooo`00Qoooo`03o`2I
oooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo
06Koool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo
02goool20000Ioooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o
09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Wooooo
ool0;Oooo`80001Woooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?oo
ooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`80001Woooo0027oooo00?o09Woooooool0;Ooo
o`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qooo
o`03o`2Ioooooooo02Goool500000oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0W
oooo00<0003oooooool00oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0Woooo00<0
003oooooool00oooo`<0001Voooo0027oooo00?o09Woooooool09oooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo0027oooo00?o09Woooooool09oooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo0027oooo00?o09Woooooool09_ooo`800005oooo00<0003oooooool0I_ooo`00Qooo
o`03o`2Ioooooooo02goool20000Ioooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1V
oooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]
oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027
oooo00?o09Woooooool0;Oooo`80001Woooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo
06Koool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo
02goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`80001Woooo0027oooo00?o
09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Wooooo
ool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo0P0006Ooool008Ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02Goool400001?oo
o`030000oooooooo06Koool008Ooool00ol0VOooooooo`0Uoooo00<0003oooooool01Oooo`030000
oooooooo06Koool008Ooool00ol0VOooooooo`0Voooo00<0003oooooool01?ooo`<0001Voooo0027
oooo00?o09Woooooool09oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo0027oooo00?o
09Woooooool09Oooo`040000oooooooo00001?ooo`030000oooooooo06Koool008Ooool00ol0VOoo
ooooo`0Voooo0P0000Goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`80001W
oooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]
oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027
oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo0P00
06Ooool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo
02goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool0
08Ooool00ol0VOooooooo`0]oooo0P0006Ooool008Ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Wooooo
ool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_oo
o`00Qoooo`03o`2Ioooooooo02goool20000Ioooo`00Qoooo`03o`2Ioooooooo02goool00`000?oo
ooooo`1Voooo0027oooo00?o09Woooooool09_ooo`800005oooo00<0003oooooool0I_ooo`00Qooo
o`03o`2Ioooooooo02Goool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo0027oooo00?o
09Woooooool09oooo`030000oooooooo00?oool30000I_ooo`00Qoooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02Goool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool09_ooo`800005oooo00<0
003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o
09Woooooool0;Oooo`80001Woooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool0
08Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool0
0`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Oooo`80001Woooo0027oooo00?o09Wooooo
ool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_oo
o`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool0;Ooo
o`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]oooo0P0006Ooool008Ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02goool00`000?ooooooo`1V
oooo0027oooo00?o09Woooooool0;Oooo`030000oooooooo06Koool008Ooool00ol0VOooooooo`0]
oooo0P0006Ooool008Ooool00ol0VOooooooo`0]oooo00<0003oooooool0I_ooo`00Qoooo`03o`2I
oooooooo02goool00`000?ooooooo`1Voooo0027oooo00?o09Woooooool09oooo`<00003oooo00<0
003oooooool0I_ooo`00Qoooo`03o`2Ioooooooo02Soool00`000?ooooooo`02oooo00<0003ooooo
ool0I_ooo`00Qoooo`03o`2Ioooooooo02Goool500000oooo`<0001Voooo002_oooo00@0003ooooo
ool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0
003oooooool00009oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.44268 .26487 L
.46172 .26487 L
.47106 .26487 L
.47567 .26487 L
.47791 .26487 L
.47889 .26487 L
.47994 .26487 L
s
.47994 .26487 m
.48043 .61803 L
s
0 .4 1 r
.02381 .26431 m
.06244 .2641 L
.10458 .2638 L
.14415 .26341 L
.18221 .2629 L
.22272 .26217 L
.26171 .2612 L
.30316 .2598 L
.34309 .25797 L
.3815 .25564 L
.42237 .25242 L
.44268 .2505 L
.46172 .24854 L
.47106 .24752 L
.47567 .247 L
.47791 .24675 L
.47889 .24664 L
.47994 .24652 L
.48116 .26487 L
.48231 .26487 L
.48484 .26487 L
.49018 .26487 L
.49955 .26487 L
.54055 .26487 L
.58004 .26487 L
.61801 .26487 L
.65844 .26487 L
.69735 .26487 L
.73871 .26487 L
.77855 .26487 L
.81688 .26487 L
.85766 .26487 L
.89693 .26487 L
.93468 .26487 L
.97489 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@0000?<ol0201Vob`co`020000;S?o0080000goooo001[oooo1@0000Lco`0<06Ko1c?o000306Ko
<ol0<ol002Xco`000`0003?o03?o000_<ol0100003?oool0067oool20000501Voa<co`000`1Voc?o
03?o000Z<ol000<0000co`0co`00<c?o00X0000Yoooo001?oooo501VobLco`000`1Voc?o03?o000Z
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo
01goool00`000?ooooooo`0@oooo00?o09Woooooool02_ooo`030000oooooooo01goool00`000?oo
ooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool008[oool00ol0VOooooooo`0Z
oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:
oooo00?o09Woooooool0:_ooo`80001Woooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo
06Koool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`80001Woooo002:oooo00?o
09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo00<0003ooooo
ool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Wooooo
ool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo0P0006Ooool008[oool0
0ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOoo
ooooo`0Zoooo0P0006Ooool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_oo
o`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool08_ooo`D00003
oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02Coool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02Coool00`000?ooooooo`03oooo0`0006Koool0
08[oool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`030000oooooooo06Koool008[oool0
0ol0VOooooooo`0Toooo00<0003oooooool00oooo`030000oooooooo06Koool008[oool00ol0VOoo
ooooo`0Soooo0P0000Goool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`80001W
oooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Z
oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:
oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo0P00
06Ooool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool0
08[oool00ol0VOooooooo`0Zoooo0P0006Ooool008[oool00ol0VOooooooo`0Zoooo00<0003ooooo
ool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Wooooo
ool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_oo
o`00R_ooo`03o`2Ioooooooo02[oool20000Ioooo`00R_ooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`1Voooo002:oooo00?o09Woooooool08_ooo`@00004oooo00<0003oooooool0I_ooo`00R_oo
o`03o`2Ioooooooo02;oool00`000?ooooooo`05oooo00<0003oooooool0I_ooo`00R_ooo`03o`2I
oooooooo02?oool00`000?ooooooo`04oooo0`0006Koool008[oool00ol0VOooooooo`0Toooo00<0
003oooooool00oooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Roooo00@0003ooooo
ool00004oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02?oool200001Oooo`030000
oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo0P0006Ooool008[oool00ol0VOooooooo`0Z
oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:
oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo00<0
003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool20000Ioooo`00R_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool0
08[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool2
0000Ioooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Wooooo
ool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_oo
o`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_oo
o`80001Woooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOoo
ooooo`0Soooo0P0000Goool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool08_ooo`040000
oooooooo00001?ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Toooo00<0003ooooo
ool00oooo`<0001Voooo002:oooo00?o09Woooooool09Oooo`030000oooooooo00;oool00`000?oo
ooooo`1Voooo002:oooo00?o09Woooooool08_ooo`040000oooooooo00001?ooo`030000oooooooo
06Koool008[oool00ol0VOooooooo`0Soooo0P0000Goool00`000?ooooooo`1Voooo002:oooo00?o
09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo0P0006Ooool0
08[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool0
0ol0VOooooooo`0Zoooo0P0006Ooool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_oo
o`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_oo
o`030000oooooooo06Koool008[oool00ol0VOooooooo`0Zoooo00<0003oooooool0I_ooo`00R_oo
o`03o`2Ioooooooo02[oool20000Ioooo`00R_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`1V
oooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo06Koool008[oool00ol0VOooooooo`0Z
oooo00<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo02[oool20000Ioooo`00R_ooo`03o`2I
oooooooo02[oool00`000?ooooooo`1Voooo002:oooo00?o09Woooooool0:_ooo`030000oooooooo
06Koool008[oool00ol0VOooooooo`0Toooo0`0000?oool00`000?ooooooo`1Voooo002:oooo00?o
09Woooooool09Oooo`030000oooooooo00;oool00`000?ooooooo`1Voooo002:oooo00?o09Wooooo
ool08_ooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool00;3oool00`000?oo
o`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Goool300000_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002oooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.44268 .26487 L
.46172 .26487 L
.47994 .26487 L
.48519 .26487 L
.48778 .26487 L
.49018 .26487 L
.49235 .26487 L
.49356 .26487 L
s
.49356 .26487 m
.494 .61803 L
s
0 .4 1 r
.02381 .26445 m
.06244 .2643 L
.10458 .26408 L
.14415 .26379 L
.18221 .26341 L
.22272 .26287 L
.26171 .26215 L
.30316 .26111 L
.34309 .25976 L
.3815 .25803 L
.42237 .25564 L
.44268 .25422 L
.46172 .25276 L
.47994 .25127 L
.48519 .25082 L
.48778 .2506 L
.49018 .25039 L
.49235 .25021 L
.49356 .2501 L
.49466 .26487 L
.49587 .26487 L
.49718 .26487 L
.49955 .26487 L
.54055 .26487 L
.58004 .26487 L
.61801 .26487 L
.65844 .26487 L
.69735 .26487 L
.73871 .26487 L
.77855 .26487 L
.81688 .26487 L
.85766 .26487 L
.89693 .26487 L
.93468 .26487 L
.97489 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@0000I<ol000<0I_lco`0co`009c?o0080000^<ol00P0003Ooool006_oool500004c?o00/0I_lY
<ol000<0000co`0co`00;c?o00@0000coooo001Qoooo2P00008co`0F06Ko2S?o000306Ko<ol0<ol0
02Lco`000`0003?o03?o000c<ol02P0002Woool005Koool30000501Vob4co`000`1Voc?o03?o000V
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool010000?ooooooool0V@?oool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`030000oooooooo01?oool00ol0VOooooooo`07oooo00<0003oooooool07Oooo`030000
oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00SOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool0
08goool00ol0VOooooooo`0Woooo0P0006Ooool008goool00ol0VOooooooo`0Woooo00<0003ooooo
ool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Wooooo
ool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo0P0006Ooool008goool0
0ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOoo
ooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool20000Ioooo`00SOoo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000
oooooooo06Koool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2I
oooooooo02Ooool20000Ioooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=
oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Ooooo1@00
00?oool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool08Oooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo002=oooo00?o09Woooooool08Oooo`030000oooooooo00?oool30000I_oo
o`00SOooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00SOoo
o`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00SOooo`03o`2I
oooooooo023oool200001Oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo0P00
06Ooool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool0
08goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool2
0000Ioooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Wooooo
ool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_oo
o`00SOooo`03o`2Ioooooooo02Ooool20000Ioooo`00SOooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOoo
ooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1V
oooo002=oooo00?o09Woooooool09oooo`80001Woooo002=oooo00?o09Woooooool09oooo`030000
oooooooo06Koool008goool00ol0VOooooooo`0Ooooo100000Coool00`000?ooooooo`1Voooo002=
oooo00?o09Woooooool07oooo`030000oooooooo00Goool00`000?ooooooo`1Voooo002=oooo00?o
09Woooooool08?ooo`030000oooooooo00Coool30000I_ooo`00SOooo`03o`2Ioooooooo027oool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo01ooool010000?oo
ooooo`0000Coool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool08?ooo`800005oooo00<0
003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool20000Ioooo`00SOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool0
08goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool0
0`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`80001Woooo002=oooo00?o09Wooooo
ool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_oo
o`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09ooo
o`80001Woooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOoo
ooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1V
oooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0W
oooo0P0006Ooool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2I
oooooooo023oool200001Oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Ooooo00@0
003oooooool00004oooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo027oool00`000?oo
ooooo`03oooo0`0006Koool008goool00ol0VOooooooo`0Roooo00<0003oooooool00_ooo`030000
oooooooo06Koool008goool00ol0VOooooooo`0Ooooo00@0003oooooool00004oooo00<0003ooooo
ool0I_ooo`00SOooo`03o`2Ioooooooo023oool200001Oooo`030000oooooooo06Koool008goool0
0ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool20000Iooo
o`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09ooo
o`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOoo
o`03o`2Ioooooooo02Ooool20000Ioooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1V
oooo002=oooo00?o09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0W
oooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1Voooo002=
oooo00?o09Woooooool09oooo`80001Woooo002=oooo00?o09Woooooool09oooo`030000oooooooo
06Koool008goool00ol0VOooooooo`0Woooo00<0003oooooool0I_ooo`00SOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`1Voooo002=oooo00?o09Woooooool09oooo`80001Woooo002=oooo00?o
09Woooooool09oooo`030000oooooooo06Koool008goool00ol0VOooooooo`0Woooo00<0003ooooo
ool0I_ooo`00SOooo`03o`2Ioooooooo027oool300000oooo`030000oooooooo06Koool008goool0
0ol0VOooooooo`0Roooo00<0003oooooool00_ooo`030000oooooooo06Koool008goool00ol0VOoo
ooooo`0Ooooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000
oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool2
00002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.48147 .26487 L
.49012 .26487 L
.49955 .26487 L
.50205 .26487 L
.50342 .26487 L
.50471 .26487 L
.50592 .26487 L
s
.50592 .26487 m
.50644 .61803 L
s
0 .4 1 r
.02381 .26459 m
.06244 .2645 L
.10458 .26435 L
.14415 .26416 L
.18221 .26391 L
.22272 .26355 L
.26171 .26307 L
.30316 .26239 L
.34309 .26149 L
.3815 .26035 L
.42237 .25877 L
.46172 .25687 L
.48147 .25579 L
.49012 .2553 L
.49955 .25476 L
.50205 .25462 L
.50342 .25454 L
.50471 .25447 L
.50592 .2544 L
.50722 .26487 L
.50841 .26487 L
.5095 .26487 L
.51896 .26487 L
.53984 .26487 L
.57933 .26487 L
.6173 .26487 L
.65772 .26487 L
.69663 .26487 L
.73799 .26487 L
.77784 .26487 L
.81617 .26487 L
.85695 .26487 L
.89622 .26487 L
.93397 .26487 L
.97417 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0001Hco`0@06Ko9S?o00030000<ol0<ol003<co`0:0000:Oooo`00E_ooo`/00002
<ol07P1Vo`lco`000`1Voc?o03?o000T<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00
017oool001Koool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00?o09T0003oool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`0Moooo00<0
003oooooool07_ooo`030000oooooooo01goool00`000?ooooooo`0Foooo00?o09Woooooool01?oo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo
02Goool0093oool00ol0VOooooooo`0Toooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo
02Coool00`000?ooooooo`1Voooo002@oooo00?o09Woooooool09?ooo`80001Woooo002@oooo00?o
09Woooooool09?ooo`030000oooooooo06Koool0093oool00ol0VOooooooo`0Toooo00<0003ooooo
ool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`1Voooo002@oooo00?o09Wooooo
ool09?ooo`80001Woooo002@oooo00?o09Woooooool09?ooo`030000oooooooo06Koool0093oool0
0ol0VOooooooo`0Toooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`1Voooo002@oooo00?o09Woooooool09?ooo`030000oooooooo06Koool0093oool00ol0VOoo
ooooo`0Toooo0P0006Ooool0093oool00ol0VOooooooo`0Toooo00<0003oooooool0I_ooo`00T?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`1Voooo002@oooo00?o09Woooooool09?ooo`030000
oooooooo06Koool0093oool00ol0VOooooooo`0Toooo0P0006Ooool0093oool00ol0VOooooooo`0T
oooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`1Voooo002@
oooo00?o09Woooooool07?ooo`D00003oooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo
01koool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`03oooo0`0006Koool0093oool00ol0VOooooooo`0Noooo00<0003oooooool00ooo
o`030000oooooooo06Koool0093oool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000
oooooooo06Koool0093oool00ol0VOooooooo`0Moooo0P0000Goool00`000?ooooooo`1Voooo002@
oooo00?o09Woooooool09?ooo`80001Woooo002@oooo00?o09Woooooool09?ooo`030000oooooooo
06Koool0093oool00ol0VOooooooo`0Toooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo
02Coool00`000?ooooooo`1Voooo002@oooo00?o09Woooooool09?ooo`030000oooooooo06Koool0
093oool00ol0VOooooooo`0Toooo0P0006Ooool0093oool00ol0VOooooooo`0Toooo00<0003ooooo
ool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`1Voooo002@oooo00?o09Wooooo
ool09?ooo`030000oooooooo06Koool0093oool00ol0VOooooooo`0Toooo0P0006Ooool0093oool0
0ol0VOooooooo`0Toooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`1Voooo002@oooo00?o09Woooooool09?ooo`030000oooooooo06Koool0093oool00ol0VOoo
ooooo`0Toooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo02Coool20000Ioooo`00T?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`1Voooo002@oooo00?o09Woooooool07?ooo`@00004
oooo00<0003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo01coool00`000?ooooooo`05oooo00<0
003oooooool0I_ooo`00T?ooo`03o`2Ioooooooo01goool00`000?ooooooo`04oooo0`0006Koool0
097oool00ol0VOooooooo`0Moooo00<0003oooooool00oooo`030000oooooooo06Koool0097oool0
0ol0VOooooooo`0Koooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00TOooo`03o`2I
oooooooo01coool200001Oooo`030000oooooooo06Koool0097oool00ol0VOooooooo`0Soooo0P00
06Ooool0097oool00ol0VOooooooo`0Soooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo
02?oool00`000?ooooooo`1Voooo002Aoooo00?o09Woooooool08oooo`030000oooooooo06Koool0
097oool00ol0VOooooooo`0Soooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo02?oool2
0000Ioooo`00TOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1Voooo002Aoooo00?o09Wooooo
ool08oooo`030000oooooooo06Koool0097oool00ol0VOooooooo`0Soooo00<0003oooooool0I_oo
o`00TOooo`03o`2Ioooooooo02?oool20000Ioooo`00TOooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`1Voooo002Aoooo00?o09Woooooool08oooo`030000oooooooo06Koool0097oool00ol0VOoo
ooooo`0Soooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1V
oooo002Aoooo00?o09Woooooool08oooo`80001Woooo002Aoooo00?o09Woooooool08oooo`030000
oooooooo06Koool0097oool00ol0VOooooooo`0Loooo0P0000Goool00`000?ooooooo`1Voooo002A
oooo00?o09Woooooool06oooo`040000oooooooo00001?ooo`030000oooooooo06Koool0097oool0
0ol0VOooooooo`0Moooo00<0003oooooool00oooo`<0001Voooo002Aoooo00?o09Woooooool07_oo
o`030000oooooooo00;oool00`000?ooooooo`1Voooo002Aoooo00?o09Woooooool06oooo`040000
oooooooo00001?ooo`030000oooooooo06Koool0097oool00ol0VOooooooo`0Loooo0P0000Goool0
0`000?ooooooo`1Voooo002Aoooo00?o09Woooooool08oooo`030000oooooooo06Koool0097oool0
0ol0VOooooooo`0Soooo0P0006Ooool0097oool00ol0VOooooooo`0Soooo00<0003oooooool0I_oo
o`00TOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1Voooo002Aoooo00?o09Woooooool08ooo
o`030000oooooooo06Koool0097oool00ol0VOooooooo`0Soooo0P0006Ooool0097oool00ol0VOoo
ooooo`0Soooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1V
oooo002Aoooo00?o09Woooooool08oooo`030000oooooooo06Koool0097oool00ol0VOooooooo`0S
oooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo02?oool20000Ioooo`00TOooo`03o`2I
oooooooo02?oool00`000?ooooooo`1Voooo002Aoooo00?o09Woooooool08oooo`030000oooooooo
06Koool0097oool00ol0VOooooooo`0Soooo00<0003oooooool0I_ooo`00TOooo`03o`2Ioooooooo
02?oool20000Ioooo`00TOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1Voooo002Aoooo00?o
09Woooooool08oooo`030000oooooooo06Koool0097oool00ol0VOooooooo`0Moooo0`0000?oool0
0`000?ooooooo`1Voooo002Aoooo00?o09Woooooool07_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Voooo002Aoooo00?o09Woooooool06oooo`D00003oooo0`0006Koool00:ooool010000?oo
ooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400000oooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`030000oooooooo00Coool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.5095 .26487 L
.51441 .26487 L
.5168 .26487 L
.51784 .26487 L
.51896 .26487 L
s
.51896 .26487 m
.51948 .61803 L
s
0 .4 1 r
.02381 .26473 m
.06244 .26468 L
.10458 .26461 L
.14415 .26452 L
.18221 .26439 L
.22272 .26421 L
.26171 .26398 L
.30316 .26364 L
.34309 .26319 L
.3815 .26262 L
.42237 .26183 L
.46172 .26089 L
.49955 .25984 L
.5095 .25956 L
.51441 .25942 L
.5168 .25935 L
.51784 .25932 L
.51896 .25929 L
.52026 .26487 L
.52148 .26487 L
.52417 .26487 L
.52986 .26487 L
.53984 .26487 L
.58084 .26487 L
.62033 .26487 L
.6583 .26487 L
.69873 .26487 L
.73763 .26487 L
.779 .26487 L
.81884 .26487 L
.85717 .26487 L
.89795 .26487 L
.93722 .26487 L
.97497 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;00005S?o01h0I_lR
<ol000<0000co`0co`00?C?o00l0000Joooo000@ooooo`00017oool001Koool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00@0003ooooo
oooo09T2oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool04_ooo`005_ooo`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`030000oooooooo01[oool01?l0VOooooooo`0001ooool00`000?ooooooo`0Moooo00<0
003oooooool07_ooo`030000oooooooo02Goool009Coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Wooooo
ool08?ooo`80001Woooo002Doooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool0
0ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`1Voooo002Doooo00?o09Woooooool08?ooo`80001Woooo002Doooo00?o09Woooooool08?oo
o`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000
oooooooo06Koool009Coool00ol0VOooooooo`0Poooo0P0006Ooool009Coool00ol0VOooooooo`0P
oooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002D
oooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo0P00
06Ooool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo
023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool06?ooo`D00003oooo00<0003ooooo
ool0I_ooo`00U?ooo`03o`2Ioooooooo01[oool00`000?ooooooo`03oooo00<0003oooooool0I_oo
o`00U?ooo`03o`2Ioooooooo01[oool00`000?ooooooo`03oooo0`0006Koool009Coool00ol0VOoo
ooooo`0Joooo00<0003oooooool00oooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0J
oooo00<0003oooooool00oooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Ioooo0P00
00Goool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`80001Woooo002Doooo00?o
09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Wooooo
ool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo0P0006Ooool009Coool0
0ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOoo
ooooo`0Poooo0P0006Ooool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000
oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2I
oooooooo023oool20000Ioooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002D
oooo00?o09Woooooool06?ooo`@00004oooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo
01Soool00`000?ooooooo`05oooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`04oooo0`0006Koool009Coool00ol0VOooooooo`0Joooo00<0003oooooool00ooo
o`030000oooooooo06Koool009Coool00ol0VOooooooo`0Hoooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo01Woool200001Oooo`030000oooooooo06Koool0
09Coool00ol0VOooooooo`0Poooo0P0006Ooool009Coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Wooooo
ool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_oo
o`00U?ooo`03o`2Ioooooooo023oool20000Ioooo`00U?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOoo
ooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo023oool20000Ioooo`00U?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000
oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2I
oooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`80001Woooo002D
oooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Ioooo0P00
00Goool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool06?ooo`040000oooooooo00001?oo
o`030000oooooooo06Koool009Coool00ol0VOooooooo`0Joooo00<0003oooooool00oooo`<0001V
oooo002Doooo00?o09Woooooool06oooo`030000oooooooo00;oool00`000?ooooooo`1Voooo002D
oooo00?o09Woooooool06?ooo`040000oooooooo00001?ooo`030000oooooooo06Koool009Coool0
0ol0VOooooooo`0Ioooo0P0000Goool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?oo
o`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo0P0006Ooool009Coool00ol0VOoo
ooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1V
oooo002Doooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0P
oooo0P0006Ooool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2I
oooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000oooooooo
06Koool009Coool00ol0VOooooooo`0Poooo00<0003oooooool0I_ooo`00U?ooo`03o`2Ioooooooo
023oool20000Ioooo`00U?ooo`03o`2Ioooooooo023oool00`000?ooooooo`1Voooo002Doooo00?o
09Woooooool08?ooo`030000oooooooo06Koool009Coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0I_ooo`00U?ooo`03o`2Ioooooooo023oool20000Ioooo`00U?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`1Voooo002Doooo00?o09Woooooool08?ooo`030000oooooooo06Koool009Coool0
0ol0VOooooooo`0Joooo0`0000?oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool06ooo
o`030000oooooooo00;oool00`000?ooooooo`1Voooo002Doooo00?o09Woooooool06?ooo`D00003
oooo0`0006Koool00:ooool010000?ooooooo`0006goool00;3oool00`000?ooo`00001]oooo002a
oooo0P0006goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool500000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
01?oool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool2
00000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.44089) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.51896 .26487 L
.52455 .26487 L
.52731 .26487 L
.52865 .26487 L
.52986 .26487 L
.53105 .26487 L
s
.53105 .26487 m
.5315 .61803 L
s
0 .4 1 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.51896 .26487 L
.52455 .26487 L
.52731 .26487 L
.52865 .26487 L
.52986 .26487 L
.53105 .26487 L
.53217 .26487 L
.53335 .26487 L
.53463 .26487 L
.53984 .26487 L
.58084 .26487 L
.62033 .26487 L
.6583 .26487 L
.69873 .26487 L
.73763 .26487 L
.779 .26487 L
.81884 .26487 L
.85717 .26487 L
.89795 .26487 L
.93722 .26487 L
.97497 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.44089) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:[oool5000000?oool0003o
ool01Oooo`<0001Voooo002Woooo1P000003<ol00000000000800005oooo00<0003oooooool0I_oo
o`00YOooo`800008<ol000<0000co`0000000P0000?oool00`000?ooooooo`1Voooo002Toooo00<0
000co`0co`002C?o00800002<ol000@0003oooooool0001Xoooo002Soooo00<0000co`0co`003c?o
00<0001Xoooo002Qoooo0P0001@co`020000Ioooo`00X?ooo`030000<ol0<ol001@co`020000Iooo
o`00Woooo`030000<ol0<ol001Dco`000`0003?o0000001Voooo002Noooo00<0000co`0co`005S?o
00040000<ol0<ol00000IOooo`00WOooo`030000<ol0<ol001Lco`0200000S?o00030000oooooooo
06;oool009coool00`0003?o03?o000H<ol000<0000co`0co`000S?o00030000oooooooo067oool0
09_oool00`0003?o03?o000I<ol000<0000co`0co`000c?o00030000oooooooo063oool009[oool0
0`0003?o03?o000J<ol000<0000co`0co`0013?o00030000oooooooo05ooool009Woool00`0003?o
03?o000K<ol000<0000co`0co`001C?o00030000oooooooo05koool009Soool00`0003?o03?o000L
<ol00P0000Lco`000`000?ooooooo`1Moooo002Goooo00<0000co`0co`007C?o00030000<ol0<ol0
00Lco`000`000?ooooooo`1Loooo002Foooo00<0000co`0co`007S?o00030000<ol0<ol000Pco`00
0`000?ooooooo`1Koooo002Eoooo00<0000co`0co`007c?o00030000<ol0<ol000Tco`000`000?oo
ooooo`1Joooo002Doooo00<0000co`0co`0083?o0080000;<ol000<0003oooooool0FOooo`00Tooo
o`030000<ol0<ol0024co`000`0003?o03?o000;<ol000<0003oooooool0F?ooo`00T_ooo`030000
<ol0<ol0028co`000`0003?o03?o000<<ol000<0003oooooool0Eoooo`00TOooo`030000<ol0<ol0
01/co`0500000c?o00030000<ol0<ol000dco`000`000?ooooooo`1Foooo002@oooo00<0000co`0c
o`007S?o00030000<ol0<ol000<co`000`0003?o03?o000><ol000<0003oooooool0EOooo`00Sooo
o`030000<ol0<ol001lco`000`0003?o03?o0003<ol00`0000lco`000`000?ooooooo`1Doooo002>
oooo00<0000co`0co`0063?o00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol0010co`00
0`000?ooooooo`1Coooo002=oooo00<0000co`0co`008C?o00030000<ol0<ol000<co`000`0003?o
03?o000A<ol000<0003oooooool0D_ooo`00S?ooo`030000<ol0<ol0024co`0200001C?o00030000
<ol0<ol0018co`000`000?ooooooo`1Aoooo002:oooo0P0002/co`02000053?o00030000oooooooo
053oool008Woool00`0003?o03?o000[<ol000<0000co`0co`0053?o0080001@oooo0028oooo00<0
000co`0co`00;3?o00030000<ol0<ol001Hco`000`000?ooooooo`1=oooo0027oooo00<0000co`0c
o`00;C?o00030000<ol0<ol001Lco`000`000?ooooooo`1<oooo0026oooo00<0000co`0co`00;S?o
00030000<ol0<ol001Pco`000`000?ooooooo`1;oooo0024oooo0P00034co`0200006S?o0080001;
oooo0022oooo0P0003<co`000`0003?o03?o000K<ol000<0003oooooool0B?ooo`006Oooo`80000O
oooo0`0001coool200007Oooo`@00004oooo0P0001Hco`0500006S?o00030000<ol0<ol001/co`05
00006oooo`@0000Woooo000Hoooo00@0003oooooool0000Ooooo00<0003oooooool06_ooo`040000
oooooooo00007?ooo`030000oooooooo00Coool00`0003?o03?o000H<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0300006oooo`030000oooooooo02Soool001_oool00`000?ooooooo`0J
oooo1@0001goool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00030000<ol0<ol00080000Joooo00<0003oooooool09oooo`004_ooo`@00003
oooo0P0001Ooool400000_ooo`040000oooooooo00005_ooo`@00005oooo00<0003oooooool05?oo
o`@00004oooo0`0001Dco`04000013?o00030000<ol0<ol001Xco`000`0003?o03?o000M<ol000<0
000co`0co`000S?o0080000Ioooo00<0003oooooool09_ooo`006Oooo`030000oooooooo01goool0
0`000?ooo`00000Loooo00@0003oooooool0000Loooo100001hco`000`0003?o03?o000J<ol000<0
000co`0co`007C?o00030000<ol0<ol000@co`0200005Oooo`040000oooooooo00009oooo`006Ooo
o`<0000Noooo0P0001goool200006_ooo`H0000N<ol00P0001`co`000`0003?o03?o000L<ol00P00
00Pco`0300004oooo`80000Xoooo001`oooo1@00048co`020000:S?o00D0000hoooo001[oooo1@00
04Lco`000`0003?o03?o000^<ol01@0003?oool006Koool50000C3?o00030000<ol0<ol003<co`05
0000;_ooo`00HOooo`D0001A<ol000<0000co`0co`00>3?o00X0000Toooo0018oooo6@0005Hco`00
0`0003?o03?o0012<ol0300001Soool0017oooom00004_ooo`005oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool04oooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Wooooo
ool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo0P0006Ooool009Ooool0
0ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?oo
ooooo`1Voooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOoo
ooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool20000Ioooo`00Uooo
o`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Oooo`030000
oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2I
oooooooo01goool20000Ioooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002G
oooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0
003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o
09Woooooool07Oooo`80001Woooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool0
09Ooool00ol0VOooooooo`0Eoooo1@0000?oool00`000?ooooooo`1Voooo002Goooo00?o09Wooooo
ool05oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool05ooo
o`030000oooooooo00?oool30000I_ooo`00Uoooo`03o`2Ioooooooo01Ooool00`000?ooooooo`03
oooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01Ooool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01Koool200001Oooo`030000oooooooo06Koool0
09Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool2
0000Ioooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Wooooo
ool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_oo
o`00Uoooo`03o`2Ioooooooo01goool20000Ioooo`00Uoooo`03o`2Ioooooooo01goool00`000?oo
ooooo`1Voooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOoo
ooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1V
oooo002Goooo00?o09Woooooool07Oooo`80001Woooo002Goooo00?o09Woooooool07Oooo`030000
oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2I
oooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Oooo`80001Woooo002G
oooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Eoooo1000
00Coool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool05Oooo`030000oooooooo00Goool0
0`000?ooooooo`1Voooo002Goooo00?o09Woooooool05_ooo`030000oooooooo00Coool30000I_oo
o`00Uoooo`03o`2Ioooooooo01Ooool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Uooo
o`03o`2Ioooooooo01Goool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Goooo00?o
09Woooooool05_ooo`800005oooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool0
0`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Oooo`80001Woooo002Goooo00?o09Wooooo
ool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_oo
o`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Ooo
o`80001Woooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOoo
ooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1V
oooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0M
oooo0P0006Ooool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2I
oooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Oooo`030000oooooooo
06Koool009Ooool00ol0VOooooooo`0Moooo0P0006Ooool009Ooool00ol0VOooooooo`0Moooo00<0
003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o
09Woooooool05_ooo`800005oooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01Goool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool05oooo`030000
oooooooo00?oool30000I_ooo`00Uoooo`03o`2Ioooooooo01Soool00`000?ooooooo`02oooo00<0
003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01Goool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo002Goooo00?o09Woooooool05_ooo`800005oooo00<0003oooooool0I_ooo`00Uooo
o`03o`2Ioooooooo01goool20000Ioooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1V
oooo002Goooo00?o09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0M
oooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002G
oooo00?o09Woooooool07Oooo`80001Woooo002Goooo00?o09Woooooool07Oooo`030000oooooooo
06Koool009Ooool00ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo
01goool00`000?ooooooo`1Voooo002Goooo00?o09Woooooool07Oooo`80001Woooo002Goooo00?o
09Woooooool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo00<0003ooooo
ool0I_ooo`00Uoooo`03o`2Ioooooooo01goool00`000?ooooooo`1Voooo002Goooo00?o09Wooooo
ool07Oooo`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Moooo0P0006Ooool009Ooool0
0ol0VOooooooo`0Moooo00<0003oooooool0I_ooo`00Uoooo`03o`2Ioooooooo01Ooool300000ooo
o`030000oooooooo06Koool009Ooool00ol0VOooooooo`0Hoooo00<0003oooooool00_ooo`030000
oooooooo06Koool009Ooool00ol0VOooooooo`0Eoooo1@0000?oool30000I_ooo`00[oooo`040000
oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool0
0?oooolQoooo001Ooooo00<0003oooooool0G?ooo`030000oooooooo05ooool005koool00`000?oo
ooooo`08oooo00<0003oooooool0Doooo`030000oooooooo05koool005koool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0`0000;oool200001Oooo`<00003oooo0`0000;oool2
00001?ooo`800003oooo0`0000Goool01@000?ooooooooooo`000003oooo1@0000;oool200004Ooo
o`030000oooooooo05koool005koool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0
003oool000001_ooo`050000oooooooooooo000000;oool00`000?ooooooo`0>oooo00<0003ooooo
ool0G_ooo`00GOooo`030000oooooooo00;oool00`000?ooooooo`0<oooo1@0000Ooool5000000?o
ool0000000000`000005oooo0000oooooooo000000;oool010000?ooooooo`0000?oool300001_oo
o`030000oooooooo00Goool01@000?ooooooooooo`000002oooo00<0003oooooool03oooo`030000
oooooooo05goool005koool00`000?ooooooo`0500002oooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`800003oooo00@0
003oooooool00005oooo00<0003oool000001_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`0>oooo00<0003oooooool0G_ooo`00G_ooo`050000oooooooooooo000000ooool00`000?oo
o`000009oooo00<0003oool000000oooo`030000oooo000000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000Coool01@000?ooooooooooo`000005oooo00D0
003oooooooooool000000_ooo`030000oooooooo00Coool200000_ooo`<00003oooo00<0003ooooo
ool0G_ooo`00Goooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool200001?oo
o`800004oooo0`0000goool200001?ooo`800003oooo0`0000;oool01P000?ooooooo`000?ooo`00
00;oool00`000?ooooooo`1Ooooo002foooo00<0003oooooool00P0006Goool00;Goool200000_oo
o`<0001Toooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.72869, \
-3.20208, 0.0312172, 0.0448981}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.72869, -3.20208, 0.0312172, 0.0448981}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53057 .26487 L
.53984 .26487 L
.54221 .26487 L
.54337 .26487 L
.54444 .26487 L
s
.54444 .26487 m
.54493 .61803 L
s
0 .4 1 r
.02381 .26501 m
.06244 .26506 L
.10458 .26513 L
.14415 .26523 L
.18221 .26535 L
.22272 .26553 L
.26171 .26577 L
.30316 .26611 L
.34309 .26655 L
.3815 .26712 L
.42237 .26791 L
.46172 .26885 L
.49955 .2699 L
.52059 .2705 L
.53057 .27077 L
.53984 .27101 L
.54221 .27107 L
.54337 .2711 L
.54444 .27113 L
.54567 .26487 L
.54632 .26487 L
.54701 .26487 L
.54934 .26487 L
.55972 .26487 L
.57861 .26487 L
.61658 .26487 L
.65701 .26487 L
.69592 .26487 L
.73728 .26487 L
.77712 .26487 L
.81545 .26487 L
.85623 .26487 L
.8955 .26487 L
.93325 .26487 L
.97345 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0
I_l00`1Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000
06Ko06Ko00@0I_l00`00001Vo`1Vo`0306Ko00<00000I_l0I_l0101Vo`030000oooooooo00?oool0
10000?ooooooo`1Vo`;oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo01goool0
0`000?ooooooo`0Hoooo1@1Vo`04000006Ko06Ko06Ko7?ooo`030000oooooooo01goool00`000?oo
ooooo`0Noooo00<0003oooooool09Oooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1V
oooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0J
oooo0P0006Ooool009[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_ooo`030000oooooooo
06Koool009[oool00ol0VOooooooo`0Joooo0P0006Ooool009[oool00ol0VOooooooo`0Joooo00<0
003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o
09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool20000Ioooo`00V_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool0
0ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool20000Iooo
o`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_oo
o`030000oooooooo06Koool009[oool00ol0VOooooooo`0Boooo1@0000?oool00`000?ooooooo`1V
oooo002Joooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002J
oooo00?o09Woooooool05?ooo`030000oooooooo00?oool30000I_ooo`00V_ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01Coool0
0`000?ooooooo`03oooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01?oool200001Ooo
o`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo0P0006Ooool009[oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1V
oooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0J
oooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool20000Ioooo`00V_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_ooo`030000oooooooo
06Koool009[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo
01[oool20000Ioooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o
09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Wooooo
ool06_ooo`80001Woooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool0
0ol0VOooooooo`0Boooo100000Coool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool04_oo
o`030000oooooooo00Goool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool04oooo`030000
oooooooo00Coool30000I_ooo`00V_ooo`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo002Joooo00?o09Woooooool04oooo`800005oooo00<0003oooooool0I_ooo`00V_oo
o`03o`2Ioooooooo01[oool20000Ioooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1V
oooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0J
oooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002J
oooo00?o09Woooooool06_ooo`80001Woooo002Joooo00?o09Woooooool06_ooo`030000oooooooo
06Koool009[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_ooo`80001Woooo002Joooo00?o
09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Wooooo
ool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo0P0006Ooool009[oool0
0ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01?oool200001Ooo
o`030000oooooooo06Koool009[oool00ol0VOooooooo`0Boooo00@0003oooooool00004oooo00<0
003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo0`0006Koool0
09[oool00ol0VOooooooo`0Eoooo00<0003oooooool00_ooo`030000oooooooo06Koool009[oool0
0ol0VOooooooo`0Boooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00V_ooo`03o`2I
oooooooo01?oool200001Oooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0
003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool20000Ioooo`00V_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool0
09[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool2
0000Ioooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Wooooo
ool06_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_oo
o`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1Voooo002Joooo00?o09Woooooool06_oo
o`80001Woooo002Joooo00?o09Woooooool06_ooo`030000oooooooo06Koool009[oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`1V
oooo002Joooo00?o09Woooooool06_ooo`80001Woooo002Joooo00?o09Woooooool06_ooo`030000
oooooooo06Koool009[oool00ol0VOooooooo`0Joooo00<0003oooooool0I_ooo`00V_ooo`03o`2I
oooooooo01Coool300000oooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Eoooo00<0
003oooooool00_ooo`030000oooooooo06Koool009[oool00ol0VOooooooo`0Boooo1@0000?oool3
0000I_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool2
0000KOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53984 .26487 L
.54934 .26487 L
.55195 .26487 L
.55338 .26487 L
.55472 .26487 L
.55598 .26487 L
.55669 .26487 L
s
.55669 .26487 m
.55695 .61803 L
s
0 .4 1 r
.02381 .26515 m
.06244 .26525 L
.10458 .2654 L
.14415 .26559 L
.18221 .26584 L
.22272 .2662 L
.26171 .26667 L
.30316 .26736 L
.34309 .26825 L
.3815 .2694 L
.42237 .27098 L
.46172 .27288 L
.49955 .27498 L
.52059 .27618 L
.53984 .27722 L
.54934 .27769 L
.55195 .27781 L
.55338 .27788 L
.55472 .27794 L
.55598 .278 L
.55669 .27803 L
.55734 .26487 L
.5585 .26487 L
.55972 .26487 L
.57861 .26487 L
.61658 .26487 L
.65701 .26487 L
.69592 .26487 L
.73728 .26487 L
.77712 .26487 L
.81545 .26487 L
.85623 .26487 L
.8955 .26487 L
.93325 .26487 L
.97345 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`03000006Ko06Ko00@0I_l00`00001Vo`1Vo`03
06Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0
I_l00`1Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0306Ko00?oool0003oool01?ooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<00000I_ooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?ooooooo`0Loooo00<0
I_l00000I_l04@1Vo`goool00`000?ooooooo`03oooo00<0I_ooooooool05oooo`030000oooooooo
01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00R_oooa80I_l00oooo`1Vooooo`0H
oooo00<0003oooooool0I_ooo`00W?ooo`80I_lIoooo00<0003oooooool0I_ooo`00WOooo`03o`2I
oooooooo01Ooool20000Ioooo`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002M
oooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0
003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool20000Ioooo`00WOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool0
09goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`80001Woooo002Moooo00?o09Wooooo
ool05oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0003oooooool0I_oo
o`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05ooo
o`80001Woooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo00ooool500000oooo`030000
oooooooo06Koool009goool00ol0VOooooooo`0Aoooo00<0003oooooool00oooo`030000oooooooo
06Koool009goool00ol0VOooooooo`0Aoooo00<0003oooooool00oooo`<0001Voooo002Moooo00?o
09Woooooool04Oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Moooo00?o09Wooooo
ool04Oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool04?oo
o`800005oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool20000Ioooo`00WOoo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000
oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`80001Woooo002M
oooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0
003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o
09Woooooool05oooo`80001Woooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool0
09goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool0
0ol0VOooooooo`0Goooo0P0006Ooool009goool00ol0VOooooooo`0Goooo00<0003oooooool0I_oo
o`00WOooo`03o`2Ioooooooo00ooool400001?ooo`030000oooooooo06Koool009goool00ol0VOoo
ooooo`0?oooo00<0003oooooool01Oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0@
oooo00<0003oooooool01?ooo`<0001Voooo002Moooo00?o09Woooooool04Oooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool03oooo`040000oooooooo00001?oo
o`030000oooooooo06Koool009goool00ol0VOooooooo`0@oooo0P0000Goool00`000?ooooooo`1V
oooo002Moooo00?o09Woooooool05oooo`80001Woooo002Moooo00?o09Woooooool05oooo`030000
oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000oooooooo
06Koool009goool00ol0VOooooooo`0Goooo0P0006Ooool009goool00ol0VOooooooo`0Goooo00<0
003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o
09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0Goooo0P0006Ooool0
09goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool0
0ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool20000Iooo
o`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool04?oo
o`800005oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo00ooool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool04Oooo`030000oooooooo00?oool3
0000I_ooo`00WOooo`03o`2Ioooooooo01;oool00`000?ooooooo`02oooo00<0003oooooool0I_oo
o`00WOooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002M
oooo00?o09Woooooool04?ooo`800005oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`80001Woooo002Moooo00?o
09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOooooooo`0Goooo00<0003ooooo
ool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Wooooo
ool05oooo`80001Woooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool0
0ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000oooooooo06Koool009goool00ol0VOoo
ooooo`0Goooo0P0006Ooool009goool00ol0VOooooooo`0Goooo00<0003oooooool0I_ooo`00WOoo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002Moooo00?o09Woooooool05oooo`030000
oooooooo06Koool009goool00ol0VOooooooo`0Goooo0P0006Ooool009goool00ol0VOooooooo`0G
oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1Voooo002M
oooo00?o09Woooooool04Oooo`<00003oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo
01;oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00WOooo`03o`2Ioooooooo00ooool5
00000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOoo
o`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800003oooo100000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0003ooooo
ool01?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P00
00?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53984 .26487 L
.54934 .26487 L
.55972 .26487 L
.56446 .26487 L
.56706 .26487 L
.56834 .26487 L
.56951 .26487 L
s
.56951 .26487 m
.56996 .61803 L
s
0 .4 1 r
.02381 .26529 m
.06244 .26544 L
.10458 .26566 L
.14415 .26595 L
.18221 .26633 L
.22272 .26688 L
.26171 .26759 L
.30316 .26863 L
.34309 .26999 L
.3815 .27171 L
.42237 .27411 L
.46172 .27698 L
.49955 .28016 L
.52059 .28197 L
.53984 .28355 L
.54934 .28426 L
.55972 .28497 L
.56446 .28527 L
.56706 .28542 L
.56834 .2855 L
.56951 .28556 L
.57063 .26487 L
.57181 .26487 L
.57429 .26487 L
.57861 .26487 L
.61658 .26487 L
.65701 .26487 L
.69592 .26487 L
.73728 .26487 L
.77712 .26487 L
.81545 .26487 L
.85623 .26487 L
.8955 .26487 L
.93325 .26487 L
.97345 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
10000?ooooooooooo`<0I_l00`00001Vo`1Vo`0306Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko
00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko0080I_l2oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00D0003oooooooooool0I_l00_ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo01koool00`000?oo
ooooo`08oooo501Vo`03oooo0000oooo01koool00`000?ooooooo`07oooo00<0I_ooooooool04ooo
o`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00M_oooa@0I_lG
oooo00<0I_ooooooool04oooo`030000oooooooo06Koool008[oool806Ko3oooo`0306Kooooooooo
01?oool00`000?ooooooo`1Voooo002Boooo401VoaGoool20000Ioooo`00XOooo`03o`2Ioooooooo
01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04oooo`030000oooooooo06Koool0
0:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool2
0000Ioooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Wooooo
ool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_oo
o`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04ooo
o`80001Woooo002Qoooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool00ol0VOoo
ooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1V
oooo002Qoooo00?o09Woooooool04oooo`80001Woooo002Qoooo00?o09Woooooool04oooo`030000
oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2I
oooooooo00_oool500000oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0=oooo00<0
003oooooool00oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0=oooo00<0003ooooo
ool00oooo`<0001Voooo002Qoooo00?o09Woooooool03Oooo`030000oooooooo00?oool00`000?oo
ooooo`1Voooo002Qoooo00?o09Woooooool03Oooo`030000oooooooo00?oool00`000?ooooooo`1V
oooo002Qoooo00?o09Woooooool03?ooo`800005oooo00<0003oooooool0I_ooo`00XOooo`03o`2I
oooooooo01?oool20000Ioooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Q
oooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0
003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o
09Woooooool04oooo`80001Woooo002Qoooo00?o09Woooooool04oooo`030000oooooooo06Koool0
0:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04oooo`80001Woooo002Qoooo00?o09Wooooo
ool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_oo
o`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04ooo
o`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo0P0006Ooool00:7oool00ol0VOoo
ooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo00_oool400001?ooo`030000
oooooooo06Koool00:7oool00ol0VOooooooo`0;oooo00<0003oooooool01Oooo`030000oooooooo
06Koool00:7oool00ol0VOooooooo`0<oooo00<0003oooooool01?ooo`<0001Voooo002Qoooo00?o
09Woooooool03Oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Qoooo00?o09Wooooo
ool02oooo`040000oooooooo00001?ooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0<
oooo0P0000Goool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04oooo`80001Woooo002Q
oooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0
003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o
09Woooooool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo0P0006Ooool0
0:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool0
0ol0VOooooooo`0Coooo0P0006Ooool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_oo
o`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04ooo
o`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOoo
o`03o`2Ioooooooo01?oool20000Ioooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1V
oooo002Qoooo00?o09Woooooool03?ooo`800005oooo00<0003oooooool0I_ooo`00XOooo`03o`2I
oooooooo00_oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Qoooo00?o09Wooooo
ool03Oooo`030000oooooooo00?oool30000I_ooo`00XOooo`03o`2Ioooooooo00koool00`000?oo
ooooo`02oooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo00_oool010000?ooooooo`00
00Coool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool03?ooo`800005oooo00<0003ooooo
ool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Wooooo
ool04oooo`80001Woooo002Qoooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool0
0ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?oo
ooooo`1Voooo002Qoooo00?o09Woooooool04oooo`80001Woooo002Qoooo00?o09Woooooool04ooo
o`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOoo
o`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool04oooo`030000
oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo0P0006Ooool00:7oool00ol0VOooooooo`0C
oooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1Voooo002Q
oooo00?o09Woooooool04oooo`030000oooooooo06Koool00:7oool00ol0VOooooooo`0Coooo0P00
06Ooool00:7oool00ol0VOooooooo`0Coooo00<0003oooooool0I_ooo`00XOooo`03o`2Ioooooooo
01?oool00`000?ooooooo`1Voooo002Qoooo00?o09Woooooool03Oooo`<00003oooo00<0003ooooo
ool0I_ooo`00XOooo`03o`2Ioooooooo00koool00`000?ooooooo`02oooo00<0003oooooool0I_oo
o`00XOooo`03o`2Ioooooooo00_oool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]
oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool00ooo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002ooo
o`050000oooooooooooo000007goool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.55838 .26487 L
.56817 .26487 L
.57355 .26487 L
.57861 .26487 L
.57995 .26487 L
.58137 .26487 L
.58211 .26487 L
s
.58211 .26487 m
.58244 .61803 L
s
0 .4 1 r
.02381 .26544 m
.06244 .26564 L
.10458 .26594 L
.14415 .26633 L
.18221 .26684 L
.22272 .26758 L
.26171 .26854 L
.30316 .26994 L
.34309 .27177 L
.3815 .2741 L
.42237 .27733 L
.46172 .28121 L
.49955 .28549 L
.53984 .29006 L
.55838 .29187 L
.56817 .29268 L
.57355 .29307 L
.57861 .29341 L
.57995 .29349 L
.58137 .29357 L
.58211 .29362 L
.58293 .26487 L
.58367 .26487 L
.58436 .26487 L
.58957 .26487 L
.59975 .26487 L
.61984 .26487 L
.65874 .26487 L
.70011 .26487 L
.73995 .26487 L
.77828 .26487 L
.81906 .26487 L
.85833 .26487 L
.89608 .26487 L
.93628 .26487 L
.97497 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`03000006Ko06Ko00<0I_l0
0`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00@0I_l00`00001Vo`1Vo`03
06Ko00<00000I_l0I_l0101Vo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool07Oooo`030000oooooooo01koool00`00001Vo`1Vo`0B06Ko2ooo
o`030000oooooooo01goool00`000?ooooooo`0:oooo00<0I_ooooooool04?ooo`030000oooooooo
01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00K?oooa@0I_lToooo00<0I_oooooo
ool04?ooo`030000oooooooo06Koool0083oool:06Ko6_ooo`0306Kooooooooo013oool00`000?oo
ooooo`1Voooo002:oooo201Voa;oool00`1Vooooooooo`0@oooo0P0006Ooool009;oool506Ko3Ooo
o`0306Kooooooooo013oool00`000?ooooooo`1Voooo002Goooo3P1Voa;oool00`000?ooooooo`1V
oooo002Toooo00<0I_ooooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@
oooo0P0006Ooool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2I
oooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`030000oooooooo
06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo
013oool20000Ioooo`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o
09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0003ooooo
ool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool20000Ioooo`00Y?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool00:Coool0
0ol0VOooooooo`08oooo1@0000?oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool02_oo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool02_ooo`030000
oooooooo00?oool30000I_ooo`00Y?ooo`03o`2Ioooooooo00[oool00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo00[oool00`000?ooooooo`03oooo00<0003ooooo
ool0I_ooo`00Y?ooo`03o`2Ioooooooo00Woool200001Oooo`030000oooooooo06Koool00:Coool0
0ol0VOooooooo`0@oooo0P0006Ooool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_oo
o`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?oo
o`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?oo
o`03o`2Ioooooooo013oool20000Ioooo`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1V
oooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@
oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool20000Ioooo`00Y?ooo`03o`2I
oooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`030000oooooooo
06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`80001Woooo002Toooo00?o
09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`08oooo100000Coool0
0`000?ooooooo`1Voooo002Toooo00?o09Woooooool02?ooo`030000oooooooo00Goool00`000?oo
ooooo`1Voooo002Toooo00?o09Woooooool02Oooo`030000oooooooo00Coool30000I_ooo`00Y?oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2I
oooooooo00Soool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Toooo00?o09Wooooo
ool02Oooo`800005oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool20000Iooo
o`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?oo
o`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?oo
o`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`80001W
oooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@
oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002T
oooo00?o09Woooooool04?ooo`80001Woooo002Toooo00?o09Woooooool04?ooo`030000oooooooo
06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool0
0:Coool00ol0VOooooooo`0@oooo0P0006Ooool00:Coool00ol0VOooooooo`0@oooo00<0003ooooo
ool0I_ooo`00Y?ooo`03o`2Ioooooooo00Woool200001Oooo`030000oooooooo06Koool00:Coool0
0ol0VOooooooo`08oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2I
oooooooo00[oool00`000?ooooooo`03oooo0`0006Koool00:Coool00ol0VOooooooo`0;oooo00<0
003oooooool00_ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`08oooo00@0003ooooo
ool00004oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo00Woool200001Oooo`030000
oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2I
oooooooo013oool20000Ioooo`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002T
oooo00?o09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0
003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool20000Ioooo`00Y?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool0
0:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?ooo`80001Woooo002Toooo00?o09Wooooo
ool04?ooo`030000oooooooo06Koool00:Coool00ol0VOooooooo`0@oooo00<0003oooooool0I_oo
o`00Y?ooo`03o`2Ioooooooo013oool00`000?ooooooo`1Voooo002Toooo00?o09Woooooool04?oo
o`80001Woooo002Toooo00?o09Woooooool04?ooo`030000oooooooo06Koool00:Coool00ol0VOoo
ooooo`0@oooo00<0003oooooool0I_ooo`00Y?ooo`03o`2Ioooooooo00[oool300000oooo`030000
oooooooo06Koool00:Coool00ol0VOooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo
06Koool00:Coool00ol0VOooooooo`08oooo1@0000?oool30000I_ooo`00[oooo`040000oooooooo
0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002oooo`050000oooooooooooo000007goool007[oool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`D00003oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.55838 .26487 L
.57861 .26487 L
.58392 .26487 L
.58957 .26487 L
.59232 .26487 L
.59367 .26487 L
.59491 .26487 L
s
.59491 .26487 m
.59536 .61803 L
s
0 .4 1 r
.02381 .26559 m
.06244 .26584 L
.10458 .26623 L
.14415 .26672 L
.18221 .26737 L
.22272 .2683 L
.26171 .26953 L
.30316 .2713 L
.34309 .27362 L
.3815 .27658 L
.42237 .28067 L
.46172 .28559 L
.49955 .29103 L
.53984 .29683 L
.55838 .29912 L
.57861 .30107 L
.58392 .30146 L
.58957 .30182 L
.59232 .30197 L
.59367 .30203 L
.59491 .30209 L
.59604 .26487 L
.59723 .26487 L
.59975 .26487 L
.61984 .26487 L
.65781 .26487 L
.69823 .26487 L
.73714 .26487 L
.7785 .26487 L
.81835 .26487 L
.85668 .26487 L
.89746 .26487 L
.93672 .26487 L
.97448 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00<0I_l0
0`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00@0I_l00`00001Vo`1Vo`03
06Ko00<00000I_l0I_l0101Vo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`040000oooooooo06Ko0_ooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool07_ooo`03000006Ko06Ko0180I_l;
oooo00<0003oooooool07Oooo`030000oooooooo00goool00`1Vooooooooo`0=oooo00<0003ooooo
ool07Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo001/oooo2P1Voc7oool00`1Voooo
ooooo`0=oooo00<0003oooooool0I_ooo`00M_ooo`X0I_lWoooo00<0I_ooooooool03Oooo`030000
oooooooo06Koool0083oool806Ko7oooo`0306Kooooooooo00goool20000Ioooo`00R?ooo`D0I_lJ
oooo00<0I_ooooooool03Oooo`030000oooooooo06Koool008goool706Ko4oooo`0306Kooooooooo
00goool00`000?ooooooo`1Voooo002Doooo201Vo`_oool00`1Vooooooooo`0=oooo00<0003ooooo
ool0I_ooo`00W?ooo`T0I_l2oooo00<0I_ooooooool03Oooo`80001Woooo002Uoooo0`1Vo`ooool0
0`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?oo
ooooo`1Voooo002Woooo00?o09Woooooool03Oooo`80001Woooo002Woooo00?o09Woooooool03Ooo
o`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yooo
o`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`80001W
oooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=
oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00Goool500000oooo`030000oooooooo
06Koool00:Ooool00ol0VOooooooo`07oooo00<0003oooooool00oooo`030000oooooooo06Koool0
0:Ooool00ol0VOooooooo`07oooo00<0003oooooool00oooo`<0001Voooo002Woooo00?o09Wooooo
ool01oooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool01ooo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool01_ooo`800005
oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool20000Ioooo`00Yoooo`03o`2I
oooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo
06Koool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo
00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`80001Woooo002Woooo00?o
09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=oooo00<0003ooooo
ool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Wooooo
ool03Oooo`80001Woooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?oo
ooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOoo
ooooo`0=oooo0P0006Ooool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yooo
o`03o`2Ioooooooo00Goool400001?ooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`06oooo00<0
003oooooool01?ooo`<0001Voooo002Woooo00?o09Woooooool01oooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo002Woooo00?o09Woooooool01Oooo`040000oooooooo00001?ooo`030000
oooooooo06Koool00:Ooool00ol0VOooooooo`06oooo0P0000Goool00`000?ooooooo`1Voooo002W
oooo00?o09Woooooool03Oooo`80001Woooo002Woooo00?o09Woooooool03Oooo`030000oooooooo
06Koool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo
00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool0
0:Ooool00ol0VOooooooo`0=oooo0P0006Ooool00:Ooool00ol0VOooooooo`0=oooo00<0003ooooo
ool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Wooooo
ool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=oooo0P0006Ooool00:Ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?oo
ooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOoo
ooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool20000Ioooo`00Yooo
o`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool01_ooo`800005
oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Coool0
0`000?ooooooo`1Voooo002Woooo00?o09Woooooool01oooo`030000oooooooo00?oool30000I_oo
o`00Yoooo`03o`2Ioooooooo00Soool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Yooo
o`03o`2Ioooooooo00Goool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Woooo00?o
09Woooooool01_ooo`800005oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool0
0`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`80001Woooo002Woooo00?o09Wooooo
ool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_oo
o`00Yoooo`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Ooo
o`80001Woooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOoo
ooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?ooooooo`1V
oooo002Woooo00?o09Woooooool03Oooo`030000oooooooo06Koool00:Ooool00ol0VOooooooo`0=
oooo0P0006Ooool00:Ooool00ol0VOooooooo`0=oooo00<0003oooooool0I_ooo`00Yoooo`03o`2I
oooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o09Woooooool03Oooo`030000oooooooo
06Koool00:Ooool00ol0VOooooooo`0=oooo0P0006Ooool00:Ooool00ol0VOooooooo`0=oooo00<0
003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00goool00`000?ooooooo`1Voooo002Woooo00?o
09Woooooool01oooo`<00003oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Yoooo`03o`2Ioooooooo00Goool500000ooo
o`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOooo`00/Ooo
o`80001]oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.58872 .26487 L
.59405 .26487 L
.59975 .26487 L
.60256 .26487 L
.60521 .26487 L
.60637 .26487 L
.60759 .26487 L
s
.60759 .26487 m
.60784 .61803 L
s
0 .4 1 r
.02381 .26575 m
.06244 .26606 L
.10458 .26653 L
.14415 .26713 L
.18221 .26792 L
.22272 .26906 L
.26171 .27056 L
.30316 .27273 L
.34309 .27556 L
.3815 .27918 L
.42237 .28418 L
.46172 .29019 L
.49955 .29683 L
.53984 .30391 L
.55838 .30671 L
.57861 .3091 L
.58392 .30958 L
.58957 .31001 L
.59446 .31032 L
.59975 .31058 L
.60257 .31069 L
.60517 .31077 L
.60646 .3108 L
.60766 .31083 L
.60891 .26487 L
.60957 .26487 L
.61028 .26487 L
.61984 .26487 L
.6612 .26487 L
.70104 .26487 L
.73937 .26487 L
.78015 .26487 L
.81942 .26487 L
.85717 .26487 L
.89737 .26487 L
.93606 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool00_ooo`80I_l0
0`00001Vo`1Vo`0306Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`03
06Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00@00000I_l0
I_l0I_l2oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`00001V
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo01Goool906Ko00<00000I_l0
I_l0201VoaGoool00`000?ooooooo`0Moooo00<0003oooooool04?ooo`03o`2I06Kooooo00[oool0
0`000?ooooooo`0Moooo00<0003oooooool07_ooo`030000oooooooo02Goool006;oool:06Ko?_oo
o`03o`2I06Kooooo00[oool00`000?ooooooo`1Voooo001/oooo2P1VocCoool00ol0V@1Vooooo`0:
oooo00<0003oooooool0I_ooo`00M_ooo`P0I_l/oooo00?o09T0I_ooool02_ooo`80001Woooo001n
oooo1@1VobOoool00`1Vooooooooo`0:oooo00<0003oooooool0I_ooo`00Poooo`L0I_lPoooo00<0
I_ooooooool02_ooo`030000oooooooo06Koool008[oool806Ko6?ooo`0306Kooooooooo00[oool0
0`000?ooooooo`1Voooo002Boooo1@1Voa?oool00`1Vooooooooo`0:oooo0P0006Ooool009Ooool5
06Ko3_ooo`0306Kooooooooo00[oool00`000?ooooooo`1Voooo002Loooo201Vo`Koool00`1Voooo
ooooo`0:oooo00<0003oooooool0I_ooo`00Y?ooo`L0I_l<oooo00<0003oooooool0I_ooo`00Z_oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`80001W
oooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:
oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Z
oooo00?o09Woooooool02_ooo`80001Woooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo
06Koool00:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo
00;oool500000oooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`04oooo00<0003oooooool00ooo
o`<0001Voooo002Zoooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`1V
oooo002Zoooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Z
oooo00?o09Woooooool00oooo`800005oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo
00[oool20000Ioooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o
09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Wooooo
ool02_ooo`80001Woooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo06Koool00:[oool0
0ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`80001Woooo002Zoooo00?o09Woooooool02_oo
o`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`030000
oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo0P0006Ooool00:[oool00ol0VOooooooo`0:
oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00;oool400001?ooo`030000oooooooo
06Koool00:[oool00ol0VOooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo06Koool0
0:[oool00ol0VOooooooo`03oooo00<0003oooooool01?ooo`<0001Voooo002Zoooo00?o09Wooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool00_oo
o`040000oooooooo00001?ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`03oooo0P00
00Goool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`80001Woooo002Zoooo00?o
09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Wooooo
ool02_ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo0P0006Ooool00:[oool0
0ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOoo
ooooo`0:oooo0P0006Ooool00:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`030000
oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2I
oooooooo00[oool20000Ioooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Z
oooo00?o09Woooooool00oooo`800005oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo
00;oool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool01?oo
o`030000oooooooo00?oool30000I_ooo`00Z_ooo`03o`2Ioooooooo00Goool00`000?ooooooo`02
oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00;oool010000?ooooooo`0000Coool0
0`000?ooooooo`1Voooo002Zoooo00?o09Woooooool00oooo`800005oooo00<0003oooooool0I_oo
o`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_oo
o`80001Woooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOoo
ooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1V
oooo002Zoooo00?o09Woooooool02_ooo`80001Woooo002Zoooo00?o09Woooooool02_ooo`030000
oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2I
oooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o09Woooooool02_ooo`030000oooooooo
06Koool00:[oool00ol0VOooooooo`0:oooo0P0006Ooool00:[oool00ol0VOooooooo`0:oooo00<0
003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`1Voooo002Zoooo00?o
09Woooooool02_ooo`030000oooooooo06Koool00:[oool00ol0VOooooooo`0:oooo0P0006Ooool0
0:[oool00ol0VOooooooo`0:oooo00<0003oooooool0I_ooo`00Z_ooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`1Voooo002Zoooo00?o09Woooooool01?ooo`<00003oooo00<0003oooooool0I_oo
o`00Z_ooo`03o`2Ioooooooo00Goool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00Z_oo
o`03o`2Ioooooooo00;oool500000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`
oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.60873 .26487 L
.61445 .26487 L
.61726 .26487 L
.61849 .26487 L
.61914 .26487 L
.61984 .26487 L
s
.61984 .26487 m
.62036 .61803 L
s
0 .4 1 r
.02381 .26592 m
.06244 .26629 L
.10458 .26685 L
.14415 .26757 L
.18221 .26851 L
.22272 .26987 L
.26171 .27165 L
.30316 .27423 L
.34309 .27761 L
.3815 .28192 L
.42237 .28788 L
.46172 .29504 L
.49955 .30295 L
.53984 .31139 L
.55838 .31473 L
.57861 .31757 L
.58392 .31814 L
.58957 .31866 L
.59446 .31903 L
.59975 .31934 L
.60257 .31947 L
.60517 .31956 L
.60766 .31963 L
.60891 .31966 L
.61028 .31968 L
.61153 .3197 L
.61267 .31971 L
.61398 .31972 L
.61522 .31972 L
.61637 .31971 L
.61743 .3197 L
.6186 .31969 L
.61984 .31967 L
.62097 .26487 L
.62222 .26487 L
.62472 .26487 L
.62921 .26487 L
.63931 .26487 L
.65759 .26487 L
.69815 .26487 L
.73719 .26487 L
.77869 .26487 L
.81867 .26487 L
.85714 .26487 L
.89806 .26487 L
.93746 .26487 L
.97535 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool00_ooo`80I_l0
0`00001Vo`1Vo`0306Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`03
06Ko00<00000I_l0I_l0101Vo`03000006Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00@00000I_l0
I_l0I_l2oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool01@000?oo
ooooool0V@1Vo`02oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`0Boooo000Foooo00<0003oooooool07Oooo`030000oooooooo01Goool906Ko00<0
003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Coooo00?o09T0I_ooool01ooo
o`030000oooooooo01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00F?oooa80I_m3
oooo00?o09T0I_ooool01oooo`030000oooooooo06Koool006[oool506Ko?_ooo`03o`2I06Kooooo
00Ooool00`000?ooooooo`1Voooo001_oooo1`1VocOoool00ol0V@1Vooooo`07oooo0P0006Ooool0
07Koool806Ko;oooo`03o`2I06Kooooo00Ooool00`000?ooooooo`1Voooo001noooo1@1Vob[oool0
0`1Vooooooooo`07oooo00<0003oooooool0I_ooo`00Poooo`D0I_lUoooo00<0I_ooooooool01ooo
o`030000oooooooo06Koool008Soool506Ko8?ooo`0306Kooooooooo00Ooool20000Ioooo`00SOoo
o`D0I_lKoooo00<0I_ooooooool01oooo`030000oooooooo06Koool009;oool506Ko5_ooo`0306Ko
oooooooo00Ooool00`000?ooooooo`1Voooo002Goooo1@1Voa7oool00`1Vooooooooo`07oooo00<0
003oooooool0I_ooo`00W?ooo`D0I_l<oooo00<0I_ooooooool01oooo`030000oooooooo06Koool0
0:7oool=06Ko2Oooo`80001Woooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool0
0:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`1Voooo002]oooo00?o09Woooooool01oooo`80001Woooo002]oooo00?o09Wooooo
ool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_oo
o`00[Oooo`03o`2Ioooo000000@00003oooo00<0003oooooool0I_ooo`00[Oooo`05o`2Ioooooooo
oooo000000Goool00`000?ooooooo`1Voooo002]oooo00Go09Woooooooooool000001Oooo`<0001V
oooo002]oooo00Go09Woooooooooool000001Oooo`030000oooooooo06Koool00:goool01Ol0VOoo
ooooooooo`000005oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00800005oooo00<0
003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool20000Ioooo`00[Oooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`1Voooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool0
0:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`1Voooo002]oooo00?o09Woooooool01oooo`80001Woooo002]oooo00?o09Wooooo
ool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_oo
o`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1Voooo002]oooo00?o09Woooooool01ooo
o`80001Woooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOoo
ooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1V
oooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07
oooo0P0006Ooool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2I
oooo000000<00004oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooo000000Ooool00`000?oo
ooooo`1Voooo002]oooo00Co09Woooooool00006oooo0`0006Koool00:goool01Ol0VOoooooooooo
o`000005oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00800005oooo00<0003oooooool0I_oo
o`00[Oooo`03o`2Ioooooooo00Ooool20000Ioooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`1Voooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOoo
ooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1V
oooo002]oooo00?o09Woooooool01oooo`80001Woooo002]oooo00?o09Woooooool01oooo`030000
oooooooo06Koool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2I
oooooooo00Ooool00`000?ooooooo`1Voooo002]oooo00?o09Woooooool01oooo`80001Woooo002]
oooo00?o09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo00<0
003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1Voooo002]oooo00?o
09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo0P0006Ooool0
0:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00800005
oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0I_ooo`00[Oooo`05o`2Ioooooooooooo000000Goool30000I_ooo`00[Oooo`03o`2I
oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00800005
oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1Voooo002]
oooo00?o09Woooooool01oooo`80001Woooo002]oooo00?o09Woooooool01oooo`030000oooooooo
06Koool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`1Voooo002]oooo00?o09Woooooool01oooo`80001Woooo002]oooo00?o
09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo00<0003ooooo
ool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1Voooo002]oooo00?o09Wooooo
ool01oooo`030000oooooooo06Koool00:goool00ol0VOooooooo`07oooo0P0006Ooool00:goool0
0ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Oooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`1Voooo002]oooo00?o09Woooooool01oooo`030000oooooooo06Koool00:goool00ol0VOoo
ooooo`07oooo0P0006Ooool00:goool00ol0VOooooooo`07oooo00<0003oooooool0I_ooo`00[Ooo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`1Voooo002]oooo00Co09Woooooooooool300000ooo
o`030000oooooooo06Koool00:goool00ol0VOooooooo`02oooo00<0003oooooool00_ooo`030000
oooooooo06Koool00:goool00ol0VOooo`00000400000oooo`<0001Voooo002_oooo00@0003ooooo
ool0001]oooo002`oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0
003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000
oooooooo00002oooo`050000oooooooooooo000007goool007_oool01@000?ooooooooooo`00000?
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo017oool200002Oooo`@00002oooo00<0003oooooool0O?ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.60873 .26487 L
.61984 .26487 L
.6254 .26487 L
.62812 .26487 L
.63064 .26487 L
.63182 .26487 L
.63292 .26487 L
s
.63292 .26487 m
.63338 .61803 L
s
0 .4 1 r
.02381 .2661 m
.06244 .26653 L
.10458 .26718 L
.14415 .26803 L
.18221 .26913 L
.22272 .27072 L
.26171 .27281 L
.30316 .27583 L
.34309 .27979 L
.3815 .28483 L
.42237 .2918 L
.46172 .30019 L
.49955 .30945 L
.53984 .31933 L
.55838 .32324 L
.57861 .32657 L
.58392 .32724 L
.58957 .32784 L
.59446 .32827 L
.59975 .32864 L
.60257 .32879 L
.60517 .3289 L
.60766 .32898 L
.60891 .32901 L
.61028 .32904 L
.61153 .32906 L
.61267 .32907 L
.61398 .32908 L
.61522 .32908 L
.61637 .32908 L
.61743 .32907 L
.6186 .32905 L
.61984 .32903 L
.62222 .32897 L
.62472 .32888 L
.62921 .32867 L
.63041 .32859 L
.6317 .32851 L
.63292 .32843 L
.63403 .26487 L
.63533 .26487 L
.63674 .26487 L
.63931 .26487 L
.65759 .26487 L
.6985 .26487 L
.73791 .26487 L
.7758 .26487 L
.81613 .26487 L
.85496 .26487 L
.89624 .26487 L
Mistroke
.936 .26487 L
.97424 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00<0I_l0
0`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool07Oooo`030000oooooooo00_ooolC06Ko00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Goooo00<0I_ooooooool00oooo`030000oooooooo
01goool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00F?ooo`X0I_m?oooo00<0I_oooooo
ool00oooo`030000oooooooo06Koool006;oool:06KoAOooo`0306Kooooooooo00?oool00`000?oo
ooooo`1Voooo001/oooo201Vocgoool00`1Vooooooooo`03oooo0P0006Ooool007Coool506Ko>?oo
o`0306Kooooooooo00?oool00`000?ooooooo`1Voooo001ioooo1@1Voc?oool00`1Vooooooooo`03
oooo00<0003oooooool0I_ooo`00O_ooo`D0I_l^oooo00<0I_ooooooool00oooo`030000oooooooo
06Koool008?oool406Ko:_ooo`0306Kooooooooo00?oool20000Ioooo`00Qoooo`<0I_lWoooo00<0
I_ooooooool00oooo`030000oooooooo06Koool008[oool406Ko8oooo`0306Kooooooooo00?oool0
0`000?ooooooo`1Voooo002>oooo101Voaooool00`1Vooooooooo`03oooo00<0003oooooool0I_oo
o`00T_ooo`D0I_lJoooo00<0I_ooooooool00oooo`030000oooooooo06Koool009Ooool506Ko5Ooo
o`0306Kooooooooo00?oool20000Ioooo`00W?ooo`D0I_l@oooo00<0I_ooooooool00oooo`030000
oooooooo06Koool00:7ooolA06Ko1Oooo`030000oooooooo06Koool00:coool00`1Vooooooooo`02
oooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOooooooo`03oooo0P00
06Ooool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo
00?oool00`000?ooooooo`1Voooo002_oooo1@0000?oool00`000?ooooooo`1Voooo002aoooo00<0
003oooooool00oooo`030000oooooooo06Koool00;7oool00`000?ooooooo`03oooo0`0006Koool0
0;7oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`030000oooooooo00?oool0
0`000?ooooooo`1Voooo002`oooo0P0000Goool00`000?ooooooo`1Voooo002aoooo00?o09Wooooo
ool00oooo`80001Woooo002aoooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool0
0ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOoo
ooooo`03oooo0P0006Ooool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Ooo
o`03o`2Ioooooooo00?oool00`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000
oooooooo06Koool00;7oool00ol0VOooooooo`03oooo0P0006Ooool00;7oool00ol0VOooooooo`03
oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool00`000?ooooooo`1Voooo002a
oooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOooooooo`03oooo00<0
003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool20000Ioooo`00/Oooo`03o`2Ioooooooo
00?oool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1Voooo002_oooo00<0
003ooooo09T01Oooo`030000oooooooo06Koool00;3oool00`000?l0VOooo`04oooo0`0006Koool0
0;7oool00`000?ooooooo`03oooo00<0003oooooool0I_ooo`00[oooo`040000ooooo`2I00001?oo
o`030000oooooooo06Koool00;3oool200001Oooo`030000oooooooo06Koool00;7oool00ol0VOoo
ooooo`03oooo0P0006Ooool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Ooo
o`03o`2Ioooooooo00?oool00`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000
oooooooo06Koool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`03o`2I
oooooooo00?oool20000Ioooo`00/Oooo`03o`2Ioooooooo00?oool00`000?ooooooo`1Voooo002a
oooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOooooooo`03oooo00<0
003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool20000Ioooo`00/Oooo`03o`2Ioooooooo
00?oool00`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000oooooooo06Koool0
0;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`80001Woooo002aoooo00?o09Wooooo
ool00oooo`030000oooooooo06Koool00;3oool200001Oooo`030000oooooooo06Koool00:ooool0
10000?ooool0V@0000Coool00`000?ooooooo`1Voooo002aoooo00<0003oooooool00oooo`<0001V
oooo002aoooo00?o09T0003oool00oooo`030000oooooooo06Koool00:ooool010000?ooool0V@00
00Coool00`000?ooooooo`1Voooo002`oooo0P0000Goool00`000?ooooooo`1Voooo002aoooo00?o
09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOooooooo`03oooo0P0006Ooool0
0;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool0
0ol0VOooooooo`03oooo0P0006Ooool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_oo
o`00/Oooo`03o`2Ioooooooo00?oool00`000?ooooooo`1Voooo002aoooo00?o09Woooooool00ooo
o`030000oooooooo06Koool00;7oool00ol0VOooooooo`03oooo00<0003oooooool0I_ooo`00/Ooo
o`03o`2Ioooooooo00?oool20000Ioooo`00/Oooo`03o`2Ioooooooo00?oool00`000?ooooooo`1V
oooo002aoooo00?o09Woooooool00oooo`030000oooooooo06Koool00;7oool00ol0VOooooooo`03
oooo00<0003oooooool0I_ooo`00/Oooo`03o`2Ioooooooo00?oool20000Ioooo`00/Oooo`03o`2I
oooooooo00?oool00`000?ooooooo`1Voooo002aoooo00?o09Woooooool00oooo`030000oooooooo
06Koool00;7oool300000oooo`030000oooooooo06Koool00;7oool00ol0V@000?ooo`03oooo00<0
003oooooool0I_ooo`00[oooo`D00003oooo0`0006Koool00:ooool010000?ooooooo`0006goool0
0;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Woool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.61984 .26487 L
.6298 .26487 L
.63527 .26487 L
.64043 .26487 L
.64277 .26487 L
.64405 .26487 L
.64524 .26487 L
s
.64524 .26487 m
.64576 .61803 L
s
0 .4 1 r
.02381 .26629 m
.06244 .26679 L
.10458 .26754 L
.14415 .26852 L
.18221 .26979 L
.22272 .27163 L
.26171 .27405 L
.30316 .27754 L
.34309 .28211 L
.3815 .28794 L
.42237 .296 L
.46172 .30569 L
.49955 .3164 L
.53984 .32782 L
.55838 .33234 L
.57861 .33618 L
.58392 .33696 L
.58957 .33766 L
.59446 .33815 L
.59975 .33857 L
.60257 .33875 L
.60517 .33888 L
.60766 .33897 L
.60891 .33901 L
.61028 .33904 L
.61153 .33906 L
.61267 .33908 L
.61398 .33909 L
.61522 .33909 L
.61637 .33908 L
.61743 .33907 L
.6186 .33905 L
.61984 .33903 L
.62222 .33896 L
.62472 .33886 L
.62921 .33861 L
.63403 .33824 L
.63931 .33772 L
.64166 .33745 L
.64388 .33717 L
.64511 .33701 L
.64581 .33692 L
.64645 .26487 L
.64758 .26487 L
.64878 .26487 L
.65759 .26487 L
.69547 .26487 L
.73581 .26487 L
.77464 .26487 L
.81591 .26487 L
Mistroke
.85567 .26487 L
.89392 .26487 L
.93462 .26487 L
.9738 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00<0I_l0
0`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00@0003oooooool0I_l2oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Moooo00<0003oooooool02oooo`X0I_l9oooo00<0003ooooo
ool07Oooo`030000oooooooo01goool00`000?ooooooo`0Joooo00@0I_ooooooool0000Ooooo00<0
003oooooool07_ooo`030000oooooooo02Goool004kooolB06KoE?ooo`0406Kooooooooo0000J?oo
o`00H?ooo`D0I_m?oooo00@0I_ooooooool0001Xoooo001Uoooo1`1VodSoool00`1Vooooooooo`02
0000Ioooo`00K?ooo`P0I_m0oooo00@0I_ooooooool0001Xoooo001doooo1@1Voc_oool0101Voooo
ooooo`0006Soool007Woool406Ko=oooo`0406Kooooooooo0000J?ooo`00OOooo`<0I_ldoooo00<0
I_ooooooool00P0006Ooool0083oool406Ko<?ooo`0406Kooooooooo0000J?ooo`00Q?ooo`@0I_l/
oooo00@0I_ooooooool0001Xoooo0028oooo1@1VobOoool0101Vooooooooo`0006Soool008goool4
06Ko8oooo`0406Kooooooooo0000J?ooo`00TOooo`<0I_lPoooo00<0I_ooooooool00P0006Ooool0
09Coool406Ko7?ooo`0406Kooooooooo0000J?ooo`00V?ooo`@0I_lHoooo00@0I_ooooooool0001X
oooo002Loooo1@1Voa?oool0101Vooooooooo`0006Soool00:7oool406Ko3oooo`0306Kooooooooo
0080001Woooo002Uoooo401Vo`;oool00`000?ooooooo`1Voooo002doooo00Co09Woooooool0001X
oooo002_oooo1@000004o`2Ioooooooo0000J?ooo`00/Oooo`040000ooooooooo`2I0_ooo`030000
oooooooo06Koool00;7oool010000?ooooooool0V@;oool30000I_ooo`00/Oooo`040000oooooooo
o`2I0_ooo`030000oooooooo06Koool00;7oool010000?ooooooool0V@;oool00`000?ooooooo`1V
oooo002`oooo0P0000;oool01?l0VOooooooo`0006Soool00;Coool00ol0VOooooooo`020000Iooo
o`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2I
oooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`03o`2Ioooooooo0080001W
oooo002doooo00Co09Woooooool0001Xoooo002doooo00Co09Woooooool0001Xoooo002doooo00Co
09Woooooool0001Xoooo002doooo00?o09Woooooool00P0006Ooool00;Coool01?l0VOooooooo`00
06Soool00;Coool01?l0VOooooooo`0006Soool00;Coool01?l0VOooooooo`0006Soool00;Coool0
1?l0VOooooooo`0006Soool00;Coool00ol0VOooooooo`020000Ioooo`00]?ooo`04o`2Ioooooooo
0000J?ooo`00[oooo`@000001Oooool0VOooooooo`00001Xoooo002_oooo00<0003oooooool00_oo
o`04o`2Ioooooooo0000J?ooo`00/?ooo`050000ooooooooooooo`2I00;oool30000I_ooo`00/Ooo
o`040000ooooooooo`2I0_ooo`030000oooooooo06Koool00:ooool01P000?ooooooo`000?ooool0
V@;oool00`000?ooooooo`1Voooo002`oooo0P0000;oool01?l0VOooooooo`0006Soool00;Coool0
0ol0VOooooooo`020000Ioooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo
0000J?ooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?oo
o`03o`2Ioooooooo0080001Woooo002doooo00Co09Woooooool0001Xoooo002doooo00Co09Wooooo
ool0001Xoooo002doooo00Co09Woooooool0001Xoooo002doooo00?o09Woooooool00P0006Ooool0
0;Coool01?l0VOooooooo`0006Soool00;Coool01?l0VOooooooo`0006Soool00;Coool01?l0VOoo
ooooo`0006Soool00;Coool01?l0VOooooooo`0006Soool00;Coool00ol0VOooooooo`020000Iooo
o`00]?ooo`04o`2Ioooooooo0000J?ooo`00/?ooo`800002oooo00Co09Woooooool0001Xoooo002_
oooo00H0003oooooool0003ooooo09T2oooo00<0003oooooool0I_ooo`00/Oooo`040000oooooooo
o`2I0_ooo`<0001Voooo002boooo00<0003ooooo09T00_ooo`030000oooooooo06Koool00:ooool0
1P000?ooooooo`000?ooool0V@;oool00`000?ooooooo`1Voooo002`oooo0P0000;oool01?l0VOoo
ooooo`0006Soool00;Coool01?l0VOooooooo`0006Soool00;Coool00ol0VOooooooo`020000Iooo
o`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2I
oooooooo0000J?ooo`00]?ooo`03o`2Ioooooooo0080001Woooo002doooo00Co09Woooooool0001X
oooo002doooo00Co09Woooooool0001Xoooo002doooo00Co09Woooooool0001Xoooo002doooo00Co
09Woooooool0001Xoooo002doooo00?o09Woooooool00P0006Ooool00;Coool01?l0VOooooooo`00
06Soool00;Coool01?l0VOooooooo`0006Soool00;Coool01?l0VOooooooo`0006Soool00;Coool0
0ol0VOooooooo`020000Ioooo`00]?ooo`04o`2Ioooooooo0000J?ooo`00]?ooo`04o`2Ioooooooo
0000J?ooo`00/Oooo`<000001?l0VOooooooo`0006Soool00;;oool00`000?ooool0V@02oooo00<0
003oooooool0I_ooo`00[oooo`D000000ol0VOooooooo`030000I_ooo`00[oooo`040000oooooooo
0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Woool300001?ooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.61984 .26487 L
.6298 .26487 L
.64043 .26487 L
.64559 .26487 L
.65045 .26487 L
.65482 .26487 L
.65602 .26487 L
.65728 .26487 L
.65836 .26487 L
s
.65836 .26487 m
.65883 .61803 L
s
0 .4 1 r
.02381 .26649 m
.06244 .26707 L
.10458 .26793 L
.14415 .26905 L
.18221 .2705 L
.22272 .27261 L
.26171 .27537 L
.30316 .27938 L
.34309 .28461 L
.3815 .29128 L
.42237 .30051 L
.46172 .31161 L
.49955 .32386 L
.53984 .33694 L
.55838 .34211 L
.57861 .34651 L
.58392 .3474 L
.58957 .3482 L
.59446 .34877 L
.59975 .34925 L
.60257 .34945 L
.60517 .3496 L
.60766 .34971 L
.60891 .34975 L
.61028 .34979 L
.61153 .34981 L
.61267 .34983 L
.61398 .34984 L
.61522 .34984 L
.61637 .34983 L
.61743 .34982 L
.6186 .3498 L
.61984 .34977 L
.62222 .34969 L
.62472 .34957 L
.62921 .34929 L
.63403 .34886 L
.63931 .34827 L
.64878 .34687 L
.65336 .34605 L
.65537 .34566 L
.65644 .34545 L
.65759 .34522 L
.65885 .26487 L
.66004 .26487 L
.66264 .26487 L
.66811 .26487 L
.67804 .26487 L
.69663 .26487 L
.73791 .26487 L
Mistroke
.77767 .26487 L
.81591 .26487 L
.85661 .26487 L
.89579 .26487 L
.93743 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00<0I_l0
1000001Vo`1Vo`1Vo`?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Moooo00@0003ooooooooooolD06Ko2Oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Noooo00<0003oooooool09Oooo`00C_ooo`X0I_mOoooo00<0003oooooool0I_ooo`00F?oo
o`X0I_mEoooo00<0003oooooool0I_ooo`00H_ooo`P0I_m=oooo0P0006Ooool006[oool506KoB?oo
o`030000oooooooo06Koool006ooool506Ko@oooo`030000oooooooo06Koool007Coool506Ko?_oo
o`030000oooooooo06Koool007Woool406Ko>_ooo`80001Woooo001moooo0`1VocOoool00`000?oo
ooooo`1Voooo0020oooo101Voc?oool00`000?ooooooo`1Voooo0024oooo0`1Voc3oool00`000?oo
ooooo`1Voooo0027oooo0`1Vobgoool00`000?ooooooo`1Voooo002:oooo101VobWoool20000Iooo
o`00S_ooo`<0I_lVoooo00<0003oooooool0I_ooo`00TOooo`<0I_lSoooo00<0003oooooool0I_oo
o`00U?ooo`@0I_lOoooo00<0003oooooool0I_ooo`00V?ooo`<0I_lLoooo0P0006Ooool009_oool2
06Ko6_ooo`030000oooooooo06Koool009goool406Ko5_ooo`030000oooooooo06Koool00:7oool7
06Ko1oooo`D0000306Ko00<0003oooooool0I_ooo`00Z?ooo`T0I_l00`000?ooooooo`03oooo00<0
003oooooool0I_ooo`00/Oooo`030000oooooooo00?oool30000I_ooo`00/Oooo`030000oooooooo
00?oool00`000?ooooooo`1Voooo002aoooo00<0003oooooool00oooo`030000oooooooo06Koool0
0;3oool200001Oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000oooooooo
06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]oooo`030000
oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?oo
ooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]oooo`80001Woooo002goooo00<0003ooooo
ool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`80001Woooo002goooo00<0003oooooool0I_ooo`00[oooo`@00004
oooo00<0003oooooool0I_ooo`00[oooo`030000oooooooo00Goool00`000?ooooooo`1Voooo002`
oooo00<0003oooooool01?ooo`<0001Voooo002aoooo00<0003oooooool00oooo`030000oooooooo
06Koool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002`oooo0P0000Goool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool0
0;Ooool20000Ioooo`00]oooo`030000oooooooo06Koool00;3oool200001Oooo`030000oooooooo
06Koool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo002aoooo00<0003ooooo
ool00oooo`<0001Voooo002boooo00<0003oooooool00_ooo`030000oooooooo06Koool00:ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1Voooo002`oooo0P0000Goool00`000?ooooooo`1V
oooo002goooo00<0003oooooool0I_ooo`00]oooo`80001Woooo002goooo00<0003oooooool0I_oo
o`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo0P0006Ooool0
0;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo
06Koool00;Ooool00`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1V
oooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Iooo
o`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002aoooo0`0000?oool0
0`000?ooooooo`1Voooo002boooo00<0003oooooool00_ooo`030000oooooooo06Koool00:ooool5
00000oooo`<0001Voooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool00000KOoo
o`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0
003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003ooooo
ool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800004oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`1noooo001m
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003ooooo
ool0OOooo`00O_ooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`030000oooooooo
07koool007koool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo
07koool007ooool00`000?ooooooo`0Aoooo0P0000Woool00`000?ooooooo`1ooooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.64043 .26487 L
.65045 .26487 L
.65954 .26487 L
.66412 .26487 L
.66652 .26487 L
.66906 .26487 L
.67014 .26487 L
.67129 .26487 L
s
.67129 .26487 m
.67179 .61803 L
s
0 .4 1 r
.02381 .26671 m
.06244 .26737 L
.10458 .26835 L
.14415 .26962 L
.18221 .27127 L
.22272 .27367 L
.26171 .27681 L
.30316 .28136 L
.34309 .2873 L
.3815 .29489 L
.42237 .30537 L
.46172 .31799 L
.49955 .33192 L
.53984 .34678 L
.55838 .35265 L
.57861 .35766 L
.58392 .35866 L
.58957 .35957 L
.59446 .36022 L
.59975 .36077 L
.60257 .361 L
.60517 .36117 L
.60766 .36129 L
.60891 .36134 L
.61028 .36138 L
.61153 .36141 L
.61267 .36142 L
.61398 .36144 L
.61522 .36144 L
.61637 .36143 L
.61743 .36142 L
.6186 .36139 L
.61984 .36136 L
.62222 .36127 L
.62472 .36114 L
.62921 .36081 L
.63403 .36033 L
.63931 .35966 L
.64878 .35807 L
.65759 .35619 L
.66264 .35495 L
.66529 .35425 L
.66811 .35349 L
.6693 .35316 L
.67057 .3528 L
.6713 .35259 L
.67197 .26487 L
.67328 .26487 L
.67804 .26487 L
.69663 .26487 L
Mistroke
.73639 .26487 L
.77464 .26487 L
.81533 .26487 L
.85452 .26487 L
.89615 .26487 L
.93627 .26487 L
.97487 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`03000006Ko06Ko00<0I_l0
1000001Vo`1Vo`1Vo`?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00D0003ooooooooo09T0I_l00_ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo01;oool001Koool00`000?ooooooo`0Moooo00@0003ooooooooooolD06Ko2Oooo`030000
oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`050000ooooooooo`2I06Ko
01_oool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00C_ooo`X0I_mOoooo00D0003ooooo
oooo09T0I_l0I?ooo`00F?ooo`P0I_mGoooo00D0003ooooooooo09T0I_l0I?ooo`00H?ooo`D0I_mB
oooo0P000003ooooo`2I06Ko06Coool006Goool506KoCOooo`050000ooooooooo`2I06Ko06Coool0
06[oool506KoB?ooo`050000ooooooooo`2I06Ko06Coool006ooool506Ko@oooo`050000oooooooo
o`2I06Ko06Coool007Coool506Ko?_ooo`8000000oooool0V@1Vo`1Toooo001ioooo101Voc[oool0
1@000?ooooooool0V@1Vo`1Toooo001moooo0P1VocSoool010000?ooooooo`1VofGoool007ooool3
06Ko=Oooo`040000oooooooo06KoIOooo`00P_ooo`80I_lcoooo00@0003oooooool0I_mUoooo0024
oooo0`1Voc3oool2000000?oool0I_ooool0I?ooo`00Qoooo`<0I_l]oooo00@0003oooooool0I_mU
oooo002:oooo101VobWoool010000?ooooooo`1VofGoool008koool306Ko9_ooo`040000oooooooo
06KoIOooo`00TOooo`80I_lToooo0P000003oooo06Kooooo06Coool009?oool306Ko8Oooo`040000
oooooooo06KoIOooo`00U_ooo`80I_lOoooo00@0003oooooool0I_mUoooo002Hoooo101Voa?oool5
00000oooo`040000oooooooo06KoIOooo`00W?ooo`@0I_lAoooo00<0003oooooool00oooo`040000
oooooooo06KoIOooo`00X?ooo`80I_l?oooo00<0003oooooool00oooo`<000000`1Vooooooooo`1S
oooo002Roooo1P1Vo`Woool00`00001Vo`1Vo`0306Ko00@0003ooooooooo09UUoooo002Xoooo2@1V
o`030000oooooooo00?oool010000?ooooooool0VFGoool00;3oool200001Oooo`040000oooooooo
o`2IIOooo`00]oooo`8000000oooool0VOooo`1Toooo002goooo00@0003ooooooooo09UUoooo002g
oooo00@0003ooooooooo09UUoooo002goooo00@0003ooooooooo09UUoooo002goooo00@0003ooooo
oooo09UUoooo002goooo0P000003ooooo`2Ioooo06Coool00;Ooool010000?ooooooool0VFGoool0
0;Ooool010000?ooooooool0VFGoool00;Ooool010000?ooooooool0VFGoool00;Ooool2000000?o
oooo09Woool0I?ooo`00]oooo`040000ooooooooo`2IIOooo`00]oooo`040000ooooooooo`2IIOoo
o`00]oooo`040000ooooooooo`2IIOooo`00]oooo`040000ooooooooo`2IIOooo`00]oooo`800000
0oooool0VOooo`1Toooo002goooo00@0003ooooooooo09UUoooo002_oooo100000Coool010000?oo
ooooool0VFGoool00:ooool00`000?ooooooo`05oooo00@0003ooooooooo09UUoooo002`oooo00<0
003oooooool01?ooo`<000000ol0VOooooooo`1Soooo002aoooo00<0003oooooool00oooo`050000
ooooooooooooo`2I06Coool00:ooool010000?ooooooo`0000Coool01@000?ooooooooooool0V@1T
oooo002`oooo0P0000Goool01@000?ooooooooooool0V@1Toooo002goooo0P0000;oool00ol0VOoo
ooooo`1Roooo002goooo00D0003ooooooooooooo09T0I?ooo`00]oooo`050000ooooooooooooo`2I
06Coool00;Ooool01@000?ooooooooooool0V@1Toooo002goooo00D0003ooooooooooooo09T0I?oo
o`00]oooo`800002oooo00?o09Woooooool0H_ooo`00]oooo`050000ooooooooooooo`2I06Coool0
0;Ooool01@000?ooooooooooool0V@1Toooo002goooo00D0003ooooooooooooo09T0I?ooo`00]ooo
o`800002oooo00?o09Woooooool0H_ooo`00]oooo`050000ooooooooooooo`2I06Coool00;Ooool0
1@000?ooooooooooool0V@1Toooo002goooo00D0003ooooooooooooo09T0I?ooo`00]oooo`050000
ooooooooooooo`2I06Coool00;Ooool200000_ooo`03o`2Ioooooooo06;oool00;Ooool01@000?oo
ooooooooool0V@1Toooo002`oooo0P0000Goool01@000?ooooooooooool0V@1Toooo002_oooo00@0
003oooooool00004oooo00D0003ooooooooooooo09T0I?ooo`00/Oooo`030000oooooooo00?oool3
000000?ooooo09Woool0Hoooo`00/_ooo`030000oooooooo00;oool01@000?ooooooooooool0V@1T
oooo002_oooo00@0003oooooool00004oooo00D0003ooooooooooooo09T0I?ooo`00/?ooo`800005
oooo00D0003ooooooooooooo09T0I?ooo`00]oooo`050000ooooooooooooo`2I06Coool00;Ooool2
00000_ooo`03o`2Ioooooooo06;oool00;Ooool01@000?ooooooooooool0V@1Toooo002goooo00D0
003ooooooooooooo09T0I?ooo`00]oooo`050000ooooooooooooo`2I06Coool00;Ooool200000_oo
o`03o`2Ioooooooo06;oool00;Ooool01@000?ooooooooooool0V@1Toooo002goooo00D0003ooooo
oooooooo09T0I?ooo`00]oooo`050000ooooooooooooo`2I06Coool00;Ooool01@000?oooooooooo
ool0V@1Toooo002goooo0P0000;oool00ol0VOooooooo`1Roooo002goooo00D0003ooooooooooooo
09T0I?ooo`00]oooo`050000ooooooooooooo`2I06Coool00;Ooool01@000?ooooooooooool0V@1T
oooo002goooo0P0000;oool00ol0VOooooooo`1Roooo002goooo00D0003ooooooooooooo09T0I?oo
o`00]oooo`050000ooooooooooooo`2I06Coool00;7oool300000oooo`050000ooooooooooooo`2I
06Coool00;;oool00`000?ooooooo`02oooo00D0003ooooooooooooo09T0I?ooo`00[oooo`D00003
oooo0`000003ooooo`2Ioooo06?oool00:ooool010000?ooooooo`0006goool00;3oool00`000?oo
o`00001]oooo002aoooo0P0006goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool500000_ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Woool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.64043 .26487 L
.65954 .26487 L
.66906 .26487 L
.67803 .26487 L
.68044 .26487 L
.68176 .26487 L
.683 .26487 L
.68364 .26487 L
s
.68364 .26487 m
.68391 .61803 L
s
0 .4 1 r
.02381 .26695 m
.06244 .26769 L
.10458 .2688 L
.14415 .27023 L
.18221 .2721 L
.22272 .27481 L
.26171 .27836 L
.30316 .2835 L
.34309 .29022 L
.3815 .29879 L
.42237 .31065 L
.46172 .3249 L
.49955 .34064 L
.53984 .35744 L
.55838 .36408 L
.57861 .36974 L
.58392 .37087 L
.58957 .3719 L
.59446 .37263 L
.59975 .37325 L
.60257 .37351 L
.60517 .3737 L
.60766 .37384 L
.60891 .37389 L
.61028 .37394 L
.61153 .37397 L
.61267 .37399 L
.61398 .374 L
.61522 .374 L
.61637 .37399 L
.61743 .37398 L
.6186 .37395 L
.61984 .37392 L
.62222 .37381 L
.62472 .37367 L
.62921 .3733 L
.63403 .37275 L
.63931 .37199 L
.64878 .37019 L
.65759 .36807 L
.66811 .36502 L
.67328 .36335 L
.67804 .36171 L
.68028 .36092 L
.68238 .36016 L
.68343 .35977 L
.68456 .26487 L
.68582 .26487 L
.68696 .26487 L
.69663 .26487 L
Mistroke
.73639 .26487 L
.77464 .26487 L
.81533 .26487 L
.85452 .26487 L
.89615 .26487 L
.93627 .26487 L
.97487 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool05oooo`H0I_l00`00001Vo`1Vo`0;06Ko4oooo`030000oooooooo
01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo00Coool00`1Voooo
ooooo`0Foooo00<0003oooooool07_ooo`030000oooooooo02Goool004Coool:06KoJOooo`030000
oooooooo00Coool00`1Vooooooooo`1Ooooo001>oooo2P1Voeooool00`000?ooooooo`04oooo00<0
I_ooooooool0Goooo`00F?ooo`P0I_mGoooo0P0000Goool00`1Vooooooooo`1Ooooo001Poooo1@1V
oe;oool00`000?ooooooo`04oooo00<0I_ooooooool0Goooo`00IOooo`D0I_m=oooo00<0003ooooo
ool01?ooo`0306Kooooooooo05ooool006[oool506KoB?ooo`030000oooooooo00Coool00`1Voooo
ooooo`1Ooooo001_oooo101VodCoool200001Oooo`0306Kooooooooo05ooool007?oool306Ko@Ooo
o`030000oooooooo00Coool00`1Vooooooooo`1Ooooo001foooo101Vocgoool00`000?ooooooo`04
oooo00<0I_ooooooool0Goooo`00N_ooo`<0I_ljoooo00<0003oooooool00oooo`0306Koo`2Ioooo
063oool007goool306Ko=oooo`030000oooooooo00?oool00`1Vool0VOooo`1Poooo0020oooo101V
oc?oool200001?ooo`0306Koo`2Ioooo063oool008Coool306Ko<?ooo`030000oooooooo00?oool0
0`1Vool0VOooo`1Poooo0027oooo0P1Vobkoool00`000?ooooooo`03oooo00<0I_oo09Woool0H?oo
o`00ROooo`<0I_l[oooo00<0003oooooool00oooo`0306Koo`2Ioooo063oool008coool206Ko:Ooo
o`800004oooo00<0I_oo09Woool0H?ooo`00S_ooo`80I_lWoooo00<0003oooooool00oooo`0306Ko
o`2Ioooo063oool0093oool206Ko9Oooo`030000oooooooo00?oool00`1Vool0VOooo`1Poooo002B
oooo0P1Voa_oool500000oooo`030000oooooooo00?oool00`1Vool0VOooo`1Poooo002Doooo0P1V
oa_oool00`000?ooooooo`03oooo00<0003oooooool00oooo`0306Koo`2Ioooo063oool009Koool2
06Ko6Oooo`030000oooooooo00?oool300000oooo`0306Koo`2Ioooo063oool009Soool406Ko5Ooo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0I_oo09Woool0H?ooo`00W?ooo`@0I_lA
oooo00<0003oooooool00oooo`040000oooooooooooo0`1Vo`03o`2Ioooooooo05ooool00:3oool2
06Ko3_ooo`800005oooo00@00000I_l0I_l0I_l3oooo00?o09Woooooool0Goooo`00X_ooo`D0I_l;
oooo1@1Vo`800005oooo00?o09Woooooool0Goooo`00Yoooo`/0I_l5oooo00<0003oooooool01?oo
o`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]ooo
o`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2I
oooooooo05ooool00;Ooool200001Oooo`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04
oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002g
oooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;Ooool200001Oooo`03o`2Ioooooooo
05ooool00;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo
00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool0
0;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`800005oooo00?o09Wooooo
ool0Goooo`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002_oooo100000Coool0
0`000?ooooooo`04oooo00?o09Woooooool0Goooo`00[oooo`030000oooooooo00Goool00`000?oo
ooooo`04oooo00?o09Woooooool0Goooo`00/?ooo`030000oooooooo00Coool300001?ooo`03o`2I
oooooooo05ooool00;7oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`03o`2Ioooooooo
05ooool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`04oooo00?o09Woooooool0Gooo
o`00/?ooo`800005oooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;Ooool200001Ooo
o`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]ooo
o`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2I
oooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`800005
oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002g
oooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o
09Woooooool0Goooo`00]oooo`800005oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo
00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool0
0;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo00Coool0
0ol0VOooooooo`1Ooooo002goooo0P0000Goool00ol0VOooooooo`1Ooooo002goooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo05ooool00;3oool200001Oooo`030000oooooooo00Coool00ol0VOoo
ooooo`1Ooooo002_oooo00@0003oooooool00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo
05ooool00;7oool00`000?ooooooo`03oooo0`0000Coool00ol0VOooooooo`1Ooooo002boooo00<0
003oooooool00_ooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002_oooo00@0003ooooo
ool00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;3oool200001Oooo`030000
oooooooo00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2Ioooooooo
05ooool00;Ooool200001Oooo`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o
09Woooooool0Goooo`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002goooo00<0
003oooooool01?ooo`03o`2Ioooooooo05ooool00;Ooool200001Oooo`03o`2Ioooooooo05ooool0
0;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo00Coool0
0ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;Ooool0
0`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]oooo`800005oooo00?o09Woooooool0Gooo
o`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1Ooooo002goooo00<0003oooooool01?oo
o`03o`2Ioooooooo05ooool00;Ooool00`000?ooooooo`04oooo00?o09Woooooool0Goooo`00]ooo
o`800005oooo00?o09Woooooool0Goooo`00]oooo`030000oooooooo00Coool00ol0VOooooooo`1O
oooo002goooo00<0003oooooool01?ooo`03o`2Ioooooooo05ooool00;7oool300000oooo`030000
oooooooo00Coool00ol0VOooooooo`1Ooooo002boooo00<0003oooooool00_ooo`030000oooooooo
00Coool00ol0VOooooooo`1Ooooo002_oooo1@0000?oool300001?ooo`03o`2Ioooooooo05ooool0
0:ooool010000?ooooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P0006goool0
0?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool400000ooo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Soool0
0`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.64043 .26487 L
.65954 .26487 L
.67803 .26487 L
.68335 .26487 L
.68837 .26487 L
.69287 .26487 L
.6941 .26487 L
.6954 .26487 L
.69652 .26487 L
s
.69652 .26487 m
.697 .61803 L
s
0 .4 1 r
.02381 .26721 m
.06244 .26804 L
.10458 .26929 L
.14415 .27091 L
.18221 .27301 L
.22272 .27606 L
.26171 .28005 L
.30316 .28583 L
.34309 .2934 L
.3815 .30304 L
.42237 .31637 L
.46172 .33241 L
.49955 .35013 L
.53984 .36902 L
.55838 .37649 L
.57861 .38286 L
.58392 .38414 L
.58957 .38529 L
.59446 .38612 L
.59975 .38681 L
.60257 .3871 L
.60517 .38732 L
.60766 .38747 L
.60891 .38753 L
.61028 .38759 L
.61153 .38762 L
.61267 .38765 L
.61398 .38766 L
.61522 .38766 L
.61637 .38765 L
.61743 .38763 L
.6186 .38761 L
.61984 .38756 L
.62222 .38745 L
.62472 .38728 L
.62921 .38687 L
.63403 .38626 L
.63931 .3854 L
.64878 .38338 L
.65759 .38098 L
.67632 .37451 L
.68619 .37049 L
.69158 .36816 L
.69422 .36699 L
.69537 .36647 L
.69663 .3659 L
.69794 .26487 L
.69918 .26487 L
.70192 .26487 L
.70774 .26487 L
Mistroke
.71798 .26487 L
.73813 .26487 L
.77883 .26487 L
.81801 .26487 L
.85964 .26487 L
.89976 .26487 L
.93836 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool010000?ooooooo`1Vo`;oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0Goooo1P1Vo`03000006Ko06Ko00/0I_lCoooo00<0003ooooo
ool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool01oooo`0306Ko
oooooooo01?oool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00A?ooo`X0I_mYoooo00<0
003oooooool01oooo`0306Kooooooooo05coool004koool806KoHOooo`030000oooooooo00Ooool0
0`1Vooooooooo`1Loooo001Foooo1@1Voecoool200002?ooo`0306Kooooooooo05coool005_oool7
06KoEOooo`030000oooooooo00Ooool00`1Vooooooooo`1Loooo001Roooo1`1Vodkoool00`000?oo
ooooo`07oooo00<0I_ooooooool0G?ooo`00JOooo`<0I_m;oooo00<0003oooooool01oooo`0306Ko
oooooooo05coool006coool406KoAoooo`800008oooo00<0I_ooooooool0G?ooo`00L?ooo`<0I_m4
oooo00<0003oooooool01oooo`0306Kooooooooo05coool007?oool306Ko@Oooo`030000oooooooo
00Ooool00`1Vooooooooo`1Loooo001foooo101Vocgoool00`000?ooooooo`07oooo00<0I_oooooo
ool0G?ooo`00N_ooo`<0I_ljoooo00<0003oooooool01oooo`0306Kooooooooo05coool007goool2
06Ko>?ooo`800008oooo00<0I_ooooooool0G?ooo`00Ooooo`<0I_leoooo00<0003oooooool01ooo
o`0306Kooooooooo05coool008;oool206Ko<oooo`030000oooooooo00Ooool00`1Vooooooooo`1L
oooo0024oooo0P1Voc7oool00`000?ooooooo`07oooo00<0I_ooooooool0G?ooo`00Q_ooo`80I_l_
oooo0P0000Soool00`1Vooooooooo`1Loooo0028oooo0P1Vobgoool00`000?ooooooo`07oooo00<0
I_ooooooool0G?ooo`00R_ooo`80I_l[oooo00<0003oooooool01oooo`0306Kooooooooo05coool0
08coool206Ko8Oooo`D00003oooo00<0003oooooool01oooo`0306Kooooooooo05coool008koool2
06Ko8Oooo`030000oooooooo00?oool00`000?ooooooo`07oooo00<0I_ooooooool0G?ooo`00T?oo
o`80I_lOoooo00<0003oooooool00oooo`<00007oooo00<0I_ooooooool0G?ooo`00T_ooo`80I_lM
oooo00<0003oooooool00oooo`030000oooooooo00Ooool00`1Vooooooooo`1Loooo002Doooo0P1V
oa_oool00`000?ooooooo`03oooo00<0003oooooool01oooo`0306Kooooooooo05coool009Koool2
06Ko6?ooo`800005oooo00<0003oooooool01_ooo`80I_mNoooo002Hoooo0`1Voacoool200001Ooo
o`80I_l00oooool0VOooo`1Moooo002Koooo0P1Voa[oool010000?ooooooooooo`<0I_l3oooo00?o
09Woooooool0G?ooo`00WOooo`@0I_lFoooo00@0003oool0I_l0I_l6oooo00?o09Woooooool0G?oo
o`00XOooo`@0I_l?oooo0`1Vo`03000006Kooooo00Ooool00ol0VOooooooo`1Loooo002Uoooo3`1V
o`?oool00`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`800008oooo00?o09Wooooo
ool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002goooo00<0003ooooo
ool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?oo
o`00]oooo`800008oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOoo
ooooo`1Loooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?oo
ooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1L
oooo002goooo0P0000Soool00ol0VOooooooo`1Loooo002goooo00<0003oooooool01oooo`03o`2I
oooooooo05coool00:ooool400001?ooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002_
oooo00<0003oooooool01Oooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002`oooo00<0
003oooooool01?ooo`<00007oooo00?o09Woooooool0G?ooo`00/Oooo`030000oooooooo00?oool0
0`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00[oooo`040000oooooooo00001?ooo`030000
oooooooo00Ooool00ol0VOooooooo`1Loooo002`oooo0P0000Goool00`000?ooooooo`07oooo00?o
09Woooooool0G?ooo`00]oooo`800008oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo
00Ooool00ol0VOooooooo`1Loooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo05coool0
0;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool0
0ol0VOooooooo`1Loooo002goooo0P0000Soool00ol0VOooooooo`1Loooo002goooo00<0003ooooo
ool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?oo
o`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002goooo0P0000Soool00ol0VOoo
ooooo`1Loooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?oo
ooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1L
oooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool200002?ooo`03o`2I
oooooooo05coool00;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00/?ooo`800005
oooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00:ooool010000?ooooooo`0000Coool0
0`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00/Oooo`030000oooooooo00?oool300001ooo
o`03o`2Ioooooooo05coool00;;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`03o`2I
oooooooo05coool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`07oooo00?o09Wooooo
ool0G?ooo`00/?ooo`800005oooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool0
0`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`800008oooo00?o09Woooooool0G?oo
o`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002goooo00<0003oooooool01ooo
o`03o`2Ioooooooo05coool00;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00]ooo
o`800008oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1L
oooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?ooooooo`07
oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo00Ooool00ol0VOooooooo`1Loooo002g
oooo0P0000Soool00ol0VOooooooo`1Loooo002goooo00<0003oooooool01oooo`03o`2Ioooooooo
05coool00;Ooool00`000?ooooooo`07oooo00?o09Woooooool0G?ooo`00]oooo`030000oooooooo
00Ooool00ol0VOooooooo`1Loooo002goooo0P0000Soool00ol0VOooooooo`1Loooo002goooo00<0
003oooooool01oooo`03o`2Ioooooooo05coool00;Ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0G?ooo`00/Oooo`<00003oooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00;;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`03o`2Ioooooooo05coool00:ooool500000ooo
o`<00007oooo00?o09Woooooool0G?ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000
oooo000006goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?ooooooooooo`00001m
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.67958 .26487 L
.69774 .26487 L
.7026 .26487 L
.70516 .26487 L
.70656 .26487 L
.70787 .26487 L
.70901 .26487 L
s
.70901 .26487 m
.7095 .61803 L
s
0 .4 1 r
.02381 .2675 m
.06244 .26843 L
.10458 .26983 L
.14415 .27164 L
.18221 .274 L
.22272 .27741 L
.26171 .28189 L
.30316 .28837 L
.34309 .29685 L
.3815 .30766 L
.42237 .32262 L
.46172 .3406 L
.49955 .36046 L
.53984 .38165 L
.55838 .39003 L
.57861 .39717 L
.58392 .3986 L
.58957 .39989 L
.59446 .40082 L
.59975 .4016 L
.60257 .40192 L
.60517 .40216 L
.60766 .40234 L
.60891 .40241 L
.61028 .40247 L
.61153 .40251 L
.61267 .40253 L
.61398 .40255 L
.61522 .40255 L
.61637 .40254 L
.61743 .40252 L
.6186 .40249 L
.61984 .40244 L
.62222 .40231 L
.62472 .40212 L
.62921 .40166 L
.63403 .40097 L
.63931 .40001 L
.64878 .39774 L
.65759 .39506 L
.67632 .3878 L
.69663 .37815 L
.70203 .37539 L
.70498 .37385 L
.70642 .37309 L
.70774 .37239 L
.70894 .37175 L
.71009 .26487 L
.7113 .26487 L
.71261 .26487 L
Mistroke
.71798 .26487 L
.73813 .26487 L
.77883 .26487 L
.81801 .26487 L
.85964 .26487 L
.89976 .26487 L
.93836 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`0406Ko00<00000I_l0I_l00`1Vo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool05oooo`H0I_l01000001Vo`1Vo`1Voagoool00`000?ooooooo`0M
oooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0:oooo00<0I_oooooo
ool04?ooo`030000oooooooo01koool00`000?ooooooo`0Uoooo000joooo4P1Vof_oool00`000?oo
ooooo`0:oooo00<0I_ooooooool0FOooo`00C?ooo`D0I_mVoooo00<0003oooooool02_ooo`0306Ko
oooooooo05Woool0057oool706KoGoooo`80000;oooo00<0I_ooooooool0FOooo`00F?ooo`P0I_mG
oooo00<0003oooooool02_ooo`0306Kooooooooo05Woool0063oool506KoD_ooo`030000oooooooo
00[oool00`1Vooooooooo`1Ioooo001Uoooo101Vodkoool00`000?ooooooo`0:oooo00<0I_oooooo
ool0FOooo`00JOooo`<0I_m;oooo0P0000_oool00`1Vooooooooo`1Ioooo001/oooo101VodOoool0
0`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00L?ooo`<0I_m4oooo00<0003oooooool02_oo
o`0306Kooooooooo05Woool007?oool206Ko@_ooo`030000oooooooo00[oool00`1Vooooooooo`1I
oooo001eoooo0`1Vocooool00`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00N?ooo`80I_lm
oooo0P0000_oool00`1Vooooooooo`1Ioooo001joooo0`1Voc[oool00`000?ooooooo`0:oooo00<0
I_ooooooool0FOooo`00OOooo`80I_lhoooo00<0003oooooool02_ooo`0306Kooooooooo05Woool0
07ooool306Ko=Oooo`030000oooooooo00[oool00`1Vooooooooo`1Ioooo0022oooo0P1Voc?oool2
00002oooo`0306Kooooooooo05Woool008Coool206Ko<Oooo`030000oooooooo00[oool00`1Voooo
ooooo`1Ioooo0026oooo0P1Vobooool00`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00R?oo
o`80I_lUoooo1@0000?oool00`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00R_ooo`80I_lU
oooo00<0003oooooool00oooo`030000oooooooo00[oool00`1Vooooooooo`1Ioooo002<oooo0P1V
ob?oool00`000?ooooooo`03oooo0`0000[oool00`1Vooooooooo`1Ioooo002>oooo0P1Vob7oool0
0`000?ooooooo`03oooo00<0003oooooool02_ooo`0306Kooooooooo05Woool0093oool206Ko7ooo
o`030000oooooooo00?oool00`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00T_ooo`80I_lL
oooo0P0000Goool00`000?ooooooo`0:oooo00<0I_ooooooool0FOooo`00U?ooo`0306Kooooooooo
023oool200002oooo`0306Kooooooooo05Woool009Goool206Ko8?ooo`030000oooooooo00Soool2
06Ko00?o09Woooooool0FOooo`00Uoooo`80I_lNoooo00<0003oooooool01_ooo`80I_l2oooo00?o
09Woooooool0FOooo`00VOooo`80I_lLoooo00<0003oooooool01?ooo`80I_l4oooo00?o09Wooooo
ool0FOooo`00Voooo`80I_lJoooo00@0003oooooooooool306Ko1_ooo`03o`2Ioooooooo05Woool0
09goool306Ko5oooo`80000206Ko2Oooo`03o`2Ioooooooo05Woool00:3oool206Ko5Oooo`030000
06Kooooo00[oool00ol0VOooooooo`1Ioooo002Roooo1@1Vo`_oool506Ko00<0003oooooool02_oo
o`03o`2Ioooooooo05Woool00:Ooool;06Ko1Oooo`030000oooooooo00[oool00ol0VOooooooo`1I
oooo002goooo0P0000_oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_ooo`03o`2I
oooooooo05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`030000
oooooooo00[oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo
05Woool00;Ooool200002oooo`03o`2Ioooooooo05Woool00;Ooool00`000?ooooooo`0:oooo00?o
09Woooooool0FOooo`00[oooo`@00004oooo00<0003oooooool02_ooo`03o`2Ioooooooo05Woool0
0:ooool00`000?ooooooo`05oooo00<0003oooooool02_ooo`03o`2Ioooooooo05Woool00;3oool0
0`000?ooooooo`04oooo0`0000[oool00ol0VOooooooo`1Ioooo002aoooo00<0003oooooool00ooo
o`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002_oooo00@0003oooooool00004oooo00<0
003oooooool02_ooo`03o`2Ioooooooo05Woool00;3oool200001Oooo`030000oooooooo00[oool0
0ol0VOooooooo`1Ioooo002goooo0P0000_oool00ol0VOooooooo`1Ioooo002goooo00<0003ooooo
ool02_ooo`03o`2Ioooooooo05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Woooooool0FOoo
o`00]oooo`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_oo
o`03o`2Ioooooooo05Woool00;Ooool200002oooo`03o`2Ioooooooo05Woool00;Ooool00`000?oo
ooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`030000oooooooo00[oool00ol0VOooooooo`1I
oooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo05Woool00;Ooool200002oooo`03o`2I
oooooooo05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`030000
oooooooo00[oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo
05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`80000;oooo00?o
09Woooooool0FOooo`00]oooo`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002`oooo0P00
00Goool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00[oooo`040000oooooooo00001?oo
o`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002aoooo00<0003oooooool00oooo`<0000:
oooo00?o09Woooooool0FOooo`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0:oooo00?o
09Woooooool0FOooo`00[oooo`040000oooooooo00001?ooo`030000oooooooo00[oool00ol0VOoo
ooooo`1Ioooo002`oooo0P0000Goool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]ooo
o`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002goooo0P0000_oool00ol0VOooooooo`1I
oooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo05Woool00;Ooool00`000?ooooooo`0:
oooo00?o09Woooooool0FOooo`00]oooo`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002g
oooo0P0000_oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo
05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`030000oooooooo
00[oool00ol0VOooooooo`1Ioooo002goooo00<0003oooooool02_ooo`03o`2Ioooooooo05Woool0
0;Ooool200002oooo`03o`2Ioooooooo05Woool00;Ooool00`000?ooooooo`0:oooo00?o09Wooooo
ool0FOooo`00]oooo`030000oooooooo00[oool00ol0VOooooooo`1Ioooo002goooo00<0003ooooo
ool02_ooo`03o`2Ioooooooo05Woool00;Ooool200002oooo`03o`2Ioooooooo05Woool00;Ooool0
0`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00]oooo`030000oooooooo00[oool00ol0VOoo
ooooo`1Ioooo002aoooo0`0000?oool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00/_oo
o`030000oooooooo00;oool00`000?ooooooo`0:oooo00?o09Woooooool0FOooo`00[oooo`D00003
oooo0`0000[oool00ol0VOooooooo`1Ioooo002_oooo00@0003oooooool0001]oooo002`oooo00<0
003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800005oooo0`0000;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02_oo
o`050000oooooooooooo000007goool007[oool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Ooool500000oooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooo`000003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002oooo`800002oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.70787 .26487 L
.71284 .26487 L
.71741 .26487 L
.71998 .26487 L
.72127 .26487 L
.72201 .26487 L
s
.72201 .26487 m
.72228 .61803 L
s
0 .4 1 r
.02381 .26781 m
.06244 .26885 L
.10458 .27041 L
.14415 .27244 L
.18221 .27507 L
.22272 .27889 L
.26171 .2839 L
.30316 .29115 L
.34309 .30063 L
.3815 .31272 L
.42237 .32944 L
.46172 .34955 L
.49955 .37176 L
.53984 .39545 L
.55838 .40481 L
.57861 .4128 L
.58392 .41439 L
.58957 .41585 L
.59446 .41688 L
.59975 .41775 L
.60257 .41811 L
.60517 .41838 L
.60766 .41858 L
.60891 .41866 L
.61028 .41872 L
.61153 .41877 L
.61267 .4188 L
.61398 .41881 L
.61522 .41882 L
.61637 .4188 L
.61743 .41878 L
.6186 .41874 L
.61984 .41869 L
.62222 .41855 L
.62472 .41834 L
.62921 .41782 L
.63403 .41705 L
.63931 .41598 L
.64878 .41344 L
.65759 .41044 L
.69663 .39154 L
.70687 .3856 L
.71227 .3824 L
.71522 .38063 L
.71798 .37897 L
.72038 .37752 L
.72108 .3771 L
.72174 .3767 L
.72297 .26487 L
.72363 .26487 L
Mistroke
.72433 .26487 L
.7256 .26487 L
.72846 .26487 L
.73813 .26487 L
.77976 .26487 L
.81988 .26487 L
.85849 .26487 L
.89954 .26487 L
.93908 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00D0003ooooo
oooo09T0I_l00_ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo000Foooo00<0003oooooool03Ooooa00I_l01000001Vo`1Vo`1Voagoool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0=oooo00?o
09T0I_ooool03Oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo000joooo2P1Vog?oool0
0`000?ooooooo`0=oooo00?o09T0I_ooool0E_ooo`00A?ooo`X0I_mYoooo00<0003oooooool03Ooo
o`03o`2I06Kooooo05Koool004koool806KoHOooo`80000>oooo00?o09T0I_ooool0E_ooo`00E_oo
o`D0I_mLoooo00<0003oooooool03Oooo`03o`2I06Kooooo05Koool005_oool506KoEoooo`030000
oooooooo00goool00ol0V@1Vooooo`1Foooo001Poooo1@1Voe;oool00`000?ooooooo`0=oooo00?o
09T0I_ooool0E_ooo`00IOooo`@0I_m>oooo0P0000koool00ol0V@1Vooooo`1Foooo001Yoooo0`1V
od_oool00`000?ooooooo`0=oooo00?o09T0I_ooool0E_ooo`00K?ooo`@0I_m7oooo00<0003ooooo
ool03Oooo`03o`2I06Kooooo05Koool0073oool206KoAOooo`030000oooooooo00goool00ol0V@1V
ooooo`1Foooo001boooo0P1Vod?oool00`000?ooooooo`0=oooo00?o09T0I_ooool0E_ooo`00M?oo
o`80I_m1oooo0P0000koool00ol0V@1Vooooo`1Foooo001foooo0P1Vocooool00`000?ooooooo`0=
oooo00<0I_ooooooool0E_ooo`00N?ooo`80I_lmoooo00<0003oooooool03Oooo`0306Kooooooooo
05Koool007[oool206Ko>oooo`030000oooooooo00goool00`1Vooooooooo`1Foooo001loooo0P1V
ocWoool200003_ooo`0306Kooooooooo05Koool007koool206Ko=oooo`030000oooooooo00goool0
0`1Vooooooooo`1Foooo0020oooo0P1VocGoool00`000?ooooooo`0=oooo00<0I_ooooooool0E_oo
o`00P_ooo`80I_l[oooo1@0000?oool00`000?ooooooo`0=oooo00<0I_ooooooool0E_ooo`00Q?oo
o`80I_l[oooo00<0003oooooool00oooo`030000oooooooo00goool00`1Vooooooooo`1Foooo0026
oooo0P1VobWoool00`000?ooooooo`03oooo0`0000goool00`1Vooooooooo`1Foooo0028oooo0P1V
obOoool00`000?ooooooo`03oooo00<0003oooooool03Oooo`0306Kooooooooo05Koool008[oool2
06Ko9Oooo`030000oooooooo00?oool00`000?ooooooo`0=oooo00<0I_ooooooool0E_ooo`00S?oo
o`80I_lRoooo0P0000Goool00`000?ooooooo`0=oooo00<0I_ooooooool0E_ooo`00S_ooo`80I_lW
oooo0P0000koool00`1Vooooooooo`1Foooo002@oooo0P1VobGoool00`000?ooooooo`0=oooo00<0
I_ooooooool0E_ooo`00T_ooo`80I_lSoooo00<0003oooooool03?ooo`80I_mHoooo002Doooo00<0
I_ooooooool08?ooo`030000oooooooo00_oool206Ko00?o09Woooooool0E_ooo`00UOooo`80I_lP
oooo00<0003oooooool02Oooo`80I_l2oooo00?o09Woooooool0E_ooo`00Uoooo`80I_lNoooo0P00
00Soool206Ko1?ooo`03o`2Ioooooooo05Koool009Woool00`1Vooooooooo`0Koooo00<0003ooooo
ool01Oooo`80I_l6oooo00?o09Woooooool0E_ooo`00V_ooo`80I_lKoooo00<0003oooooool00ooo
o`80I_l8oooo00?o09Woooooool0E_ooo`00W?ooo`80I_lIoooo00@0003oooooooooool206Ko2_oo
o`03o`2Ioooooooo05Koool009koool206Ko5oooo`80000206Ko3?ooo`03o`2Ioooooooo05Koool0
0:3oool206Ko5Oooo`03000006Kooooo00goool00ol0VOooooooo`1Foooo002Roooo0`1Vo`ooool3
06Ko00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00:Goool?06Ko0oooo`030000oooooooo
00goool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool0
0;Ooool200003_ooo`03o`2Ioooooooo05Koool00;Ooool00`000?ooooooo`0=oooo00?o09Wooooo
ool0E_ooo`00[oooo`@00004oooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00:ooool0
0`000?ooooooo`05oooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00;3oool00`000?oo
ooooo`04oooo0`0000goool00ol0VOooooooo`1Foooo002aoooo00<0003oooooool00oooo`030000
oooooooo00goool00ol0VOooooooo`1Foooo002_oooo00@0003oooooool00004oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo05Koool00;3oool200001Oooo`030000oooooooo00goool00ol0VOoo
ooooo`1Foooo002goooo0P0000koool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Ooo
o`03o`2Ioooooooo05Koool00;Ooool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00]ooo
o`030000oooooooo00goool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Oooo`03o`2I
oooooooo05Koool00;Ooool200003_ooo`03o`2Ioooooooo05Koool00;Ooool00`000?ooooooo`0=
oooo00?o09Woooooool0E_ooo`00]oooo`030000oooooooo00goool00ol0VOooooooo`1Foooo002g
oooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00;Ooool200003_ooo`03o`2Ioooooooo
05Koool00;Ooool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00]oooo`030000oooooooo
00goool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool0
0;Ooool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00]oooo`80000>oooo00?o09Wooooo
ool0E_ooo`00]oooo`030000oooooooo00goool00ol0VOooooooo`1Foooo002`oooo0P0000Goool0
0`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00[oooo`040000oooooooo00001?ooo`030000
oooooooo00goool00ol0VOooooooo`1Foooo002aoooo00<0003oooooool00oooo`<0000=oooo00?o
09Woooooool0E_ooo`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00?o09Wooooo
ool0E_ooo`00[oooo`040000oooooooo00001?ooo`030000oooooooo00goool00ol0VOooooooo`1F
oooo002`oooo0P0000Goool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00]oooo`030000
oooooooo00goool00ol0VOooooooo`1Foooo002goooo0P0000koool00ol0VOooooooo`1Foooo002g
oooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00;Ooool00`000?ooooooo`0=oooo00?o
09Woooooool0E_ooo`00]oooo`030000oooooooo00goool00ol0VOooooooo`1Foooo002goooo0P00
00koool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool0
0;Ooool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00]oooo`030000oooooooo00goool0
0ol0VOooooooo`1Foooo002goooo00<0003oooooool03Oooo`03o`2Ioooooooo05Koool00;Ooool2
00003_ooo`03o`2Ioooooooo05Koool00;Ooool00`000?ooooooo`0=oooo00?o09Woooooool0E_oo
o`00]oooo`030000oooooooo00goool00ol0VOooooooo`1Foooo002goooo00<0003oooooool03Ooo
o`03o`2Ioooooooo05Koool00;Ooool200003_ooo`03o`2Ioooooooo05Koool00;Ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0E_ooo`00]oooo`030000oooooooo00goool00ol0VOooooooo`1F
oooo002aoooo0`0000?oool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00/_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00?o09Woooooool0E_ooo`00[oooo`D00003oooo0`00
00goool00ol0VOooooooo`1Foooo002_oooo00@0003oooooool0001]oooo002`oooo00<0003oool0
0000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000_ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71741 .26487 L
.72307 .26487 L
.72841 .26487 L
.73074 .26487 L
.7332 .26487 L
.73449 .26487 L
s
.73449 .26487 m
.73478 .61803 L
s
0 .4 1 r
.02381 .26814 m
.06244 .26931 L
.10458 .27105 L
.14415 .27331 L
.18221 .27625 L
.22272 .28052 L
.26171 .2861 L
.30316 .29419 L
.34309 .30477 L
.3815 .31825 L
.42237 .33691 L
.46172 .35934 L
.49955 .38412 L
.53984 .41055 L
.55838 .421 L
.57861 .42991 L
.58392 .43169 L
.58957 .43331 L
.59446 .43446 L
.59975 .43544 L
.60257 .43584 L
.60517 .43614 L
.60766 .43636 L
.60891 .43644 L
.61028 .43652 L
.61153 .43657 L
.61267 .4366 L
.61398 .43662 L
.61522 .43662 L
.61637 .43661 L
.61743 .43658 L
.6186 .43654 L
.61984 .43648 L
.62222 .43632 L
.62472 .43609 L
.62921 .43551 L
.63403 .43466 L
.63931 .43345 L
.64878 .43063 L
.65759 .42728 L
.69663 .40619 L
.70687 .39957 L
.71798 .39217 L
.72307 .38873 L
.72846 .38509 L
.73068 .38359 L
.73307 .38198 L
.73377 .3815 L
.73443 .38106 L
.73568 .26487 L
Mistroke
.73685 .26487 L
.73813 .26487 L
.77883 .26487 L
.81801 .26487 L
.85964 .26487 L
.89976 .26487 L
.93836 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`03o`2I0000oooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool03Ooooa00I_l01000001Vo`1Vo`1Voagoool00`000?ooooooo`0M
oooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0@oooo00?o09T0I_oo
ool02_ooo`030000oooooooo01koool00`000?ooooooo`0Uoooo000joooo2P1Vog?oool00`000?oo
ooooo`0@oooo00?o09T0I_ooool0Doooo`00A?ooo`P0I_m[oooo00<0003oooooool04?ooo`03o`2I
06Kooooo05?oool004coool506KoI_ooo`80000Aoooo00?o09T0I_ooool0Doooo`00DOooo`D0I_mQ
oooo00<0003oooooool04?ooo`03o`2I06Kooooo05?oool005Koool506KoG?ooo`030000oooooooo
013oool00ol0V@1Vooooo`1Coooo001Koooo1@1VoeOoool00`000?ooooooo`0@oooo00?o09T0I_oo
ool0Doooo`00H?ooo`D0I_mBoooo0P00017oool00ol0V@1Vooooo`1Coooo001Uoooo101Vodkoool0
0`000?ooooooo`0@oooo00?o09T0I_ooool0Doooo`00JOooo`80I_m<oooo00<0003oooooool04?oo
o`03o`2I06Kooooo05?oool006_oool306KoBOooo`030000oooooooo013oool00ol0V@1Vooooo`1C
oooo001^oooo0P1VodOoool00`000?ooooooo`0@oooo00?o09T0I_ooool0Doooo`00L?ooo`<0I_m4
oooo0P00017oool00ol0V@1Vooooo`1Coooo001coooo0P1Vod;oool00`000?ooooooo`0@oooo00<0
I_ooooooool0Doooo`00MOooo`<0I_looooo00<0003oooooool04?ooo`0306Kooooooooo05?oool0
07Soool206Ko?Oooo`030000oooooooo013oool00`1Vooooooooo`1Coooo001joooo0P1Voc_oool2
00004Oooo`0306Kooooooooo05?oool007coool206Ko>Oooo`030000oooooooo013oool00`1Voooo
ooooo`1Coooo001noooo0P1VocOoool00`000?ooooooo`0@oooo00<0I_ooooooool0Doooo`00P?oo
o`0306Kooooooooo02coool500000oooo`030000oooooooo013oool00`1Vooooooooo`1Coooo0021
oooo0P1Vobkoool00`000?ooooooo`03oooo00<0003oooooool04?ooo`0306Kooooooooo05?oool0
08?oool206Ko;?ooo`030000oooooooo00?oool300004?ooo`0306Kooooooooo05?oool008Goool0
0`1Vooooooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo013oool00`1Vooooooooo`1C
oooo0026oooo0P1VobWoool00`000?ooooooo`03oooo00<0003oooooool04?ooo`0306Kooooooooo
05?oool008Soool206Ko9_ooo`800005oooo00<0003oooooool04?ooo`0306Kooooooooo05?oool0
08[oool00`1Vooooooooo`0Zoooo0P00017oool00`1Vooooooooo`1Coooo002;oooo0P1Vob[oool0
0`000?ooooooo`0@oooo00<0I_ooooooool0Doooo`00SOooo`80I_lXoooo00<0003oooooool04?oo
o`0306Kooooooooo05?oool008ooool00`1Vooooooooo`0Uoooo00<0003oooooool03oooo`80I_mE
oooo002@oooo0P1VobGoool00`000?ooooooo`0?oooo00<0I_oo09Woool0E?ooo`00T_ooo`0306Ko
oooooooo02;oool200003Oooo`<0I_l00oooool0VOooo`1Doooo002Coooo00<0I_ooooooool08Ooo
o`030000oooooooo00[oool206Ko1?ooo`03o`2Ioooooooo05?oool009Coool206Ko8Oooo`030000
oooooooo00Woool00`1Vooooooooo`04oooo00?o09Woooooool0Doooo`00U_ooo`0306Kooooooooo
01koool00`000?ooooooo`08oooo00<0I_ooooooool01Oooo`03o`2Ioooooooo05?oool009Ooool2
06Ko7_ooo`800008oooo00<0I_ooooooool01_ooo`03o`2Ioooooooo05?oool009Woool00`1Voooo
ooooo`0Koooo00<0003oooooool01Oooo`80I_l9oooo00?o09Woooooool0Doooo`00V_ooo`80I_lK
oooo00<0003oooooool00oooo`80I_l;oooo00?o09Woooooool0Doooo`00W?ooo`80I_lIoooo00@0
003oooooooooool206Ko3Oooo`03o`2Ioooooooo05?oool009koool206Ko5oooo`040000oooo06Ko
06Ko3oooo`03o`2Ioooooooo05?oool00:3oool206Ko5Oooo`80000Aoooo00?o09Woooooool0Dooo
o`00X_ooo`80I_l@oooo0`1Vo`030000oooooooo013oool00ol0VOooooooo`1Coooo002Toooo1@1V
o`Koool4000000D0I_ooooooooooool000004_ooo`03o`2Ioooooooo05?oool00:Woool606Ko00<0
003oooooool01Oooo`030000oooooooo013oool00ol0VOooooooo`1Coooo002`oooo00<0003ooooo
ool01?ooo`<0000@oooo00?o09Woooooool0Doooo`00/Oooo`030000oooooooo00?oool00`000?oo
ooooo`0Aoooo00?o09Woooooool0D_ooo`00[oooo`040000oooooooo00001?ooo`030000oooooooo
017oool00ol0VOooooooo`1Boooo002`oooo0P0000Goool00`000?ooooooo`0Aoooo00?o09Wooooo
ool0D_ooo`00]oooo`80000Boooo00?o09Woooooool0D_ooo`00]oooo`030000oooooooo017oool0
0ol0VOooooooo`1Boooo002goooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;Ooool0
0`000?ooooooo`0Aoooo00?o09Woooooool0D_ooo`00]oooo`030000oooooooo017oool00ol0VOoo
ooooo`1Boooo002goooo0P0001;oool00ol0VOooooooo`1Boooo002goooo00<0003oooooool04Ooo
o`03o`2Ioooooooo05;oool00;Ooool00`000?ooooooo`0Aoooo00?o09Woooooool0D_ooo`00]ooo
o`030000oooooooo017oool00ol0VOooooooo`1Boooo002goooo0P0001;oool00ol0VOooooooo`1B
oooo002goooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;Ooool00`000?ooooooo`0A
oooo00?o09Woooooool0D_ooo`00]oooo`030000oooooooo017oool00ol0VOooooooo`1Boooo002g
oooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;Ooool200004_ooo`03o`2Ioooooooo
05;oool00;Ooool00`000?ooooooo`0Aoooo00?o09Woooooool0D_ooo`00/?ooo`800005oooo00<0
003oooooool04Oooo`03o`2Ioooooooo05;oool00:ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0Aoooo00?o09Woooooool0D_ooo`00/Oooo`030000oooooooo00?oool300004Oooo`03o`2I
oooooooo05;oool00;;oool00`000?ooooooo`02oooo00<0003oooooool04Oooo`03o`2Ioooooooo
05;oool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`0Aoooo00?o09Woooooool0D_oo
o`00/?ooo`800005oooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;Ooool00`000?oo
ooooo`0Aoooo00?o09Woooooool0D_ooo`00]oooo`80000Boooo00?o09Woooooool0D_ooo`00]ooo
o`030000oooooooo017oool00ol0VOooooooo`1Boooo002goooo00<0003oooooool04Oooo`03o`2I
oooooooo05;oool00;Ooool00`000?ooooooo`0Aoooo00?o09Woooooool0D_ooo`00]oooo`80000B
oooo00?o09Woooooool0D_ooo`00]oooo`030000oooooooo017oool00ol0VOooooooo`1Boooo002g
oooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;Ooool00`000?ooooooo`0Aoooo00?o
09Woooooool0D_ooo`00]oooo`030000oooooooo017oool00ol0VOooooooo`1Boooo002goooo0P00
01;oool00ol0VOooooooo`1Boooo002goooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool0
0;Ooool00`000?ooooooo`0Aoooo00?o09Woooooool0D_ooo`00]oooo`030000oooooooo017oool0
0ol0VOooooooo`1Boooo002goooo0P0001;oool00ol0VOooooooo`1Boooo002goooo00<0003ooooo
ool04Oooo`03o`2Ioooooooo05;oool00;Ooool00`000?ooooooo`0Aoooo00?o09Woooooool0D_oo
o`00/Oooo`<00003oooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00;;oool00`000?oo
ooooo`02oooo00<0003oooooool04Oooo`03o`2Ioooooooo05;oool00:ooool500000oooo`<0000A
oooo00?o09Woooooool0D_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo0000
06goool00;7oool20000KOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200000oooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000>oooo00<0003oooooool01oooo`<00004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71905 .26487 L
.72912 .26487 L
.73838 .26487 L
.74309 .26487 L
.74546 .26487 L
.74611 .26487 L
.7468 .26487 L
s
.7468 .26487 m
.74731 .61803 L
s
0 .4 1 r
.02381 .26852 m
.06244 .26981 L
.10458 .27176 L
.14415 .27427 L
.18221 .27755 L
.22272 .28229 L
.26171 .28851 L
.30316 .29752 L
.34309 .3093 L
.3815 .32432 L
.42237 .3451 L
.46172 .37008 L
.49955 .39768 L
.53984 .42711 L
.55838 .43875 L
.57861 .44867 L
.58392 .45065 L
.58957 .45246 L
.59446 .45374 L
.59975 .45483 L
.60257 .45528 L
.60517 .45561 L
.60766 .45585 L
.60891 .45595 L
.61028 .45603 L
.61153 .45609 L
.61267 .45612 L
.61398 .45614 L
.61522 .45615 L
.61637 .45613 L
.61743 .4561 L
.6186 .45606 L
.61984 .45599 L
.62222 .45582 L
.62472 .45556 L
.62921 .45491 L
.63403 .45396 L
.63931 .45262 L
.64878 .44947 L
.65759 .44574 L
.69663 .42225 L
.71654 .40771 L
.72703 .39983 L
.73276 .39552 L
.73813 .39149 L
.7429 .38794 L
.74428 .38692 L
.74559 .38595 L
.74676 .38509 L
.74803 .26487 L
Mistroke
.74878 .26487 L
.74947 .26487 L
.75077 .26487 L
.75369 .26487 L
.75893 .26487 L
.77811 .26487 L
.81671 .26487 L
.85777 .26487 L
.89731 .26487 L
.93533 .26487 L
.97581 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l0101Vo`030000
06Ko06Ko00<0I_l00`00001Vo`1Vo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`040000oooooooo06Ko0_ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
01;oool001Koool00`000?ooooooo`0=oooo2P1Vo`Koool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool05?ooo`0306Ko
oooooooo00Koool00`000?ooooooo`0Noooo00<0003oooooool09Oooo`00<?oooa40I_mfoooo00<0
003oooooool05?ooo`0306Kooooooooo04ooool0047oool606KoL?ooo`030000oooooooo01Coool0
0`1Vooooooooo`1?oooo0017oooo1`1VofWoool200005Oooo`0306Kooooooooo04ooool004koool8
06KoHOooo`030000oooooooo01Coool00`1Vooooooooo`1?oooo001Foooo1@1Voecoool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Coooo`00Foooo`@0I_mHoooo00<0003oooooool05?ooo`0306Ko
oooooooo04ooool005ooool306KoEOooo`80000Eoooo00<0I_ooooooool0Coooo`00H_ooo`@0I_mA
oooo00<0003oooooool05?ooo`0306Kooooooooo04ooool006Koool306KoC_ooo`030000oooooooo
01Coool00`1Vooooooooo`1?oooo001Yoooo0P1Vodcoool00`000?ooooooo`0Doooo00<0I_oooooo
ool0Coooo`00Joooo`<0I_m9oooo00<0003oooooool05?ooo`0306Kooooooooo04ooool006koool2
06KoAoooo`80000Eoooo00<0I_ooooooool0Coooo`00L?ooo`80I_m5oooo00<0003oooooool05?oo
o`0306Kooooooooo04ooool007;oool206Ko@oooo`030000oooooooo01Coool00`1Vooooooooo`1?
oooo001doooo0P1Vod7oool00`000?ooooooo`0Doooo00<0I_ooooooool0Coooo`00M_ooo`0306Ko
oooooooo03koool200005Oooo`0306Kooooooooo04ooool007Ooool206Ko?_ooo`030000oooooooo
01Coool00`1Vooooooooo`1?oooo001ioooo0P1Voccoool00`000?ooooooo`0Doooo00<0I_oooooo
ool0Coooo`00Noooo`0306Kooooooooo037oool500000oooo`030000oooooooo01Coool00`1Voooo
ooooo`1?oooo001loooo0P1Voc?oool00`000?ooooooo`03oooo00<0003oooooool05?ooo`0306Ko
oooooooo04ooool007koool206Ko<Oooo`030000oooooooo00?oool300005?ooo`0306Kooooooooo
04ooool0083oool00`1Vooooooooo`0^oooo00<0003oooooool00oooo`030000oooooooo01Coool0
0`1Vooooooooo`1?oooo0021oooo0P1Vobkoool00`000?ooooooo`03oooo00<0003oooooool05?oo
o`0306Kooooooooo04ooool008?oool206Ko:oooo`800005oooo00<0003oooooool05?ooo`0306Ko
oooooooo04ooool008Goool00`1Vooooooooo`0_oooo0P0001Goool00`1Vooooooooo`1?oooo0026
oooo0P1Vobooool00`000?ooooooo`0Doooo00<0I_ooooooool0Coooo`00R?ooo`0306Kooooooooo
02coool00`000?ooooooo`0Doooo00<0I_ooooooool0Coooo`00ROooo`0306Kooooooooo02_oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0Coooo`00R_ooo`80I_l[oooo00<0003oooooool04ooo
o`80I_mAoooo002<oooo00<0I_ooooooool0:?ooo`80000Boooo0P1Vo`03ooooo`2Ioooo053oool0
08goool206Ko:?ooo`030000oooooooo013oool01@1Vooooooooooooool0V@1Aoooo002?oooo00<0
I_ooooooool09Oooo`030000oooooooo00ooool00`1Vooooooooo`02oooo00?o09Woooooool0Cooo
o`00T?ooo`80I_lUoooo00<0003oooooool03Oooo`80I_l5oooo00?o09Woooooool0Coooo`00T_oo
o`0306Kooooooooo02;oool200003Oooo`0306Kooooooooo00Goool00ol0VOooooooo`1?oooo002C
oooo00<0I_ooooooool08Oooo`030000oooooooo00_oool00`1Vooooooooo`06oooo00?o09Wooooo
ool0Coooo`00U?ooo`80I_lQoooo00<0003oooooool02Oooo`80I_l9oooo00?o09Woooooool0Cooo
o`00U_ooo`0306Kooooooooo01koool00`000?ooooooo`08oooo00<0I_ooooooool02Oooo`03o`2I
oooooooo04ooool009Ooool206Ko7_ooo`030000oooooooo00Ooool00`1Vooooooooo`0:oooo00?o
09Woooooool0Coooo`00VOooo`0306Kooooooooo01_oool200001_ooo`80I_l=oooo00?o09Wooooo
ool0Coooo`00V_ooo`80I_lKoooo00<0003oooooool00oooo`80I_l?oooo00?o09Woooooool0Cooo
o`00W?ooo`80I_lAoooo100000Coool00`000?ooooooo`02oooo00<0I_ooooooool03oooo`03o`2I
oooooooo04ooool009koool00`1Vooooooooo`0>oooo00<0003oooooool01Oooo`030000oooooooo
0080I_lBoooo00?o09Woooooool0Coooo`00Woooo`80I_l?oooo00<0003oooooool01?ooo`<0000D
oooo00?o09Woooooool0Coooo`00XOooo`80I_l>oooo00<0003oooooool00oooo`030000oooooooo
01Coool00ol0VOooooooo`1?oooo002Soooo0P1Vo`[oool01@000?ooooooo`000?ooo`0306Ko00<0
003oooooool05?ooo`03o`2Ioooooooo04ooool00:Goool506Ko1_ooo`80000206Ko0oooo`030000
oooooooo01Coool00ol0VOooooooo`1?oooo002Zoooo1P1Vo`Ooool200005Oooo`03o`2Ioooooooo
04ooool00;Ooool00`000?ooooooo`0Doooo00?o09Woooooool0Coooo`00]oooo`030000oooooooo
01Coool00ol0VOooooooo`1?oooo002goooo00<0003oooooool05?ooo`03o`2Ioooooooo04ooool0
0;Ooool00`000?ooooooo`0Doooo00?o09Woooooool0Coooo`00]oooo`80000Eoooo00?o09Wooooo
ool0Coooo`00]oooo`030000oooooooo01Coool00ol0VOooooooo`1?oooo002goooo00<0003ooooo
ool05?ooo`03o`2Ioooooooo04ooool00;Ooool00`000?ooooooo`0Doooo00?o09Woooooool0Cooo
o`00]oooo`80000Eoooo00?o09Woooooool0Coooo`00]oooo`030000oooooooo01Coool00ol0VOoo
ooooo`1?oooo002goooo00<0003oooooool05?ooo`03o`2Ioooooooo04ooool00;Ooool00`000?oo
ooooo`0Doooo00?o09Woooooool0Coooo`00]oooo`030000oooooooo01Coool00ol0VOooooooo`1?
oooo002goooo0P0001Goool00ol0VOooooooo`1?oooo002goooo00<0003oooooool05?ooo`03o`2I
oooooooo04ooool00;3oool200001Oooo`030000oooooooo01Coool00ol0VOooooooo`1?oooo002_
oooo00@0003oooooool00004oooo00<0003oooooool05?ooo`03o`2Ioooooooo04ooool00;7oool0
0`000?ooooooo`03oooo0`0001Coool00ol0VOooooooo`1?oooo002boooo00<0003oooooool00_oo
o`030000oooooooo01Coool00ol0VOooooooo`1?oooo002_oooo00@0003oooooool00004oooo00<0
003oooooool05?ooo`03o`2Ioooooooo04ooool00;3oool200001Oooo`030000oooooooo01Coool0
0ol0VOooooooo`1?oooo002goooo00<0003oooooool05?ooo`03o`2Ioooooooo04ooool00;Ooool2
00005Oooo`03o`2Ioooooooo04ooool00;Ooool00`000?ooooooo`0Doooo00?o09Woooooool0Cooo
o`00]oooo`030000oooooooo01Coool00ol0VOooooooo`1?oooo002goooo00<0003oooooool05?oo
o`03o`2Ioooooooo04ooool00;Ooool200005Oooo`03o`2Ioooooooo04ooool00;Ooool00`000?oo
ooooo`0Doooo00?o09Woooooool0Coooo`00]oooo`030000oooooooo01Coool00ol0VOooooooo`1?
oooo002goooo00<0003oooooool05?ooo`03o`2Ioooooooo04ooool00;Ooool00`000?ooooooo`0D
oooo00?o09Woooooool0Coooo`00]oooo`80000Eoooo00?o09Woooooool0Coooo`00]oooo`030000
oooooooo01Coool00ol0VOooooooo`1?oooo002goooo00<0003oooooool05?ooo`03o`2Ioooooooo
04ooool00;Ooool00`000?ooooooo`0Doooo00?o09Woooooool0Coooo`00]oooo`80000Eoooo00?o
09Woooooool0Coooo`00]oooo`030000oooooooo01Coool00ol0VOooooooo`1?oooo002goooo00<0
003oooooool05?ooo`03o`2Ioooooooo04ooool00;7oool300000oooo`030000oooooooo01Coool0
0ol0VOooooooo`1?oooo002boooo00<0003oooooool00_ooo`030000oooooooo01Coool00ol0VOoo
ooooo`1?oooo002_oooo1@0000?oool300005?ooo`03o`2Ioooooooo04ooool00:ooool010000?oo
ooooo`0006goool00;3oool00`000?ooo`00001]oooo002aoooo0P0006goool00?oooolQoooo003o
oooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000
oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?oo
ooooo`0:oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooooooo0000017oool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002Oooo`@00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71905 .26487 L
.73838 .26487 L
.74806 .26487 L
.75315 .26487 L
.75593 .26487 L
.75729 .26487 L
.75853 .26487 L
.7597 .26487 L
s
.7597 .26487 m
.76014 .61803 L
s
0 .4 1 r
.02381 .26893 m
.06244 .27037 L
.10458 .27253 L
.14415 .27532 L
.18221 .27897 L
.22272 .28425 L
.26171 .29116 L
.30316 .30118 L
.34309 .31428 L
.3815 .33099 L
.42237 .35409 L
.46172 .38187 L
.49955 .41256 L
.53984 .4453 L
.55838 .45824 L
.57861 .46927 L
.58392 .47148 L
.58957 .47348 L
.59446 .47491 L
.59975 .47612 L
.60257 .47662 L
.60517 .47699 L
.60766 .47726 L
.60891 .47737 L
.61028 .47746 L
.61153 .47752 L
.61267 .47756 L
.61398 .47758 L
.61522 .47759 L
.61637 .47757 L
.61743 .47754 L
.6186 .47749 L
.61984 .47742 L
.62222 .47722 L
.62472 .47693 L
.62921 .47621 L
.63403 .47515 L
.63931 .47366 L
.64878 .47016 L
.65759 .46602 L
.69663 .4399 L
.71654 .42372 L
.73813 .40569 L
.74823 .39736 L
.75376 .39288 L
.75646 .39071 L
.75764 .38977 L
.75893 .38874 L
.7601 .38782 L
.76119 .26487 L
Mistroke
.76223 .26487 L
.76333 .26487 L
.76806 .26487 L
.77811 .26487 L
.81975 .26487 L
.85986 .26487 L
.89847 .26487 L
.93952 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l00P1Vo`;oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool04_ooo`005_ooo`030000oooooooo00;ooolE06Ko1_ooo`030000oooooooo01koool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Goooo00<0
I_ooooooool00oooo`030000oooooooo01koool00`000?ooooooo`0Uoooo000`oooo2P1Voggoool0
0`000?ooooooo`0Goooo00<0I_ooooooool0C?ooo`00>_ooo`X0I_mcoooo00<0003oooooool05ooo
o`0306Kooooooooo04coool004Coool806KoJoooo`80000Hoooo00<0I_ooooooool0C?ooo`00C?oo
o`D0I_mVoooo00<0003oooooool05oooo`0306Kooooooooo04coool0057oool506KoHOooo`030000
oooooooo01Ooool00`1Vooooooooo`1<oooo001Foooo1@1Voecoool00`000?ooooooo`0Goooo00<0
I_ooooooool0C?ooo`00Foooo`@0I_mHoooo0P0001Soool00`1Vooooooooo`1<oooo001Ooooo0P1V
oeKoool00`000?ooooooo`0Goooo00<0I_ooooooool0C?ooo`00HOooo`<0I_mCoooo00<0003ooooo
ool05oooo`0306Kooooooooo04coool006Coool206KoDOooo`030000oooooooo01Ooool00`1Voooo
ooooo`1<oooo001Voooo0`1Vodkoool00`000?ooooooo`0Goooo00<0I_ooooooool0C?ooo`00JOoo
o`80I_m<oooo0P0001Soool00`1Vooooooooo`1<oooo001[oooo0`1VodWoool00`000?ooooooo`0G
oooo00<0I_ooooooool0C?ooo`00K_ooo`80I_m7oooo00<0003oooooool05oooo`0306Kooooooooo
04coool0073oool206KoAOooo`030000oooooooo01Ooool00`1Vooooooooo`1<oooo001boooo0P1V
od?oool200006?ooo`0306Kooooooooo04coool007Coool206Ko@Oooo`030000oooooooo01Ooool0
0`1Vooooooooo`1<oooo001foooo00<0I_ooooooool0?_ooo`030000oooooooo01Ooool00`1Voooo
ooooo`1<oooo001goooo0P1VocKoool500000oooo`030000oooooooo01Ooool00`1Vooooooooo`1<
oooo001ioooo0P1VocKoool00`000?ooooooo`03oooo00<0003oooooool05oooo`0306Kooooooooo
04coool007_oool00`1Vooooooooo`0coooo00<0003oooooool00oooo`<0000Goooo00<0I_oooooo
ool0C?ooo`00O?ooo`80I_lcoooo00<0003oooooool00oooo`030000oooooooo01Ooool00`1Voooo
ooooo`1<oooo001noooo00<0I_ooooooool0<?ooo`030000oooooooo00?oool00`000?ooooooo`0G
oooo00<0I_ooooooool0C?ooo`00Ooooo`0306Kooooooooo02koool200001Oooo`030000oooooooo
01Ooool00`1Vooooooooo`1<oooo0020oooo0P1VocGoool200006?ooo`0306Kooooooooo04coool0
08;oool00`1Vooooooooo`0boooo00<0003oooooool05oooo`0306Kooooooooo04coool008?oool2
06Ko<_ooo`030000oooooooo01Ooool00`1Vooooooooo`1<oooo0025oooo00<0I_ooooooool0;ooo
o`030000oooooooo01Ooool00`1Vooooooooo`1<oooo0026oooo00<0I_ooooooool0;_ooo`030000
oooooooo01Ooool00`1Vooooooooo`1<oooo0027oooo0P1Vobkoool200005oooo`80I_m>oooo0029
oooo00<0I_ooooooool0:oooo`030000oooooooo01Goool00`1Vooooool0V@1>oooo002:oooo00<0
I_ooooooool0:_ooo`030000oooooooo01Coool0101Vooooooooool0VDkoool008_oool00`1Voooo
ooooo`0Yoooo00<0003oooooool04_ooo`80I_l3oooo00?o09Woooooool0C?ooo`00S?ooo`80I_lY
oooo0P0001;oool00`1Vooooooooo`03oooo00?o09Woooooool0C?ooo`00S_ooo`0306Kooooooooo
02Koool00`000?ooooooo`0@oooo00<0I_ooooooool01?ooo`03o`2Ioooooooo04coool008ooool0
0`1Vooooooooo`0Uoooo00<0003oooooool03_ooo`80I_l7oooo00?o09Woooooool0C?ooo`00T?oo
o`0306Kooooooooo02Coool00`000?ooooooo`0=oooo00<0I_ooooooool01oooo`03o`2Ioooooooo
04coool0097oool206Ko9?ooo`030000oooooooo00coool00`1Vooooooooo`08oooo00?o09Wooooo
ool0C?ooo`00Toooo`0306Kooooooooo027oool200003?ooo`0306Kooooooooo00Woool00ol0VOoo
ooooo`1<oooo002Doooo00<0I_ooooooool08?ooo`030000oooooooo00[oool00`1Vooooooooo`0:
oooo00?o09Woooooool0C?ooo`00UOooo`0306Kooooooooo01Ooool400001?ooo`030000oooooooo
00Woool00`1Vooooooooo`0;oooo00?o09Woooooool0C?ooo`00U_ooo`80I_lGoooo00<0003ooooo
ool01Oooo`030000oooooooo00Soool00`1Vooooooooo`0<oooo00?o09Woooooool0C?ooo`00V?oo
o`0306Kooooooooo01Goool00`000?ooooooo`04oooo0`0000Ooool00`1Vooooooooo`0=oooo00?o
09Woooooool0C?ooo`00VOooo`0306Kooooooooo01Goool00`000?ooooooo`03oooo00<0003ooooo
ool01Oooo`80I_l@oooo00?o09Woooooool0C?ooo`00V_ooo`80I_lCoooo00@0003oooooool00004
oooo00<0003oooooool00oooo`80I_lBoooo00?o09Woooooool0C?ooo`00W?ooo`80I_lBoooo0P00
00Goool00`000?ooooooo`02oooo00<0I_ooooooool04_ooo`03o`2Ioooooooo04coool009koool0
0`1Vooooooooo`0Foooo0P000003oooo06Ko06Ko01Goool00ol0VOooooooo`1<oooo002Ooooo0P1V
oaKoool00`00001Vo`1Vo`0Goooo00?o09Woooooool0C?ooo`00XOooo`80I_lDoooo00<0003ooooo
ool05oooo`03o`2Ioooooooo04coool00:?oool00`1Vooooooooo`0>oooo0`1Vo`030000oooooooo
01Ooool00ol0VOooooooo`1<oooo002Toooo101Vo`[oool206Ko0oooo`030000oooooooo01Ooool0
0ol0VOooooooo`1<oooo002Xoooo2P1Vo`Goool200006?ooo`03o`2Ioooooooo04coool00;Ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00]oooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1<oooo002goooo00<0003oooooool05oooo`03o`2Ioooooooo04coool00;Ooool200006?oo
o`03o`2Ioooooooo04coool00;Ooool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00]ooo
o`030000oooooooo01Ooool00ol0VOooooooo`1<oooo002goooo00<0003oooooool05oooo`03o`2I
oooooooo04coool00;Ooool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00]oooo`80000H
oooo00?o09Woooooool0C?ooo`00]oooo`030000oooooooo01Ooool00ol0VOooooooo`1<oooo002`
oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00[oooo`040000oooooooo
00001?ooo`030000oooooooo01Ooool00ol0VOooooooo`1<oooo002aoooo00<0003oooooool00ooo
o`<0000Goooo00?o09Woooooool0C?ooo`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0G
oooo00?o09Woooooool0C?ooo`00[oooo`040000oooooooo00001?ooo`030000oooooooo01Ooool0
0ol0VOooooooo`1<oooo002`oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0C?oo
o`00]oooo`030000oooooooo01Ooool00ol0VOooooooo`1<oooo002goooo0P0001Soool00ol0VOoo
ooooo`1<oooo002goooo00<0003oooooool05oooo`03o`2Ioooooooo04coool00;Ooool00`000?oo
ooooo`0Goooo00?o09Woooooool0C?ooo`00]oooo`030000oooooooo01Ooool00ol0VOooooooo`1<
oooo002goooo0P0001Soool00ol0VOooooooo`1<oooo002goooo00<0003oooooool05oooo`03o`2I
oooooooo04coool00;Ooool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00]oooo`030000
oooooooo01Ooool00ol0VOooooooo`1<oooo002goooo00<0003oooooool05oooo`03o`2Ioooooooo
04coool00;Ooool200006?ooo`03o`2Ioooooooo04coool00;Ooool00`000?ooooooo`0Goooo00?o
09Woooooool0C?ooo`00]oooo`030000oooooooo01Ooool00ol0VOooooooo`1<oooo002goooo00<0
003oooooool05oooo`03o`2Ioooooooo04coool00;Ooool200006?ooo`03o`2Ioooooooo04coool0
0;Ooool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00]oooo`030000oooooooo01Ooool0
0ol0VOooooooo`1<oooo002aoooo0`0000?oool00`000?ooooooo`0Goooo00?o09Woooooool0C?oo
o`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0Goooo00?o09Woooooool0C?ooo`00[ooo
o`D00003oooo0`0001Ooool00ol0VOooooooo`1<oooo002_oooo00@0003oooooool0001]oooo002`
oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool500000_ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo0P0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71905 .26487 L
.73838 .26487 L
.74806 .26487 L
.75853 .26487 L
.76334 .26487 L
.76842 .26487 L
.77051 .26487 L
.77166 .26487 L
.77275 .26487 L
s
.77275 .26487 m
.77327 .61803 L
s
0 .4 1 r
.02381 .26937 m
.06244 .27098 L
.10458 .27338 L
.14415 .27648 L
.18221 .28053 L
.22272 .28639 L
.26171 .29408 L
.30316 .30521 L
.34309 .31976 L
.3815 .33831 L
.42237 .36398 L
.46172 .39484 L
.49955 .42893 L
.53984 .46529 L
.55838 .47966 L
.57861 .49191 L
.58392 .49437 L
.58957 .4966 L
.59446 .49818 L
.59975 .49952 L
.60257 .50008 L
.60517 .50049 L
.60766 .50079 L
.60891 .50091 L
.61028 .50101 L
.61153 .50108 L
.61267 .50113 L
.61398 .50115 L
.61522 .50115 L
.61637 .50114 L
.61743 .5011 L
.6186 .50105 L
.61984 .50096 L
.62222 .50075 L
.62472 .50043 L
.62921 .49963 L
.63403 .49845 L
.63931 .4968 L
.64878 .49291 L
.65759 .48831 L
.69663 .45929 L
.71654 .44132 L
.73813 .42129 L
.74823 .41204 L
.75893 .40247 L
.76333 .39862 L
.76806 .39455 L
.76946 .39336 L
.77078 .39224 L
.77196 .39124 L
Mistroke
.77325 .26487 L
.77448 .26487 L
.77577 .26487 L
.77811 .26487 L
.81975 .26487 L
.85986 .26487 L
.89847 .26487 L
.93952 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l00P1Vo`;oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00@0003oooooool0I_l2oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo000Foooo00<0003oooooool00_oooaD0I_l6oooo00<0003oooooool07_ooo`030000
oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01[oool0
101Vooooooooo`00023oool00`000?ooooooo`0Uoooo000`oooo2P1Voggoool00`000?ooooooo`0J
oooo00<0I_ooooooool0BOooo`00>_ooo`L0I_mfoooo00<0003oooooool06_ooo`0306Kooooooooo
04Woool0047oool606KoL?ooo`80000Koooo00<0I_ooooooool0BOooo`00Aoooo`D0I_m[oooo00<0
003oooooool06_ooo`0306Kooooooooo04Woool004coool506KoI_ooo`030000oooooooo01[oool0
0`1Vooooooooo`19oooo001Aoooo1@1Vof7oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOoo
o`00E_ooo`D0I_mLoooo0P0001_oool00`1Vooooooooo`19oooo001Koooo101VoeSoool00`000?oo
ooooo`0Joooo00<0I_ooooooool0BOooo`00Goooo`80I_mFoooo00<0003oooooool06_ooo`0306Ko
oooooooo04Woool0067oool306KoDoooo`030000oooooooo01[oool00`1Vooooooooo`19oooo001T
oooo0P1Voe7oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOooo`00I_ooo`80I_m?oooo0P00
01_oool00`1Vooooooooo`19oooo001Xoooo0P1Vodgoool00`000?ooooooo`0Joooo00<0I_oooooo
ool0BOooo`00J_ooo`80I_m;oooo00<0003oooooool06_ooo`0306Kooooooooo04Woool006coool2
06KoBOooo`030000oooooooo01[oool00`1Vooooooooo`19oooo001^oooo0P1VodOoool200006ooo
o`0306Kooooooooo04Woool0073oool206KoAOooo`030000oooooooo01[oool00`1Vooooooooo`19
oooo001boooo0P1Vod?oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOooo`00M?ooo`80I_li
oooo1@0000?oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOooo`00M_ooo`0306Kooooooooo
03Soool00`000?ooooooo`03oooo00<0003oooooool06_ooo`0306Kooooooooo04Woool007Ooool2
06Ko>?ooo`030000oooooooo00?oool300006_ooo`0306Kooooooooo04Woool007Woool206Ko=_oo
o`030000oooooooo00?oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOooo`00Noooo`0306Ko
oooooooo03?oool00`000?ooooooo`03oooo00<0003oooooool06_ooo`0306Kooooooooo04Woool0
07coool00`1Vooooooooo`0aoooo0P0000Goool00`000?ooooooo`0Joooo00<0I_ooooooool0BOoo
o`00OOooo`80I_lhoooo0P0001_oool00`1Vooooooooo`19oooo001ooooo00<0I_ooooooool0=Ooo
o`030000oooooooo01[oool00`1Vooooooooo`19oooo0020oooo00<0I_ooooooool0=?ooo`030000
oooooooo01[oool00`1Vooooooooo`19oooo0021oooo00<0I_ooooooool0<oooo`030000oooooooo
01[oool00`1Vooooooooo`19oooo0022oooo0P1Voc?oool00`000?ooooooo`0Joooo00<0I_oooooo
ool0BOooo`00Q?ooo`0306Kooooooooo033oool200006oooo`0306Kooooooooo04Woool008Goool0
0`1Vooooooooo`0_oooo00<0003oooooool06Oooo`80I_m;oooo0026oooo00<0I_ooooooool0;_oo
o`030000oooooooo01Soool00`1Vooooool0V@1;oooo0027oooo00<0I_ooooooool0;Oooo`030000
oooooooo01Ooool0101Vooooooooool0VD_oool008Soool00`1Vooooooooo`0/oooo0P0001Ooool0
1@1Vooooooooooooool0V@1;oooo0029oooo00<0I_ooooooool0:oooo`030000oooooooo01Goool0
0`1Vooooooooo`02oooo00?o09Woooooool0BOooo`00R_ooo`80I_l[oooo00<0003oooooool05?oo
o`0306Kooooooooo00?oool00ol0VOooooooo`19oooo002<oooo00<0I_ooooooool0:?ooo`030000
oooooooo01;oool206Ko1_ooo`03o`2Ioooooooo04Woool008goool00`1Vooooooooo`0Woooo00<0
003oooooool04Oooo`0306Kooooooooo00Koool00ol0VOooooooo`19oooo002>oooo00<0I_oooooo
ool09_ooo`80000Aoooo00<0I_ooooooool01oooo`03o`2Ioooooooo04Woool008ooool00`1Voooo
ooooo`0Uoooo00<0003oooooool03oooo`0306Kooooooooo00Soool00ol0VOooooooo`19oooo002@
oooo00<0I_ooooooool07?ooo`@00004oooo00<0003oooooool03_ooo`0306Kooooooooo00Woool0
0ol0VOooooooo`19oooo002Aoooo00<0I_ooooooool06oooo`030000oooooooo00Goool00`000?oo
ooooo`0=oooo00<0I_ooooooool02_ooo`03o`2Ioooooooo04Woool009;oool00`1Vooooooooo`0K
oooo00<0003oooooool01?ooo`<0000<oooo00<0I_ooooooool02oooo`03o`2Ioooooooo04Woool0
09?oool00`1Vooooooooo`0Koooo00<0003oooooool00oooo`030000oooooooo00_oool00`1Voooo
ooooo`0<oooo00?o09Woooooool0BOooo`00U?ooo`80I_lIoooo00@0003oooooool00004oooo00<0
003oooooool02_ooo`0306Kooooooooo00goool00ol0VOooooooo`19oooo002Foooo00<0I_oooooo
ool05oooo`800005oooo00<0003oooooool02Oooo`0306Kooooooooo00koool00ol0VOooooooo`19
oooo002Goooo00<0I_ooooooool07Oooo`800009oooo00<0I_ooooooool03oooo`03o`2Ioooooooo
04Woool009Soool00`1Vooooooooo`0Loooo00<0003oooooool01oooo`0306Kooooooooo013oool0
0ol0VOooooooo`19oooo002Ioooo00<0I_ooooooool06oooo`030000oooooooo00Goool206Ko4ooo
o`03o`2Ioooooooo04Woool009[oool00`1Vooooooooo`0Joooo00<0003oooooool01?ooo`0306Ko
oooooooo01?oool00ol0VOooooooo`19oooo002Koooo0P1Voa[oool00`000?ooooooo`03oooo00<0
I_ooooooool05?ooo`03o`2Ioooooooo04Woool009goool00`1Vooooooooo`0Goooo0P0000;oool2
06Ko5oooo`03o`2Ioooooooo04Woool009koool00`1Vooooooooo`0Foooo00@0003oooooool0I_lI
oooo00?o09Woooooool0BOooo`00Woooo`80I_lFoooo00<00000I_l0I_l06_ooo`03o`2Ioooooooo
04Woool00:7oool206Ko5?ooo`030000oooooooo01[oool00ol0VOooooooo`19oooo002Soooo0P1V
o`ooool306Ko0P0001_oool00ol0VOooooooo`19oooo002Uoooo0`1Vo`Woool306Ko0oooo`030000
oooooooo01[oool00ol0VOooooooo`19oooo002Xoooo2@1Vo`Koool00`000?ooooooo`0Joooo00?o
09Woooooool0BOooo`00]oooo`030000oooooooo01[oool00ol0VOooooooo`19oooo002goooo00<0
003oooooool06_ooo`03o`2Ioooooooo04Woool00;Ooool200006oooo`03o`2Ioooooooo04Woool0
0;Ooool00`000?ooooooo`0Joooo00?o09Woooooool0BOooo`00/?ooo`800005oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo04Woool00:ooool010000?ooooooo`0000Coool00`000?ooooooo`0J
oooo00?o09Woooooool0BOooo`00/Oooo`030000oooooooo00?oool300006_ooo`03o`2Ioooooooo
04Woool00;;oool00`000?ooooooo`02oooo00<0003oooooool06_ooo`03o`2Ioooooooo04Woool0
0:ooool010000?ooooooo`0000Coool00`000?ooooooo`0Joooo00?o09Woooooool0BOooo`00/?oo
o`800005oooo00<0003oooooool06_ooo`03o`2Ioooooooo04Woool00;Ooool00`000?ooooooo`0J
oooo00?o09Woooooool0BOooo`00]oooo`80000Koooo00?o09Woooooool0BOooo`00]oooo`030000
oooooooo01[oool00ol0VOooooooo`19oooo002goooo00<0003oooooool06_ooo`03o`2Ioooooooo
04Woool00;Ooool00`000?ooooooo`0Joooo00?o09Woooooool0BOooo`00]oooo`80000Koooo00?o
09Woooooool0BOooo`00]oooo`030000oooooooo01[oool00ol0VOooooooo`19oooo002goooo00<0
003oooooool06_ooo`03o`2Ioooooooo04Woool00;Ooool00`000?ooooooo`0Joooo00?o09Wooooo
ool0BOooo`00]oooo`030000oooooooo01[oool00ol0VOooooooo`19oooo002goooo0P0001_oool0
0ol0VOooooooo`19oooo002goooo00<0003oooooool06_ooo`03o`2Ioooooooo04Woool00;Ooool0
0`000?ooooooo`0Joooo00?o09Woooooool0BOooo`00]oooo`030000oooooooo01[oool00ol0VOoo
ooooo`19oooo002goooo0P0001_oool00ol0VOooooooo`19oooo002goooo00<0003oooooool06_oo
o`03o`2Ioooooooo04Woool00;Ooool00`000?ooooooo`0Joooo00?o09Woooooool0BOooo`00/Ooo
o`<00003oooo00<0003oooooool06_ooo`03o`2Ioooooooo04Woool00;;oool00`000?ooooooo`02
oooo00<0003oooooool06_ooo`03o`2Ioooooooo04Woool00:ooool500000oooo`<0000Joooo00?o
09Woooooool0BOooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool0
0;7oool20000KOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool2
00000oooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool02?ooo`<00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.75718 .26487 L
.76707 .26487 L
.77751 .26487 L
.78008 .26487 L
.78283 .26487 L
.78364 .26487 L
.78441 .26487 L
.7851 .26487 L
s
.7851 .26487 m
.7854 .61803 L
s
0 .4 1 r
.02381 .26987 m
.06244 .27164 L
.10458 .27431 L
.14415 .27776 L
.18221 .28225 L
.22272 .28876 L
.26171 .29728 L
.30316 .30963 L
.34309 .32578 L
.3815 .34637 L
.42237 .37485 L
.46172 .4091 L
.49955 .44693 L
.53984 .48729 L
.55838 .50324 L
.57861 .51683 L
.58392 .51956 L
.58957 .52203 L
.59446 .52379 L
.59975 .52528 L
.60257 .52589 L
.60517 .52635 L
.60766 .52668 L
.60891 .52682 L
.61028 .52693 L
.61153 .52701 L
.61267 .52706 L
.61398 .52709 L
.61522 .52709 L
.61637 .52707 L
.61743 .52703 L
.6186 .52697 L
.61984 .52688 L
.62222 .52663 L
.62472 .52628 L
.62921 .52539 L
.63403 .52409 L
.63931 .52225 L
.64878 .51793 L
.65759 .51283 L
.69663 .48063 L
.73813 .43846 L
.75893 .41757 L
.76806 .40878 L
.77291 .40423 L
.77811 .39945 L
.7807 .39711 L
.78316 .39491 L
.78422 .39396 L
.78536 .39296 L
Mistroke
.78661 .26487 L
.78776 .26487 L
.7968 .26487 L
.81658 .26487 L
.85821 .26487 L
.89833 .26487 L
.93693 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<00000I_l0I_l00P1Vo`;oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`03000006Kooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool04_ooo`005_ooo`030000oooooooo00;oool;06Ko4?ooo`030000oooooooo01koool00`000?oo
ooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0
0000I_ooool07_ooo`030000oooooooo02Goool002KooolB06KoOoooo`030000oooooooo01goool0
0ol0V@1Vooooo`16oooo000hoooo101Vog_oool00`000?ooooooo`0Moooo00?o09T0I_ooool0A_oo
o`00??ooo`P0I_mcoooo0P0001koool00ol0V@1Vooooo`16oooo0014oooo201Vof_oool00`000?oo
ooooo`0Moooo00?o09T0I_ooool0A_ooo`00C?ooo`D0I_mVoooo00<0003oooooool07Oooo`03o`2I
06Kooooo04Koool0057oool406KoH_ooo`030000oooooooo01goool00ol0V@1Vooooo`16oooo001E
oooo0P1Vof3oool200007_ooo`03o`2I06Kooooo04Koool005Ooool306KoGOooo`030000oooooooo
01goool00ol0V@1Vooooo`16oooo001Joooo0P1Voe_oool00`000?ooooooo`0Moooo00?o09T0I_oo
ool0A_ooo`00G?ooo`<0I_mHoooo00<0003oooooool07Oooo`03o`2I06Kooooo04Koool005ooool2
06KoE_ooo`030000oooooooo01goool00ol0V@1Vooooo`16oooo001Qoooo0`1Voe?oool200007_oo
o`03o`2I06Kooooo04Koool006Coool206KoDOooo`030000oooooooo01goool00ol0V@1Vooooo`16
oooo001Voooo0P1Vodooool00`000?ooooooo`0Moooo00?o09T0I_ooool0A_ooo`00J?ooo`80I_m=
oooo00<0003oooooool07Oooo`0306Kooooooooo04Koool006[oool206KoBoooo`80000Noooo00<0
I_ooooooool0A_ooo`00K?ooo`80I_m9oooo00<0003oooooool07Oooo`0306Kooooooooo04Koool0
06koool206KoAoooo`030000oooooooo01goool00`1Vooooooooo`16oooo001`oooo0P1Vocgoool5
00000oooo`030000oooooooo01goool00`1Vooooooooo`16oooo001boooo0P1Vocgoool00`000?oo
ooooo`03oooo00<0003oooooool07Oooo`0306Kooooooooo04Koool007Coool00`1Vooooooooo`0j
oooo00<0003oooooool00oooo`<0000Moooo00<0I_ooooooool0A_ooo`00MOooo`0306Kooooooooo
03Woool00`000?ooooooo`03oooo00<0003oooooool07Oooo`0306Kooooooooo04Koool007Koool2
06Ko>Oooo`030000oooooooo00?oool00`000?ooooooo`0Moooo00<0I_ooooooool0A_ooo`00N?oo
o`0306Kooooooooo03Goool200001Oooo`030000oooooooo01goool00`1Vooooooooo`16oooo001i
oooo0P1Voccoool200007_ooo`0306Kooooooooo04Koool007_oool00`1Vooooooooo`0ioooo00<0
003oooooool07Oooo`0306Kooooooooo04Koool007coool00`1Vooooooooo`0hoooo00<0003ooooo
ool07Oooo`0306Kooooooooo04Koool007goool00`1Vooooooooo`0goooo00<0003oooooool07Ooo
o`0306Kooooooooo04Koool007koool00`1Vooooooooo`0foooo00<0003oooooool07Oooo`0306Ko
oooooooo04Koool007ooool00`1Vooooooooo`0eoooo0P0001koool00`1Vooooooooo`16oooo0020
oooo0P1VocGoool00`000?ooooooo`0Moooo00<0I_ooooooool0A_ooo`00P_ooo`0306Kooooooooo
03;oool00`000?ooooooo`0Koooo0P1Vo`03o`2Ioooooooo04Koool008?oool00`1Vooooooooo`0a
oooo00<0003oooooool06_ooo`0406Koooooooooo`2IB?ooo`00Q?ooo`0306Kooooooooo033oool2
00006oooo`0406Koooooooooo`2IB?ooo`00QOooo`0306Kooooooooo02ooool00`000?ooooooo`0I
oooo00D0I_oooooooooooooo09T0B?ooo`00Q_ooo`0306Kooooooooo02koool00`000?ooooooo`0H
oooo00<0I_ooooooool00_ooo`03o`2Ioooooooo04Koool008Ooool00`1Vooooooooo`0]oooo00<0
003oooooool05oooo`0306Kooooooooo00?oool00ol0VOooooooo`16oooo0028oooo00<0I_oooooo
ool0;?ooo`030000oooooooo01Koool00`1Vooooooooo`04oooo00?o09Woooooool0A_ooo`00ROoo
o`0306Kooooooooo02_oool200005_ooo`0306Kooooooooo00Goool00ol0VOooooooo`16oooo002:
oooo0P1Vob_oool00`000?ooooooo`0Coooo0P1Vo`Soool00ol0VOooooooo`16oooo002<oooo00<0
I_ooooooool08?ooo`@00004oooo00<0003oooooool04_ooo`0306Kooooooooo00Soool00ol0VOoo
ooooo`16oooo002=oooo00<0I_ooooooool07oooo`030000oooooooo00Goool00`000?ooooooo`0A
oooo00<0I_ooooooool02Oooo`03o`2Ioooooooo04Koool008koool00`1Vooooooooo`0Ooooo00<0
003oooooool01?ooo`<0000@oooo00<0I_ooooooool02_ooo`03o`2Ioooooooo04Koool008ooool0
0`1Vooooooooo`0Ooooo00<0003oooooool00oooo`030000oooooooo00ooool00`1Vooooooooo`0;
oooo00?o09Woooooool0A_ooo`00T?ooo`0306Kooooooooo01coool010000?ooooooo`0000Coool0
0`000?ooooooo`0>oooo00<0I_ooooooool03?ooo`03o`2Ioooooooo04Koool0097oool00`1Voooo
ooooo`0Loooo0P0000Goool00`000?ooooooo`0=oooo00<0I_ooooooool03Oooo`03o`2Ioooooooo
04Koool009;oool00`1Vooooooooo`0Roooo0P0000goool00`1Vooooooooo`0>oooo00?o09Wooooo
ool0A_ooo`00Toooo`0306Kooooooooo027oool00`000?ooooooo`0<oooo00<0I_ooooooool03_oo
o`03o`2Ioooooooo04Koool009Coool00`1Vooooooooo`0Poooo00<0003oooooool02oooo`0306Ko
oooooooo00ooool00ol0VOooooooo`16oooo002Doooo00<0I_ooooooool08?ooo`030000oooooooo
00[oool00`1Vooooooooo`0@oooo00?o09Woooooool0A_ooo`00UOooo`0306Kooooooooo01ooool0
0`000?ooooooo`09oooo00<0I_ooooooool04Oooo`03o`2Ioooooooo04Koool009Koool00`1Voooo
ooooo`0Noooo0P0000Woool00`1Vooooooooo`0Boooo00?o09Woooooool0A_ooo`00Uoooo`0306Ko
oooooooo01goool00`000?ooooooo`07oooo00<0I_ooooooool04oooo`03o`2Ioooooooo04Koool0
09Soool00`1Vooooooooo`0Loooo00<0003oooooool01_ooo`0306Kooooooooo01Coool00ol0VOoo
ooooo`16oooo002Ioooo00<0I_ooooooool06oooo`030000oooooooo00Coool206Ko5oooo`03o`2I
oooooooo04Koool009[oool00`1Vooooooooo`0Joooo0P0000Coool00`1Vooooooooo`0Goooo00?o
09Woooooool0A_ooo`00Voooo`80I_lJoooo00<0003oooooool00_ooo`0306Kooooooooo01Soool0
0ol0VOooooooo`16oooo002Moooo00<0I_ooooooool05oooo`050000oooooooooooo06Ko01_oool0
0ol0VOooooooo`16oooo002Noooo00<0I_ooooooool05_ooo`040000oooo06Ko06Ko7?ooo`03o`2I
oooooooo04Koool009ooool206Ko5_ooo`03000006Kooooo01goool00ol0VOooooooo`16oooo002Q
oooo0P1VoaCoool200007_ooo`03o`2Ioooooooo04Koool00:?oool00`1Vooooooooo`0>oooo0`1V
o`030000oooooooo01goool00ol0VOooooooo`16oooo002Toooo0`1Vo`Woool200000P1Vo`?oool0
0`000?ooooooo`0Moooo00?o09Woooooool0A_ooo`00Yoooo`<0I_l5oooo00@00000I_l0I_l00004
oooo00<0003oooooool07Oooo`03o`2Ioooooooo04Koool00:[oool606Ko00?oool0003oool01?oo
o`<0000Moooo00?o09Woooooool0A_ooo`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0M
oooo00?o09Woooooool0A_ooo`00[oooo`040000oooooooo00001?ooo`030000oooooooo01goool0
0ol0VOooooooo`16oooo002`oooo0P0000Goool00`000?ooooooo`0Moooo00?o09Woooooool0A_oo
o`00]oooo`030000oooooooo01goool00ol0VOooooooo`16oooo002goooo0P0001koool00ol0VOoo
ooooo`16oooo002goooo00<0003oooooool07Oooo`03o`2Ioooooooo04Koool00;Ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0A_ooo`00]oooo`030000oooooooo01goool00ol0VOooooooo`16
oooo002goooo0P0001koool00ol0VOooooooo`16oooo002goooo00<0003oooooool07Oooo`03o`2I
oooooooo04Koool00;Ooool00`000?ooooooo`0Moooo00?o09Woooooool0A_ooo`00]oooo`030000
oooooooo01goool00ol0VOooooooo`16oooo002goooo00<0003oooooool07Oooo`03o`2Ioooooooo
04Koool00;Ooool200007_ooo`03o`2Ioooooooo04Koool00;Ooool00`000?ooooooo`0Moooo00?o
09Woooooool0A_ooo`00]oooo`030000oooooooo01goool00ol0VOooooooo`16oooo002goooo00<0
003oooooool07Oooo`03o`2Ioooooooo04Koool00;Ooool200007_ooo`03o`2Ioooooooo04Koool0
0;Ooool00`000?ooooooo`0Moooo00?o09Woooooool0A_ooo`00]oooo`030000oooooooo01goool0
0ol0VOooooooo`16oooo002aoooo0`0000?oool00`000?ooooooo`0Moooo00?o09Woooooool0A_oo
o`00/_ooo`030000oooooooo00;oool00`000?ooooooo`0Moooo00?o09Woooooool0A_ooo`00[ooo
o`D00003oooo0`0001goool00ol0VOooooooo`16oooo002_oooo00@0003oooooool0001]oooo002`
oooo00<0003oool00000KOooo`00/Oooo`80001]oooo003ooooo8Oooo`00ooooob7oool007ooool0
0`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?oo
ooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool400000oooo`800004oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00[oool0
0`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oo
ooooo`0:oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oooooool0O_ooo`00Ooooo`030000oooooooo017oool200002Oooo`030000
oooooooo07ooool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.75718 .26487 L
.77751 .26487 L
.78293 .26487 L
.78866 .26487 L
.79355 .26487 L
.79489 .26487 L
.79633 .26487 L
.79703 .26487 L
.79769 .26487 L
s
.79769 .26487 m
.79818 .61803 L
s
0 .4 1 r
.02381 .27041 m
.06244 .27238 L
.10458 .27534 L
.14415 .27916 L
.18221 .28414 L
.22272 .29136 L
.26171 .30081 L
.30316 .31451 L
.34309 .33242 L
.3815 .35525 L
.42237 .38683 L
.46172 .42481 L
.49955 .46676 L
.53984 .51151 L
.55838 .5292 L
.57861 .54427 L
.58392 .5473 L
.58957 .55004 L
.59446 .55198 L
.59975 .55364 L
.60257 .55432 L
.60517 .55483 L
.60766 .5552 L
.60891 .55534 L
.61028 .55547 L
.61153 .55556 L
.61267 .55561 L
.61398 .55564 L
.61522 .55565 L
.61637 .55562 L
.61743 .55558 L
.6186 .55551 L
.61984 .55541 L
.62222 .55514 L
.62472 .55475 L
.62921 .55377 L
.63403 .55232 L
.63931 .55028 L
.64878 .5455 L
.65759 .53983 L
.69663 .50412 L
.73813 .45736 L
.75893 .4342 L
.77811 .4141 L
.78776 .40458 L
.79248 .40007 L
.79455 .39814 L
.7968 .39605 L
.798 .39494 L
.79913 .26487 L
Mistroke
.8002 .26487 L
.80134 .26487 L
.80622 .26487 L
.81658 .26487 L
.85821 .26487 L
.89833 .26487 L
.93693 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00D0003ooooooooo09T0I_l00_oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo000Foooo00<00000I_l0I_l03@1Voa3oool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`050000
ooooooooo`2I06Ko01coool00`000?ooooooo`0Uoooo000Voooo2P1VohOoool00`000?ooooooo`0P
oooo00?o09T0I_ooool0@oooo`00<?ooo`X0I_mmoooo00<0003oooooool08?ooo`03o`2I06Kooooo
04?oool003[oool706KoM_ooo`80000Qoooo00?o09T0I_ooool0@oooo`00@Oooo`H0I_m`oooo00<0
003oooooool08?ooo`03o`2I06Kooooo04?oool004Ooool506KoJoooo`030000oooooooo023oool0
0ol0V@1Vooooo`13oooo001<oooo1@1VofKoool00`000?ooooooo`0Poooo00?o09T0I_ooool0@ooo
o`00DOooo`@0I_mRoooo0P00027oool00ol0V@1Vooooo`13oooo001Eoooo0P1Vof3oool00`000?oo
ooooo`0Poooo00?o09T0I_ooool0@oooo`00Eoooo`<0I_mMoooo00<0003oooooool08?ooo`03o`2I
06Kooooo04?oool005[oool206KoFoooo`030000oooooooo023oool00ol0V@1Vooooo`13oooo001L
oooo0`1VoeSoool00`000?ooooooo`0Poooo00?o09T0I_ooool0@oooo`00Goooo`80I_mFoooo0P00
027oool00ol0V@1Vooooo`13oooo001Qoooo0`1Voe?oool00`000?ooooooo`0Poooo00?o09T0I_oo
ool0@oooo`00I?ooo`80I_mAoooo00<0003oooooool08?ooo`03o`2I06Kooooo04?oool006Koool2
06KoCoooo`030000oooooooo023oool00ol0V@1Vooooo`13oooo001Xoooo0P1Vodgoool200008Ooo
o`03o`2I06Kooooo04?oool006[oool206KoBoooo`030000oooooooo023oool00ol0V@1Vooooo`13
oooo001/oooo00<0I_ooooooool0B?ooo`030000oooooooo023oool00ol0V@1Vooooo`13oooo001]
oooo0P1Vod3oool500000oooo`030000oooooooo023oool00ol0V@1Vooooo`13oooo001_oooo0P1V
od3oool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2I06Kooooo04?oool0077oool0
0`1Vooooooooo`0moooo00<0003oooooool00oooo`<0000Poooo00?o09T0I_ooool0@oooo`00L_oo
o`0306Kooooooooo03coool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2I06Kooooo
04?oool007?oool206Ko??ooo`030000oooooooo00?oool00`000?ooooooo`0Poooo00?o09T0I_oo
ool0@oooo`00MOooo`0306Kooooooooo03Soool200001Oooo`030000oooooooo023oool00ol0V@1V
ooooo`13oooo001foooo00<0I_ooooooool0?_ooo`80000Qoooo00?o09T0I_ooool0@oooo`00Mooo
o`0306Kooooooooo03goool00`000?ooooooo`0Poooo00?o09T0I_ooool0@oooo`00N?ooo`80I_lm
oooo00<0003oooooool08?ooo`03o`2I06Kooooo04?oool007[oool00`1Vooooooooo`0joooo00<0
003oooooool08?ooo`03o`2I06Kooooo04?oool007_oool00`1Vooooooooo`0ioooo00<0003ooooo
ool08?ooo`03o`2I06Kooooo04?oool007coool00`1Vooooooooo`0hoooo0P00027oool00ol0V@1V
ooooo`13oooo001moooo00<0I_ooooooool0=oooo`030000oooooooo023oool206KoA?ooo`00O_oo
o`0306Kooooooooo03Koool00`000?ooooooo`0Poooo00<0I_ooooooool0@oooo`00Ooooo`0306Ko
oooooooo03Goool00`000?ooooooo`0Ooooo00<0I_oo09Woool0A?ooo`00P?ooo`0306Kooooooooo
03Coool200007oooo`0306Koooooo`2I04Goool0087oool00`1Vooooooooo`0coooo00<0003ooooo
ool07?ooo`80I_l2oooo00?o09Woooooool0@oooo`00P_ooo`0306Kooooooooo03;oool00`000?oo
ooooo`0Koooo00<0I_ooooooool00_ooo`03o`2Ioooooooo04?oool008?oool00`1Vooooooooo`0a
oooo00<0003oooooool06_ooo`0306Kooooooooo00?oool00ol0VOooooooo`13oooo0024oooo00<0
I_ooooooool0<?ooo`030000oooooooo01Woool00`1Vooooooooo`04oooo00?o09Woooooool0@ooo
o`00QOooo`0306Kooooooooo02ooool200006_ooo`0306Kooooooooo00Coool00ol0VOooooooo`13
oooo0026oooo00<0I_ooooooool0;_ooo`030000oooooooo01Soool00`1Vooooooooo`05oooo00?o
09Woooooool0@oooo`00Qoooo`0306Kooooooooo02Goool400001?ooo`030000oooooooo01Ooool0
0`1Vooooooooo`06oooo00?o09Woooooool0@oooo`00R?ooo`0306Kooooooooo02Coool00`000?oo
ooooo`05oooo00<0003oooooool05_ooo`0306Kooooooooo00Ooool00ol0VOooooooo`13oooo0029
oooo00<0I_ooooooool09?ooo`030000oooooooo00Coool300005Oooo`0306Kooooooooo00Soool0
0ol0VOooooooo`13oooo002:oooo00<0I_ooooooool09?ooo`030000oooooooo00?oool00`000?oo
ooooo`0Doooo00<0I_ooooooool02_ooo`03o`2Ioooooooo04;oool008_oool00`1Vooooooooo`0Q
oooo00@0003oooooool00004oooo00<0003oooooool04oooo`0306Kooooooooo00_oool00ol0VOoo
ooooo`12oooo002<oooo00<0I_ooooooool08Oooo`800005oooo00<0003oooooool04_ooo`0306Ko
oooooooo00coool00ol0VOooooooo`12oooo002=oooo00<0I_ooooooool09oooo`80000Boooo00<0
I_ooooooool03Oooo`03o`2Ioooooooo04;oool008koool00`1Vooooooooo`0Voooo00<0003ooooo
ool04?ooo`0306Kooooooooo00koool00ol0VOooooooo`12oooo002?oooo00<0I_ooooooool09Ooo
o`030000oooooooo00ooool00`1Vooooooooo`0?oooo00?o09Woooooool0@_ooo`00T?ooo`0306Ko
oooooooo02Coool00`000?ooooooo`0>oooo00<0I_ooooooool04?ooo`03o`2Ioooooooo04;oool0
097oool00`1Vooooooooo`0Soooo00<0003oooooool03_ooo`0306Kooooooooo013oool00ol0VOoo
ooooo`12oooo002Aoooo00<0I_ooooooool08oooo`80000>oooo00<0I_ooooooool04Oooo`03o`2I
oooooooo04;oool009;oool00`1Vooooooooo`0Roooo00<0003oooooool03?ooo`0306Kooooooooo
01;oool00ol0VOooooooo`12oooo002Coooo00<0I_ooooooool08Oooo`030000oooooooo00_oool0
0`1Vooooooooo`0Coooo00?o09Woooooool0@_ooo`00U?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0:oooo00<0I_ooooooool05?ooo`03o`2Ioooooooo04;oool009Goool00`1Vooooooooo`0O
oooo0P0000[oool00`1Vooooooooo`0Eoooo00?o09Woooooool0@_ooo`00U_ooo`0306Kooooooooo
01koool00`000?ooooooo`09oooo00<0I_ooooooool05Oooo`03o`2Ioooooooo04;oool009Koool0
0`1Vooooooooo`0Noooo00<0003oooooool02?ooo`0306Kooooooooo01Koool00ol0VOooooooo`12
oooo002Goooo00<0I_ooooooool07Oooo`030000oooooooo00Ooool00`1Vooooooooo`0Goooo00?o
09Woooooool0@_ooo`00V?ooo`0306Kooooooooo01coool00`000?ooooooo`06oooo00<0I_oooooo
ool06?ooo`03o`2Ioooooooo04;oool009Woool00`1Vooooooooo`0Koooo0P0000Koool00`1Voooo
ooooo`0Ioooo00?o09Woooooool0@_ooo`00V_ooo`0306Kooooooooo01[oool00`000?ooooooo`04
oooo00<0I_ooooooool06_ooo`03o`2Ioooooooo04;oool009_oool206Ko4oooo`800005oooo00<0
003oooooool00oooo`0306Kooooooooo01_oool00ol0VOooooooo`12oooo002Moooo00<0I_oooooo
ool03oooo`040000oooooooo00001?ooo`040000oooooooooooo0P1Voakoool00ol0VOooooooo`12
oooo002Noooo00<0I_ooooooool04?ooo`030000oooooooo00?oool3000000<0I_ooooooool07_oo
o`03o`2Ioooooooo04;oool009ooool00`1Vooooooooo`0@oooo00<0003oooooool00_ooo`030000
oooo06Ko027oool00ol0VOooooooo`12oooo002Poooo0P1Vo`goool010000?ooooooo`0000Coool0
0`00001Vooooo`0Qoooo00?o09Woooooool0@_ooo`00X_ooo`0306Kooooooooo00_oool200001Ooo
o`030000oooooooo027oool00ol0VOooooooo`12oooo002Soooo00<0I_ooooooool03oooo`80I_l0
0`000?ooooooo`0Qoooo00?o09Woooooool0@_ooo`00Y?ooo`0306Kooooooooo00coool206Ko0_oo
o`80000Roooo00?o09Woooooool0@_ooo`00YOooo`@0I_l7oooo0`1Vo`Coool00`000?ooooooo`0Q
oooo00?o09Woooooool0@_ooo`00ZOooo`L0I_l7oooo00<0003oooooool08Oooo`03o`2Ioooooooo
04;oool00;Ooool00`000?ooooooo`0Qoooo00?o09Woooooool0@_ooo`00]oooo`80000Roooo00?o
09Woooooool0@_ooo`00]oooo`030000oooooooo027oool00ol0VOooooooo`12oooo002goooo00<0
003oooooool08Oooo`03o`2Ioooooooo04;oool00;Ooool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0@_ooo`00]oooo`030000oooooooo027oool00ol0VOooooooo`12oooo002goooo0P0002;oool0
0ol0VOooooooo`12oooo002goooo00<0003oooooool08Oooo`03o`2Ioooooooo04;oool00;Ooool0
0`000?ooooooo`0Qoooo00?o09Woooooool0@_ooo`00]oooo`030000oooooooo027oool00ol0VOoo
ooooo`12oooo002goooo0P0002;oool00ol0VOooooooo`12oooo002goooo00<0003oooooool08Ooo
o`03o`2Ioooooooo04;oool00;Ooool00`000?ooooooo`0Qoooo00?o09Woooooool0@_ooo`00/Ooo
o`<00003oooo00<0003oooooool08Oooo`03o`2Ioooooooo04;oool00;;oool00`000?ooooooo`02
oooo00<0003oooooool08Oooo`03o`2Ioooooooo04;oool00:ooool500000oooo`<0000Qoooo00?o
09Woooooool0@_ooo`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool0
0;7oool20000KOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool2
00000oooo`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00_oool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0
003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.04262 .26479 L
.06244 .26475 L
.08255 .26471 L
.10458 .26464 L
.12415 .26456 L
.14509 .26444 L
.16639 .26427 L
.18653 .26404 L
.20651 .26374 L
.22495 .26335 L
.24367 .26284 L
.2643 .26206 L
.28371 .26107 L
.30459 .25961 L
.32572 .25758 L
.34581 .25494 L
.36562 .25144 L
.384 .24716 L
.40453 .24088 L
.42313 .23346 L
.44238 .22371 L
.4632 .2104 L
.5042 .1752 L
.54369 .13377 L
.56355 .11412 L
.58166 .09974 L
.58646 .09676 L
.59168 .09398 L
.59619 .092 L
.60117 .09029 L
.60389 .08957 L
.60644 .08904 L
.60775 .08882 L
.60913 .08863 L
.60986 .08855 L
.61065 .08847 L
.61136 .08841 L
.61204 .08837 L
.61335 .08831 L
.61455 .08829 L
.61584 .0883 L
.61657 .08833 L
.61724 .08836 L
.61836 .08844 L
.6196 .08855 L
.62088 .08871 L
.62209 .08888 L
.62467 .08937 L
.62707 .08995 L
Mistroke
.63249 .09171 L
.63728 .09375 L
.64237 .09641 L
.66091 .10974 L
.70255 .15165 L
.74266 .19156 L
.78127 .22031 L
.80124 .23112 L
.82232 .23995 L
.842 .24623 L
.86035 .25072 L
.88074 .25449 L
.89931 .25706 L
.91843 .25906 L
.9392 .26066 L
.95715 .26169 L
.97619 .26251 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.77751 .26487 L
.7878 .26487 L
.79892 .26487 L
.80403 .26487 L
.80682 .26487 L
.80819 .26487 L
.80943 .26487 L
.81057 .26487 L
s
.81057 .26487 m
.811 .61803 L
s
0 .4 1 r
.02381 .27101 m
.06244 .2732 L
.10458 .27647 L
.14415 .28071 L
.18221 .28623 L
.22272 .29422 L
.26171 .3047 L
.30316 .31988 L
.34309 .33973 L
.3815 .36503 L
.42237 .40003 L
.46172 .44212 L
.49955 .48861 L
.53984 .5382 L
.55838 .5578 L
.57861 .57451 L
.58392 .57786 L
.58957 .5809 L
.59446 .58306 L
.59975 .58489 L
.60257 .58565 L
.60517 .58621 L
.60766 .58662 L
.60891 .58678 L
.61028 .58692 L
.61153 .58701 L
.61267 .58707 L
.61398 .58711 L
.61522 .58711 L
.61637 .58709 L
.61743 .58704 L
.6186 .58697 L
.61984 .58685 L
.62222 .58656 L
.62472 .58612 L
.62921 .58503 L
.63403 .58343 L
.63931 .58117 L
.64878 .57586 L
.65759 .56959 L
.69663 .53002 L
.73813 .47819 L
.75893 .45253 L
.77811 .43025 L
.7968 .41025 L
.80134 .40567 L
.80622 .40086 L
.80765 .39948 L
.80901 .39817 L
.81024 .39701 L
Mistroke
.81093 .39635 L
.81157 .26487 L
.81284 .26487 L
.81399 .26487 L
.81658 .26487 L
.8567 .26487 L
.8953 .26487 L
.93635 .26487 L
.97589 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.126984 0.264872 0.0882906 [
[.02381 .25237 -6 -9 ]
[.02381 .25237 6 0 ]
[.15079 .25237 -6 -9 ]
[.15079 .25237 6 0 ]
[.27778 .25237 -6 -9 ]
[.27778 .25237 6 0 ]
[.40476 .25237 -6 -9 ]
[.40476 .25237 6 0 ]
[.53175 .25237 -6 -9 ]
[.53175 .25237 6 0 ]
[.78571 .25237 -3 -9 ]
[.78571 .25237 3 0 ]
[.9127 .25237 -3 -9 ]
[.9127 .25237 3 0 ]
[.64623 0 -12 -4.5 ]
[.64623 0 0 4.5 ]
[.64623 .08829 -12 -4.5 ]
[.64623 .08829 0 4.5 ]
[.64623 .17658 -12 -4.5 ]
[.64623 .17658 0 4.5 ]
[.64623 .35316 -6 -4.5 ]
[.64623 .35316 0 4.5 ]
[.64623 .44145 -6 -4.5 ]
[.64623 .44145 0 4.5 ]
[.64623 .52974 -6 -4.5 ]
[.64623 .52974 0 4.5 ]
[.64623 .61803 -6 -4.5 ]
[.64623 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26487 m
.02381 .27112 L
s
[(-5)] .02381 .25237 0 1 Mshowa
.15079 .26487 m
.15079 .27112 L
s
[(-4)] .15079 .25237 0 1 Mshowa
.27778 .26487 m
.27778 .27112 L
s
[(-3)] .27778 .25237 0 1 Mshowa
.40476 .26487 m
.40476 .27112 L
s
[(-2)] .40476 .25237 0 1 Mshowa
.53175 .26487 m
.53175 .27112 L
s
[(-1)] .53175 .25237 0 1 Mshowa
.78571 .26487 m
.78571 .27112 L
s
[(1)] .78571 .25237 0 1 Mshowa
.9127 .26487 m
.9127 .27112 L
s
[(2)] .9127 .25237 0 1 Mshowa
.125 Mabswid
.04921 .26487 m
.04921 .26862 L
s
.0746 .26487 m
.0746 .26862 L
s
.1 .26487 m
.1 .26862 L
s
.1254 .26487 m
.1254 .26862 L
s
.17619 .26487 m
.17619 .26862 L
s
.20159 .26487 m
.20159 .26862 L
s
.22698 .26487 m
.22698 .26862 L
s
.25238 .26487 m
.25238 .26862 L
s
.30317 .26487 m
.30317 .26862 L
s
.32857 .26487 m
.32857 .26862 L
s
.35397 .26487 m
.35397 .26862 L
s
.37937 .26487 m
.37937 .26862 L
s
.43016 .26487 m
.43016 .26862 L
s
.45556 .26487 m
.45556 .26862 L
s
.48095 .26487 m
.48095 .26862 L
s
.50635 .26487 m
.50635 .26862 L
s
.55714 .26487 m
.55714 .26862 L
s
.58254 .26487 m
.58254 .26862 L
s
.60794 .26487 m
.60794 .26862 L
s
.63333 .26487 m
.63333 .26862 L
s
.68413 .26487 m
.68413 .26862 L
s
.70952 .26487 m
.70952 .26862 L
s
.73492 .26487 m
.73492 .26862 L
s
.76032 .26487 m
.76032 .26862 L
s
.81111 .26487 m
.81111 .26862 L
s
.83651 .26487 m
.83651 .26862 L
s
.8619 .26487 m
.8619 .26862 L
s
.8873 .26487 m
.8873 .26862 L
s
.9381 .26487 m
.9381 .26862 L
s
.96349 .26487 m
.96349 .26862 L
s
.98889 .26487 m
.98889 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.65873 0 m
.66498 0 L
s
[(-3)] .64623 0 1 0 Mshowa
.65873 .08829 m
.66498 .08829 L
s
[(-2)] .64623 .08829 1 0 Mshowa
.65873 .17658 m
.66498 .17658 L
s
[(-1)] .64623 .17658 1 0 Mshowa
.65873 .35316 m
.66498 .35316 L
s
[(1)] .64623 .35316 1 0 Mshowa
.65873 .44145 m
.66498 .44145 L
s
[(2)] .64623 .44145 1 0 Mshowa
.65873 .52974 m
.66498 .52974 L
s
[(3)] .64623 .52974 1 0 Mshowa
.65873 .61803 m
.66498 .61803 L
s
[(4)] .64623 .61803 1 0 Mshowa
.125 Mabswid
.65873 .01766 m
.66248 .01766 L
s
.65873 .03532 m
.66248 .03532 L
s
.65873 .05297 m
.66248 .05297 L
s
.65873 .07063 m
.66248 .07063 L
s
.65873 .10595 m
.66248 .10595 L
s
.65873 .12361 m
.66248 .12361 L
s
.65873 .14126 m
.66248 .14126 L
s
.65873 .15892 m
.66248 .15892 L
s
.65873 .19424 m
.66248 .19424 L
s
.65873 .2119 m
.66248 .2119 L
s
.65873 .22956 m
.66248 .22956 L
s
.65873 .24721 m
.66248 .24721 L
s
.65873 .28253 m
.66248 .28253 L
s
.65873 .30019 m
.66248 .30019 L
s
.65873 .31785 m
.66248 .31785 L
s
.65873 .3355 m
.66248 .3355 L
s
.65873 .37082 m
.66248 .37082 L
s
.65873 .38848 m
.66248 .38848 L
s
.65873 .40614 m
.66248 .40614 L
s
.65873 .42379 m
.66248 .42379 L
s
.65873 .45911 m
.66248 .45911 L
s
.65873 .47677 m
.66248 .47677 L
s
.65873 .49443 m
.66248 .49443 L
s
.65873 .51209 m
.66248 .51209 L
s
.65873 .5474 m
.66248 .5474 L
s
.65873 .56506 m
.66248 .56506 L
s
.65873 .58272 m
.66248 .58272 L
s
.65873 .60038 m
.66248 .60038 L
s
.25 Mabswid
.65873 0 m
.65873 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002`oooo0P0006koool00:ooool010000?ooooooo`0006goool00;7oool00`000?oo
ooooo`03oooo0`0006Koool00:Woool400001Oooo`030000oooooooo00;oool00`000?ooooooo`1V
oooo002_oooo00@0003oooooool00004oooo00<0003oooooool0I_ooo`00/?ooo`800005oooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool20000Ioooo`00]oooo`030000
oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002goooo00<0003oooooool0I_ooo`00]ooo
o`80001Woooo002goooo00<0003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool0
0`000?ooooooo`1Voooo002goooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002goooo00<0
003oooooool0I_ooo`00]oooo`030000oooooooo06Koool00;Ooool00`000?ooooooo`1Voooo002g
oooo0P0006Ooool00;Ooool00`000?ooooooo`1Voooo002_oooo100000Coool00`000?ooooooo`1V
oooo002_oooo00<0003oooooool01Oooo`030000oooooooo06Koool00:_oool300000_ooo`030000
oooooooo00Coool30000I_ooo`00Yoooo`/00005oooo00<0003oooooool0I_ooo`00Y_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000Coool00`000?ooooooo`1Voooo002Toooo0P0000Xco`02
000000<co`00003oool00_ooo`030000oooooooo06Koool00:?oool00`0003?o03?o000><ol00P00
0003oooo0000oooo06Ooool00:7oool200004c?o00<0001Woooo002Poooo00<0000co`0co`0053?o
0080001Woooo002Ooooo00<0000co`0co`005C?o00030000<ol0000006Koool009koool00`0003?o
03?o000F<ol000@0000co`0co`00001Uoooo002Moooo00<0000co`0co`005c?o00800002<ol000<0
003oooooool0H_ooo`00W?ooo`030000<ol0<ol001Pco`000`0003?o03?o0002<ol000<0003ooooo
ool0HOooo`00Voooo`030000<ol0<ol001Tco`000`0003?o03?o0003<ol000<0003oooooool0H?oo
o`00V_ooo`030000<ol0<ol001Xco`000`0003?o03?o0003<ol000<0003oooooool0H?ooo`00VOoo
o`030000<ol0<ol001/co`000`0003?o03?o0004<ol000<0003oooooool0Goooo`00V?ooo`030000
<ol0<ol001`co`0200001S?o00030000oooooooo05koool009Ooool00`0003?o03?o000M<ol000<0
000co`0co`001S?o00030000oooooooo05goool009Koool00`0003?o03?o000N<ol000<0000co`0c
o`001c?o00030000oooooooo05coool009Goool00`0003?o03?o000O<ol000<0000co`0co`0023?o
00030000oooooooo05_oool009Coool00`0003?o03?o000P<ol00P0000Xco`000`000?ooooooo`1J
oooo002Coooo00<0000co`0co`008C?o00030000<ol0<ol000Xco`000`000?ooooooo`1Ioooo002B
oooo00<0000co`0co`008S?o00030000<ol0<ol000/co`000`000?ooooooo`1Hoooo002Aoooo00<0
000co`0co`006c?o00D00003<ol000<0000co`0co`0033?o00030000oooooooo05Ooool0093oool0
0`0003?o03?o000N<ol000<0000co`0co`000c?o00030000<ol0<ol000dco`000`000?ooooooo`1F
oooo002?oooo00<0000co`0co`007c?o00030000<ol0<ol000<co`0300003S?o00030000oooooooo
05Goool008koool00`0003?o03?o000H<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`003c?o00030000oooooooo05Coool008goool00`0003?o03?o000Q<ol000<0000co`0co`000c?o
00030000<ol0<ol0010co`000`000?ooooooo`1Coooo002<oooo00<0000co`0co`008C?o00800005
<ol000<0000co`0co`004C?o00030000oooooooo05;oool008[oool20000:c?o0080000C<ol000<0
003oooooool0DOooo`00ROooo`030000<ol0<ol002/co`000`0003?o03?o000C<ol00P00057oool0
08Soool00`0003?o03?o000/<ol000<0000co`0co`005C?o00030000oooooooo04koool008Ooool0
0`0003?o03?o000]<ol000<0000co`0co`005S?o00030000oooooooo04goool008Koool00`0003?o
03?o000^<ol000<0000co`0co`005c?o0080001=oooo0024oooo0P00034co`0200006S?o00030000
oooooooo04[oool008?oool00`0003?o03?o000a<ol000<0000co`0co`006S?o0080001:oooo000H
oooo0P0001ooool300007Oooo`80000Moooo100000Goool200005C?o00D0000J<ol000<0000co`0c
o`006c?o00D0000Loooo100002Koool001Ooool010000?ooooooo`0001ooool00`000?ooooooo`0K
oooo00@0003oooooool0000Loooo00<0003oooooool01?ooo`80000I<ol000<0000co`0co`006S?o
00030000<ol0<ol001dco`0200007Oooo`030000oooooooo02Ooool001[oool00`000?ooooooo`0J
oooo1@0001koool00`000?ooooooo`0Loooo00@0003oooooooooool200006c?o00030000<ol0<ol0
01Xco`0200007S?o00040000<ol0000000007?ooo`030000oooooooo02Koool0017oool400000ooo
o`80000Goooo100000;oool010000?ooooooo`0001Ooool400001Oooo`030000oooooooo01Coool4
00001?ooo`<0000E<ol0100000@co`000`0003?o03?o000J<ol000<0000co`0co`007C?o00040000
<ol0<ol0<ol00P0001_oool00`000?ooooooo`0Uoooo000Hoooo00<0003oooooool07Oooo`030000
oooo000001goool010000?ooooooo`0001coool400007S?o00030000<ol0<ol001Xco`000`0003?o
03?o000M<ol000<0000co`0co`000c?o00<0000Foooo00@0003oooooool0000Voooo000Hoooo0`00
01koool200007_ooo`80000Koooo1@0001hco`02000073?o00030000<ol0<ol001`co`02000023?o
00@0000Coooo0P0002Ooool007Coool20000@C?o00030000<ol0<ol002Xco`030000>Oooo`00L?oo
o`@00013<ol00P0002hco`020000=oooo`00Joooo`D00017<ol000<0000co`0co`00;c?o00@0000c
oooo001Qoooo2P0004`co`000`0003?o03?o000c<ol02P0002Woool005Koool;0000ES?o00030000
<ol0<ol003dco`0?00006_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo000Foooo00<00000I_l0I_l03@1Voa3oool00`000?ooooooo`0Noooo00<0003oooooool07Ooo
o`030000oooooooo01goool00`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo
00Coool00`1Vooooooooo`0Goooo00<0003oooooool09Oooo`009_ooo`X0I_n7oooo00<0003ooooo
ool09?ooo`0306Kooooooooo03ooool0033oool806KoOoooo`030000oooooooo02Coool00`1Voooo
ooooo`0ooooo000hoooo101Vog_oool200009Oooo`0306Kooooooooo03ooool003coool506KoM_oo
o`030000oooooooo02Coool00`1Vooooooooo`0ooooo0011oooo1P1Vog3oool00`000?ooooooo`0T
oooo00<0I_ooooooool0?oooo`00Aoooo`D0I_m[oooo00<0003oooooool09?ooo`0306Kooooooooo
03ooool004coool506KoI_ooo`80000Uoooo00<0I_ooooooool0?oooo`00DOooo`@0I_mRoooo00<0
003oooooool09?ooo`0306Kooooooooo03ooool005Goool206KoH?ooo`030000oooooooo02Coool0
0`1Vooooooooo`0ooooo001Goooo0`1Voegoool00`000?ooooooo`0Toooo00<0I_ooooooool0?ooo
o`00F_ooo`80I_mKoooo00<0003oooooool09?ooo`0306Kooooooooo03ooool005coool206KoFOoo
o`80000Uoooo00<0I_ooooooool0?oooo`00G_ooo`80I_mGoooo00<0003oooooool09?ooo`0306Ko
oooooooo03ooool0063oool206KoEOooo`030000oooooooo02Coool00`1Vooooooooo`0ooooo001R
oooo0P1Voe?oool00`000?ooooooo`0Toooo00<0I_ooooooool0?oooo`00I?ooo`80I_mAoooo0P00
02Goool00`1Vooooooooo`0ooooo001Voooo0P1Vodooool00`000?ooooooo`0Toooo00<0I_oooooo
ool0?oooo`00J?ooo`80I_m=oooo00<0003oooooool09?ooo`0306Kooooooooo03ooool006[oool0
0`1Vooooooooo`12oooo1@0000?oool00`000?ooooooo`0Toooo00<0I_ooooooool0?oooo`00Jooo
o`0306Kooooooooo04?oool00`000?ooooooo`03oooo00<0003oooooool09?ooo`0306Kooooooooo
03ooool006coool206Ko@oooo`030000oooooooo00?oool300009?ooo`0306Kooooooooo03ooool0
06koool00`1Vooooooooo`10oooo00<0003oooooool00oooo`030000oooooooo02Coool00`1Voooo
ooooo`0ooooo001_oooo0P1Vod3oool00`000?ooooooo`03oooo00<0003oooooool09?ooo`0306Ko
oooooooo03ooool0077oool00`1Vooooooooo`0loooo0P0000Goool00`000?ooooooo`0Toooo00<0
I_ooooooool0?oooo`00L_ooo`0306Kooooooooo04;oool200009Oooo`0306Kooooooooo03ooool0
07?oool206Ko@_ooo`030000oooooooo02Coool00`1Vooooooooo`0ooooo001eoooo00<0I_oooooo
ool0?oooo`030000oooooooo02Coool00`1Vooooooooo`0ooooo001foooo00<0I_ooooooool0?_oo
o`030000oooooooo02Coool00`1Vooooooooo`0ooooo001goooo00<0I_ooooooool0?Oooo`030000
oooooooo02Coool00`1Vooooooooo`0ooooo001hoooo0P1Vocgoool200009Oooo`0306Kooooooooo
03ooool007[oool00`1Vooooooooo`0joooo00<0003oooooool09?ooo`0306Kooooooooo03ooool0
07_oool00`1Vooooooooo`0ioooo00<0003oooooool08oooo`80I_m1oooo001loooo00<0I_oooooo
ool0>?ooo`030000oooooooo02?oool00`1Vool0VOooo`10oooo001moooo00<0I_ooooooool0=ooo
o`80000Roooo0P1Vo`03ooooo`2Ioooo043oool007koool00`1Vooooooooo`0foooo00<0003ooooo
ool08?ooo`0506Koooooooooooooo`2I047oool007ooool00`1Vooooooooo`0eoooo00<0003ooooo
ool07oooo`0306Kooooooooo00;oool00ol0VOooooooo`0ooooo0020oooo00<0I_ooooooool0=?oo
o`030000oooooooo01koool00`1Vooooooooo`03oooo00?o09Woooooool0?oooo`00P?ooo`0306Ko
oooooooo03Coool00`000?ooooooo`0Moooo00<0I_ooooooool01?ooo`03o`2Ioooooooo03ooool0
087oool00`1Vooooooooo`0coooo0P0001goool00`1Vooooooooo`05oooo00?o09Woooooool0?ooo
o`00P_ooo`0306Kooooooooo03;oool00`000?ooooooo`0Koooo00<0I_ooooooool01_ooo`03o`2I
oooooooo03ooool008?oool00`1Vooooooooo`0Yoooo100000Coool00`000?ooooooo`0Joooo00<0
I_ooooooool01oooo`03o`2Ioooooooo03ooool008Coool00`1Vooooooooo`0Xoooo00<0003ooooo
ool01Oooo`030000oooooooo01[oool00`1Vooooooooo`07oooo00?o09Woooooool0?oooo`00QOoo
o`0306Kooooooooo02Soool00`000?ooooooo`04oooo0`0001Woool00`1Vooooooooo`08oooo00?o
09Woooooool0?oooo`00Q_ooo`0306Kooooooooo02Soool00`000?ooooooo`03oooo00<0003ooooo
ool06?ooo`0306Kooooooooo00Woool00ol0VOooooooo`0ooooo0027oooo00<0I_ooooooool09Ooo
o`040000oooooooo00001?ooo`030000oooooooo01Soool00`1Vooooooooo`09oooo00?o09Wooooo
ool0?oooo`00Qoooo`0306Kooooooooo02Koool200001Oooo`030000oooooooo01Ooool00`1Voooo
ooooo`0:oooo00?o09Woooooool0?oooo`00R?ooo`0306Kooooooooo02coool200005oooo`0306Ko
oooooooo00_oool00ol0VOooooooo`0ooooo0029oooo00<0I_ooooooool0:oooo`030000oooooooo
01Goool00`1Vooooooooo`0<oooo00?o09Woooooool0?oooo`00R_ooo`0306Kooooooooo02[oool0
0`000?ooooooo`0Doooo00<0I_ooooooool03Oooo`03o`2Ioooooooo03ooool008_oool00`1Voooo
ooooo`0Yoooo00<0003oooooool04oooo`0306Kooooooooo00koool00ol0VOooooooo`0ooooo002<
oooo00<0I_ooooooool0:?ooo`030000oooooooo01;oool00`1Vooooooooo`0?oooo00?o09Wooooo
ool0?oooo`00S?ooo`0306Kooooooooo02Soool200004_ooo`0306Kooooooooo013oool00ol0VOoo
ooooo`0ooooo002=oooo00<0I_ooooooool09oooo`030000oooooooo013oool00`1Vooooooooo`0A
oooo00?o09Woooooool0?oooo`00S_ooo`0306Kooooooooo02Koool00`000?ooooooo`0?oooo00<0
I_ooooooool04_ooo`03o`2Ioooooooo03ooool008ooool00`1Vooooooooo`0Uoooo00<0003ooooo
ool03oooo`0306Kooooooooo01;oool00ol0VOooooooo`0ooooo002@oooo00<0I_ooooooool09?oo
o`80000?oooo00<0I_ooooooool04oooo`03o`2Ioooooooo03ooool0097oool00`1Vooooooooo`0S
oooo00<0003oooooool03Oooo`0306Kooooooooo01Coool00ol0VOooooooo`0ooooo002Aoooo00<0
I_ooooooool08oooo`030000oooooooo00coool00`1Vooooooooo`0Eoooo00?o09Woooooool0?ooo
o`00T_ooo`0306Kooooooooo02;oool00`000?ooooooo`0<oooo00<0I_ooooooool05Oooo`03o`2I
oooooooo03ooool009?oool00`1Vooooooooo`0Qoooo00<0003oooooool02oooo`0306Kooooooooo
01Koool00ol0VOooooooo`0ooooo002Doooo00<0I_ooooooool08?ooo`80000;oooo00<0I_oooooo
ool05oooo`03o`2Ioooooooo03ooool009Coool00`1Vooooooooo`0Poooo00<0003oooooool02Ooo
o`0306Kooooooooo01Soool00ol0VOooooooo`0ooooo002Eoooo00<0I_ooooooool06?ooo`800005
oooo00<0003oooooool02Oooo`0306Kooooooooo01Soool00ol0VOooooooo`0ooooo002Foooo00<0
I_ooooooool05_ooo`040000oooooooo00001?ooo`030000oooooooo00Soool00`1Vooooooooo`0I
oooo00?o09Woooooool0?oooo`00Uoooo`0306Kooooooooo01Ooool00`000?ooooooo`03oooo0`00
00Ooool00`1Vooooooooo`0Joooo00?o09Woooooool0?oooo`00Uoooo`0306Kooooooooo01Soool0
0`000?ooooooo`02oooo00<0003oooooool01_ooo`0306Kooooooooo01_oool00ol0VOooooooo`0o
oooo002Hoooo00<0I_ooooooool05?ooo`040000oooooooo00001?ooo`030000oooooooo00Goool0
0`1Vooooooooo`0Loooo00?o09Woooooool0?oooo`00VOooo`0306Kooooooooo01Coool200001Ooo
o`030000oooooooo00Coool00`1Vooooooooo`0Moooo00?o09Woooooool0?oooo`00V_ooo`0306Ko
oooooooo01[oool00`000?ooooooo`03oooo00<0I_ooooooool07_ooo`03o`2Ioooooooo03ooool0
09_oool206Ko6_ooo`800003oooo00<0I_ooooooool07oooo`03o`2Ioooooooo03ooool009goool0
0`1Vooooooooo`0Goooo00D0003oooooooooool0I_l08_ooo`03o`2Ioooooooo03ooool009koool0
0`1Vooooooooo`0Foooo00@0003oooooool0I_lSoooo00?o09Woooooool0?oooo`00Woooo`0306Ko
oooooooo01Goool00`000?ooo`1Vo`0Toooo00?o09Woooooool0?oooo`00X?ooo`0306Kooooooooo
01Coool200009Oooo`03o`2Ioooooooo03ooool00:7oool00`1Vooooooooo`0Coooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo03ooool00:;oool00`1Vooooooooo`0Aoooo00<0I_l0003oool09Ooo
o`03o`2Ioooooooo03ooool00:?oool00`1Vooooooooo`0>oooo0P1Vo`03oooo0000oooo02Goool0
0ol0VOooooooo`0ooooo002Toooo0`1Vo`_oool206Ko0oooo`030000oooooooo02Coool00ol0VOoo
ooooo`0ooooo002Woooo0P1Vo`Ooool206Ko1Oooo`80000Uoooo00?o09Woooooool0?oooo`00ZOoo
o`L0I_l7oooo00<0003oooooool09?ooo`03o`2Ioooooooo03ooool00;Ooool00`000?ooooooo`0T
oooo00?o09Woooooool0?oooo`00]oooo`030000oooooooo02Coool00ol0VOooooooo`0ooooo002g
oooo0P0002Goool00ol0VOooooooo`0ooooo002goooo00<0003oooooool09?ooo`03o`2Ioooooooo
03ooool00;Ooool00`000?ooooooo`0Toooo00?o09Woooooool0?oooo`00/Oooo`<00003oooo00<0
003oooooool09?ooo`03o`2Ioooooooo03ooool00;;oool00`000?ooooooo`02oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo03ooool00:ooool500000oooo`<0000Toooo00?o09Woooooool0?ooo
o`00[oooo`040000oooooooo0000KOooo`00/?ooo`030000oooo000006goool00;7oool20000KOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200000oooo`@00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02Ooo
o`030000oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.70592, \
-3.20105, 0.0310585, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.70592, -3.20105, 0.0310585, 0.0446699}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-2.5\), \ 
              2}, \ PlotRange -> {\(-2.5\), 1.5}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]Plot[{10\ UnitStep[
                  x - x0 - t]}, \ {x, \ \(-2.5\), \ 2}, \ 
            PlotStyle\  \[Rule] \ Hue[0.9], \ 
            PlotRange -> {\(-2.5\), 1.5}], \ \[IndentingNewLine]Plot[{g[x, 
                t]}, \ {x, \ \(-2.5\), \ 2}, 
            PlotStyle\  \[Rule] \ 
              Hue[ .6], \ \ PlotRange -> {\(-2.5\), 
                1.5}]}, \ \[IndentingNewLine]{t, \ \(-0.5\), \ 0.5, 0.01}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.22738 .38627 L
.23233 .38627 L
.23357 .38627 L
.23426 .38627 L
.23491 .38627 L
s
.23491 .38627 m
.23502 .61803 L
s
0 .4 1 r
.02381 .37117 m
.06244 .36825 L
.10458 .36448 L
.14415 .36033 L
.18221 .35575 L
.20342 .35296 L
.22272 .35027 L
.22738 .3496 L
.23233 .34889 L
.23357 .3487 L
.23426 .3486 L
.23491 .34851 L
.23568 .38627 L
.23638 .38627 L
.23775 .38627 L
.24276 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol001Hco`0206Ko7C?o00030000<ol0<ol002lco`00
0`0003?o03?o000c<ol000<0000co`0co`003c?o0080000Poooo00<0003oooooool05oooo`00:_oo
o`<00006<ol000<0000co`0co`004C?o00H0I_lM<ol000<0000co`0co`00;c?o00030000<ol0<ol0
03<co`000`0003?o03?o000A<ol00`0001koool00`000?ooooooo`0Foooo000Voooo1000008co`04
000013?o00030000<ol0<ol000<co`0=06Ko1C?o000306Ko<ol0<ol001<co`04000013?o00030000
<ol0<ol002lco`020000=3?o00030000<ol0<ol001@co`0400006oooo`030000oooooooo01Goool0
02;oool400002c?o000506Ko000006Ko06Ko000000@0I_lB<ol000<0I_lco`0co`006c?o00030000
<ol0<ol002lco`000`0003?o03?o000c<ol000<0000co`0co`0063?o00D0000Doooo00@0003ooooo
ool0000Foooo000Noooo100000@co`0;06Ko0S?o0080000G<ol000<0I_lco`0co`006S?o0080000a
<ol000<0000co`0co`00<S?o0080000O<ol01@00013oool200005oooo`006Oooo`<0000:06Ko9S?o
000306Ko<ol0<ol004dco`000`0003?o03?o001H<ol01@0002Coool001Koool606Ko<3?o000306Ko
<ol0<ol004dco`020000GS?o00L0000Moooo000Foooo=S?o000306Ko<ol0<ol004dco`000`0003?o
03?o001T<ol01P0001Ooool001Kooolf<ol000<0I_lco`0co`00CC?o00030000<ol0<ol006Tco`0H
oooo000Foooo=S?o000306Ko<ol0<ol004dco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`02oooo00?o09Woooooool00_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000
oooooooo01Soool00ol0VOooooooo`0Hoooo00<0003oooooool0<_ooo`030000oooooooo03?oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`00C?ooo`03o`2Ioooooooo04goool00`000?oo
ooooo`21oooo001<oooo00?o09Woooooool0COooo`800022oooo001<oooo00?o09Woooooool0COoo
o`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?oo
o`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`800022
oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=
oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<
oooo00?o09Woooooool0COooo`800022oooo001<oooo00?o09Woooooool0COooo`030000oooooooo
087oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo
04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`800022oooo001<oooo00?o
09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`0joooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo03Woool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001<oooo00?o09Wooooo
ool0>Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00C?ooo`03o`2I
oooooooo03Woool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool004coool0
0ol0VOooooooo`0ioooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
087oool004coool00ol0VOooooooo`0joooo0P0000[oool300001?ooo`030000oooooooo087oool0
04coool00ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0003ooooo
ool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Wooooo
ool0COooo`800022oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool0
0ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?oo
ooooo`21oooo001<oooo00?o09Woooooool0COooo`800022oooo001<oooo00?o09Woooooool0COoo
o`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?oo
o`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`800022
oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`15
oooo1@0000?oool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0Aoooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0Aoooo`030000oooooooo00?oool3
0000POooo`00C?ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00C?ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00C?oo
o`03o`2Ioooooooo04Koool200001Oooo`030000oooooooo087oool004coool00ol0VOooooooo`1=
oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2I
oooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`030000oooooooo
087oool004coool00ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0
003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o
09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo0P0008;oool0
04coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool0
0`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool0
0ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POoo
o`00C?ooo`03o`2Ioooooooo03Woool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21
oooo001<oooo00?o09Woooooool0>oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`21oooo001<oooo00?o09Woooooool0>oooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?oo
ooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000Woool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.22738 .38627 L
.23233 .38627 L
.23491 .38627 L
.23562 .38627 L
.23638 .38627 L
.2371 .38627 L
s
.2371 .38627 m
.23719 .61803 L
s
0 .4 1 r
.02381 .37149 m
.06244 .36864 L
.10458 .36495 L
.14415 .36089 L
.18221 .35641 L
.20342 .35368 L
.22272 .35105 L
.22738 .35039 L
.23233 .34969 L
.23491 .34932 L
.23562 .34922 L
.23638 .34911 L
.2371 .34901 L
.23775 .38627 L
.23898 .38627 L
.24032 .38627 L
.24276 .38627 L
.26171 .38627 L
.30236 .38627 L
.34148 .38627 L
.38307 .38627 L
.42313 .38627 L
.46168 .38627 L
.50269 .38627 L
.54217 .38627 L
.58015 .38627 L
.62057 .38627 L
.65948 .38627 L
.70084 .38627 L
.74069 .38627 L
.77902 .38627 L
.8198 .38627 L
.85906 .38627 L
.89681 .38627 L
.93702 .38627 L
.97571 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol0014co`0606Ko7C?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o0005<ol02`1Vo`Dco`000`1Voc?o03?o000C<ol0100000@co`000`0003?o03?o000_
<ol00P0003@co`000`0003?o03?o000D<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo1000
00`co`00100003?o03?o0000008co`0406Ko43?o000306Ko<ol0<ol001/co`000`0003?o03?o000_
<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_oo
o`007_ooo`@0000?<ol00P1Vo`80000306Ko53?o000306Ko<ol0<ol001Xco`020000<C?o00030000
<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000023?o00/0I_lK<ol000<0
I_lco`0co`00CC?o00030000<ol0<ol005Pco`0500009?ooo`005_oooa00I_lV<ol000<0I_lco`0c
o`00CC?o0080001N<ol01`0001goool001Kooolf<ol000<0I_lco`0co`00CC?o00030000<ol0<ol0
06@co`0600005oooo`005_ooocHco`000`1Voc?o03?o001=<ol000<0000co`0co`00JC?o01Soool0
01Kooolf<ol000<0I_lco`0co`00CC?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0
017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00;oool00ol0VOooooooo`02oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`0boooo00<0003oooooool0<oooo`030000
oooooooo03?oool00`000?ooooooo`0Eoooo001<oooo00?o09Woooooool0COooo`030000oooooooo
087oool004coool00ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0
003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o
09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo0P0008;oool0
04coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool0
0`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool0
0ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POoo
o`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COoo
o`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOoo
ooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo03[oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0>Oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool004coool00ol0VOooooooo`0i
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001<oooo00?o09Wooooo
ool0>Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00C?ooo`03o`2I
oooooooo03Woool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00C?ooo`03o`2Ioooooooo03[oool200002_ooo`<00004oooo00<0003oooooool0POooo`00C?oo
o`03o`2Ioooooooo04goool20000P_ooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21
oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=
oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2I
oooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`030000oooooooo
087oool004coool00ol0VOooooooo`1=oooo0P0008;oool004coool00ol0VOooooooo`1=oooo00<0
003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o
09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo0P0008;oool0
04coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04Goool5
00000oooo`030000oooooooo087oool004coool00ol0VOooooooo`17oooo00<0003oooooool00ooo
o`030000oooooooo087oool004coool00ol0VOooooooo`17oooo00<0003oooooool00oooo`<00021
oooo001<oooo00?o09Woooooool0Aoooo`030000oooooooo00?oool00`000?ooooooo`21oooo001<
oooo00?o09Woooooool0Aoooo`030000oooooooo00?oool00`000?ooooooo`21oooo001<oooo00?o
09Woooooool0A_ooo`800005oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool2
0000P_ooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Wooooo
ool0COooo`030000oooooooo087oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POoo
o`00C?ooo`03o`2Ioooooooo04goool20000P_ooo`00C?ooo`03o`2Ioooooooo04goool00`000?oo
ooooo`21oooo001<oooo00?o09Woooooool0COooo`030000oooooooo087oool004coool00ol0VOoo
ooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2Ioooooooo04goool20000P_ooo`00C?oo
o`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<oooo00?o09Woooooool0COooo`030000
oooooooo087oool004coool00ol0VOooooooo`1=oooo00<0003oooooool0POooo`00C?ooo`03o`2I
oooooooo04goool20000P_ooo`00C?ooo`03o`2Ioooooooo04goool00`000?ooooooo`21oooo001<
oooo00?o09Woooooool0>Oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
04coool00ol0VOooooooo`0koooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool004coool00ol0VOooooooo`0koooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<000001?ooo`000000000000Coool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`D00002oooo0`0000Coool00`000?ooooooo`1doooo001e
oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Ooo
o`040000oooooooo00002Oooo`030000oooo000000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1eoooo001foooo00<0003oooooool05oooo`80000;oooo0P0000?oool300000_ooo`030000
oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23496 .38627 L
.2364 .38627 L
.23775 .38627 L
.2389 .38627 L
s
.2389 .38627 m
.23909 .61803 L
s
0 .4 1 r
.02381 .37182 m
.06244 .36902 L
.10458 .36542 L
.14415 .36145 L
.18221 .35707 L
.20342 .35439 L
.22272 .35182 L
.23233 .3505 L
.23496 .35013 L
.2364 .34993 L
.23775 .34974 L
.2389 .34958 L
.24014 .38627 L
.24084 .38627 L
.24151 .38627 L
.24276 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol0014co`0706Ko73?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000;<ol01@1Vo`Hco`000`1Voc?o03?o000B<ol0100000@co`000`0003?o03?o000_
<ol00P0003@co`000`0003?o03?o000D<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo1000
00`co`00100003?o03?o000000@co`0806Ko2c?o000306Ko<ol0<ol001Xco`000`0003?o03?o000_
<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_oo
o`007_ooo`@0000?<ol00P1Vo`80000506Ko4c?o000306Ko<ol0<ol001Tco`020000<C?o00030000
<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000023?o00/0I_lL<ol000<0
I_lco`0co`00C3?o00030000<ol0<ol005Pco`0500009?ooo`005_oooa00I_lW<ol000<0I_lco`0c
o`00C3?o0080001N<ol01`0001goool001Kooolg<ol000<0I_lco`0co`00C3?o00030000<ol0<ol0
06@co`0600005oooo`005_ooocLco`000`1Voc?o03?o001<<ol000<0000co`0co`00JC?o01Soool0
01Kooolg<ol000<0I_lco`0co`00C3?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0
017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00?oool01Ol0VOooooooooooo`00000:
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0Ioooo00?o
09Woooooool05oooo`030000oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<ooo
o`030000oooooooo01Goool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COoo
o`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21
oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<
oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2I
oooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo
087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo
04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003ooooo
ool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool0
0`000?ooooooo`21oooo001=oooo00?o09Woooooool0>Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool004goool00ol0VOooooooo`0hoooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo03Soool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool004goool00ol0VOooooooo`0hoooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0>?oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0>Oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001=oooo00?o09Wooooo
ool0C?ooo`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool0
0ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_oo
o`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?oo
o`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COoo
o`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21
oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<
oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2I
oooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0A?ooo`D00003oooo00<0
003oooooool0POooo`00COooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00COooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo0`00087oool004goool0
0ol0VOooooooo`16oooo00<0003oooooool00oooo`030000oooooooo087oool004goool00ol0VOoo
ooooo`16oooo00<0003oooooool00oooo`030000oooooooo087oool004goool00ol0VOooooooo`15
oooo0P0000Goool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`800022oooo001=
oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0
003oooooool0POooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0C?ooo`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool0
04goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool0
0`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`800022oooo001=oooo00?o09Wooooo
ool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POoo
o`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?oo
o`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOoo
ooooo`0hoooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00COooo`03o`2I
oooooooo03[oool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00COooo`03o`2Ioooooooo03[oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool0
0`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?oo
ooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800005oooo0`0000;oool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002oooo`040000oooooooo00000_ooo`050000oooooooooooo0000
07Ooool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?oo
o`D000001Oooo`000?ooooooo`000004oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo
00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?oo
ooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000
oooo000000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001foooo00<0003ooooo
ool05oooo`80000;oooo0P0000?oool200000oooo`030000oooooooo07Koool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23496 .38627 L
.23775 .38627 L
.24014 .38627 L
.24079 .38627 L
.24149 .38627 L
s
.24149 .38627 m
.24168 .61803 L
s
0 .4 1 r
.02381 .37214 m
.06244 .36941 L
.10458 .36589 L
.14415 .362 L
.18221 .35772 L
.20342 .3551 L
.22272 .35259 L
.23233 .3513 L
.23496 .35094 L
.23775 .35055 L
.24014 .35023 L
.24079 .35013 L
.24149 .35004 L
.24276 .38627 L
.24402 .38627 L
.24519 .38627 L
.24783 .38627 L
.25266 .38627 L
.26171 .38627 L
.30084 .38627 L
.34242 .38627 L
.38249 .38627 L
.42104 .38627 L
.46204 .38627 L
.50153 .38627 L
.5395 .38627 L
.57993 .38627 L
.61883 .38627 L
.6602 .38627 L
.70004 .38627 L
.73837 .38627 L
.77915 .38627 L
.81842 .38627 L
.85617 .38627 L
.89637 .38627 L
.93506 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol0014co`0706Ko73?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000;<ol01@1Vo`Hco`000`1Voc?o03?o000B<ol0100000@co`000`0003?o03?o000_
<ol00P0003@co`000`0003?o03?o000D<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo1000
00`co`00100003?o03?o000000@co`0806Ko2c?o000306Ko<ol0<ol001Xco`000`0003?o03?o000_
<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_oo
o`007_ooo`@0000?<ol00P1Vo`80000506Ko4c?o000306Ko<ol0<ol001Tco`020000<C?o00030000
<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000023?o00/0I_lL<ol000<0
I_lco`0co`00C3?o00030000<ol0<ol005Pco`0500009?ooo`005_oooa00I_lX<ol000<0I_lco`0c
o`00Bc?o0080001N<ol01`0001goool001Kooolh<ol000<0I_lco`0co`00Bc?o00030000<ol0<ol0
06@co`0600005oooo`005_ooocPco`000`1Voc?o03?o001;<ol000<0000co`0co`00JC?o01Soool0
01Kooolh<ol000<0I_lco`0co`00Bc?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0
017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00?oool01Ol0VOooooooooooo`00000:
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0Ioooo00?o
09Woooooool05oooo`030000oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<ooo
o`030000oooooooo01Goool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COoo
o`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21
oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<
oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2I
oooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo
087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo
04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003ooooo
ool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool0
0`000?ooooooo`21oooo001=oooo00?o09Woooooool0>Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool004goool00ol0VOooooooo`0hoooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo03Soool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool004goool00ol0VOooooooo`0hoooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0>?oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0>Oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001=oooo00?o09Wooooo
ool0C?ooo`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool0
0ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_oo
o`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?oo
o`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COoo
o`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21
oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<
oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool20000P_ooo`00COooo`03o`2I
oooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0A?ooo`D00003oooo00<0
003oooooool0POooo`00COooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00COooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo0`00087oool004goool0
0ol0VOooooooo`16oooo00<0003oooooool00oooo`030000oooooooo087oool004goool00ol0VOoo
ooooo`16oooo00<0003oooooool00oooo`030000oooooooo087oool004goool00ol0VOooooooo`15
oooo0P0000Goool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`800022oooo001=
oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0
003oooooool0POooo`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o
09Woooooool0C?ooo`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool0
04goool00ol0VOooooooo`1<oooo00<0003oooooool0POooo`00COooo`03o`2Ioooooooo04coool0
0`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?ooo`800022oooo001=oooo00?o09Wooooo
ool0C?ooo`030000oooooooo087oool004goool00ol0VOooooooo`1<oooo00<0003oooooool0POoo
o`00COooo`03o`2Ioooooooo04coool00`000?ooooooo`21oooo001=oooo00?o09Woooooool0C?oo
o`800022oooo001=oooo00?o09Woooooool0C?ooo`030000oooooooo087oool004goool00ol0VOoo
ooooo`0hoooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00COooo`03o`2I
oooooooo03[oool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00COooo`03o`2Ioooooooo03[oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool0
0`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?oo
ooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800005oooo0`0000?oool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo
00;oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000Soool500000oooo`030000oooooooo00?oool00`000?ooooooo`1doooo001e
oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool0
1@000?ooooooooooo`00001goooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooo000000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001f
oooo00<0003oooooool05oooo`80000;oooo0P0000;oool400000_ooo`030000oooooooo07Koool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23739 .38627 L
.24016 .38627 L
.24152 .38627 L
.24276 .38627 L
s
.24276 .38627 m
.24294 .61803 L
s
0 .4 1 r
.02381 .37246 m
.06244 .36979 L
.10458 .36635 L
.14415 .36256 L
.18221 .35837 L
.20342 .35581 L
.22272 .35336 L
.23233 .35209 L
.23739 .35142 L
.24016 .35104 L
.24152 .35086 L
.24276 .35069 L
.24392 .38627 L
.24502 .38627 L
.24745 .38627 L
.25261 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol001Dco`0406Ko6c?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000;<ol02@1Vo`<co`000`1Voc?o03?o000A<ol0100000@co`000`0003?o03?o000_
<ol00P0003@co`000`0003?o03?o000D<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo1000
00`co`00100003?o03?o000000@co`0806Ko33?o000306Ko<ol0<ol001Tco`000`0003?o03?o000_
<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_oo
o`007_ooo`@0000?<ol00P1Vo`80000506Ko53?o000306Ko<ol0<ol001Pco`020000<C?o00030000
<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000023?o00/0I_lM<ol000<0
I_lco`0co`00Bc?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<00003<ol02P1VobPco`00
0`1Voc?o03?o001;<ol00P0005hco`0700007Oooo`005_ooo`H0I_lb<ol000<0I_lco`0co`00Bc?o
00030000<ol0<ol006@co`0600005oooo`005_ooocPco`000`1Voc?o03?o001;<ol000<0000co`0c
o`00JC?o01Soool001Kooolh<ol000<0I_lco`0co`00Bc?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Coool01?l0VOoo
ooooo`0000[oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
01[oool00ol0VOooooooo`0Foooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21
oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000
oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>
oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0
003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o
09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool0
04koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool0
0`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Wooooo
ool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`0hoooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo03Ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0=ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00C_ooo`03o`2Ioooooooo
03Ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`0goooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
04koool00ol0VOooooooo`0hoooo0P0000[oool300001?ooo`030000oooooooo087oool004koool0
0ol0VOooooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POoo
o`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Booo
o`800022oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21
oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000
oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>
oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`13oooo1@00
00?oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0AOooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001>oooo00?o09Woooooool0AOooo`030000oooooooo00?oool30000POoo
o`00C_ooo`03o`2Ioooooooo04Goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00C_oo
o`03o`2Ioooooooo04Goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04Coool200001Oooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo0P00
08;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo
04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool0
04koool00ol0VOooooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003ooooo
ool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Wooooo
ool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo0P0008;oool004koool0
0ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?oo
ooooo`21oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_oo
o`03o`2Ioooooooo03Ooool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001>
oooo00?o09Woooooool0>Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001>oooo00?o09Woooooool0>Oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000Goool3000000Coool0000000000004oooo00<0
003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00@0003oooooool00002oooo00D0
003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00008oooo1@000005oooo0000oooooooo000000Coool00`000?ooooooo`1doooo001e
oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool3
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00009oooo00<0003oool000000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001f
oooo00<0003oooooool05oooo`80000;oooo0P0000?oool300000_ooo`030000oooooooo07Koool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23739 .38627 L
.24016 .38627 L
.24276 .38627 L
.24392 .38627 L
.24502 .38627 L
s
.24502 .38627 m
.24521 .61803 L
s
0 .4 1 r
.02381 .37278 m
.06244 .37018 L
.10458 .36681 L
.14415 .36311 L
.18221 .35902 L
.20342 .35652 L
.22272 .35412 L
.23233 .35289 L
.23739 .35222 L
.24016 .35186 L
.24276 .35152 L
.24392 .35136 L
.24502 .35122 L
.24629 .38627 L
.24745 .38627 L
.25261 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol001Hco`0306Ko6c?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000;<ol02P1Vo`8co`000`1Voc?o03?o000A<ol0100000@co`000`0003?o03?o000_
<ol00P0003@co`000`0003?o03?o000D<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo1000
00`co`00100003?o03?o000000@co`0806Ko33?o000306Ko<ol0<ol001Tco`000`0003?o03?o000_
<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_oo
o`007_ooo`@0000?<ol00P1Vo`80000506Ko53?o000306Ko<ol0<ol001Pco`020000<C?o00030000
<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000023?o00/0I_lM<ol000<0
I_lco`0co`00Bc?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<00003<ol02P1VobTco`00
0`1Voc?o03?o001:<ol00P0005hco`0700007Oooo`005_ooo`H0I_lc<ol000<0I_lco`0co`00BS?o
00030000<ol0<ol006@co`0600005oooo`005_ooocTco`000`1Voc?o03?o001:<ol000<0000co`0c
o`00JC?o01Soool001Koooli<ol000<0I_lco`0co`00BS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Coool01?l0VOoo
ooooo`0000[oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
01[oool00ol0VOooooooo`0Foooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21
oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000
oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>
oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0
003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o
09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool0
04koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool0
0`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Wooooo
ool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`0hoooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo03Ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0=ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00C_ooo`03o`2Ioooooooo
03Ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`0goooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
04koool00ol0VOooooooo`0hoooo0P0000[oool300001?ooo`030000oooooooo087oool004koool0
0ol0VOooooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POoo
o`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Booo
o`800022oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21
oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>oooo00?o09Woooooool0Boooo`030000
oooooooo087oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`800022oooo001>
oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`13oooo1@00
00?oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0AOooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001>oooo00?o09Woooooool0AOooo`030000oooooooo00?oool30000POoo
o`00C_ooo`03o`2Ioooooooo04Goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00C_oo
o`03o`2Ioooooooo04Goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00C_ooo`03o`2I
oooooooo04Coool200001Oooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo0P00
08;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo
04_oool00`000?ooooooo`21oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool0
04koool00ol0VOooooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003ooooo
ool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?ooooooo`21oooo001>oooo00?o09Wooooo
ool0Boooo`030000oooooooo087oool004koool00ol0VOooooooo`1;oooo0P0008;oool004koool0
0ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo04_oool00`000?oo
ooooo`21oooo001>oooo00?o09Woooooool0Boooo`030000oooooooo087oool004koool00ol0VOoo
ooooo`1;oooo0P0008;oool004koool00ol0VOooooooo`1;oooo00<0003oooooool0POooo`00C_oo
o`03o`2Ioooooooo03Ooool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001>
oooo00?o09Woooooool0>Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001>oooo00?o09Woooooool0>Oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`800004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0003oooooool0000;oooo00@0003oooooool00002oooo00D0003ooooo
ooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool00008oooo1@0000Coool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000
oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002Ooo
o`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23739 .38627 L
.24276 .38627 L
.24502 .38627 L
.24627 .38627 L
.24745 .38627 L
.24812 .38627 L
s
.24812 .38627 m
.24822 .61803 L
s
0 .4 1 r
.02381 .3731 m
.06244 .37056 L
.10458 .36727 L
.14415 .36365 L
.18221 .35966 L
.20342 .35722 L
.22272 .35488 L
.23233 .35368 L
.23739 .35303 L
.24276 .35234 L
.24502 .35205 L
.24627 .35188 L
.24745 .35173 L
.24812 .35164 L
.24884 .38627 L
.25012 .38627 L
.25261 .38627 L
.26171 .38627 L
.30236 .38627 L
.34148 .38627 L
.38307 .38627 L
.42313 .38627 L
.46168 .38627 L
.50269 .38627 L
.54217 .38627 L
.58015 .38627 L
.62057 .38627 L
.65948 .38627 L
.70084 .38627 L
.74069 .38627 L
.77902 .38627 L
.8198 .38627 L
.85906 .38627 L
.89681 .38627 L
.93702 .38627 L
.97571 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol001Pco`0206Ko6S?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000@<ol01`1Vo`03<ol006Ko<ol0014co`04000013?o00030000<ol0<ol002lco`02
0000=3?o00030000<ol0<ol001@co`0400006oooo`030000oooooooo01Goool002;oool4000033?o
00040000<ol0<ol0000013?o00d0I_l8<ol000<0I_lco`0co`0063?o00030000<ol0<ol002lco`00
0`0003?o03?o000c<ol000<0000co`0co`0063?o00D0000Doooo00@0003oooooool0000Foooo000N
oooo100000lco`0206Ko0P0000D0I_lE<ol000<0I_lco`0co`005c?o0080000a<ol000<0000co`0c
o`00<S?o0080000O<ol01@00013oool200005oooo`006Oooo`D00008<ol02`1Voahco`000`1Voc?o
03?o001:<ol000<0000co`0co`00F3?o00D0000Toooo000Foooo0`0000<co`0:06Ko:C?o000306Ko
<ol0<ol004Xco`020000GS?o00L0000Moooo000Foooo1P1Voc<co`000`1Voc?o03?o001:<ol000<0
000co`0co`00I3?o00H0000Goooo000Foooo>C?o000306Ko<ol0<ol004Xco`000`0003?o03?o001Y
<ol06?ooo`005_ooocTco`000`1Voc?o03?o001:<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01Oooo`03o`2Ioooo0000
00[oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo01_oool0
0ol0VOooooooo`0Eoooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`00Coooo`03o`2Ioooooooo04[oool00`000?ooooooo`21oooo001?
oooo00?o09Woooooool0B_ooo`800022oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo
087oool004ooool00ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo
04[oool00`000?ooooooo`21oooo001?oooo00?o09Woooooool0B_ooo`800022oooo001?oooo00?o
09Woooooool0B_ooo`030000oooooooo087oool004ooool00ol0VOooooooo`1:oooo00<0003ooooo
ool0POooo`00Coooo`03o`2Ioooooooo04[oool00`000?ooooooo`21oooo001?oooo00?o09Wooooo
ool0B_ooo`800022oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo087oool004ooool0
0ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`21oooo001?oooo00?o09Woooooool0B_ooo`800022oooo001?oooo00?o09Woooooool0B_oo
o`030000oooooooo087oool004ooool00ol0VOooooooo`0goooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo03Koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001?oooo00?o09Woooooool0=_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00Coooo`03o`2Ioooooooo03Koool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool004ooool00ol0VOooooooo`0f
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool004ooool0
0ol0VOooooooo`0goooo0P0000[oool300001?ooo`030000oooooooo087oool004ooool00ol0VOoo
ooooo`1:oooo0P0008;oool004ooool00ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Cooo
o`03o`2Ioooooooo04[oool00`000?ooooooo`21oooo001?oooo00?o09Woooooool0B_ooo`800022
oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo087oool004ooool00ol0VOooooooo`1:
oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo04[oool00`000?ooooooo`21oooo001?
oooo00?o09Woooooool0B_ooo`800022oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo
087oool004ooool00ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo
04[oool00`000?ooooooo`21oooo001?oooo00?o09Woooooool0B_ooo`800022oooo001?oooo00?o
09Woooooool0B_ooo`030000oooooooo087oool004ooool00ol0VOooooooo`12oooo1@0000?oool0
0`000?ooooooo`21oooo001?oooo00?o09Woooooool0A?ooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001?oooo00?o09Woooooool0A?ooo`030000oooooooo00?oool30000POooo`00Cooo
o`03o`2Ioooooooo04Coool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Coooo`03o`2I
oooooooo04Coool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo
04?oool200001Oooo`030000oooooooo087oool004ooool00ol0VOooooooo`1:oooo0P0008;oool0
04ooool00ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`21oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo087oool004ooool0
0ol0VOooooooo`1:oooo0P0008;oool004ooool00ol0VOooooooo`1:oooo00<0003oooooool0POoo
o`00Coooo`03o`2Ioooooooo04[oool00`000?ooooooo`21oooo001?oooo00?o09Woooooool0B_oo
o`030000oooooooo087oool004ooool00ol0VOooooooo`1:oooo0P0008;oool004ooool00ol0VOoo
ooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2Ioooooooo04[oool00`000?ooooooo`21
oooo001?oooo00?o09Woooooool0B_ooo`030000oooooooo087oool004ooool00ol0VOooooooo`1:
oooo0P0008;oool004ooool00ol0VOooooooo`1:oooo00<0003oooooool0POooo`00Coooo`03o`2I
oooooooo03Koool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001?oooo00?o
09Woooooool0>?ooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001?oooo00?o09Woooooool0>?ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Goool300000oooo`<00002oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`050000oooooooooooo0000
07Ooool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?oo
o`D000000oooo`000000000300000oooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009
oooo00<0003oool000000oooo`030000oooo000000?oool00`000?ooooooo`1eoooo001foooo00<0
003oooooool05oooo`80000;oooo0P0000Coool200000_ooo`030000oooooooo07Koool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23739 .38627 L
.24276 .38627 L
.24745 .38627 L
.24873 .38627 L
.24944 .38627 L
.25012 .38627 L
s
.25012 .38627 m
.25031 .61803 L
s
0 .4 1 r
.02381 .37342 m
.06244 .37094 L
.10458 .36773 L
.14415 .3642 L
.18221 .36031 L
.20342 .35793 L
.22272 .35564 L
.23233 .35446 L
.23739 .35383 L
.24276 .35316 L
.24745 .35256 L
.24873 .3524 L
.24944 .35231 L
.25012 .35222 L
.25142 .38627 L
.25261 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol001Tco`0206Ko6C?o00030000<ol0<ol002lco`000`0003?o03?o000c<ol000<0
000co`0co`004C?o00<0000Noooo00<0003oooooool05_ooo`009_ooo`@00002<ol0100000@co`00
0`0003?o03?o000@<ol0201Vo`03<ol006Ko<ol0010co`04000013?o00030000<ol0<ol002lco`02
0000=3?o00030000<ol0<ol001@co`0400006oooo`030000oooooooo01Goool002;oool4000033?o
00040000<ol0<ol0000013?o00d0I_l9<ol000<0I_lco`0co`005c?o00030000<ol0<ol002lco`00
0`0003?o03?o000c<ol000<0000co`0co`0063?o00D0000Doooo00@0003oooooool0000Foooo000N
oooo100000lco`0206Ko0P0000D0I_lF<ol000<0I_lco`0co`005S?o0080000a<ol000<0000co`0c
o`00<S?o0080000O<ol01@00013oool200005oooo`006Oooo`D00008<ol02`1Voalco`000`1Voc?o
03?o0019<ol000<0000co`0co`00F3?o00D0000Toooo000Foooo0`0000<co`0:06Ko:S?o000306Ko
<ol0<ol004Tco`020000GS?o00L0000Moooo000Foooo1P1Voc@co`000`1Voc?o03?o0019<ol000<0
000co`0co`00I3?o00H0000Goooo000Foooo>S?o000306Ko<ol0<ol004Tco`000`0003?o03?o001Y
<ol06?ooo`005_ooocXco`000`1Voc?o03?o0019<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01_ooo`03o`2I0000oooo
00Woool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo01coool0
0ol0VOooooooo`0Doooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@
oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo
087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo
04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o
09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0003ooooo
ool0POooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Wooooo
ool0BOooo`800022oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool0
0ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool00`000?oo
ooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o09Woooooool0BOoo
o`030000oooooooo087oool0053oool00ol0VOooooooo`0foooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo03Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0=Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00D?ooo`03o`2Ioooooooo03Goool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool0053oool00ol0VOooooooo`0e
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0053oool0
0ol0VOooooooo`0foooo0P0000[oool300001?ooo`030000oooooooo087oool0053oool00ol0VOoo
ooooo`19oooo0P0008;oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?oo
o`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022
oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19
oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@
oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo
087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo
04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o
09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`11oooo1@0000?oool0
0`000?ooooooo`21oooo001@oooo00?o09Woooooool0@oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001@oooo00?o09Woooooool0@oooo`030000oooooooo00?oool30000POooo`00D?oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00D?ooo`03o`2I
oooooooo04?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo
04;oool200001Oooo`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo0P0008;oool0
053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool0
0`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool0
0ol0VOooooooo`19oooo0P0008;oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POoo
o`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOoo
o`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo0P0008;oool0053oool00ol0VOoo
ooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21
oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19
oooo0P0008;oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2I
oooooooo03Goool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001@oooo00?o
09Woooooool0=oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001@oooo00?o09Woooooool0=oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool0000;oooo00@0003oooooool00002oooo00D0003oooooooooool0
0000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo1@0000?oool00`000?ooooooo`03oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo
00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00005oooo00D0003oooooooooool0
0000Moooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?oo
o`000002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo
01Ooool200002oooo`800003oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.23739 .38627 L
.24276 .38627 L
.24745 .38627 L
.24873 .38627 L
.25012 .38627 L
.25142 .38627 L
s
.25142 .38627 m
.2516 .61803 L
s
0 .4 1 r
.02381 .37374 m
.06244 .37131 L
.10458 .36819 L
.14415 .36474 L
.18221 .36094 L
.20342 .35862 L
.22272 .35639 L
.23233 .35524 L
.23739 .35463 L
.24276 .35397 L
.24745 .35339 L
.24873 .35323 L
.25012 .35306 L
.25142 .3529 L
.25261 .38627 L
.25377 .38627 L
.25484 .38627 L
.25728 .38627 L
.26171 .38627 L
.30084 .38627 L
.34242 .38627 L
.38249 .38627 L
.42104 .38627 L
.46204 .38627 L
.50153 .38627 L
.5395 .38627 L
.57993 .38627 L
.61883 .38627 L
.6602 .38627 L
.70004 .38627 L
.73837 .38627 L
.77915 .38627 L
.81842 .38627 L
.85617 .38627 L
.89637 .38627 L
.93506 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`0043?o00X0I_lA<ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o000000`co`05
06Ko2C?o000306Ko<ol0<ol001Lco`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`08
06Ko3S?o000306Ko<ol0<ol001Hco`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool5000023?o01@0I_lF<ol000<0I_lco`0co`00BC?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<00003<ol02P1VobXco`000`1Voc?o03?o0019<ol00P0005hco`07
00007Oooo`005_ooo`H0I_ld<ol000<0I_lco`0co`00BC?o00030000<ol0<ol006@co`0600005ooo
o`005_ooocXco`000`1Voc?o03?o0019<ol000<0000co`0co`00JC?o01Soool001Kooolj<ol000<0
I_lco`0co`00BC?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Koool00ol0V@000?ooo`09oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Loooo00?o09Woooooool05?ooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool2
0000P_ooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Wooooo
ool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POoo
o`00D?ooo`03o`2Ioooooooo04Woool20000P_ooo`00D?ooo`03o`2Ioooooooo04Woool00`000?oo
ooooo`21oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOoo
ooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool20000P_ooo`00D?oo
o`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`030000
oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2I
oooooooo04Woool20000P_ooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@
oooo00?o09Woooooool0=_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
053oool00ol0VOooooooo`0eoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00D?ooo`03o`2Ioooooooo03Goool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool0053oool00ol0VOooooooo`0eoooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0=Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0=_ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@
oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0
003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool20000P_ooo`00D?ooo`03o`2Ioooooooo
04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0
053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool2
0000P_ooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Wooooo
ool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POoo
o`00D?ooo`03o`2Ioooooooo04Woool20000P_ooo`00D?ooo`03o`2Ioooooooo04Woool00`000?oo
ooooo`21oooo001@oooo00?o09Woooooool0@Oooo`D00003oooo00<0003oooooool0POooo`00D?oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00D?ooo`03o`2I
oooooooo04?oool00`000?ooooooo`03oooo0`00087oool0053oool00ol0VOooooooo`13oooo00<0
003oooooool00oooo`030000oooooooo087oool0053oool00ol0VOooooooo`13oooo00<0003ooooo
ool00oooo`030000oooooooo087oool0053oool00ol0VOooooooo`12oooo0P0000Goool00`000?oo
ooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o09Woooooool0BOoo
o`030000oooooooo087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?oo
o`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022
oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`19
oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo04Woool00`000?ooooooo`21oooo001@
oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o09Woooooool0BOooo`030000oooooooo
087oool0053oool00ol0VOooooooo`19oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo
04Woool00`000?ooooooo`21oooo001@oooo00?o09Woooooool0BOooo`800022oooo001@oooo00?o
09Woooooool0BOooo`030000oooooooo087oool0053oool00ol0VOooooooo`0eoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00D?ooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800005oooo0`000003oooo0000000000800003oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool0000;oooo00@0003oooooool00006oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo1@0000;oool00`000?oo
ooooo`04oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oool000000_oo
o`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P00
00_oool200000oooo`800003oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.24276 .38627 L
.24754 .38627 L
.25016 .38627 L
.25144 .38627 L
.25261 .38627 L
.25368 .38627 L
s
.25368 .38627 m
.25384 .61803 L
s
0 .4 1 r
.02381 .37405 m
.06244 .37169 L
.10458 .36864 L
.14415 .36529 L
.18221 .36158 L
.20342 .35932 L
.22272 .35714 L
.23233 .35602 L
.24276 .35478 L
.24754 .35421 L
.25016 .35389 L
.25144 .35373 L
.25261 .35359 L
.25368 .35346 L
.2547 .38627 L
.25577 .38627 L
.25694 .38627 L
.26171 .38627 L
.30236 .38627 L
.34148 .38627 L
.38307 .38627 L
.42313 .38627 L
.46168 .38627 L
.50269 .38627 L
.54217 .38627 L
.58015 .38627 L
.62057 .38627 L
.65948 .38627 L
.70084 .38627 L
.74069 .38627 L
.77902 .38627 L
.8198 .38627 L
.85906 .38627 L
.89681 .38627 L
.93702 .38627 L
.97571 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`0053?o00L0I_l@<ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o000000`co`09
06Ko1S?o000306Ko<ol0<ol001Hco`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`08
06Ko3c?o000306Ko<ol0<ol001Dco`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool500004c?o00T0I_lG<ol000<0I_lco`0co`00B3?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<00003<ol05@1Vob0co`000`1Voc?o03?o0018<ol00P0005hco`07
00007Oooo`005_ooo`H0I_le<ol000<0I_lco`0co`00B3?o00030000<ol0<ol006@co`0600005ooo
o`005_oooc/co`000`1Voc?o03?o0018<ol000<0000co`0co`00JC?o01Soool001Kooolk<ol000<0
I_lco`0co`00B3?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Moooo00?o09Woooooool04oooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool2
0000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Wooooo
ool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POoo
o`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOoo
ooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOoo
o`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000
oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2I
oooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001A
oooo00?o09Woooooool0=Oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
057oool00ol0VOooooooo`0doooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00DOooo`03o`2Ioooooooo03Coool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool0057oool00ol0VOooooooo`0doooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0=?ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0=Oooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001A
oooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0
003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo
04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0
057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool2
0000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Wooooo
ool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POoo
o`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0@?ooo`D00003oooo00<0003oooooool0POooo`00DOoo
o`03o`2Ioooooooo04;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00DOooo`03o`2I
oooooooo04;oool00`000?ooooooo`03oooo0`00087oool0057oool00ol0VOooooooo`12oooo00<0
003oooooool00oooo`030000oooooooo087oool0057oool00ol0VOooooooo`12oooo00<0003ooooo
ool00oooo`030000oooooooo087oool0057oool00ol0VOooooooo`11oooo0P0000Goool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o09Woooooool0B?oo
o`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOoo
o`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022
oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18
oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001A
oooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo
087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo
04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o
09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`0doooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo
03Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800005oooo0`000003oooo0000000000<00002oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`1e
oooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool5
00000oooo`030000oooooooo00?oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@00
01;oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0
003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool0
0`000?ooo`000004oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Koool00`000?oo
ooooo`0Goooo0P0000_oool200000oooo`800003oooo00<0003oooooool0M_ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.24276 .38627 L
.24754 .38627 L
.25016 .38627 L
.25261 .38627 L
.2547 .38627 L
.25587 .38627 L
s
.25587 .38627 m
.25603 .61803 L
s
0 .4 1 r
.02381 .37437 m
.06244 .37206 L
.10458 .3691 L
.14415 .36582 L
.18221 .36222 L
.20342 .36001 L
.22272 .35789 L
.23233 .3568 L
.24276 .35559 L
.24754 .35503 L
.25016 .35472 L
.25261 .35443 L
.2547 .35418 L
.25587 .35404 L
.25694 .38627 L
.25811 .38627 L
.25939 .38627 L
.26171 .38627 L
.30236 .38627 L
.34148 .38627 L
.38307 .38627 L
.42313 .38627 L
.46168 .38627 L
.50269 .38627 L
.54217 .38627 L
.58015 .38627 L
.62057 .38627 L
.65948 .38627 L
.70084 .38627 L
.74069 .38627 L
.77902 .38627 L
.8198 .38627 L
.85906 .38627 L
.89681 .38627 L
.93702 .38627 L
.97571 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`005S?o00D0I_l@<ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o000000`co`0;
06Ko13?o000306Ko<ol0<ol001Hco`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`08
06Ko3c?o000306Ko<ol0<ol001Dco`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool500004c?o00T0I_lG<ol000<0I_lco`0co`00B3?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<00003<ol05@1Vob0co`000`1Voc?o03?o0018<ol00P0005hco`07
00007Oooo`005_ooo`H0I_le<ol000<0I_lco`0co`00B3?o00030000<ol0<ol006@co`0600005ooo
o`005_oooc/co`000`1Voc?o03?o0018<ol000<0000co`0co`00JC?o01Soool001Kooolk<ol000<0
I_lco`0co`00B3?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Moooo00?o09Woooooool04oooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool2
0000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Wooooo
ool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POoo
o`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOoo
ooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOoo
o`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000
oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2I
oooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001A
oooo00?o09Woooooool0=Oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
057oool00ol0VOooooooo`0doooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00DOooo`03o`2Ioooooooo03Coool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool0057oool00ol0VOooooooo`0doooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0=?ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0=Oooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001A
oooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0
003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo
04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0
057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool2
0000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Wooooo
ool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POoo
o`00DOooo`03o`2Ioooooooo04Soool20000P_ooo`00DOooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0@?ooo`D00003oooo00<0003oooooool0POooo`00DOoo
o`03o`2Ioooooooo04;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00DOooo`03o`2I
oooooooo04;oool00`000?ooooooo`03oooo0`00087oool0057oool00ol0VOooooooo`12oooo00<0
003oooooool00oooo`030000oooooooo087oool0057oool00ol0VOooooooo`12oooo00<0003ooooo
ool00oooo`030000oooooooo087oool0057oool00ol0VOooooooo`11oooo0P0000Goool00`000?oo
ooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o09Woooooool0B?oo
o`030000oooooooo087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOoo
o`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022
oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`18
oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo04Soool00`000?ooooooo`21oooo001A
oooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o09Woooooool0B?ooo`030000oooooooo
087oool0057oool00ol0VOooooooo`18oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo
04Soool00`000?ooooooo`21oooo001Aoooo00?o09Woooooool0B?ooo`800022oooo001Aoooo00?o
09Woooooool0B?ooo`030000oooooooo087oool0057oool00ol0VOooooooo`0doooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00DOooo`03o`2Ioooooooo
03Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800005oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000_oool0
1@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000Soool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oool000000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000_oool200000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.24276 .38627 L
.24754 .38627 L
.25261 .38627 L
.2547 .38627 L
.25694 .38627 L
.25823 .38627 L
s
.25823 .38627 m
.2584 .61803 L
s
0 .4 1 r
.02381 .37468 m
.06244 .37244 L
.10458 .36955 L
.14415 .36636 L
.18221 .36285 L
.20342 .3607 L
.22272 .35864 L
.23233 .35758 L
.24276 .3564 L
.24754 .35585 L
.25261 .35527 L
.2547 .35503 L
.25694 .35476 L
.25823 .35461 L
.2594 .38627 L
.26059 .38627 L
.26171 .38627 L
.2999 .38627 L
.34055 .38627 L
.37968 .38627 L
.42126 .38627 L
.46133 .38627 L
.49988 .38627 L
.54088 .38627 L
.58037 .38627 L
.61834 .38627 L
.65876 .38627 L
.69767 .38627 L
.73903 .38627 L
.77888 .38627 L
.81721 .38627 L
.85799 .38627 L
.89726 .38627 L
.93501 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`005S?o00H0I_l?<ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o0000014co`06
06Ko1C?o000306Ko<ol0<ol001Dco`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`0=
06Ko2c?o000306Ko<ol0<ol001@co`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool500004c?o00T0I_lH<ol000<0I_lco`0co`00Ac?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<00003<ol05@1Vob4co`000`1Voc?o03?o0017<ol00P0005hco`07
00007Oooo`005_ooo`H0I_lf<ol000<0I_lco`0co`00Ac?o00030000<ol0<ol006@co`0600005ooo
o`005_oooc`co`000`1Voc?o03?o0017<ol000<0000co`0co`00JC?o01Soool001Koooll<ol000<0
I_lco`0co`00Ac?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?l0VOooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Noooo00?o09Woooooool04_ooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
05;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool2
0000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Wooooo
ool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POoo
o`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOoo
ooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_oo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000
oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2I
oooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001B
oooo00?o09Woooooool0=?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
05;oool00ol0VOooooooo`0coooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00D_ooo`03o`2Ioooooooo03?oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool005;oool00ol0VOooooooo`0coooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0<oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0=?ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001B
oooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0
003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool0
05;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool2
0000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Wooooo
ool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POoo
o`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0?oooo`D00003oooo00<0003oooooool0POooo`00D_oo
o`03o`2Ioooooooo047oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00D_ooo`03o`2I
oooooooo047oool00`000?ooooooo`03oooo0`00087oool005;oool00ol0VOooooooo`11oooo00<0
003oooooool00oooo`030000oooooooo087oool005;oool00ol0VOooooooo`11oooo00<0003ooooo
ool00oooo`030000oooooooo087oool005;oool00ol0VOooooooo`10oooo0P0000Goool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o09Woooooool0Aooo
o`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_oo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022
oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17
oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001B
oooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo
087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o
09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`0coooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800004oooo0P0000?oool300001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001d
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0`0000Coool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000_oool010000?ooooooo`0000;oool01@000?ooooooooooo`00001goooo001e
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.20342 .38627 L
.22272 .38627 L
.23233 .38627 L
.24276 .38627 L
.24754 .38627 L
.25261 .38627 L
.25694 .38627 L
.25813 .38627 L
.2594 .38627 L
.26061 .38627 L
s
.26061 .38627 m
.26077 .61803 L
s
0 .4 1 r
.02381 .37499 m
.06244 .37281 L
.10458 .37 L
.14415 .3669 L
.18221 .36348 L
.20342 .36139 L
.22272 .35938 L
.23233 .35835 L
.24276 .3572 L
.24754 .35667 L
.25261 .3561 L
.25694 .35561 L
.25813 .35548 L
.2594 .35533 L
.26061 .35519 L
.26171 .38627 L
.263 .38627 L
.26421 .38627 L
.26647 .38627 L
.27155 .38627 L
.2807 .38627 L
.30142 .38627 L
.33997 .38627 L
.38097 .38627 L
.42046 .38627 L
.45843 .38627 L
.49886 .38627 L
.53776 .38627 L
.57913 .38627 L
.61897 .38627 L
.6573 .38627 L
.69808 .38627 L
.73735 .38627 L
.7751 .38627 L
.8153 .38627 L
.85399 .38627 L
.89513 .38627 L
.93475 .38627 L
.97286 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`0063?o00@0I_l?<ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o0000014co`08
06Ko0c?o000306Ko<ol0<ol001Dco`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`0=
06Ko2c?o000306Ko<ol0<ol001@co`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool500004c?o00T0I_lH<ol000<0I_lco`0co`00Ac?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<0000=<ol02`1Vob4co`000`1Voc?o03?o0017<ol00P0005hco`07
00007Oooo`005_oooa00I_l]<ol000<0I_lco`0co`00AS?o00030000<ol0<ol006@co`0600005ooo
o`005_ooocdco`000`1Voc?o03?o0016<ol000<0000co`0co`00JC?o01Soool001Kooolm<ol000<0
I_lco`0co`00AS?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?l0VOooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Noooo00?o09Woooooool04_ooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
05;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool2
0000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Wooooo
ool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POoo
o`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOoo
ooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_oo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000
oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2I
oooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001B
oooo00?o09Woooooool0=?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
05;oool00ol0VOooooooo`0coooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00D_ooo`03o`2Ioooooooo03?oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool005;oool00ol0VOooooooo`0coooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0<oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0=?ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001B
oooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0
003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool0
05;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool2
0000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Wooooo
ool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POoo
o`00D_ooo`03o`2Ioooooooo04Ooool20000P_ooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0?oooo`D00003oooo00<0003oooooool0POooo`00D_oo
o`03o`2Ioooooooo047oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00D_ooo`03o`2I
oooooooo047oool00`000?ooooooo`03oooo0`00087oool005;oool00ol0VOooooooo`11oooo00<0
003oooooool00oooo`030000oooooooo087oool005;oool00ol0VOooooooo`11oooo00<0003ooooo
ool00oooo`030000oooooooo087oool005;oool00ol0VOooooooo`10oooo0P0000Goool00`000?oo
ooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o09Woooooool0Aooo
o`030000oooooooo087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_oo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022
oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`17
oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo04Ooool00`000?ooooooo`21oooo001B
oooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o09Woooooool0Aoooo`030000oooooooo
087oool005;oool00ol0VOooooooo`17oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`21oooo001Boooo00?o09Woooooool0Aoooo`800022oooo001Boooo00?o
09Woooooool0Aoooo`030000oooooooo087oool005;oool00ol0VOooooooo`0coooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00D_ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool0
07Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000
oooooooo00D0000Boooo00@0003oooooool0000;oooo00@0003oooooooooool200001?ooo`030000
oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.25127 .38627 L
.25666 .38627 L
.2593 .38627 L
.26045 .38627 L
.26171 .38627 L
s
.26171 .38627 m
.26191 .61803 L
s
0 .4 1 r
.02381 .3753 m
.06244 .37318 L
.10458 .37044 L
.14415 .36743 L
.18221 .3641 L
.22272 .36012 L
.24141 .35815 L
.25127 .35708 L
.25666 .35649 L
.2593 .3562 L
.26045 .35607 L
.26171 .35593 L
.26301 .38627 L
.26425 .38627 L
.26698 .38627 L
.27279 .38627 L
.28302 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`006S?o00<0I_l><ol0100000@co`000`0003?o03?o000_<ol00P0003@co`000`0003?o03?o000D
<ol0100001_oool00`000?ooooooo`0Eoooo000Roooo100000`co`00100003?o03?o000000hco`0=
06Ko0S?o000306Ko<ol0<ol001@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000
<ol0<ol001Pco`0500005?ooo`040000oooooooo00005_ooo`007_ooo`@0000A<ol00P0000Dco`0:
06Ko3c?o000306Ko<ol0<ol001<co`020000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@
oooo0P0001Ooool001Woool500004c?o00T0I_lI<ol000<0I_lco`0co`00AS?o00030000<ol0<ol0
05Pco`0500009?ooo`005_ooo`<0000=<ol02`1Vob8co`000`1Voc?o03?o0016<ol00P0005hco`07
00007Oooo`005_oooa00I_l]<ol000<0I_lco`0co`00AS?o00030000<ol0<ol006@co`0600005ooo
o`005_ooocdco`000`1Voc?o03?o0016<ol000<0000co`0co`00JC?o01Soool001Kooolm<ol000<0
I_lco`0co`00AS?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooool0V@08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Ooooo00?o09Woooooool04Oooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
05?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool2
0000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Wooooo
ool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOoo
ooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Dooo
o`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000
oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2I
oooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001C
oooo00?o09Woooooool0<oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
05?oool00ol0VOooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo03;oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool005?oool00ol0VOooooooo`0boooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0<_ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0<oooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`800022oooo001C
oooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo
04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool0
05?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool2
0000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Wooooo
ool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`21oooo001Coooo00?o09Woooooool0?_ooo`D00003oooo00<0003oooooool0POooo`00Dooo
o`03o`2Ioooooooo043oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Doooo`03o`2I
oooooooo043oool00`000?ooooooo`03oooo0`00087oool005?oool00ol0VOooooooo`10oooo00<0
003oooooool00oooo`030000oooooooo087oool005?oool00ol0VOooooooo`10oooo00<0003ooooo
ool00oooo`030000oooooooo087oool005?oool00ol0VOooooooo`0ooooo0P0000Goool00`000?oo
ooooo`21oooo001Coooo00?o09Woooooool0A_ooo`800022oooo001Coooo00?o09Woooooool0A_oo
o`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Dooo
o`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`800022
oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16
oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001C
oooo00?o09Woooooool0A_ooo`800022oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo
087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo
04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`800022oooo001Coooo00?o
09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`0boooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo03Coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo
03Coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo
07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0M?ooo`00MOooo`030000
oooooooo00D0000Boooo00@0003oooooool0000;oooo00<0003oooooool00oooo`050000oooooooo
oooo000007Ooool007Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`800003oooo100000;oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.25127 .38627 L
.25666 .38627 L
.26171 .38627 L
.26301 .38627 L
.26425 .38627 L
.26493 .38627 L
s
.26493 .38627 m
.26504 .61803 L
s
0 .4 1 r
.02381 .37561 m
.06244 .37355 L
.10458 .37089 L
.14415 .36796 L
.18221 .36473 L
.22272 .36086 L
.24141 .35894 L
.25127 .3579 L
.25666 .35733 L
.26171 .35678 L
.26301 .35664 L
.26425 .35651 L
.26493 .35644 L
.26568 .38627 L
.26698 .38627 L
.27279 .38627 L
.28302 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`0073?o000306Ko<ol0<ol000`co`04000013?o00030000<ol0<ol002lco`020000=3?o00030000
<ol0<ol001@co`0400006oooo`030000oooooooo01Goool002;oool4000033?o00040000<ol0<ol0
00005S?o00P0I_lF<ol000<0000co`0co`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H
<ol01@0001Coool010000?ooooooo`0001Koool001koool400004C?o0080000?<ol0201Vo`Lco`00
0`1Voc?o03?o000C<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`0500004?ooo`80000G
oooo000Ioooo1@0001<co`0C06Ko3c?o000306Ko<ol0<ol004Hco`000`0003?o03?o001H<ol01@00
02Coool001Koool300003C?o00/0I_lR<ol000<0I_lco`0co`00AS?o0080001N<ol01`0001goool0
01Koool@06Ko;S?o000306Ko<ol0<ol004Dco`000`0003?o03?o001T<ol01P0001Ooool001Koooln
<ol000<0I_lco`0co`00AC?o00030000<ol0<ol006Tco`0Hoooo000Foooo?S?o000306Ko<ol0<ol0
04Dco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003ooooo09T02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Eoooo000aoooo00<0003oooooool07oooo`03o`2Ioooooooo017oool00`000?ooooooo`0b
oooo00<0003oooooool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Coooo00?o
09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo0P0008;oool0
05?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool0
0`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool0
0ol0VOooooooo`16oooo0P0008;oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_oo
o`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo0P0008;oool005?oool00ol0VOoo
ooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21
oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16
oooo0P0008;oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2I
oooooooo03?oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Coooo00?o
09Woooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
087oool005?oool00ol0VOooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<00021oooo001Coooo00?o09Woooooool0<_ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo03?oool200002_ooo`<00004
oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2I
oooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo
087oool005?oool00ol0VOooooooo`16oooo0P0008;oool005?oool00ol0VOooooooo`16oooo00<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o
09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo0P0008;oool0
05?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool0
0`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool0
0ol0VOooooooo`16oooo0P0008;oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo03koool500000oooo`030000oooooooo087oool005?oool00ol0VOoo
ooooo`10oooo00<0003oooooool00oooo`030000oooooooo087oool005?oool00ol0VOooooooo`10
oooo00<0003oooooool00oooo`<00021oooo001Coooo00?o09Woooooool0@?ooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0@?ooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001Coooo00?o09Woooooool0?oooo`800005oooo00<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOoo
ooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Dooo
o`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0A_ooo`030000
oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0003oooooool0POooo`00Doooo`03o`2I
oooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo04Koool00`000?ooooooo`21oooo001C
oooo00?o09Woooooool0A_ooo`030000oooooooo087oool005?oool00ol0VOooooooo`16oooo00<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo04Koool20000P_ooo`00Doooo`03o`2Ioooooooo
04Koool00`000?ooooooo`21oooo001Coooo00?o09Woooooool0<_ooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo087oool005?oool00ol0VOooooooo`0doooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo087oool005?oool00ol0VOooooooo`0doooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool2
0000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool3
0000R?ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800003oooo0`0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002oooo`030000oooooooo00<00004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool2
00002_ooo`800004oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.25127 .38627 L
.26171 .38627 L
.26425 .38627 L
.26565 .38627 L
.26634 .38627 L
.26698 .38627 L
s
.26698 .38627 m
.26709 .61803 L
s
0 .4 1 r
.02381 .37592 m
.06244 .37392 L
.10458 .37133 L
.14415 .36849 L
.18221 .36535 L
.22272 .36159 L
.24141 .35973 L
.25127 .35872 L
.26171 .35764 L
.26425 .35737 L
.26565 .35722 L
.26634 .35715 L
.26698 .35708 L
.26773 .38627 L
.26855 .38627 L
.26998 .38627 L
.27279 .38627 L
.28302 .38627 L
.30316 .38627 L
.34228 .38627 L
.38387 .38627 L
.42393 .38627 L
.46248 .38627 L
.50349 .38627 L
.54298 .38627 L
.58095 .38627 L
.62137 .38627 L
.66028 .38627 L
.70164 .38627 L
.74149 .38627 L
.77982 .38627 L
.8206 .38627 L
.85986 .38627 L
.89761 .38627 L
.93782 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000F<ol02@1VoaDco`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0000lco`0806Ko23?o000306Ko<ol0<ol0018co`02
0000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool500004c?o
01<0I_l@<ol000<0I_lco`0co`00AC?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000=
<ol02`1Vob<co`000`1Voc?o03?o0015<ol00P0005hco`0700007Oooo`005_oooa00I_l^<ol000<0
I_lco`0co`00AC?o00030000<ol0<ol006@co`0600005oooo`005_ooochco`000`1Voc?o03?o0015
<ol000<0000co`0co`00JC?o01Soool001Koooln<ol000<0I_lco`0co`00AC?o00030000<ol0<ol0
06Tco`0Hoooo000@ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool010000?ooooooool0V@Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Ooo
o`030000oooooooo023oool00ol0VOooooooo`0@oooo00<0003oooooool0<_ooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00E?ooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Wooooo
ool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOoo
o`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21
oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Woooooool0AOooo`030000
oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2I
oooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001D
oooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`0boooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo037oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Doooo00?o
09Woooooool0<Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00E?oo
o`03o`2Ioooooooo037oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`0aoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo087oool005Coool00ol0VOooooooo`0boooo0P0000[oool300001?ooo`030000oooooooo
087oool005Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0
003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o
09Woooooool0AOooo`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Wooooo
ool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOoo
o`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`0moooo1@0000?oool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0?oooo`030000
oooooooo00?oool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0?oooo`030000oooooooo
00?oool30000POooo`00E?ooo`03o`2Ioooooooo03ooool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00E?ooo`03o`2Ioooooooo03ooool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo03koool200001Oooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?oo
o`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`030000
oooooooo087oool005Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15
oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001D
oooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo0P00
08;oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo
04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0003ooooo
ool0POooo`00E?ooo`03o`2Ioooooooo037oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001Doooo00?o09Woooooool0<oooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0<oooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool0
0`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQ
oooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0
003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`800004
oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo
00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`00
00_oool010000?ooooooooooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.25127 .38627 L
.26171 .38627 L
.26425 .38627 L
.26698 .38627 L
.26778 .38627 L
.26855 .38627 L
.26923 .38627 L
s
.26923 .38627 m
.26934 .61803 L
s
0 .4 1 r
.02381 .37623 m
.06244 .37428 L
.10458 .37178 L
.14415 .36902 L
.18221 .36597 L
.22272 .36233 L
.24141 .36052 L
.25127 .35954 L
.26171 .35849 L
.26425 .35823 L
.26698 .35795 L
.26778 .35787 L
.26855 .35779 L
.26923 .35772 L
.26998 .38627 L
.27068 .38627 L
.27144 .38627 L
.27279 .38627 L
.28302 .38627 L
.30316 .38627 L
.34474 .38627 L
.3848 .38627 L
.42335 .38627 L
.46436 .38627 L
.50385 .38627 L
.54182 .38627 L
.58224 .38627 L
.62115 .38627 L
.66251 .38627 L
.70236 .38627 L
.74069 .38627 L
.78147 .38627 L
.82073 .38627 L
.85849 .38627 L
.89869 .38627 L
.93738 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000F<ol02@1VoaDco`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0000lco`0806Ko23?o000306Ko<ol0<ol0018co`02
0000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000073?o
00X0I_l@<ol000<0I_lco`0co`00AC?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000=
<ol0501VoaXco`000`1Voc?o03?o0015<ol00P0005hco`0700007Oooo`005_oooa00I_l_<ol000<0
I_lco`0co`00A3?o00030000<ol0<ol006@co`0600005oooo`005_oooclco`000`1Voc?o03?o0014
<ol000<0000co`0co`00JC?o01Soool001Kooolo<ol000<0I_lco`0co`00A3?o00030000<ol0<ol0
06Tco`0Hoooo000@ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool010000?ooooooool0V@Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Ooo
o`030000oooooooo023oool00ol0VOooooooo`0@oooo00<0003oooooool0<_ooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00E?ooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Wooooo
ool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOoo
o`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21
oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Woooooool0AOooo`030000
oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2I
oooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001D
oooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`0boooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo037oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Doooo00?o
09Woooooool0<Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00E?oo
o`03o`2Ioooooooo037oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`0aoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo087oool005Coool00ol0VOooooooo`0boooo0P0000[oool300001?ooo`030000oooooooo
087oool005Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0
003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o
09Woooooool0AOooo`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`800022oooo001Doooo00?o09Wooooo
ool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOoo
o`800022oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`0moooo1@0000?oool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0?oooo`030000
oooooooo00?oool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0?oooo`030000oooooooo
00?oool30000POooo`00E?ooo`03o`2Ioooooooo03ooool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00E?ooo`03o`2Ioooooooo03ooool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo03koool200001Oooo`030000oooooooo087oool005Coool00ol0VOoo
ooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?oo
o`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`030000
oooooooo087oool005Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15
oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo04Goool00`000?ooooooo`21oooo001D
oooo00?o09Woooooool0AOooo`030000oooooooo087oool005Coool00ol0VOooooooo`15oooo0P00
08;oool005Coool00ol0VOooooooo`15oooo00<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo
04Goool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0AOooo`030000oooooooo087oool0
05Coool00ol0VOooooooo`15oooo0P0008;oool005Coool00ol0VOooooooo`15oooo00<0003ooooo
ool0POooo`00E?ooo`03o`2Ioooooooo037oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001Doooo00?o09Woooooool0<oooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Doooo00?o09Woooooool0<oooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool0
0`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQ
oooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0
003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00005
oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool0000:oooo00@0003oooooooooool500000oooo`030000oooooooo07Coool0
07Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`040000oooooooo00000_oo
o`050000oooooooooooo000007Ooool007Goool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Goooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0M_oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.25127 .38627 L
.26171 .38627 L
.26698 .38627 L
.26843 .38627 L
.26922 .38627 L
.26998 .38627 L
.27068 .38627 L
s
.27068 .38627 m
.2708 .61803 L
s
0 .4 1 r
.02381 .37653 m
.06244 .37465 L
.10458 .37222 L
.14415 .36954 L
.18221 .36659 L
.22272 .36306 L
.24141 .3613 L
.25127 .36035 L
.26171 .35933 L
.26698 .35881 L
.26843 .35867 L
.26922 .35859 L
.26998 .35852 L
.27068 .35845 L
.27145 .38627 L
.27214 .38627 L
.27279 .38627 L
.28302 .38627 L
.30316 .38627 L
.34228 .38627 L
.38387 .38627 L
.42393 .38627 L
.46248 .38627 L
.50349 .38627 L
.54298 .38627 L
.58095 .38627 L
.62137 .38627 L
.66028 .38627 L
.70164 .38627 L
.74149 .38627 L
.77982 .38627 L
.8206 .38627 L
.85986 .38627 L
.89761 .38627 L
.93782 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000I<ol01`1Voa@co`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0000lco`0;06Ko1S?o000306Ko<ol0<ol0014co`02
0000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000073?o
00X0I_lA<ol000<0I_lco`0co`00A3?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000=
<ol0501Voa/co`000`1Voc?o03?o0014<ol00P0005hco`0700007Oooo`005_ooo`Hco`0:06Ko;c?o
000306Ko<ol0<ol004@co`000`0003?o03?o001T<ol01P0001Ooool001Koool606Ko>C?o000306Ko
<ol0<ol004@co`000`0003?o03?o001Y<ol06?ooo`005_oooclco`000`1Voc?o03?o0014<ol000<0
000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`050000ooooooooooooo`2I00Koool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool05Oooo`00<Oooo`030000oooooooo027oool00ol0VOooooooo`0?oooo00<0003oooooool0<_oo
o`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00EOooo`03o`2I
oooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001E
oooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o
09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool0
0`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001Eoooo00?o09Wooooo
ool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POoo
o`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?oo
o`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOoo
ooooo`0aoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00EOooo`03o`2I
oooooooo033oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001Eoooo00?o09Woooooool0<?ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000POooo`00EOooo`03o`2Ioooooooo033oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo087oool005Goool00ol0VOooooooo`0`oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`0aoooo0P0000[oool300001?oo
o`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOoo
ooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21
oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000
oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2I
oooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001E
oooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o
09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`0loooo1@0000?oool00`000?ooooooo`21oooo001Eoooo00?o09Wooooo
ool0?_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0?_oo
o`030000oooooooo00?oool30000POooo`00EOooo`03o`2Ioooooooo03koool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo03koool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo03goool200001Oooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14oooo00<0003ooooo
ool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Wooooo
ool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool0
0ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOoo
ooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOoo
o`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`030000
oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14
oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo033oool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0<_ooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0<_ooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P00
08Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`00
08Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1f
oooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001e
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool2
00001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00ooo
o`030000oooooooo00?oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000_oool00`000?ooooooo`03oooo00D0003oooooooooool00000Moooo`00MOoo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:
oooo0P0000Coool200000oooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.26171 .38627 L
.26709 .38627 L
.27003 .38627 L
.27147 .38627 L
.27279 .38627 L
s
.27279 .38627 m
.27297 .61803 L
s
0 .4 1 r
.02381 .37684 m
.06244 .37501 L
.10458 .37266 L
.14415 .37007 L
.18221 .36721 L
.22272 .36378 L
.24141 .36209 L
.26171 .36018 L
.26709 .35966 L
.27003 .35938 L
.27147 .35924 L
.27279 .35911 L
.27399 .38627 L
.27513 .38627 L
.27765 .38627 L
.28302 .38627 L
.30316 .38627 L
.34135 .38627 L
.38199 .38627 L
.42112 .38627 L
.46271 .38627 L
.50277 .38627 L
.54132 .38627 L
.58233 .38627 L
.62181 .38627 L
.65979 .38627 L
.70021 .38627 L
.73912 .38627 L
.78048 .38627 L
.82032 .38627 L
.85865 .38627 L
.89944 .38627 L
.9387 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000K<ol01@1Voa@co`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0000lco`0=06Ko13?o000306Ko<ol0<ol0014co`02
0000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000073?o
00X0I_lA<ol000<0I_lco`0co`00A3?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000H
<ol02@1Voa/co`000`1Voc?o03?o0014<ol00P0005hco`0700007Oooo`005_ooo`Hco`0E06Ko9C?o
000306Ko<ol0<ol004<co`000`0003?o03?o001T<ol01P0001Ooool001Koool606Ko>S?o000306Ko
<ol0<ol004<co`000`0003?o03?o001Y<ol06?ooo`005_oood0co`000`1Voc?o03?o0013<ol000<0
000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`050000ooooooooooooo`2I00Koool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool05Oooo`00<Oooo`030000oooooooo027oool00ol0VOooooooo`0?oooo00<0003oooooool0<_oo
o`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00EOooo`03o`2I
oooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001E
oooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o
09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool0
0`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001Eoooo00?o09Wooooo
ool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POoo
o`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?oo
o`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOoo
ooooo`0aoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00EOooo`03o`2I
oooooooo033oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001Eoooo00?o09Woooooool0<?ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000POooo`00EOooo`03o`2Ioooooooo033oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo087oool005Goool00ol0VOooooooo`0`oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`0aoooo0P0000[oool300001?oo
o`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOoo
ooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21
oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000
oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2I
oooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`800022oooo001E
oooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o
09Woooooool0A?ooo`800022oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`0loooo1@0000?oool00`000?ooooooo`21oooo001Eoooo00?o09Wooooo
ool0?_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0?_oo
o`030000oooooooo00?oool30000POooo`00EOooo`03o`2Ioooooooo03koool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo03koool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo03goool200001Oooo`030000oooooooo087oool0
05Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14oooo00<0003ooooo
ool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Wooooo
ool0A?ooo`030000oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool0
0ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`030000oooooooo087oool005Goool00ol0VOoo
ooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14oooo00<0003oooooool0POooo`00EOoo
o`03o`2Ioooooooo04Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0A?ooo`030000
oooooooo087oool005Goool00ol0VOooooooo`14oooo0P0008;oool005Goool00ol0VOooooooo`14
oooo00<0003oooooool0POooo`00EOooo`03o`2Ioooooooo033oool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0<_ooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001Eoooo00?o09Woooooool0<_ooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P00
08Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`00
08Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1f
oooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001e
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool2
00000oooo`@00003oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo07Goool007Coool00`000?oo
ooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0G
oooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.26171 .38627 L
.26709 .38627 L
.27003 .38627 L
.27279 .38627 L
.27399 .38627 L
.27513 .38627 L
s
.27513 .38627 m
.27533 .61803 L
s
0 .4 1 r
.02381 .37714 m
.06244 .37538 L
.10458 .3731 L
.14415 .37059 L
.18221 .36782 L
.22272 .36451 L
.24141 .36287 L
.26171 .36102 L
.26709 .36052 L
.27003 .36025 L
.27279 .35999 L
.27399 .35988 L
.27513 .35977 L
.27645 .38627 L
.27765 .38627 L
.28302 .38627 L
.30316 .38627 L
.34135 .38627 L
.38199 .38627 L
.42112 .38627 L
.46271 .38627 L
.50277 .38627 L
.54132 .38627 L
.58233 .38627 L
.62181 .38627 L
.65979 .38627 L
.70021 .38627 L
.73912 .38627 L
.78048 .38627 L
.82032 .38627 L
.85865 .38627 L
.89944 .38627 L
.9387 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000N<ol00`1Voa<co`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0000lco`0@06Ko0S?o000306Ko<ol0<ol0010co`02
0000<C?o00030000<ol0<ol0038co`0200007c?o00D0000@oooo0P0001Ooool001Woool5000073?o
00X0I_lB<ol000<0I_lco`0co`00@c?o00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000H
<ol02@1Voa`co`000`1Voc?o03?o0013<ol00P0005hco`0700007Oooo`005_ooo`Hco`0E06Ko9C?o
000306Ko<ol0<ol004<co`000`0003?o03?o001T<ol01P0001Ooool001Koool606Ko>S?o000306Ko
<ol0<ol004<co`000`0003?o03?o001Y<ol06?ooo`005_oood0co`000`1Voc?o03?o0013<ol000<0
000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00;oool00ol0VOooooooo`03oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Roooo00?o09Woooooool03_ooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
05Koool00ol0VOooooooo`13oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo04?oool2
0000P_ooo`00E_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001Foooo00?o09Wooooo
ool0@oooo`030000oooooooo087oool005Koool00ol0VOooooooo`13oooo00<0003oooooool0POoo
o`00E_ooo`03o`2Ioooooooo04?oool20000P_ooo`00E_ooo`03o`2Ioooooooo04?oool00`000?oo
ooooo`21oooo001Foooo00?o09Woooooool0@oooo`030000oooooooo087oool005Koool00ol0VOoo
ooooo`13oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo04?oool20000P_ooo`00E_oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0@oooo`030000
oooooooo087oool005Koool00ol0VOooooooo`13oooo00<0003oooooool0POooo`00E_ooo`03o`2I
oooooooo04?oool20000P_ooo`00E_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001F
oooo00?o09Woooooool0<?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
05Koool00ol0VOooooooo`0_oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00E_ooo`03o`2Ioooooooo02ooool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool005Koool00ol0VOooooooo`0_oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0;oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0<?ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0@oooo`800022oooo001F
oooo00?o09Woooooool0@oooo`030000oooooooo087oool005Koool00ol0VOooooooo`13oooo00<0
003oooooool0POooo`00E_ooo`03o`2Ioooooooo04?oool20000P_ooo`00E_ooo`03o`2Ioooooooo
04?oool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0@oooo`030000oooooooo087oool0
05Koool00ol0VOooooooo`13oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo04?oool2
0000P_ooo`00E_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001Foooo00?o09Wooooo
ool0@oooo`030000oooooooo087oool005Koool00ol0VOooooooo`13oooo00<0003oooooool0POoo
o`00E_ooo`03o`2Ioooooooo04?oool20000P_ooo`00E_ooo`03o`2Ioooooooo04?oool00`000?oo
ooooo`21oooo001Foooo00?o09Woooooool0>oooo`D00003oooo00<0003oooooool0POooo`00E_oo
o`03o`2Ioooooooo03goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00E_ooo`03o`2I
oooooooo03goool00`000?ooooooo`03oooo0`00087oool005Koool00ol0VOooooooo`0moooo00<0
003oooooool00oooo`030000oooooooo087oool005Koool00ol0VOooooooo`0moooo00<0003ooooo
ool00oooo`030000oooooooo087oool005Koool00ol0VOooooooo`0loooo0P0000Goool00`000?oo
ooooo`21oooo001Foooo00?o09Woooooool0@oooo`800022oooo001Foooo00?o09Woooooool0@ooo
o`030000oooooooo087oool005Koool00ol0VOooooooo`13oooo00<0003oooooool0POooo`00E_oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0@oooo`800022
oooo001Foooo00?o09Woooooool0@oooo`030000oooooooo087oool005Koool00ol0VOooooooo`13
oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`21oooo001F
oooo00?o09Woooooool0@oooo`800022oooo001Foooo00?o09Woooooool0@oooo`030000oooooooo
087oool005Koool00ol0VOooooooo`13oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo
04?oool00`000?ooooooo`21oooo001Foooo00?o09Woooooool0@oooo`800022oooo001Foooo00?o
09Woooooool0@oooo`030000oooooooo087oool005Koool00ol0VOooooooo`0_oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo037oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00E_ooo`03o`2Ioooooooo
037oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800004oooo0P0000?oool500000_ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001d
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.26171 .38627 L
.26709 .38627 L
.27279 .38627 L
.27513 .38627 L
.27643 .38627 L
.27765 .38627 L
s
.27765 .38627 m
.27776 .61803 L
s
0 .4 1 r
.02381 .37744 m
.06244 .37574 L
.10458 .37354 L
.14415 .37111 L
.18221 .36844 L
.22272 .36523 L
.24141 .36364 L
.26171 .36186 L
.26709 .36138 L
.27279 .36086 L
.27513 .36065 L
.27643 .36054 L
.27765 .36042 L
.27835 .38627 L
.2791 .38627 L
.28042 .38627 L
.28302 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000P<ol00P1Voa8co`00
0`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol001Pco`0500005?ooo`040000
oooooooo00005_ooo`007_ooo`@0000A<ol00P0001Lco`0<06Ko4C?o0080000a<ol000<0000co`0c
o`00<S?o0080000O<ol01@00013oool200005oooo`006Oooo`D0000L<ol04P1Vo`/co`000`1Voc?o
03?o0012<ol000<0000co`0co`00F3?o00D0000Toooo000Foooo0`0001Pco`0906Ko7C?o000306Ko
<ol0<ol0048co`020000GS?o00L0000Moooo000Foooo1S?o01D0I_lV<ol000<0I_lco`0co`00@S?o
00030000<ol0<ol006@co`0600005oooo`005_ooo`H0I_lk<ol000<0I_lco`0co`00@S?o00030000
<ol0<ol006Tco`0Hoooo000Foooo@C?o000306Ko<ol0<ol0048co`000`0003?o03?o001Y<ol06?oo
o`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool00oooo`03o`2Ioooooooo00;oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Ooo
o`00<Oooo`030000oooooooo02?oool00ol0VOooooooo`0=oooo00<0003oooooool0<_ooo`030000
oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00Eoooo`03o`2Ioooooooo
04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o
09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003ooooo
ool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Wooooo
ool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool0
0ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?oo
ooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_oo
o`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eooo
o`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022
oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`0_
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo
02koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001G
oooo00?o09Woooooool0;_ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00Eoooo`03o`2Ioooooooo02koool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool005Ooool00ol0VOooooooo`0^oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool005Ooool00ol0VOooooooo`0_oooo0P0000[oool300001?ooo`030000
oooooooo087oool005Ooool00ol0VOooooooo`12oooo0P0008;oool005Ooool00ol0VOooooooo`12
oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001G
oooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo
087oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo
04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o
09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003ooooo
ool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Wooooo
ool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool0
0ol0VOooooooo`0joooo1@0000?oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0??oo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0??ooo`030000
oooooooo00?oool30000POooo`00Eoooo`03o`2Ioooooooo03coool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00Eoooo`03o`2Ioooooooo03coool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00Eoooo`03o`2Ioooooooo03_oool200001Oooo`030000oooooooo087oool005Ooool0
0ol0VOooooooo`12oooo0P0008;oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POoo
o`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_oo
o`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo0P0008;oool005Ooool00ol0VOoo
ooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21
oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12
oooo0P0008;oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2I
oooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo
087oool005Ooool00ol0VOooooooo`12oooo0P0008;oool005Ooool00ol0VOooooooo`12oooo00<0
003oooooool0POooo`00Eoooo`03o`2Ioooooooo02koool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001Goooo00?o09Woooooool0<?ooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0<?ooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000_oool01@000?ooooooooooo`00001joooo001hoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.26171 .38627 L
.26709 .38627 L
.27279 .38627 L
.27513 .38627 L
.27765 .38627 L
.2784 .38627 L
.2791 .38627 L
s
.2791 .38627 m
.2793 .61803 L
s
0 .4 1 r
.02381 .37775 m
.06244 .3761 L
.10458 .37397 L
.14415 .37163 L
.18221 .36905 L
.22272 .36595 L
.24141 .36442 L
.26171 .3627 L
.26709 .36223 L
.27279 .36174 L
.27513 .36153 L
.27765 .36131 L
.2784 .36125 L
.2791 .36118 L
.28042 .38627 L
.28166 .38627 L
.28302 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000G<ol0301Voa4co`020000<C?o00030000<ol0<ol0038co`02
00007c?o00D0000@oooo0P0001Ooool001Woool500009S?o00P0I_l;<ol000<0I_lco`0co`00@S?o
00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000H<ol04`1Voa<co`000`1Voc?o03?o0012
<ol00P0005hco`0700007Oooo`005_ooo`Hco`0E06Ko9S?o000306Ko<ol0<ol0048co`000`0003?o
03?o001T<ol01P0001Ooool001Koool606Ko>c?o000306Ko<ol0<ol0048co`000`0003?o03?o001Y
<ol06?ooo`005_oood4co`000`1Voc?o03?o0012<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00?oool00ol0VOooooooo`02oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool0
0`000?ooooooo`0Soooo00?o09Woooooool03Oooo`030000oooooooo03;oool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool005Ooool00ol0VOooooooo`12oooo00<0
003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool20000P_ooo`00Eoooo`03o`2Ioooooooo
04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool0
05Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool2
0000P_ooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Wooooo
ool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POoo
o`00Eoooo`03o`2Ioooooooo04;oool20000P_ooo`00Eoooo`03o`2Ioooooooo04;oool00`000?oo
ooooo`21oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOoo
ooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool20000P_ooo`00Eooo
o`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0;oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool005Ooool00ol0VOooooooo`0^oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Eoooo`03o`2I
oooooooo02koool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool005Ooool0
0ol0VOooooooo`0^oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001G
oooo00?o09Woooooool0;_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001Goooo00?o09Woooooool0;oooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001Goooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000
oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2I
oooooooo04;oool20000P_ooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001G
oooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0
003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool20000P_ooo`00Eoooo`03o`2Ioooooooo
04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool0
05Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool2
0000P_ooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Wooooo
ool0>_ooo`D00003oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo03coool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo03coool00`000?ooooooo`03
oooo0`00087oool005Ooool00ol0VOooooooo`0loooo00<0003oooooool00oooo`030000oooooooo
087oool005Ooool00ol0VOooooooo`0loooo00<0003oooooool00oooo`030000oooooooo087oool0
05Ooool00ol0VOooooooo`0koooo0P0000Goool00`000?ooooooo`21oooo001Goooo00?o09Wooooo
ool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool0
0ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?oo
ooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_oo
o`030000oooooooo087oool005Ooool00ol0VOooooooo`12oooo00<0003oooooool0POooo`00Eooo
o`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001Goooo00?o09Woooooool0@_ooo`800022
oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo087oool005Ooool00ol0VOooooooo`12
oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo04;oool00`000?ooooooo`21oooo001G
oooo00?o09Woooooool0@_ooo`800022oooo001Goooo00?o09Woooooool0@_ooo`030000oooooooo
087oool005Ooool00ol0VOooooooo`0^oooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00Eoooo`03o`2Ioooooooo033oool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo033oool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo100000;oool300001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool00oooo`<00004oooo00<0003ooooo
ool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007Ooool007Goool01@000?ooooooooooo`00000E
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool0
0`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.24141 .38627 L
.26171 .38627 L
.26709 .38627 L
.27279 .38627 L
.27765 .38627 L
.27899 .38627 L
.28042 .38627 L
.28112 .38627 L
.28178 .38627 L
s
.28178 .38627 m
.28196 .61803 L
s
0 .4 1 r
.02381 .37805 m
.06244 .37646 L
.10458 .37441 L
.14415 .37215 L
.18221 .36966 L
.22272 .36667 L
.24141 .36519 L
.26171 .36353 L
.26709 .36308 L
.27279 .3626 L
.27765 .36219 L
.27899 .36208 L
.28042 .36196 L
.28112 .3619 L
.28178 .36185 L
.28302 .38627 L
.28428 .38627 L
.28543 .38627 L
.28801 .38627 L
.29264 .38627 L
.30316 .38627 L
.34322 .38627 L
.38177 .38627 L
.42278 .38627 L
.46226 .38627 L
.50023 .38627 L
.54066 .38627 L
.57957 .38627 L
.62093 .38627 L
.66077 .38627 L
.6991 .38627 L
.73989 .38627 L
.77915 .38627 L
.8169 .38627 L
.85711 .38627 L
.89579 .38627 L
.93693 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000L<ol0201Voa0co`020000<C?o00030000<ol0<ol0038co`02
00007c?o00D0000@oooo0P0001Ooool001Woool500009S?o00d0I_l7<ol000<0I_lco`0co`00@C?o
00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000H<ol04`1Voa@co`000`1Voc?o03?o0011
<ol00P0005hco`0700007Oooo`005_oooa0co`0;06Ko9c?o000306Ko<ol0<ol0044co`000`0003?o
03?o001T<ol01P0001Ooool001Koool@06Ko<S?o000306Ko<ol0<ol0044co`000`0003?o03?o001Y
<ol06?ooo`005_oood8co`000`1Voc?o03?o0011<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Coool01Ol0VOooooooooooo`00000:oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
02Coool00ol0VOooooooo`0<oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21
oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000
oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001H
oooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0
003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o
09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool0
0`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Wooooo
ool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`0^oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo02goool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0;Ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00F?ooo`03o`2Ioooooooo
02goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`0]oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`0^oooo0P0000[oool300001?ooo`030000oooooooo087oool005Soool0
0ol0VOooooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POoo
o`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Ooo
o`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21
oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000
oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001H
oooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`0ioooo1@00
00?oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0>oooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001Hoooo00?o09Woooooool0>oooo`030000oooooooo00?oool30000POoo
o`00F?ooo`03o`2Ioooooooo03_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00F?oo
o`03o`2Ioooooooo03_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo03[oool200001Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo0P00
08;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo
047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003ooooo
ool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Wooooo
ool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo0P0008;oool005Soool0
0ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?oo
ooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?oo
o`03o`2Ioooooooo02goool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001H
oooo00?o09Woooooool0;oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Hoooo00?o09Woooooool0;oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400000oooo`800004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002Oooo`030000oooooooo00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`800003oooo00<0
003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.27731 .38627 L
.28025 .38627 L
.2817 .38627 L
.28302 .38627 L
s
.28302 .38627 m
.2832 .61803 L
s
0 .4 1 r
.02381 .37835 m
.06244 .37682 L
.10458 .37484 L
.14415 .37267 L
.18221 .37027 L
.22272 .36739 L
.26171 .36436 L
.27193 .36354 L
.27731 .3631 L
.28025 .36286 L
.2817 .36275 L
.28302 .36264 L
.28425 .38627 L
.28542 .38627 L
.288 .38627 L
.29349 .38627 L
.30316 .38627 L
.34135 .38627 L
.38199 .38627 L
.42112 .38627 L
.46271 .38627 L
.50277 .38627 L
.54132 .38627 L
.58233 .38627 L
.62181 .38627 L
.65979 .38627 L
.70021 .38627 L
.73912 .38627 L
.78048 .38627 L
.82032 .38627 L
.85865 .38627 L
.89944 .38627 L
.9387 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000J<ol02P1Voa0co`020000<C?o00030000<ol0<ol0038co`02
00007c?o00D0000@oooo0P0001Ooool001Woool500009S?o00/0I_l9<ol000<0I_lco`0co`00@C?o
00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000Q<ol02P1Voa@co`000`1Voc?o03?o0011
<ol00P0005hco`0700007Oooo`005_oooa0co`0D06Ko7S?o000306Ko<ol0<ol0044co`000`0003?o
03?o001T<ol01P0001Ooool001Koool@06Ko<S?o000306Ko<ol0<ol0044co`000`0003?o03?o001Y
<ol06?ooo`005_oood8co`000`1Voc?o03?o0011<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Coool01Ol0VOooooooooooo`00000:oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
02Coool00ol0VOooooooo`0<oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21
oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000
oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001H
oooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0
003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o
09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool0
0`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Wooooo
ool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`0^oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo02goool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0;Ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00F?ooo`03o`2Ioooooooo
02goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`0]oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`0^oooo0P0000[oool300001?ooo`030000oooooooo087oool005Soool0
0ol0VOooooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POoo
o`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Ooo
o`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21
oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001Hoooo00?o09Woooooool0@Oooo`030000
oooooooo087oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`800022oooo001H
oooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`0ioooo1@00
00?oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0>oooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001Hoooo00?o09Woooooool0>oooo`030000oooooooo00?oool30000POoo
o`00F?ooo`03o`2Ioooooooo03_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00F?oo
o`03o`2Ioooooooo03_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00F?ooo`03o`2I
oooooooo03[oool200001Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo0P00
08;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo
047oool00`000?ooooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool0
05Soool00ol0VOooooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003ooooo
ool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?ooooooo`21oooo001Hoooo00?o09Wooooo
ool0@Oooo`030000oooooooo087oool005Soool00ol0VOooooooo`11oooo0P0008;oool005Soool0
0ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?ooo`03o`2Ioooooooo047oool00`000?oo
ooooo`21oooo001Hoooo00?o09Woooooool0@Oooo`030000oooooooo087oool005Soool00ol0VOoo
ooooo`11oooo0P0008;oool005Soool00ol0VOooooooo`11oooo00<0003oooooool0POooo`00F?oo
o`03o`2Ioooooooo02goool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001H
oooo00?o09Woooooool0;oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Hoooo00?o09Woooooool0;oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400001?ooo`030000oooooooo00;oool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`050000oooooooooooo000007Ooool007Goool01@000?ooooooooooo`00000E
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800003oooo100000;oool0
0`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.27731 .38627 L
.28025 .38627 L
.28302 .38627 L
.28425 .38627 L
.28542 .38627 L
.28606 .38627 L
s
.28606 .38627 m
.28617 .61803 L
s
0 .4 1 r
.02381 .37865 m
.06244 .37718 L
.10458 .37528 L
.14415 .37318 L
.18221 .37087 L
.22272 .36811 L
.26171 .36519 L
.27193 .3644 L
.27731 .36398 L
.28025 .36375 L
.28302 .36353 L
.28425 .36344 L
.28542 .36335 L
.28606 .36329 L
.28676 .38627 L
.288 .38627 L
.29349 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000P<ol01@1Vo`lco`020000<C?o00030000<ol0<ol0038co`02
00007c?o00D0000@oooo0P0001Ooool001Woool500009S?o0140I_l4<ol000<0I_lco`0co`00@3?o
00030000<ol0<ol005Pco`0500009?ooo`005_ooo`<0000Q<ol02P1VoaDco`000`1Voc?o03?o0010
<ol00P0005hco`0700007Oooo`005_oooa0co`0D06Ko7c?o000306Ko<ol0<ol0040co`000`0003?o
03?o001T<ol01P0001Ooool001Koool@06Ko<c?o000306Ko<ol0<ol0040co`000`0003?o03?o001Y
<ol06?ooo`005_oood<co`000`1Voc?o03?o0010<ol000<0000co`0co`00JC?o01Soool0013ooooo
00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Goool01?l0VOooooooo`0000[oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003oooooool09Ooo
o`03o`2Ioooooooo00_oool00`000?ooooooo`0boooo00<0003oooooool0<oooo`030000oooooooo
03?oool00`000?ooooooo`0Eoooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool0
05Woool00ol0VOooooooo`10oooo0P0008;oool005Woool00ol0VOooooooo`10oooo00<0003ooooo
ool0POooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Wooooo
ool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo0P0008;oool005Woool0
0ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool00`000?oo
ooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOoo
ooooo`10oooo0P0008;oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOoo
o`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`030000
oooooooo087oool005Woool00ol0VOooooooo`10oooo0P0008;oool005Woool00ol0VOooooooo`10
oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo02goool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0;?ooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`0/oooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001Ioooo00?o09Woooooool0;?oo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo
02coool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00FOoo
o`03o`2Ioooooooo02goool200002_ooo`<00004oooo00<0003oooooool0POooo`00FOooo`03o`2I
oooooooo043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001I
oooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo0P00
08;oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo
043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool0
05Woool00ol0VOooooooo`10oooo0P0008;oool005Woool00ol0VOooooooo`10oooo00<0003ooooo
ool0POooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Wooooo
ool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo0P0008;oool005Woool0
0ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo03Soool500000ooo
o`030000oooooooo087oool005Woool00ol0VOooooooo`0joooo00<0003oooooool00oooo`030000
oooooooo087oool005Woool00ol0VOooooooo`0joooo00<0003oooooool00oooo`<00021oooo001I
oooo00?o09Woooooool0>_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0>_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Ioooo00?o09Wooooo
ool0>Oooo`800005oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_oo
o`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?oo
o`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOoo
o`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21
oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10
oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2I
oooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo
087oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo
043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0;?ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool005Woool0
0ol0VOooooooo`0^oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
087oool005Woool00ol0VOooooooo`0^oooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool0
0`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001f
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200000oooo`@00002oooo0`0000Coool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00003
oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00009oooo00<0003oooooool00_ooo`040000oooooooo00001?ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`040000oooooooo
oooo0`0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1e
oooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.27731 .38627 L
.28302 .38627 L
.28542 .38627 L
.28674 .38627 L
.288 .38627 L
s
.288 .38627 m
.2881 .61803 L
s
0 .4 1 r
.02381 .37895 m
.06244 .37753 L
.10458 .37571 L
.14415 .3737 L
.18221 .37148 L
.22272 .36882 L
.26171 .36602 L
.27193 .36526 L
.27731 .36486 L
.28302 .36443 L
.28542 .36425 L
.28674 .36415 L
.288 .36405 L
.28871 .38627 L
.28948 .38627 L
.29083 .38627 L
.29349 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000S<ol00P1Vo`lco`020000<C?o00030000<ol0<ol0038co`02
00007c?o00D0000@oooo0P0001Ooool001Woool50000<C?o00T0I_l00c?o001Voc?o0011<ol000<0
000co`0co`00F3?o00D0000Toooo000Foooo0`00024co`0E06Ko2S?o000306Ko<ol0<ol0040co`02
0000GS?o00L0000Moooo000Foooo43?o01@0I_lO<ol000<0I_lco`0co`00@3?o00030000<ol0<ol0
06@co`0600005oooo`005_oooa00I_lc<ol000<0I_lco`0co`00@3?o00030000<ol0<ol006Tco`0H
oooo000Foooo@c?o000306Ko<ol0<ol0040co`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01Ooo
o`04o`2Ioooooooo00002_ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0Uoooo00?o
09Woooooool02oooo`030000oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<ooo
o`030000oooooooo01Goool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOoo
o`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21
oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10
oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2I
oooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo
087oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo
043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo00<0003ooooo
ool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool0
0`000?ooooooo`21oooo001Ioooo00?o09Woooooool0;Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool005Woool00ol0VOooooooo`0/oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo02coool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool005Woool00ol0VOooooooo`0/oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0;?oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0;Oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001Ioooo00?o09Wooooo
ool0@?ooo`800022oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool0
0ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_oo
o`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?oo
o`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOoo
o`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21
oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10
oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool20000P_ooo`00FOooo`03o`2I
oooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0>?ooo`D00003oooo00<0
003oooooool0POooo`00FOooo`03o`2Ioooooooo03[oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00FOooo`03o`2Ioooooooo03[oool00`000?ooooooo`03oooo0`00087oool005Woool0
0ol0VOooooooo`0joooo00<0003oooooool00oooo`030000oooooooo087oool005Woool00ol0VOoo
ooooo`0joooo00<0003oooooool00oooo`030000oooooooo087oool005Woool00ol0VOooooooo`0i
oooo0P0000Goool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`800022oooo001I
oooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo00<0
003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0@?ooo`800022oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool0
05Woool00ol0VOooooooo`10oooo00<0003oooooool0POooo`00FOooo`03o`2Ioooooooo043oool0
0`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?ooo`800022oooo001Ioooo00?o09Wooooo
ool0@?ooo`030000oooooooo087oool005Woool00ol0VOooooooo`10oooo00<0003oooooool0POoo
o`00FOooo`03o`2Ioooooooo043oool00`000?ooooooo`21oooo001Ioooo00?o09Woooooool0@?oo
o`800022oooo001Ioooo00?o09Woooooool0@?ooo`030000oooooooo087oool005Woool00ol0VOoo
ooooo`0/oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00FOooo`03o`2I
oooooooo02koool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00FOooo`03o`2Ioooooooo02koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool0
0`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?oo
ooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800003oooo100000?oool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo07Coool0
07Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0M_oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.27731 .38627 L
.28302 .38627 L
.28542 .38627 L
.288 .38627 L
.28876 .38627 L
.28948 .38627 L
.29013 .38627 L
s
.29013 .38627 m
.29023 .61803 L
s
0 .4 1 r
.02381 .37925 m
.06244 .37789 L
.10458 .37614 L
.14415 .37421 L
.18221 .37208 L
.22272 .36953 L
.26171 .36685 L
.27193 .36612 L
.27731 .36573 L
.28302 .36532 L
.28542 .36514 L
.288 .36496 L
.28876 .3649 L
.28948 .36485 L
.29013 .3648 L
.29083 .38627 L
.2915 .38627 L
.29221 .38627 L
.29349 .38627 L
.30316 .38627 L
.34474 .38627 L
.3848 .38627 L
.42335 .38627 L
.46436 .38627 L
.50385 .38627 L
.54182 .38627 L
.58224 .38627 L
.62115 .38627 L
.66251 .38627 L
.70236 .38627 L
.74069 .38627 L
.78147 .38627 L
.82073 .38627 L
.85849 .38627 L
.89869 .38627 L
.93738 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@00034co`0<06Ko@C?o00030000<ol0<ol005Pco`0500009?oo
o`005_ooo`<0000Q<ol05@1Vo`/co`000`1Voc?o03?o000o<ol00P0005hco`0700007Oooo`005_oo
oa0co`0D06Ko83?o000306Ko<ol0<ol003lco`000`0003?o03?o001T<ol01P0001Ooool001Koool@
06Ko=3?o000306Ko<ol0<ol003lco`000`0003?o03?o001Y<ol06?ooo`005_oood@co`000`1Voc?o
03?o000o<ol000<0000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Koool00ol0VOooo`00000:oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool05Oooo`00<Oooo`030000oooooooo02Koool00ol0VOooooooo`0:oooo00<0003ooooo
ool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00F_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022
oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0o
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001J
oooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo
03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o
09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo00<0003ooooo
ool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Wooooo
ool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool0
0ol0VOooooooo`0/oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00F_oo
o`03o`2Ioooooooo02_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Joooo00?o09Woooooool0:oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000POooo`00F_ooo`03o`2Ioooooooo02_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0[oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo087oool005[oool00ol0VOooooooo`0/oooo0P0000[oool3
00001?ooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool0
0ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022
oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0o
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001J
oooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0goooo1@0000?oool00`000?ooooooo`21oooo001Joooo00?o
09Woooooool0>Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Joooo00?o09Wooooo
ool0>Oooo`030000oooooooo00?oool30000POooo`00F_ooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03Woool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03Soool200001Oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOooooooo`0ooooo00<0
003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o
09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool0
05[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool0
0ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POoo
o`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOoo
ooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo02_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0;Oooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0;Ooo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08
oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:
oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?oo
ooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool400001?ooo`<00002oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008
oooo00<0003oooooool01_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`030000oooooooo00;oool500000ooo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001eoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooo0000
00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Goool2
00000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.27731 .38627 L
.28302 .38627 L
.288 .38627 L
.28936 .38627 L
.29083 .38627 L
.29154 .38627 L
.29222 .38627 L
s
.29222 .38627 m
.29241 .61803 L
s
0 .4 1 r
.02381 .37955 m
.06244 .37825 L
.10458 .37657 L
.14415 .37472 L
.18221 .37268 L
.22272 .37024 L
.26171 .36767 L
.27193 .36697 L
.27731 .3666 L
.28302 .36621 L
.288 .36586 L
.28936 .36577 L
.29083 .36566 L
.29154 .36562 L
.29222 .36557 L
.29349 .38627 L
.29465 .38627 L
.29588 .38627 L
.29811 .38627 L
.30316 .38627 L
.34474 .38627 L
.3848 .38627 L
.42335 .38627 L
.46436 .38627 L
.50385 .38627 L
.54182 .38627 L
.58224 .38627 L
.62115 .38627 L
.66251 .38627 L
.70236 .38627 L
.74069 .38627 L
.78147 .38627 L
.82073 .38627 L
.85849 .38627 L
.89869 .38627 L
.93738 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@00034co`0<06Ko@C?o00030000<ol0<ol005Pco`0500009?oo
o`005_ooo`<0000[<ol02`1Vo`/co`000`1Voc?o03?o000o<ol00P0005hco`0700007Oooo`005_oo
oa/co`0C06Ko5S?o000306Ko<ol0<ol003lco`000`0003?o03?o001T<ol01P0001Ooool001KooolK
06Ko:S?o000306Ko<ol0<ol003hco`000`0003?o03?o001Y<ol06?ooo`005_ooodDco`000`1Voc?o
03?o000n<ol000<0000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Koool00ol0VOooo`00000:oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool05Oooo`00<Oooo`030000oooooooo02Koool00ol0VOooooooo`0:oooo00<0003ooooo
ool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00F_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022
oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0o
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001J
oooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo
03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o
09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo00<0003ooooo
ool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Wooooo
ool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool0
0ol0VOooooooo`0/oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00F_oo
o`03o`2Ioooooooo02_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Joooo00?o09Woooooool0:oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000POooo`00F_ooo`03o`2Ioooooooo02_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0[oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo087oool005[oool00ol0VOooooooo`0/oooo0P0000[oool3
00001?ooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool0
0ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`800022
oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0o
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001J
oooo00?o09Woooooool0?oooo`800022oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0goooo1@0000?oool00`000?ooooooo`21oooo001Joooo00?o
09Woooooool0>Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Joooo00?o09Wooooo
ool0>Oooo`030000oooooooo00?oool30000POooo`00F_ooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03Woool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03Soool200001Oooo`030000oooooooo
087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOooooooo`0ooooo00<0
003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o
09Woooooool0?oooo`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool0
05[oool00ol0VOooooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`21oooo001Joooo00?o09Woooooool0?oooo`030000oooooooo087oool005[oool0
0ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOooooooo`0ooooo00<0003oooooool0POoo
o`00F_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0?ooo
o`030000oooooooo087oool005[oool00ol0VOooooooo`0ooooo0P0008;oool005[oool00ol0VOoo
ooooo`0ooooo00<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo02_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0;Oooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Joooo00?o09Woooooool0;Ooo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08
oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:
oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?oo
ooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool400000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000B
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`050000oooooooooooo000007Ooool0
07Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool2
00002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.28302 .38627 L
.2881 .38627 L
.29088 .38627 L
.29224 .38627 L
.29349 .38627 L
.29462 .38627 L
s
.29462 .38627 m
.29479 .61803 L
s
0 .4 1 r
.02381 .37984 m
.06244 .3786 L
.10458 .377 L
.14415 .37523 L
.18221 .37328 L
.22272 .37095 L
.26171 .36849 L
.27193 .36782 L
.28302 .36709 L
.2881 .36676 L
.29088 .36657 L
.29224 .36648 L
.29349 .3664 L
.29462 .36632 L
.2957 .38627 L
.29684 .38627 L
.29809 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@00034co`0=06Ko@3?o00030000<ol0<ol005Pco`0500009?oo
o`005_ooo`<0000[<ol02`1Vo``co`000`1Voc?o03?o000n<ol00P0005hco`0700007Oooo`005_oo
oa/co`0C06Ko5c?o000306Ko<ol0<ol003hco`000`0003?o03?o001T<ol01P0001Ooool001KooolK
06Ko:S?o000306Ko<ol0<ol003hco`000`0003?o03?o001Y<ol06?ooo`005_ooodDco`000`1Voc?o
03?o000n<ol000<0000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00ol0V@000?ooo`09oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool05Oooo`00<Oooo`030000oooooooo02Ooool00ol0VOooooooo`09oooo00<0003ooooo
ool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00Fooo
o`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022
oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0n
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001K
oooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo
03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o
09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo00<0003ooooo
ool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Wooooo
ool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool0
0ol0VOooooooo`0[oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Fooo
o`03o`2Ioooooooo02[oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Koooo00?o09Woooooool0:_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000POooo`00Foooo`03o`2Ioooooooo02[oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0Zoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0[oooo0P0000[oool3
00001?ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool0
0ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?oo
ooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_oo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Fooo
o`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022
oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0n
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001K
oooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0foooo1@0000?oool00`000?ooooooo`21oooo001Koooo00?o
09Woooooool0>?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Koooo00?o09Wooooo
ool0>?ooo`030000oooooooo00?oool30000POooo`00Foooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03Soool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03Ooool200001Oooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOooooooo`0noooo00<0
003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o
09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool0
05_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool0
0`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool0
0ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POoo
o`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_oo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOoo
ooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo02[oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0;?ooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0;?oo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08
oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:
oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?oo
ooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool400000_ooo`@00003oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001foooo00<0003ooooo
ool05oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Koool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.28302 .38627 L
.2881 .38627 L
.29088 .38627 L
.29349 .38627 L
.29462 .38627 L
.2957 .38627 L
s
.2957 .38627 m
.29589 .61803 L
s
0 .4 1 r
.02381 .38014 m
.06244 .37895 L
.10458 .37743 L
.14415 .37574 L
.18221 .37388 L
.22272 .37166 L
.26171 .36931 L
.27193 .36868 L
.28302 .36798 L
.2881 .36766 L
.29088 .36748 L
.29349 .36732 L
.29462 .36724 L
.2957 .36718 L
.29695 .38627 L
.29809 .38627 L
.30316 .38627 L
.34135 .38627 L
.38199 .38627 L
.42112 .38627 L
.46271 .38627 L
.50277 .38627 L
.54132 .38627 L
.58233 .38627 L
.62181 .38627 L
.65979 .38627 L
.70021 .38627 L
.73912 .38627 L
.78048 .38627 L
.82032 .38627 L
.85865 .38627 L
.89944 .38627 L
.9387 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0003Tco`0506Ko@3?o00030000<ol0<ol005Pco`0500009?oo
o`005_ooo`<0000[<ol04`1Vo`@co`000`1Voc?o03?o000n<ol00P0005hco`0700007Oooo`005_oo
oa/co`0C06Ko5c?o000306Ko<ol0<ol003hco`000`0003?o03?o001T<ol01P0001Ooool001KooolK
06Ko:S?o000306Ko<ol0<ol003hco`000`0003?o03?o001Y<ol06?ooo`005_ooodDco`000`1Voc?o
03?o000n<ol000<0000co`0co`00JC?o01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00ol0V@000?ooo`09oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool05Oooo`00<Oooo`030000oooooooo02Ooool00ol0VOooooooo`09oooo00<0003ooooo
ool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00Fooo
o`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022
oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0n
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001K
oooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo
03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o
09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo00<0003ooooo
ool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Wooooo
ool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool0
0ol0VOooooooo`0[oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Fooo
o`03o`2Ioooooooo02[oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001Koooo00?o09Woooooool0:_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000POooo`00Foooo`03o`2Ioooooooo02[oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0Zoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0[oooo0P0000[oool3
00001?ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool0
0ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?oo
ooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_oo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Fooo
o`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`800022
oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0n
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001K
oooo00?o09Woooooool0?_ooo`800022oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0foooo1@0000?oool00`000?ooooooo`21oooo001Koooo00?o
09Woooooool0>?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Koooo00?o09Wooooo
ool0>?ooo`030000oooooooo00?oool30000POooo`00Foooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03Soool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03Ooool200001Oooo`030000oooooooo
087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOooooooo`0noooo00<0
003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o
09Woooooool0?_ooo`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool0
05_oool00ol0VOooooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo03koool0
0`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_ooo`030000oooooooo087oool005_oool0
0ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOooooooo`0noooo00<0003oooooool0POoo
o`00Foooo`03o`2Ioooooooo03koool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0?_oo
o`030000oooooooo087oool005_oool00ol0VOooooooo`0noooo0P0008;oool005_oool00ol0VOoo
ooooo`0noooo00<0003oooooool0POooo`00Foooo`03o`2Ioooooooo02[oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0;?ooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Koooo00?o09Woooooool0;?oo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08
oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:
oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?oo
ooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool400000_ooo`D00002oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008
oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool00oooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo
01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.28302 .38627 L
.2881 .38627 L
.29349 .38627 L
.2957 .38627 L
.29693 .38627 L
.29809 .38627 L
.29874 .38627 L
s
.29874 .38627 m
.29885 .61803 L
s
0 .4 1 r
.02381 .38044 m
.06244 .37931 L
.10458 .37785 L
.14415 .37625 L
.18221 .37448 L
.22272 .37236 L
.26171 .37013 L
.27193 .36952 L
.28302 .36886 L
.2881 .36856 L
.29349 .36823 L
.2957 .3681 L
.29693 .36802 L
.29809 .36795 L
.29874 .36791 L
.29945 .38627 L
.3007 .38627 L
.30316 .38627 L
.3438 .38627 L
.38293 .38627 L
.42451 .38627 L
.46458 .38627 L
.50313 .38627 L
.54413 .38627 L
.58362 .38627 L
.62159 .38627 L
.66202 .38627 L
.70093 .38627 L
.74229 .38627 L
.78213 .38627 L
.82046 .38627 L
.86124 .38627 L
.90051 .38627 L
.93826 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0003dco`0206Ko?c?o00030000<ol0<ol005Pco`0500009?oo
o`005_ooo`<0000[<ol05`1Vo`03<ol006Ko<ol003hco`020000GS?o00L0000Moooo000Foooo6c?o
01<0I_lH<ol000<0I_lco`0co`00?C?o00030000<ol0<ol006@co`0600005oooo`005_ooo`Hco`0E
06Ko:c?o000306Ko<ol0<ol003dco`000`0003?o03?o001Y<ol06?ooo`005_ooo`H0I_m0<ol000<0
I_lco`0co`00?C?o00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool0037oool00`000?ooooooo`0Xoooo00?o09Woooooool02?ooo`030000
oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool0
05coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool2
0000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Wooooo
ool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POoo
o`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?oo
ooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOoo
ooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?oo
o`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000
oooooooo087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2I
oooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001L
oooo00?o09Woooooool0:_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
05coool00ol0VOooooooo`0Yoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00G?ooo`03o`2Ioooooooo02Woool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool005coool00ol0VOooooooo`0Yoooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0:Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0:_ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`800022oooo001L
oooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0
003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo
03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool0
05coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool2
0000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Wooooo
ool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POoo
o`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?oo
ooooo`21oooo001Loooo00?o09Woooooool0=Oooo`D00003oooo00<0003oooooool0POooo`00G?oo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00G?ooo`03o`2I
oooooooo03Ooool00`000?ooooooo`03oooo0`00087oool005coool00ol0VOooooooo`0goooo00<0
003oooooool00oooo`030000oooooooo087oool005coool00ol0VOooooooo`0goooo00<0003ooooo
ool00oooo`030000oooooooo087oool005coool00ol0VOooooooo`0foooo0P0000Goool00`000?oo
ooooo`21oooo001Loooo00?o09Woooooool0?Oooo`800022oooo001Loooo00?o09Woooooool0?Ooo
o`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?oo
o`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`800022
oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0m
oooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001L
oooo00?o09Woooooool0?Oooo`800022oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo
087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo
03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`800022oooo001Loooo00?o
09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0Yoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo
02_oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800003oooo100000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P00
00[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.27193 .38627 L
.28302 .38627 L
.2881 .38627 L
.29349 .38627 L
.29809 .38627 L
.29935 .38627 L
.30004 .38627 L
.3007 .38627 L
s
.3007 .38627 m
.3009 .61803 L
s
0 .4 1 r
.02381 .38073 m
.06244 .37966 L
.10458 .37828 L
.14415 .37676 L
.18221 .37508 L
.22272 .37307 L
.26171 .37095 L
.27193 .37037 L
.28302 .36974 L
.2881 .36945 L
.29349 .36914 L
.29809 .36888 L
.29935 .36881 L
.30004 .36877 L
.3007 .36873 L
.30198 .38627 L
.30316 .38627 L
.34135 .38627 L
.38199 .38627 L
.42112 .38627 L
.46271 .38627 L
.50277 .38627 L
.54132 .38627 L
.58233 .38627 L
.62181 .38627 L
.65979 .38627 L
.70021 .38627 L
.73912 .38627 L
.78048 .38627 L
.82032 .38627 L
.85865 .38627 L
.89944 .38627 L
.9387 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000=S?o00h0I_lo<ol00P0005hco`0700007Oooo`005_ooob@co`0E06Ko3C?o000306Ko<ol0<ol0
03dco`000`0003?o03?o001T<ol01P0001Ooool001Koool6<ol07P1Vob8co`000`1Voc?o03?o000m
<ol000<0000co`0co`00JC?o01Soool001Koool606Ko@C?o000306Ko<ol0<ol003`co`000`0003?o
03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0:?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`0boooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Loooo00?o09Woooooool0?Ooo
o`030000oooooooo087oool005coool00ol0VOooooooo`0moooo0P0008;oool005coool00ol0VOoo
ooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21
oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0m
oooo0P0008;oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2I
oooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo
087oool005coool00ol0VOooooooo`0moooo0P0008;oool005coool00ol0VOooooooo`0moooo00<0
003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o
09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo0P0008;oool0
05coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo02[oool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0:Ooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool005coool0
0ol0VOooooooo`0Yoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001L
oooo00?o09Woooooool0:Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POoo
o`00G?ooo`03o`2Ioooooooo02Woool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0POooo`00G?ooo`03o`2Ioooooooo02[oool200002_ooo`<00004oooo00<0003ooooo
ool0POooo`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool0
0`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool0
0ol0VOooooooo`0moooo0P0008;oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POoo
o`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Ooo
o`030000oooooooo087oool005coool00ol0VOooooooo`0moooo0P0008;oool005coool00ol0VOoo
ooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21
oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0m
oooo0P0008;oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2I
oooooooo03Goool500000oooo`030000oooooooo087oool005coool00ol0VOooooooo`0goooo00<0
003oooooool00oooo`030000oooooooo087oool005coool00ol0VOooooooo`0goooo00<0003ooooo
ool00oooo`<00021oooo001Loooo00?o09Woooooool0=oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Loooo00?o09Woooooool0=oooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001Loooo00?o09Woooooool0=_ooo`800005oooo00<0003oooooool0POooo`00G?ooo`03o`2I
oooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001L
oooo00?o09Woooooool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0
003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo
03goool00`000?ooooooo`21oooo001Loooo00?o09Woooooool0?Oooo`030000oooooooo087oool0
05coool00ol0VOooooooo`0moooo00<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo03goool2
0000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?ooooooo`21oooo001Loooo00?o09Wooooo
ool0?Oooo`030000oooooooo087oool005coool00ol0VOooooooo`0moooo00<0003oooooool0POoo
o`00G?ooo`03o`2Ioooooooo03goool20000P_ooo`00G?ooo`03o`2Ioooooooo03goool00`000?oo
ooooo`21oooo001Loooo00?o09Woooooool0:Oooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo087oool005coool00ol0VOooooooo`0[oooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo087oool005coool00ol0VOooooooo`0[oooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_oo
o`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D000001?ooo`00
0000000000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?oo
ooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo00;oool300001?oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001eoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00001goooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.29779 .38627 L
.30059 .38627 L
.30182 .38627 L
.30246 .38627 L
.30316 .38627 L
s
.30316 .38627 m
.30335 .61803 L
s
0 .4 1 r
.02381 .38103 m
.06244 .38001 L
.10458 .3787 L
.14415 .37726 L
.18221 .37567 L
.22272 .37377 L
.26171 .37176 L
.28158 .3707 L
.29205 .37013 L
.29779 .36982 L
.30059 .36967 L
.30182 .36961 L
.30246 .36957 L
.30316 .36953 L
.30442 .38627 L
.3056 .38627 L
.30791 .38627 L
.31304 .38627 L
.32392 .38627 L
.34309 .38627 L
.38467 .38627 L
.42473 .38627 L
.46328 .38627 L
.50429 .38627 L
.54378 .38627 L
.58175 .38627 L
.62217 .38627 L
.66108 .38627 L
.70244 .38627 L
.74229 .38627 L
.78062 .38627 L
.8214 .38627 L
.86066 .38627 L
.89841 .38627 L
.93862 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000=S?o00l0I_ln<ol00P0005hco`0700007Oooo`005_ooob@co`0E06Ko3S?o000306Ko<ol0<ol0
03`co`000`0003?o03?o001T<ol01P0001Ooool001Koool6<ol07P1Vob<co`000`1Voc?o03?o000l
<ol000<0000co`0co`00JC?o01Soool001Koool606Ko@C?o000306Ko<ol0<ol003`co`000`0003?o
03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000o`2Ioooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0boooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Moooo00?o09Woooooool0??oo
o`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOoo
ooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0l
oooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo
087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o
09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool0
05goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo02Woool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0:?oo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool005goool0
0ol0VOooooooo`0Xoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001M
oooo00?o09Woooooool0:?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo02Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo02Woool200002_ooo`<00004oooo00<0003ooooo
ool0POooo`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool0
0`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool0
0ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??oo
o`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOoo
ooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0l
oooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03Coool500000oooo`030000oooooooo087oool005goool00ol0VOooooooo`0foooo00<0
003oooooool00oooo`030000oooooooo087oool005goool00ol0VOooooooo`0foooo00<0003ooooo
ool00oooo`<00021oooo001Moooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Moooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0=Oooo`800005oooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001M
oooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo
03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool0
05goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool2
0000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Wooooo
ool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?oo
ooooo`21oooo001Moooo00?o09Woooooool0:?ooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo087oool005goool00ol0VOooooooo`0Zoooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo087oool005goool00ol0VOooooooo`0Zoooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_oo
o`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D00002oooo0P00
00Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00001goooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool200000ooo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.29779 .38627 L
.30059 .38627 L
.30182 .38627 L
.30316 .38627 L
.30442 .38627 L
s
.30442 .38627 m
.3046 .61803 L
s
0 .4 1 r
.02381 .38132 m
.06244 .38036 L
.10458 .37913 L
.14415 .37777 L
.18221 .37627 L
.22272 .37447 L
.26171 .37258 L
.28158 .37157 L
.29205 .37104 L
.29779 .37075 L
.30059 .3706 L
.30182 .37054 L
.30316 .37047 L
.30442 .37041 L
.3056 .38627 L
.30672 .38627 L
.30791 .38627 L
.31304 .38627 L
.32392 .38627 L
.34309 .38627 L
.38467 .38627 L
.42473 .38627 L
.46328 .38627 L
.50429 .38627 L
.54378 .38627 L
.58175 .38627 L
.62217 .38627 L
.66108 .38627 L
.70244 .38627 L
.74229 .38627 L
.78062 .38627 L
.8214 .38627 L
.86066 .38627 L
.89841 .38627 L
.93862 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000?C?o00P0I_ln<ol00P0005hco`0700007Oooo`005_ooob@co`0L06Ko1c?o000306Ko<ol0<ol0
03`co`000`0003?o03?o001T<ol01P0001Ooool001Koool@<ol0501Vob<co`000`1Voc?o03?o000l
<ol000<0000co`0co`00JC?o01Soool001Koool@06Ko>3?o000306Ko<ol0<ol003/co`000`0003?o
03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000o`2Ioooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0boooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Moooo00?o09Woooooool0??oo
o`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOoo
ooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0l
oooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo
087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o
09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool0
05goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo02Woool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0:?oo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool005goool0
0ol0VOooooooo`0Xoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001M
oooo00?o09Woooooool0:?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo02Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo02Woool200002_ooo`<00004oooo00<0003ooooo
ool0POooo`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool0
0`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool0
0ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??oo
o`030000oooooooo087oool005goool00ol0VOooooooo`0loooo0P0008;oool005goool00ol0VOoo
ooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0l
oooo0P0008;oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03Coool500000oooo`030000oooooooo087oool005goool00ol0VOooooooo`0foooo00<0
003oooooool00oooo`030000oooooooo087oool005goool00ol0VOooooooo`0foooo00<0003ooooo
ool00oooo`<00021oooo001Moooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Moooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001Moooo00?o09Woooooool0=Oooo`800005oooo00<0003oooooool0POooo`00GOooo`03o`2I
oooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001M
oooo00?o09Woooooool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo00<0
003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo
03coool00`000?ooooooo`21oooo001Moooo00?o09Woooooool0??ooo`030000oooooooo087oool0
05goool00ol0VOooooooo`0loooo00<0003oooooool0POooo`00GOooo`03o`2Ioooooooo03coool2
0000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?ooooooo`21oooo001Moooo00?o09Wooooo
ool0??ooo`030000oooooooo087oool005goool00ol0VOooooooo`0loooo00<0003oooooool0POoo
o`00GOooo`03o`2Ioooooooo03coool20000P_ooo`00GOooo`03o`2Ioooooooo03coool00`000?oo
ooooo`21oooo001Moooo00?o09Woooooool0:?ooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo087oool005goool00ol0VOooooooo`0Zoooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo087oool005goool00ol0VOooooooo`0Zoooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_oo
o`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D00003oooo00<0
003oooooool00_ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00D0003oooooooooool00000Moooo`00MOooo`050000
oooooooooooo000001Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000Moooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800003oooo1000
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.29779 .38627 L
.30059 .38627 L
.30316 .38627 L
.30432 .38627 L
.3056 .38627 L
.3068 .38627 L
s
.3068 .38627 m
.30697 .61803 L
s
0 .4 1 r
.02381 .38161 m
.06244 .38071 L
.10458 .37955 L
.14415 .37827 L
.18221 .37686 L
.22272 .37517 L
.26171 .37339 L
.28158 .37244 L
.29205 .37194 L
.29779 .37167 L
.30059 .37153 L
.30316 .37141 L
.30432 .37135 L
.3056 .37129 L
.3068 .37124 L
.30791 .38627 L
.30921 .38627 L
.31039 .38627 L
.31304 .38627 L
.32392 .38627 L
.34309 .38627 L
.38315 .38627 L
.4217 .38627 L
.46271 .38627 L
.50219 .38627 L
.54016 .38627 L
.58059 .38627 L
.6195 .38627 L
.66086 .38627 L
.7007 .38627 L
.73903 .38627 L
.77982 .38627 L
.81908 .38627 L
.85683 .38627 L
.89704 .38627 L
.93572 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000?C?o00T0I_lm<ol00P0005hco`0700007Oooo`005_ooobhco`0B06Ko23?o000306Ko<ol0<ol0
03/co`000`0003?o03?o001T<ol01P0001Ooool001Koool@<ol07P1VoaXco`000`1Voc?o03?o000k
<ol000<0000co`0co`00JC?o01Soool001Koool@06Ko>3?o000306Ko<ol0<ol003/co`000`0003?o
03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000ooooo`2I00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`0boooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Noooo00?o09Woooooool0>ooo
o`030000oooooooo087oool005koool00ol0VOooooooo`0koooo0P0008;oool005koool00ol0VOoo
ooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21
oooo001Noooo00?o09Woooooool0>oooo`030000oooooooo087oool005koool00ol0VOooooooo`0k
oooo0P0008;oool005koool00ol0VOooooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2I
oooooooo03_oool00`000?ooooooo`21oooo001Noooo00?o09Woooooool0>oooo`030000oooooooo
087oool005koool00ol0VOooooooo`0koooo0P0008;oool005koool00ol0VOooooooo`0koooo00<0
003oooooool0POooo`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21oooo001Noooo00?o
09Woooooool0>oooo`030000oooooooo087oool005koool00ol0VOooooooo`0koooo0P0008;oool0
05koool00ol0VOooooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2Ioooooooo02Soool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Noooo00?o09Woooooool09ooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool005koool0
0ol0VOooooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001N
oooo00?o09Woooooool09oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POoo
o`00G_ooo`03o`2Ioooooooo02Ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0POooo`00G_ooo`03o`2Ioooooooo02Soool200002_ooo`<00004oooo00<0003ooooo
ool0POooo`00G_ooo`03o`2Ioooooooo03_oool20000P_ooo`00G_ooo`03o`2Ioooooooo03_oool0
0`000?ooooooo`21oooo001Noooo00?o09Woooooool0>oooo`030000oooooooo087oool005koool0
0ol0VOooooooo`0koooo0P0008;oool005koool00ol0VOooooooo`0koooo00<0003oooooool0POoo
o`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21oooo001Noooo00?o09Woooooool0>ooo
o`030000oooooooo087oool005koool00ol0VOooooooo`0koooo0P0008;oool005koool00ol0VOoo
ooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21
oooo001Noooo00?o09Woooooool0>oooo`030000oooooooo087oool005koool00ol0VOooooooo`0k
oooo0P0008;oool005koool00ol0VOooooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2I
oooooooo03?oool500000oooo`030000oooooooo087oool005koool00ol0VOooooooo`0eoooo00<0
003oooooool00oooo`030000oooooooo087oool005koool00ol0VOooooooo`0eoooo00<0003ooooo
ool00oooo`<00021oooo001Noooo00?o09Woooooool0=Oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Noooo00?o09Woooooool0=Oooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001Noooo00?o09Woooooool0=?ooo`800005oooo00<0003oooooool0POooo`00G_ooo`03o`2I
oooooooo03_oool20000P_ooo`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21oooo001N
oooo00?o09Woooooool0>oooo`030000oooooooo087oool005koool00ol0VOooooooo`0koooo00<0
003oooooool0POooo`00G_ooo`03o`2Ioooooooo03_oool20000P_ooo`00G_ooo`03o`2Ioooooooo
03_oool00`000?ooooooo`21oooo001Noooo00?o09Woooooool0>oooo`030000oooooooo087oool0
05koool00ol0VOooooooo`0koooo00<0003oooooool0POooo`00G_ooo`03o`2Ioooooooo03_oool2
0000P_ooo`00G_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`21oooo001Noooo00?o09Wooooo
ool0>oooo`030000oooooooo087oool005koool00ol0VOooooooo`0koooo00<0003oooooool0POoo
o`00G_ooo`03o`2Ioooooooo03_oool20000P_ooo`00G_ooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`21oooo001Noooo00?o09Woooooool09oooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo087oool005koool00ol0VOooooooo`0Yoooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo087oool005koool00ol0VOooooooo`0Yoooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_oo
o`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D000001?ooo`00
0000000000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool010000?ooooooooooo`<00004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000001Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?oo
o`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.29779 .38627 L
.30316 .38627 L
.3056 .38627 L
.30791 .38627 L
.30919 .38627 L
s
.30919 .38627 m
.3093 .61803 L
s
0 .4 1 r
.02381 .38191 m
.06244 .38106 L
.10458 .37998 L
.14415 .37878 L
.18221 .37745 L
.22272 .37587 L
.26171 .3742 L
.28158 .37332 L
.29205 .37284 L
.29779 .37259 L
.30316 .37235 L
.3056 .37224 L
.30791 .37213 L
.30919 .37207 L
.30992 .38627 L
.31059 .38627 L
.31304 .38627 L
.32392 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000A3?o00<0I_ll<ol00P0005hco`0700007Oooo`005_ooobhco`0I06Ko0S?o000306Ko<ol0<ol0
03Xco`000`0003?o03?o001T<ol01P0001Ooool001Koool@<ol07P1Voa/co`000`1Voc?o03?o000j
<ol000<0000co`0co`00JC?o01Soool001Koool@06Ko>C?o000306Ko<ol0<ol003Xco`000`0003?o
03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`040000ooooooooo`2I1oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0
037oool00`000?ooooooo`0[oooo00?o09Woooooool01Oooo`030000oooooooo03;oool00`000?oo
ooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool005ooool00ol0VOooooooo`0j
oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2I
oooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo
087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo
03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003ooooo
ool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool0
0ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_oo
o`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool09ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool005ooool00ol0VOooooooo`0V
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Gooo
o`03o`2Ioooooooo02Koool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool0
05ooool00ol0VOooooooo`0Voooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21
oooo001Ooooo00?o09Woooooool09_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`21oooo001Ooooo00?o09Woooooool09oooo`80000:oooo0`0000Coool00`000?oo
ooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`800022oooo001Ooooo00?o09Woooooool0>_oo
o`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Gooo
o`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21
oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0j
oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2I
oooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo
087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo
03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0<_ooo`D00003oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03Coool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03Coool00`000?oo
ooooo`03oooo0`00087oool005ooool00ol0VOooooooo`0doooo00<0003oooooool00oooo`030000
oooooooo087oool005ooool00ol0VOooooooo`0doooo00<0003oooooool00oooo`030000oooooooo
087oool005ooool00ol0VOooooooo`0coooo0P0000Goool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0>_ooo`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool0
05ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`800022oooo001Ooooo00?o09Wooooo
ool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POoo
o`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_oo
o`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOoo
ooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21
oooo001Ooooo00?o09Woooooool0>_ooo`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000
oooooooo087oool005ooool00ol0VOooooooo`0Voooo1@0000;oool200001?ooo`800005oooo00<0
003oooooool0POooo`00Goooo`03o`2Ioooooooo02Soool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo02Soool00`000?ooooooo`0:
oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:
oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003o
oooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOoo
o`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@0000;oool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.29779 .38627 L
.30316 .38627 L
.30791 .38627 L
.30929 .38627 L
.31059 .38627 L
s
.31059 .38627 m
.31076 .61803 L
s
0 .4 1 r
.02381 .3822 m
.06244 .38141 L
.10458 .3804 L
.14415 .37928 L
.18221 .37805 L
.22272 .37657 L
.26171 .37501 L
.28158 .37419 L
.29205 .37375 L
.29779 .37351 L
.30316 .37328 L
.30791 .37308 L
.30929 .37302 L
.31059 .37297 L
.31176 .38627 L
.31304 .38627 L
.32392 .38627 L
.34309 .38627 L
.38373 .38627 L
.42286 .38627 L
.46444 .38627 L
.50451 .38627 L
.54306 .38627 L
.58406 .38627 L
.62355 .38627 L
.66152 .38627 L
.70195 .38627 L
.74085 .38627 L
.78222 .38627 L
.82206 .38627 L
.86039 .38627 L
.90117 .38627 L
.94044 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Koooli<ol04@1Voc`co`000`0003?o03?o001T<ol01P00
01Ooool001KooolK<ol07P1Voa0co`000`1Voc?o03?o000j<ol000<0000co`0co`00JC?o01Soool0
01KooolK06Ko;S?o000306Ko<ol0<ol003Xco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`040000ooooooooo`2I1oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0[oooo00?o
09Woooooool01Oooo`030000oooooooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<ooo
o`030000oooooooo01Goool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Gooo
o`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21
oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0j
oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2I
oooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo
087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo
03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003ooooo
ool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`21oooo001Ooooo00?o09Woooooool09oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool005ooool00ol0VOooooooo`0Voooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo02Koool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool005ooool00ol0VOooooooo`0Voooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool09_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool09oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001Ooooo00?o09Wooooo
ool0>_ooo`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool0
0ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_oo
o`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_oo
o`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Gooo
o`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21
oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0j
oooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool20000P_ooo`00Goooo`03o`2I
oooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0<_ooo`D00003oooo00<0
003oooooool0POooo`00Goooo`03o`2Ioooooooo03Coool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00Goooo`03o`2Ioooooooo03Coool00`000?ooooooo`03oooo0`00087oool005ooool0
0ol0VOooooooo`0doooo00<0003oooooool00oooo`030000oooooooo087oool005ooool00ol0VOoo
ooooo`0doooo00<0003oooooool00oooo`030000oooooooo087oool005ooool00ol0VOooooooo`0c
oooo0P0000Goool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`800022oooo001O
oooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0
003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0>_ooo`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool0
05ooool00ol0VOooooooo`0joooo00<0003oooooool0POooo`00Goooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_ooo`800022oooo001Ooooo00?o09Wooooo
ool0>_ooo`030000oooooooo087oool005ooool00ol0VOooooooo`0joooo00<0003oooooool0POoo
o`00Goooo`03o`2Ioooooooo03[oool00`000?ooooooo`21oooo001Ooooo00?o09Woooooool0>_oo
o`800022oooo001Ooooo00?o09Woooooool0>_ooo`030000oooooooo087oool005ooool00ol0VOoo
ooooo`0Voooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00Goooo`03o`2I
oooooooo02Soool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00Goooo`03o`2Ioooooooo02Soool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Koool0
0`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?oo
ooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800003oooo1@0000?oool300000_ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002_ooo`030000oooooooo00Coool01@000?ooooooooooo`00001g
oooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool0
10000?ooooooooooo`D00003oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000B
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
07Ooool007Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooo000000?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05ooo
o`80000:oooo0P0000Goool200000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.30316 .38627 L
.30791 .38627 L
.31054 .38627 L
.31183 .38627 L
.31304 .38627 L
.31371 .38627 L
s
.31371 .38627 m
.31382 .61803 L
s
0 .4 1 r
.02381 .38249 m
.06244 .38176 L
.10458 .38082 L
.14415 .37978 L
.18221 .37864 L
.22272 .37726 L
.26171 .37582 L
.28158 .37505 L
.29205 .37465 L
.30316 .37421 L
.30791 .37403 L
.31054 .37393 L
.31183 .37388 L
.31304 .37383 L
.31371 .3738 L
.31444 .38627 L
.31524 .38627 L
.31597 .38627 L
.31865 .38627 L
.32392 .38627 L
.34309 .38627 L
.38315 .38627 L
.4217 .38627 L
.46271 .38627 L
.50219 .38627 L
.54016 .38627 L
.58059 .38627 L
.6195 .38627 L
.66086 .38627 L
.7007 .38627 L
.73903 .38627 L
.77982 .38627 L
.81908 .38627 L
.85683 .38627 L
.89704 .38627 L
.93572 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Koooli<ol04P1Voc/co`000`0003?o03?o001T<ol01P00
01Ooool001KooolK<ol07P1Voa4co`000`1Voc?o03?o000i<ol000<0000co`0co`00JC?o01Soool0
01KooolK06Ko;c?o000306Ko<ol0<ol003Tco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`050000ooooooooooooo`2I00Koool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003oooooool0;?oo
o`03o`2Ioooooooo00Coool00`000?ooooooo`0boooo00<0003oooooool0<oooo`030000oooooooo
03?oool00`000?ooooooo`0Eoooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0
063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool0
0ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOoo
ooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000
oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0i
oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo02Koool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001Poooo00?o09Woooooool09Oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo087oool0063oool00ol0VOooooooo`0Uoooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001Poooo00?o09Woooooool09Ooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
02Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo02Koool200002_ooo`<00004oooo00<0003oooooool0POooo`00H?ooo`03o`2I
oooooooo03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001P
oooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P00
08;oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0
063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool0
0ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo037oool500000ooo
o`030000oooooooo087oool0063oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`030000
oooooooo087oool0063oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`<00021oooo001P
oooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Poooo00?o
09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0<_ooo`800005oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool20000P_oo
o`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Ooo
o`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21
oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0i
oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool20000P_ooo`00H?ooo`03o`2I
oooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo
087oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o
09Woooooool09Oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0063oool0
0ol0VOooooooo`0Woooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
087oool0063oool00ol0VOooooooo`0Woooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool0
0`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001f
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool0000:oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1doooo001e
oooo00<0003oooooool01@0001;oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00D0
003oooooooooool00000Moooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.30316 .38627 L
.30791 .38627 L
.31054 .38627 L
.31304 .38627 L
.31444 .38627 L
.31523 .38627 L
s
.31523 .38627 m
.31534 .61803 L
s
0 .4 1 r
.02381 .38278 m
.06244 .38211 L
.10458 .38124 L
.14415 .38028 L
.18221 .37923 L
.22272 .37796 L
.26171 .37663 L
.28158 .37592 L
.29205 .37554 L
.30316 .37515 L
.30791 .37498 L
.31054 .37488 L
.31304 .37479 L
.31444 .37474 L
.31523 .37471 L
.31597 .38627 L
.31727 .38627 L
.31865 .38627 L
.32392 .38627 L
.34309 .38627 L
.38467 .38627 L
.42473 .38627 L
.46328 .38627 L
.50429 .38627 L
.54378 .38627 L
.58175 .38627 L
.62217 .38627 L
.66108 .38627 L
.70244 .38627 L
.74229 .38627 L
.78062 .38627 L
.8214 .38627 L
.86066 .38627 L
.89841 .38627 L
.93862 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooom0<ol02`1Voc/co`000`0003?o03?o001T<ol01P00
01Ooool001KooolK<ol09@1Vo`Xco`000`1Voc?o03?o000i<ol000<0000co`0co`00JC?o01Soool0
01KooolK06Ko;c?o000306Ko<ol0<ol003Tco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`050000ooooooooooooo`2I00Koool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003oooooool0;?oo
o`03o`2Ioooooooo00Coool00`000?ooooooo`0boooo00<0003oooooool0<oooo`030000oooooooo
03?oool00`000?ooooooo`0Eoooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0
063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool0
0ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOoo
ooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000
oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0i
oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo02Koool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001Poooo00?o09Woooooool09Oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo087oool0063oool00ol0VOooooooo`0Uoooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001Poooo00?o09Woooooool09Ooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
02Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo02Koool200002_ooo`<00004oooo00<0003oooooool0POooo`00H?ooo`03o`2I
oooooooo03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001P
oooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P00
08;oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0
063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0POooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo0P0008;oool0063oool0
0ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo037oool500000ooo
o`030000oooooooo087oool0063oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`030000
oooooooo087oool0063oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`<00021oooo001P
oooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Poooo00?o
09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Poooo00?o09Wooooo
ool0<_ooo`800005oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool20000P_oo
o`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Ooo
o`030000oooooooo087oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?oo
o`03o`2Ioooooooo03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21
oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo087oool0063oool00ol0VOooooooo`0i
oooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo03Woool20000P_ooo`00H?ooo`03o`2I
oooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o09Woooooool0>Oooo`030000oooooooo
087oool0063oool00ol0VOooooooo`0ioooo00<0003oooooool0POooo`00H?ooo`03o`2Ioooooooo
03Woool20000P_ooo`00H?ooo`03o`2Ioooooooo03Woool00`000?ooooooo`21oooo001Poooo00?o
09Woooooool09Oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0063oool0
0ol0VOooooooo`0Woooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
087oool0063oool00ol0VOooooooo`0Woooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool0
0`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001f
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200000oooo`D000000oooo`000000000200000oooo`030000
oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000oooo`040000oooooooo00002_ooo`050000oooooooooooo000000Koool0
0`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo07Coool0
07Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00?oool0
0`000?ooooooo`02oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Mooo
o`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.30316 .38627 L
.30791 .38627 L
.31304 .38627 L
.31454 .38627 L
.31597 .38627 L
.31725 .38627 L
.31798 .38627 L
s
.31798 .38627 m
.31808 .61803 L
s
0 .4 1 r
.02381 .38308 m
.06244 .38246 L
.10458 .38166 L
.14415 .38078 L
.18221 .37982 L
.22272 .37866 L
.26171 .37744 L
.28158 .37679 L
.29205 .37644 L
.30316 .37608 L
.30791 .37592 L
.31304 .37575 L
.31454 .3757 L
.31597 .37566 L
.31725 .37562 L
.31798 .37559 L
.31865 .38627 L
.31934 .38627 L
.31999 .38627 L
.3212 .38627 L
.32392 .38627 L
.34309 .38627 L
.38164 .38627 L
.42264 .38627 L
.46213 .38627 L
.5001 .38627 L
.54052 .38627 L
.57943 .38627 L
.62079 .38627 L
.66064 .38627 L
.69897 .38627 L
.73975 .38627 L
.77902 .38627 L
.81677 .38627 L
.85697 .38627 L
.89566 .38627 L
.9368 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooom6<ol01P1VocXco`000`0003?o03?o001T<ol01P00
01Ooool001KooolT<ol08P1Vo`Dco`000`1Voc?o03?o000h<ol000<0000co`0co`00JC?o01Soool0
01KooolT06Ko9c?o000306Ko<ol0<ol003Pco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000A
oooo000Aoooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00;oool00ol0VOooooooo`03oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000
oooooooo02goool00ol0VOooooooo`03oooo00<0003oooooool0<_ooo`030000oooooooo03?oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`00HOooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?oo
o`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOoo
o`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022
oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0h
oooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Q
oooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo
087oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo
03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o
09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0Uoooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo02Coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Qoooo00?o09Wooooo
ool09?ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00HOooo`03o`2I
oooooooo02Coool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool0067oool0
0ol0VOooooooo`0Toooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
087oool0067oool00ol0VOooooooo`0Uoooo0P0000[oool300001?ooo`030000oooooooo087oool0
067oool00ol0VOooooooo`0hoooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0003ooooo
ool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Wooooo
ool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool0
0ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?oo
o`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOoo
o`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022
oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0`
oooo1@0000?oool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0<_ooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0<_ooo`030000oooooooo00?oool3
0000POooo`00HOooo`03o`2Ioooooooo03;oool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00HOooo`03o`2Ioooooooo03;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00HOoo
o`03o`2Ioooooooo037oool200001Oooo`030000oooooooo087oool0067oool00ol0VOooooooo`0h
oooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2I
oooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo
087oool0067oool00ol0VOooooooo`0hoooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0
003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o
09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo0P0008;oool0
067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool0
0`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool0
0ol0VOooooooo`0hoooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POoo
o`00HOooo`03o`2Ioooooooo02Coool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21
oooo001Qoooo00?o09Woooooool09_ooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`21oooo001Qoooo00?o09Woooooool09_ooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?oo
ooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003o
oooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003ooooo
ool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool5000000?oool0000000000`00
00;oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`03
oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0
003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool0000:
oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0P0000?oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.30316 .38627 L
.31304 .38627 L
.31574 .38627 L
.31723 .38627 L
.31865 .38627 L
.31997 .38627 L
s
.31997 .38627 m
.32008 .61803 L
s
0 .4 1 r
.02381 .38337 m
.06244 .38281 L
.10458 .38208 L
.14415 .38128 L
.18221 .38041 L
.22272 .37935 L
.26171 .37824 L
.28158 .37765 L
.29205 .37734 L
.30316 .37701 L
.31304 .37671 L
.31574 .37663 L
.31723 .37659 L
.31865 .37655 L
.31997 .37651 L
.32071 .38627 L
.3214 .38627 L
.32392 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
oooo;S?o01h0I_lj<ol000<0000co`0co`00JC?o01Soool001Koool^06Ko7C?o000306Ko<ol0<ol0
03Pco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00;oool00ol0VOoo
ooooo`03oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo02goool00ol0VOooooooo`03
oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Wooooo
ool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool0
0ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?oo
o`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOoo
o`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022
oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0h
oooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Q
oooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo
087oool0067oool00ol0VOooooooo`0Uoooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00HOooo`03o`2Ioooooooo02Coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool09?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00HOooo`03o`2Ioooooooo02Coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool0067oool00ol0VOooooooo`0Toooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0U
oooo0P0000[oool300001?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo0P00
08;oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo
03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o
09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo00<0003ooooo
ool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Wooooo
ool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool0
0ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`800022oooo001Qoooo00?o09Woooooool0>?oo
o`030000oooooooo087oool0067oool00ol0VOooooooo`0`oooo1@0000?oool00`000?ooooooo`21
oooo001Qoooo00?o09Woooooool0<_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Q
oooo00?o09Woooooool0<_ooo`030000oooooooo00?oool30000POooo`00HOooo`03o`2Ioooooooo
03;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03;oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo037oool200001Ooo
o`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo0P0008;oool0067oool00ol0VOoo
ooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21
oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0h
oooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2I
oooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool0>?ooo`030000oooooooo
087oool0067oool00ol0VOooooooo`0hoooo0P0008;oool0067oool00ol0VOooooooo`0hoooo00<0
003oooooool0POooo`00HOooo`03o`2Ioooooooo03Soool00`000?ooooooo`21oooo001Qoooo00?o
09Woooooool0>?ooo`030000oooooooo087oool0067oool00ol0VOooooooo`0hoooo0P0008;oool0
067oool00ol0VOooooooo`0hoooo00<0003oooooool0POooo`00HOooo`03o`2Ioooooooo02Coool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Qoooo00?o09Woooooool09_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Qoooo00?o
09Woooooool09_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000?oool500000_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.29205 .38627 L
.30316 .38627 L
.31304 .38627 L
.31574 .38627 L
.31865 .38627 L
.32006 .38627 L
.32076 .38627 L
.3214 .38627 L
s
.3214 .38627 m
.32158 .61803 L
s
0 .4 1 r
.02381 .38366 m
.06244 .38315 L
.10458 .3825 L
.14415 .38179 L
.18221 .38099 L
.22272 .38004 L
.26171 .37905 L
.28158 .37852 L
.29205 .37823 L
.30316 .37794 L
.31304 .37767 L
.31574 .3776 L
.31865 .37752 L
.32006 .37748 L
.32076 .37747 L
.3214 .37745 L
.3226 .38627 L
.32392 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
oooo;S?o01l0I_li<ol000<0000co`0co`00JC?o01Soool001Koool^06Ko7S?o000306Ko<ol0<ol0
03Lco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00?oool00ol0VOoo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo02koool00ol0VOooooooo`02
oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Wooooo
ool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool0
0ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_oo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022
oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0g
oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001R
oooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo
087oool006;oool00ol0VOooooooo`0Toooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00H_ooo`03o`2Ioooooooo02?oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Roooo00?o09Woooooool08oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00H_ooo`03o`2Ioooooooo02?oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0Soooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006;oool00ol0VOooooooo`0T
oooo0P0000[oool300001?ooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P00
08;oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o
09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo00<0003ooooo
ool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Wooooo
ool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool0
0ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0_oooo1@0000?oool00`000?ooooooo`21
oooo001Roooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001R
oooo00?o09Woooooool0<Oooo`030000oooooooo00?oool30000POooo`00H_ooo`03o`2Ioooooooo
037oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo037oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo033oool200001Ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P0008;oool006;oool00ol0VOoo
ooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21
oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0g
oooo0P0008;oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2I
oooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo
087oool006;oool00ol0VOooooooo`0goooo0P0008;oool006;oool00ol0VOooooooo`0goooo00<0
003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o
09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P0008;oool0
06;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02?oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Roooo00?o09Woooooool09Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Roooo00?o
09Woooooool09Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo
02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo
07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`<00004oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo
00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001f
oooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.31875 .38627 L
.32145 .38627 L
.32263 .38627 L
.32392 .38627 L
s
.32392 .38627 m
.32409 .61803 L
s
0 .4 1 r
.02381 .38395 m
.06244 .3835 L
.10458 .38292 L
.14415 .38228 L
.18221 .38158 L
.22272 .38074 L
.26171 .37985 L
.28158 .37938 L
.30316 .37886 L
.31323 .37862 L
.31875 .37849 L
.32145 .37843 L
.32263 .3784 L
.32392 .37837 L
.32509 .38627 L
.32617 .38627 L
.32831 .38627 L
.33304 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
oooo>C?o01@0I_li<ol000<0000co`0co`00JC?o01Soool001Koooli06Ko4c?o000306Ko<ol0<ol0
03Lco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00?oool00ol0VOoo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo02koool00ol0VOooooooo`02
oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Wooooo
ool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool0
0ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_oo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022
oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0g
oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001R
oooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo
087oool006;oool00ol0VOooooooo`0Toooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00H_ooo`03o`2Ioooooooo02?oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Roooo00?o09Woooooool08oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00H_ooo`03o`2Ioooooooo02?oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0Soooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006;oool00ol0VOooooooo`0T
oooo0P0000[oool300001?ooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P00
08;oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o
09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo00<0003ooooo
ool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Wooooo
ool0=oooo`800022oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool0
0ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`21oooo001Roooo00?o09Woooooool0=oooo`800022oooo001Roooo00?o09Woooooool0=ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0_oooo1@0000?oool00`000?ooooooo`21
oooo001Roooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001R
oooo00?o09Woooooool0<Oooo`030000oooooooo00?oool30000POooo`00H_ooo`03o`2Ioooooooo
037oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo037oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo033oool200001Ooo
o`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P0008;oool006;oool00ol0VOoo
ooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21
oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0g
oooo0P0008;oool006;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2I
oooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o09Woooooool0=oooo`030000oooooooo
087oool006;oool00ol0VOooooooo`0goooo0P0008;oool006;oool00ol0VOooooooo`0goooo00<0
003oooooool0POooo`00H_ooo`03o`2Ioooooooo03Ooool00`000?ooooooo`21oooo001Roooo00?o
09Woooooool0=oooo`030000oooooooo087oool006;oool00ol0VOooooooo`0goooo0P0008;oool0
06;oool00ol0VOooooooo`0goooo00<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02?oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Roooo00?o09Woooooool09Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Roooo00?o
09Woooooool09Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo
02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0003oooooool0M?ooo`00MOoo
o`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P00
00Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0M_oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.31875 .38627 L
.32145 .38627 L
.32392 .38627 L
.32499 .38627 L
.32617 .38627 L
s
.32617 .38627 m
.32634 .61803 L
s
0 .4 1 r
.02381 .38424 m
.06244 .38385 L
.10458 .38334 L
.14415 .38278 L
.18221 .38217 L
.22272 .38143 L
.26171 .38065 L
.28158 .38024 L
.30316 .37979 L
.31323 .37958 L
.31875 .37947 L
.32145 .37941 L
.32392 .37936 L
.32499 .37934 L
.32617 .37932 L
.32728 .38627 L
.32831 .38627 L
.33304 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
oooo@3?o00h0I_lh<ol000<0000co`0co`00JC?o01Soool001Kooom006Ko3C?o000306Ko<ol0<ol0
03Hco`000`0003?o03?o001Y<ol06?ooo`004?ooool0000Aoooo000Aoooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Coool01Ol0VOoo
ooooooooo`000009oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Eoooo000aoooo00<0003oooooool0;oooo`05o`2Ioooooooooooo000003Coool0
0`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool006?oool00ol0VOoo
ooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool20000P_ooo`00Hooo
o`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`030000
oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2I
oooooooo03Koool20000P_ooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001S
oooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0
003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool20000P_ooo`00Hoooo`03o`2Ioooooooo
03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool0
06?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool2
0000P_ooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Wooooo
ool08oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool006?oool00ol0VOoo
ooooo`0Roooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00Hoooo`03o`2Ioooooooo02;oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
087oool006?oool00ol0VOooooooo`0Roooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`21oooo001Soooo00?o09Woooooool08_ooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`21oooo001Soooo00?o09Woooooool08oooo`80000:oooo0`0000Coool0
0`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o09Wooooo
ool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POoo
o`00Hoooo`03o`2Ioooooooo03Koool20000P_ooo`00Hoooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`21oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOoo
ooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool20000P_ooo`00Hooo
o`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`030000
oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2I
oooooooo03Koool20000P_ooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001S
oooo00?o09Woooooool0;_ooo`D00003oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo
033oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo033oool0
0`000?ooooooo`03oooo0`00087oool006?oool00ol0VOooooooo`0`oooo00<0003oooooool00ooo
o`030000oooooooo087oool006?oool00ol0VOooooooo`0`oooo00<0003oooooool00oooo`030000
oooooooo087oool006?oool00ol0VOooooooo`0_oooo0P0000Goool00`000?ooooooo`21oooo001S
oooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo
087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo
03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o
09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003ooooo
ool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Wooooo
ool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool0
0ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_oo
o`030000oooooooo087oool006?oool00ol0VOooooooo`0Roooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo02Coool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029
oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028
oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_oo
o`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOoo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo00?oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@00
01;oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool01@000?ooooooooooo`00001g
oooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0G
oooo0P0000[oool200000oooo`@00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.31875 .38627 L
.32392 .38627 L
.32617 .38627 L
.32728 .38627 L
.32831 .38627 L
s
.32831 .38627 m
.32849 .61803 L
s
0 .4 1 r
.02381 .38453 m
.06244 .38419 L
.10458 .38376 L
.14415 .38328 L
.18221 .38276 L
.22272 .38212 L
.26171 .38146 L
.28158 .38111 L
.30316 .38072 L
.31323 .38054 L
.31875 .38044 L
.32392 .38035 L
.32617 .38031 L
.32728 .38029 L
.32831 .38027 L
.32949 .38627 L
.33078 .38627 L
.33304 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooCC?o000306Ko<ol0<ol003Hco`000`0003?o03?o001Y<ol06?ooo`005_ooo`Hco`1806Ko>3?o
00030000<ol0<ol006Tco`0Hoooo000@ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01?ooo`05o`2Ioooooooo
oooo000000Woool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo01Goool0037oool00`000?ooooooo`0_oooo00Go09Woooooooooool00000=?ooo`030000
oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00Hoooo`03o`2Ioooooooo
03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o
09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003ooooo
ool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Wooooo
ool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool0
0ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_oo
o`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hooo
o`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022
oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0S
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo
02;oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001S
oooo00?o09Woooooool08_ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00Hoooo`03o`2Ioooooooo02;oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool006?oool00ol0VOooooooo`0Roooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool006?oool00ol0VOooooooo`0Soooo0P0000[oool300001?ooo`030000
oooooooo087oool006?oool00ol0VOooooooo`0foooo0P0008;oool006?oool00ol0VOooooooo`0f
oooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001S
oooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo
087oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo
03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`800022oooo001Soooo00?o
09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo00<0003ooooo
ool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Wooooo
ool0=_ooo`800022oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool0
0ol0VOooooooo`0^oooo1@0000?oool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0<?oo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0<?ooo`030000
oooooooo00?oool30000POooo`00Hoooo`03o`2Ioooooooo033oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00Hoooo`03o`2Ioooooooo033oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00Hoooo`03o`2Ioooooooo02ooool200001Oooo`030000oooooooo087oool006?oool0
0ol0VOooooooo`0foooo0P0008;oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POoo
o`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_oo
o`030000oooooooo087oool006?oool00ol0VOooooooo`0foooo0P0008;oool006?oool00ol0VOoo
ooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2Ioooooooo03Koool00`000?ooooooo`21
oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo087oool006?oool00ol0VOooooooo`0f
oooo0P0008;oool006?oool00ol0VOooooooo`0foooo00<0003oooooool0POooo`00Hoooo`03o`2I
oooooooo03Koool00`000?ooooooo`21oooo001Soooo00?o09Woooooool0=_ooo`030000oooooooo
087oool006?oool00ol0VOooooooo`0foooo0P0008;oool006?oool00ol0VOooooooo`0foooo00<0
003oooooool0POooo`00Hoooo`03o`2Ioooooooo02;oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001Soooo00?o09Woooooool09?ooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001Soooo00?o09Woooooool09?ooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001e
oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0
003oooooool00004oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo00@0003oooooool00002oooo0`0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:
oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.31875 .38627 L
.32392 .38627 L
.32617 .38627 L
.32831 .38627 L
.32949 .38627 L
s
.32949 .38627 m
.32968 .61803 L
s
0 .4 1 r
.02381 .38482 m
.06244 .38454 L
.10458 .38418 L
.14415 .38378 L
.18221 .38334 L
.22272 .38282 L
.26171 .38226 L
.28158 .38197 L
.30316 .38164 L
.31323 .38149 L
.31875 .38141 L
.32392 .38134 L
.32617 .3813 L
.32831 .38127 L
.32949 .38126 L
.33078 .38627 L
.33195 .38627 L
.33304 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000Foooo43?o03l0I_lg<ol000<0000co`0co`00JC?o
01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`05oooo00Co09Woooooool00009oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0
003oooooool0<?ooo`04o`2Ioooooooo0000=?ooo`030000oooooooo03?oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001T
oooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo
087oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o
09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo00<0003ooooo
ool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Wooooo
ool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Ooo
o`030000oooooooo087oool006Coool00ol0VOooooooo`0Roooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo027oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001Toooo00?o09Woooooool08Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00I?ooo`03o`2Ioooooooo027oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0Q
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0Roooo0P0000[oool300001?ooo`030000oooooooo087oool006Coool00ol0VOoo
ooooo`0eoooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?oo
o`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022
oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0e
oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001T
oooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo
087oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o
09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0]oooo1@0000?oool0
0`000?ooooooo`21oooo001Toooo00?o09Woooooool0;oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Toooo00?o09Woooooool0;oooo`030000oooooooo00?oool30000POooo`00I?oo
o`03o`2Ioooooooo02ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00I?ooo`03o`2I
oooooooo02ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
02koool200001Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo0P0008;oool0
06Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0eoooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POoo
o`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Ooo
o`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo0P0008;oool006Coool00ol0VOoo
ooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21
oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0e
oooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2I
oooooooo027oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Toooo00?o
09Woooooool08oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001Toooo00?o09Woooooool08oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool00`000?oo
ooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.31875 .38627 L
.32392 .38627 L
.32831 .38627 L
.32958 .38627 L
.33078 .38627 L
.33186 .38627 L
s
.33186 .38627 m
.33204 .61803 L
s
0 .4 1 r
.02381 .38511 m
.06244 .38489 L
.10458 .3846 L
.14415 .38428 L
.18221 .38393 L
.22272 .38351 L
.26171 .38306 L
.28158 .38283 L
.30316 .38257 L
.31323 .38245 L
.31875 .38239 L
.32392 .38233 L
.32831 .38227 L
.32958 .38226 L
.33078 .38225 L
.33186 .38223 L
.33304 .38627 L
.33436 .38627 L
.33556 .38627 L
.33825 .38627 L
.34309 .38627 L
.38315 .38627 L
.4217 .38627 L
.46271 .38627 L
.50219 .38627 L
.54016 .38627 L
.58059 .38627 L
.6195 .38627 L
.66086 .38627 L
.7007 .38627 L
.73903 .38627 L
.77982 .38627 L
.81908 .38627 L
.85683 .38627 L
.89704 .38627 L
.93572 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000Foooo6c?o03@0I_lg<ol000<0000co`0co`00JC?o
01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`05oooo00Co09Woooooool00009oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0
003oooooool0<?ooo`04o`2Ioooooooo0000=?ooo`030000oooooooo03?oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001T
oooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo
087oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o
09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo00<0003ooooo
ool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Wooooo
ool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Ooo
o`030000oooooooo087oool006Coool00ol0VOooooooo`0Roooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo027oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001Toooo00?o09Woooooool08Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00I?ooo`03o`2Ioooooooo027oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0Q
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0Roooo0P0000[oool300001?ooo`030000oooooooo087oool006Coool00ol0VOoo
ooooo`0eoooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?oo
o`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022
oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0e
oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001T
oooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo
087oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`800022oooo001Toooo00?o
09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0]oooo1@0000?oool0
0`000?ooooooo`21oooo001Toooo00?o09Woooooool0;oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001Toooo00?o09Woooooool0;oooo`030000oooooooo00?oool30000POooo`00I?oo
o`03o`2Ioooooooo02ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00I?ooo`03o`2I
oooooooo02ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo
02koool200001Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo0P0008;oool0
06Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool0
0ol0VOooooooo`0eoooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POoo
o`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21oooo001Toooo00?o09Woooooool0=Ooo
o`030000oooooooo087oool006Coool00ol0VOooooooo`0eoooo0P0008;oool006Coool00ol0VOoo
ooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`21
oooo001Toooo00?o09Woooooool0=Oooo`030000oooooooo087oool006Coool00ol0VOooooooo`0e
oooo0P0008;oool006Coool00ol0VOooooooo`0eoooo00<0003oooooool0POooo`00I?ooo`03o`2I
oooooooo027oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Toooo00?o
09Woooooool08oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001Toooo00?o09Woooooool08oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00D0003oooooooooool0
0000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo00@0003oooooool00002oooo1@0000?oool00`000?ooooooo`1doooo001eoooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1eoooo001f
oooo00<0003oooooool05oooo`80000:oooo0P0000Goool200000_ooo`030000oooooooo07Koool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.32392 .38627 L
.32831 .38627 L
.33073 .38627 L
.33304 .38627 L
.33433 .38627 L
s
.33433 .38627 m
.33444 .61803 L
s
0 .4 1 r
.02381 .3854 m
.06244 .38523 L
.10458 .38502 L
.14415 .38478 L
.18221 .38451 L
.22272 .3842 L
.26171 .38387 L
.28158 .38369 L
.30316 .3835 L
.31323 .38341 L
.32392 .38331 L
.32831 .38327 L
.33073 .38325 L
.33304 .38323 L
.33433 .38322 L
.33507 .38627 L
.33575 .38627 L
.33823 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000Foooo;S?o0280I_lf<ol000<0000co`0co`00JC?o
01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`06oooo00?o09Woool000002Oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000
oooooooo037oool00ol0VOooo`00000doooo00<0003oooooool0<oooo`030000oooooooo03?oool0
0`000?ooooooo`0Eoooo001Uoooo00?o09Woooooool0=?ooo`030000oooooooo087oool006Goool0
0ol0VOooooooo`0doooo0P0008;oool006Goool00ol0VOooooooo`0doooo00<0003oooooool0POoo
o`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?oo
o`030000oooooooo087oool006Goool00ol0VOooooooo`0doooo0P0008;oool006Goool00ol0VOoo
ooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21
oooo001Uoooo00?o09Woooooool0=?ooo`030000oooooooo087oool006Goool00ol0VOooooooo`0d
oooo0P0008;oool006Goool00ol0VOooooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2I
oooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?ooo`030000oooooooo
087oool006Goool00ol0VOooooooo`0doooo0P0008;oool006Goool00ol0VOooooooo`0doooo00<0
003oooooool0POooo`00IOooo`03o`2Ioooooooo027oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001Uoooo00?o09Woooooool08?ooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo087oool006Goool00ol0VOooooooo`0Poooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<00021oooo001Uoooo00?o09Woooooool08?ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo023oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00IOooo`03o`2I
oooooooo027oool200002_ooo`<00004oooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo
03Coool20000P_ooo`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o
09Woooooool0=?ooo`030000oooooooo087oool006Goool00ol0VOooooooo`0doooo0P0008;oool0
06Goool00ol0VOooooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo03Coool0
0`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?ooo`030000oooooooo087oool006Goool0
0ol0VOooooooo`0doooo0P0008;oool006Goool00ol0VOooooooo`0doooo00<0003oooooool0POoo
o`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?oo
o`030000oooooooo087oool006Goool00ol0VOooooooo`0doooo0P0008;oool006Goool00ol0VOoo
ooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo02coool500000oooo`030000
oooooooo087oool006Goool00ol0VOooooooo`0^oooo00<0003oooooool00oooo`030000oooooooo
087oool006Goool00ol0VOooooooo`0^oooo00<0003oooooool00oooo`<00021oooo001Uoooo00?o
09Woooooool0;_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Uoooo00?o09Wooooo
ool0;_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0;Ooo
o`800005oooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo03Coool20000P_ooo`00IOoo
o`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?ooo`030000
oooooooo087oool006Goool00ol0VOooooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2I
oooooooo03Coool20000P_ooo`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001U
oooo00?o09Woooooool0=?ooo`030000oooooooo087oool006Goool00ol0VOooooooo`0doooo00<0
003oooooool0POooo`00IOooo`03o`2Ioooooooo03Coool20000P_ooo`00IOooo`03o`2Ioooooooo
03Coool00`000?ooooooo`21oooo001Uoooo00?o09Woooooool0=?ooo`030000oooooooo087oool0
06Goool00ol0VOooooooo`0doooo00<0003oooooool0POooo`00IOooo`03o`2Ioooooooo03Coool2
0000P_ooo`00IOooo`03o`2Ioooooooo03Coool00`000?ooooooo`21oooo001Uoooo00?o09Wooooo
ool08?ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool006Goool00ol0VOoo
ooooo`0Roooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool0
06Goool00ol0VOooooooo`0Roooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POoo
o`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?oo
ooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001foooo00<0
003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0=oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0M?oo
o`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00005
oooo00D0003oooooooooool00000Moooo`00MOooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1e
oooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo
07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.32392 .38627 L
.32831 .38627 L
.33304 .38627 L
.33443 .38627 L
.33575 .38627 L
.33693 .38627 L
s
.33693 .38627 m
.33713 .61803 L
s
0 .4 1 r
.02381 .38569 m
.06244 .38558 L
.10458 .38543 L
.14415 .38528 L
.18221 .3851 L
.22272 .38489 L
.26171 .38467 L
.28158 .38455 L
.30316 .38442 L
.31323 .38436 L
.32392 .3843 L
.32831 .38427 L
.33304 .38425 L
.33443 .38424 L
.33575 .38423 L
.33693 .38422 L
.33823 .38627 L
.33945 .38627 L
.34075 .38627 L
.34309 .38627 L
.38467 .38627 L
.42473 .38627 L
.46328 .38627 L
.50429 .38627 L
.54378 .38627 L
.58175 .38627 L
.62217 .38627 L
.66108 .38627 L
.70244 .38627 L
.74229 .38627 L
.78062 .38627 L
.8214 .38627 L
.86066 .38627 L
.89841 .38627 L
.93862 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooCC?o00@0I_le<ol000<0000co`0co`00JC?o
01Soool0013ooooo00004Oooo`004Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00?o09T0003oool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000
oooooooo03;oool00ol0V@000?ooo`0coooo00<0003oooooool0<oooo`030000oooooooo03?oool0
0`000?ooooooo`0Eoooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool0
0ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POoo
o`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<ooo
o`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOoo
ooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21
oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0c
oooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2I
oooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo
087oool006Koool00ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0
003oooooool0POooo`00I_ooo`03o`2Ioooooooo023oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001Voooo00?o09Woooooool07oooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo087oool006Koool00ol0VOooooooo`0Ooooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<00021oooo001Voooo00?o09Woooooool07oooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo01ooool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00I_ooo`03o`2I
oooooooo023oool200002_ooo`<00004oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo
03?oool20000P_ooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o
09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P0008;oool0
06Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool0
0ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POoo
o`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<ooo
o`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOoo
ooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo02_oool500000oooo`030000
oooooooo087oool006Koool00ol0VOooooooo`0]oooo00<0003oooooool00oooo`030000oooooooo
087oool006Koool00ol0VOooooooo`0]oooo00<0003oooooool00oooo`<00021oooo001Voooo00?o
09Woooooool0;Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Voooo00?o09Wooooo
ool0;Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0;?oo
o`800005oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool20000P_ooo`00I_oo
o`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`030000
oooooooo087oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2I
oooooooo03?oool20000P_ooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001V
oooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo00<0
003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool20000P_ooo`00I_ooo`03o`2Ioooooooo
03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool0
06Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool2
0000P_ooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Wooooo
ool07oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool006Koool00ol0VOoo
ooooo`0Qoooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool0
06Koool00ol0VOooooooo`0Qoooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POoo
o`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?oo
ooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001foooo00<0
003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0=oooo0P0000Coool200001?ooo`800003oooo100000?oool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0
003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo07Coool0
07Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo00;oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`800003oooo00<0
003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.32392 .38627 L
.33304 .38627 L
.33554 .38627 L
.33692 .38627 L
.33823 .38627 L
s
.33823 .38627 m
.33841 .61803 L
s
0 .4 1 r
.02381 .38598 m
.06244 .38593 L
.10458 .38585 L
.14415 .38577 L
.18221 .38569 L
.22272 .38558 L
.26171 .38547 L
.28158 .38541 L
.30316 .38535 L
.31323 .38532 L
.32392 .38528 L
.33304 .38526 L
.33554 .38525 L
.33692 .38525 L
.33823 .38524 L
.33944 .38627 L
.34013 .38627 L
.34076 .38627 L
.34309 .38627 L
.38221 .38627 L
.4238 .38627 L
.46386 .38627 L
.50241 .38627 L
.54342 .38627 L
.5829 .38627 L
.62088 .38627 L
.6613 .38627 L
.70021 .38627 L
.74157 .38627 L
.78142 .38627 L
.81975 .38627 L
.86053 .38627 L
.89979 .38627 L
.93754 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`03o`2I0000oooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0b
oooo00?o09T0003oool0<oooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Wooooo
ool0<oooo`800022oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool0
0ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`21oooo001Voooo00?o09Woooooool0<oooo`800022oooo001Voooo00?o09Woooooool0<ooo
o`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_oo
o`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`800022
oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0c
oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001V
oooo00?o09Woooooool0<oooo`800022oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo
087oool006Koool00ol0VOooooooo`0Poooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00I_ooo`03o`2Ioooooooo01ooool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Voooo00?o09Woooooool07oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00I_ooo`03o`2Ioooooooo01ooool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0Ooooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Koool00ol0VOooooooo`0P
oooo0P0000[oool300001?ooo`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P00
08;oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo
03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`800022oooo001Voooo00?o
09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo00<0003ooooo
ool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Wooooo
ool0<oooo`800022oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool0
0ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`21oooo001Voooo00?o09Woooooool0<oooo`800022oooo001Voooo00?o09Woooooool0<ooo
o`030000oooooooo087oool006Koool00ol0VOooooooo`0[oooo1@0000?oool00`000?ooooooo`21
oooo001Voooo00?o09Woooooool0;Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001V
oooo00?o09Woooooool0;Oooo`030000oooooooo00?oool30000POooo`00I_ooo`03o`2Ioooooooo
02goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo02goool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo02coool200001Ooo
o`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOoo
ooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21
oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0c
oooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2I
oooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o09Woooooool0<oooo`030000oooooooo
087oool006Koool00ol0VOooooooo`0coooo0P0008;oool006Koool00ol0VOooooooo`0coooo00<0
003oooooool0POooo`00I_ooo`03o`2Ioooooooo03?oool00`000?ooooooo`21oooo001Voooo00?o
09Woooooool0<oooo`030000oooooooo087oool006Koool00ol0VOooooooo`0coooo0P0008;oool0
06Koool00ol0VOooooooo`0coooo00<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo01ooool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Voooo00?o09Woooooool08Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Voooo00?o
09Woooooool08Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo
02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200000oooo`D00002oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo
07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo00?oool00`000?ooooooo`1doooo001eoooo00<0
003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`02oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.28158 .38627 L
.30316 .38627 L
.31323 .38627 L
.32392 .38627 L
.33304 .38627 L
.33554 .38627 L
.33823 .38627 L
.33953 .38627 L
.34076 .38627 L
s
.34076 .38627 m
.34093 .61803 L
s
0 .4 1 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.42237 .38627 L
.46172 .38627 L
.49955 .38627 L
.53984 .38627 L
.57861 .38627 L
.61984 .38627 L
.65954 .38627 L
.69774 .38627 L
.73838 .38627 L
.77751 .38627 L
.81909 .38627 L
.85916 .38627 L
.89771 .38627 L
.93871 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Wooooo
ool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool0
0ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?oo
ooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_oo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Iooo
o`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022
oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0b
oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001W
oooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo
087oool006Ooool00ol0VOooooooo`0Ooooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00Ioooo`03o`2Ioooooooo01koool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Woooo00?o09Woooooool07_ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00Ioooo`03o`2Ioooooooo01koool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0Noooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0O
oooo0P0000[oool300001?ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P00
08;oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo
03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o
09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo00<0003ooooo
ool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Wooooo
ool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool0
0ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?oo
ooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_oo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0Zoooo1@0000?oool00`000?ooooooo`21
oooo001Woooo00?o09Woooooool0;?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001W
oooo00?o09Woooooool0;?ooo`030000oooooooo00?oool30000POooo`00Ioooo`03o`2Ioooooooo
02coool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo02coool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo02_oool200001Ooo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool006Ooool00ol0VOoo
ooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21
oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0b
oooo0P0008;oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2I
oooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo
087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool006Ooool00ol0VOooooooo`0boooo00<0
003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o
09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool0
06Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo01koool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Woooo00?o09Woooooool08?oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Woooo00?o
09Woooooool08?ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00Ooooo`030000oooooooo
01coool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo01?oool0
0`000?ooooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00009oooo00<0003ooooo
ool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:
oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D0000<oooo00@0003oooooool00009
oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0003ooooo
ool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.33788 .38627 L
.34055 .38627 L
.34186 .38627 L
.34309 .38627 L
s
.34309 .38627 m
.34326 .61803 L
s
0 .4 1 r
.02381 .38656 m
.06244 .38662 L
.10458 .38669 L
.14415 .38677 L
.18221 .38686 L
.22272 .38696 L
.26171 .38707 L
.30316 .3872 L
.32392 .38726 L
.33304 .38728 L
.33788 .3873 L
.34055 .38731 L
.34186 .38731 L
.34309 .38731 L
.34425 .38627 L
.34549 .38627 L
.34811 .38627 L
.35271 .38627 L
.36173 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Wooooo
ool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool0
0ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?oo
ooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_oo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Iooo
o`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022
oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0b
oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001W
oooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo
087oool006Ooool00ol0VOooooooo`0Ooooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00Ioooo`03o`2Ioooooooo01koool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Woooo00?o09Woooooool07_ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00Ioooo`03o`2Ioooooooo01koool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0Noooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0O
oooo0P0000[oool300001?ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P00
08;oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo
03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o
09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo00<0003ooooo
ool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Wooooo
ool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool0
0ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?oo
ooooo`21oooo001Woooo00?o09Woooooool0<_ooo`800022oooo001Woooo00?o09Woooooool0<_oo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0Zoooo1@0000?oool00`000?ooooooo`21
oooo001Woooo00?o09Woooooool0;?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001W
oooo00?o09Woooooool0;?ooo`030000oooooooo00?oool30000POooo`00Ioooo`03o`2Ioooooooo
02coool00`000?ooooooo`03oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo02coool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo02_oool200001Ooo
o`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool006Ooool00ol0VOoo
ooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21
oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0b
oooo0P0008;oool006Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2I
oooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o09Woooooool0<_ooo`030000oooooooo
087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool006Ooool00ol0VOooooooo`0boooo00<0
003oooooool0POooo`00Ioooo`03o`2Ioooooooo03;oool00`000?ooooooo`21oooo001Woooo00?o
09Woooooool0<_ooo`030000oooooooo087oool006Ooool00ol0VOooooooo`0boooo0P0008;oool0
06Ooool00ol0VOooooooo`0boooo00<0003oooooool0POooo`00Ioooo`03o`2Ioooooooo01koool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Woooo00?o09Woooooool08?oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Woooo00?o
09Woooooool08?ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200000oooo`D00002oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.33788 .38627 L
.34055 .38627 L
.34309 .38627 L
.34425 .38627 L
.34549 .38627 L
s
.34549 .38627 m
.3456 .61803 L
s
0 .4 1 r
.02381 .38685 m
.06244 .38696 L
.10458 .38711 L
.14415 .38727 L
.18221 .38744 L
.22272 .38765 L
.26171 .38787 L
.30316 .38812 L
.32392 .38824 L
.33304 .3883 L
.33788 .38832 L
.34055 .38834 L
.34309 .38835 L
.34425 .38836 L
.34549 .38837 L
.3462 .38627 L
.34685 .38627 L
.34811 .38627 L
.35271 .38627 L
.36173 .38627 L
.3815 .38627 L
.42157 .38627 L
.46012 .38627 L
.50112 .38627 L
.54061 .38627 L
.57858 .38627 L
.619 .38627 L
.65791 .38627 L
.69927 .38627 L
.73912 .38627 L
.77745 .38627 L
.81823 .38627 L
.8575 .38627 L
.89525 .38627 L
.93545 .38627 L
.97414 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00@0003oooooooooool706Ko00<00000I_ooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
03?oool00`000?l0VOooo`0boooo00<0003oooooool0<oooo`030000oooooooo03?oool00`000?oo
ooooo`0Eoooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOoo
ooooo`0aoooo0P0008;oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?oo
o`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000
oooooooo087oool006Soool00ol0VOooooooo`0aoooo0P0008;oool006Soool00ol0VOooooooo`0a
oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001X
oooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo0P00
08;oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo
037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool0
06Soool00ol0VOooooooo`0aoooo0P0008;oool006Soool00ol0VOooooooo`0aoooo00<0003ooooo
ool0POooo`00J?ooo`03o`2Ioooooooo01koool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001Xoooo00?o09Woooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo087oool006Soool00ol0VOooooooo`0Moooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<00021oooo001Xoooo00?o09Woooooool07Oooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo01goool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo
01koool200002_ooo`<00004oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool2
0000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Wooooo
ool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo0P0008;oool006Soool0
0ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool00`000?oo
ooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOoo
ooooo`0aoooo0P0008;oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?oo
o`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000
oooooooo087oool006Soool00ol0VOooooooo`0aoooo0P0008;oool006Soool00ol0VOooooooo`0a
oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo02Woool500000oooo`030000oooooooo
087oool006Soool00ol0VOooooooo`0[oooo00<0003oooooool00oooo`030000oooooooo087oool0
06Soool00ol0VOooooooo`0[oooo00<0003oooooool00oooo`<00021oooo001Xoooo00?o09Wooooo
ool0:oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0:ooo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0:_ooo`800005
oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?ooo`03o`2I
oooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo
087oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo
037oool20000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o
09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0003ooooo
ool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo037oool0
0`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool0
0ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_oo
o`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool07Ooo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0O
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool006Soool0
0ol0VOooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_oo
o`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28
oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001?ooo`800003oooo100000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.33788 .38627 L
.34055 .38627 L
.34309 .38627 L
.34549 .38627 L
.34615 .38627 L
.34685 .38627 L
s
.34685 .38627 m
.34704 .61803 L
s
0 .4 1 r
.02381 .38714 m
.06244 .38731 L
.10458 .38753 L
.14415 .38776 L
.18221 .38803 L
.22272 .38834 L
.26171 .38868 L
.30316 .38905 L
.32392 .38923 L
.33304 .38931 L
.33788 .38935 L
.34055 .38937 L
.34309 .3894 L
.34549 .38942 L
.34615 .38942 L
.34685 .38943 L
.34811 .38627 L
.34935 .38627 L
.35053 .38627 L
.35271 .38627 L
.36173 .38627 L
.3815 .38627 L
.42005 .38627 L
.46105 .38627 L
.50054 .38627 L
.53851 .38627 L
.57894 .38627 L
.61785 .38627 L
.65921 .38627 L
.69905 .38627 L
.73738 .38627 L
.77816 .38627 L
.81743 .38627 L
.85518 .38627 L
.89538 .38627 L
.93407 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01Oooo`<0I_l00`00001Vo`1Vo`0706Ko00<0
0000I_l0I_l0201Vo`03000006Ko06Ko00P0I_l00`00001Vooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003ooooo
ool0<oooo`030000o`2Ioooo03;oool00`000?ooooooo`0coooo00<0003oooooool0<oooo`030000
oooooooo01Goool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2I
oooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001X
oooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0
003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo
037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool0
06Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool2
0000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Wooooo
ool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POoo
o`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?oo
ooooo`21oooo001Xoooo00?o09Woooooool07_ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo087oool006Soool00ol0VOooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo01goool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`00087oool006Soool00ol0VOooooooo`0Moooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool07Oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001Xoooo00?o09Wooooo
ool07_ooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Ooo
o`800022oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOoo
ooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?oo
o`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`030000
oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2I
oooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001X
oooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0
003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool20000P_ooo`00J?ooo`03o`2Ioooooooo
037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0:Oooo`D00003oooo00<0003ooooo
ool0POooo`00J?ooo`03o`2Ioooooooo02_oool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00J?ooo`03o`2Ioooooooo02_oool00`000?ooooooo`03oooo0`00087oool006Soool00ol0VOoo
ooooo`0[oooo00<0003oooooool00oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0[
oooo00<0003oooooool00oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0Zoooo0P00
00Goool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`800022oooo001Xoooo00?o
09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0003ooooo
ool0POooo`00J?ooo`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Wooooo
ool0<Oooo`800022oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool0
0ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo037oool00`000?oo
ooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`800022oooo001Xoooo00?o09Woooooool0<Ooo
o`030000oooooooo087oool006Soool00ol0VOooooooo`0aoooo00<0003oooooool0POooo`00J?oo
o`03o`2Ioooooooo037oool00`000?ooooooo`21oooo001Xoooo00?o09Woooooool0<Oooo`800022
oooo001Xoooo00?o09Woooooool0<Oooo`030000oooooooo087oool006Soool00ol0VOooooooo`0M
oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo
01ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00J?oo
o`03o`2Ioooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:
oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo
08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00D0003ooooo
ooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.33788 .38627 L
.34309 .38627 L
.34566 .38627 L
.34693 .38627 L
.34811 .38627 L
.34918 .38627 L
s
.34918 .38627 m
.34935 .61803 L
s
0 .4 1 r
.02381 .38743 m
.06244 .38766 L
.10458 .38794 L
.14415 .38826 L
.18221 .38861 L
.22272 .38904 L
.26171 .38948 L
.30316 .38997 L
.32392 .39022 L
.33304 .39032 L
.33788 .39038 L
.34309 .39044 L
.34566 .39047 L
.34693 .39048 L
.34811 .39049 L
.34918 .3905 L
.35031 .38627 L
.35157 .38627 L
.35271 .38627 L
.36173 .38627 L
.3815 .38627 L
.42157 .38627 L
.46012 .38627 L
.50112 .38627 L
.54061 .38627 L
.57858 .38627 L
.619 .38627 L
.65791 .38627 L
.69927 .38627 L
.73912 .38627 L
.77745 .38627 L
.81823 .38627 L
.8575 .38627 L
.89525 .38627 L
.93545 .38627 L
.97414 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`1Vo`00001Vo`0906Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003ooooo09T0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Wooooo
ool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool0
0ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?oo
ooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?oo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOoo
o`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022
oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`
oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Y
oooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo
087oool006Woool00ol0VOooooooo`0Moooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00JOooo`03o`2Ioooooooo01coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool07?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00JOooo`03o`2Ioooooooo01coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006Woool00ol0VOooooooo`0Loooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0M
oooo0P0000[oool300001?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P00
08;oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo
033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o
09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo00<0003ooooo
ool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Wooooo
ool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool0
0ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?oo
ooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?oo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0Xoooo1@0000?oool00`000?ooooooo`21
oooo001Yoooo00?o09Woooooool0:_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Y
oooo00?o09Woooooool0:_ooo`030000oooooooo00?oool30000POooo`00JOooo`03o`2Ioooooooo
02[oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo02Woool200001Ooo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool006Woool00ol0VOoo
ooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21
oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`
oooo0P0008;oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2I
oooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo
087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool006Woool00ol0VOooooooo`0`oooo00<0
003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o
09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool0
06Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo01coool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool07_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Yoooo00?o
09Woooooool07_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`050000oooooooooooo000007[oool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`800005oooo0P0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.33788 .38627 L
.34309 .38627 L
.34566 .38627 L
.34811 .38627 L
.35031 .38627 L
.35156 .38627 L
s
.35156 .38627 m
.35173 .61803 L
s
0 .4 1 r
.02381 .38772 m
.06244 .388 L
.10458 .38836 L
.14415 .38876 L
.18221 .3892 L
.22272 .38973 L
.26171 .39028 L
.30316 .3909 L
.32392 .3912 L
.33304 .39134 L
.33788 .39141 L
.34309 .39148 L
.34566 .39152 L
.34811 .39155 L
.35031 .39158 L
.35156 .3916 L
.35271 .38627 L
.35389 .38627 L
.355 .38627 L
.35708 .38627 L
.36173 .38627 L
.3815 .38627 L
.42005 .38627 L
.46105 .38627 L
.50054 .38627 L
.53851 .38627 L
.57894 .38627 L
.61785 .38627 L
.65921 .38627 L
.69905 .38627 L
.73738 .38627 L
.77816 .38627 L
.81743 .38627 L
.85518 .38627 L
.89538 .38627 L
.93407 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003ooooo09T0<_ooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Wooooo
ool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool0
0ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?oo
ooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?oo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOoo
o`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022
oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`
oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Y
oooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo
087oool006Woool00ol0VOooooooo`0Moooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00JOooo`03o`2Ioooooooo01coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool07?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00JOooo`03o`2Ioooooooo01coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool006Woool00ol0VOooooooo`0Loooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0M
oooo0P0000[oool300001?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P00
08;oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo
033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o
09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo00<0003ooooo
ool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Wooooo
ool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool0
0ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?oo
ooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`800022oooo001Yoooo00?o09Woooooool0<?oo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0Xoooo1@0000?oool00`000?ooooooo`21
oooo001Yoooo00?o09Woooooool0:_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001Y
oooo00?o09Woooooool0:_ooo`030000oooooooo00?oool30000POooo`00JOooo`03o`2Ioooooooo
02[oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo02Woool200001Ooo
o`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool006Woool00ol0VOoo
ooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21
oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`
oooo0P0008;oool006Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2I
oooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool0<?ooo`030000oooooooo
087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool006Woool00ol0VOooooooo`0`oooo00<0
003oooooool0POooo`00JOooo`03o`2Ioooooooo033oool00`000?ooooooo`21oooo001Yoooo00?o
09Woooooool0<?ooo`030000oooooooo087oool006Woool00ol0VOooooooo`0`oooo0P0008;oool0
06Woool00ol0VOooooooo`0`oooo00<0003oooooool0POooo`00JOooo`03o`2Ioooooooo01coool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001Yoooo00?o09Woooooool07_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001Yoooo00?o
09Woooooool07_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000
oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.34309 .38627 L
.34772 .38627 L
.35028 .38627 L
.35154 .38627 L
.35271 .38627 L
.3538 .38627 L
s
.3538 .38627 m
.35398 .61803 L
s
0 .4 1 r
.02381 .38801 m
.06244 .38835 L
.10458 .38878 L
.14415 .38926 L
.18221 .38979 L
.22272 .39042 L
.26171 .39108 L
.30316 .39182 L
.32392 .39219 L
.33304 .39235 L
.34309 .39252 L
.34772 .3926 L
.35028 .39264 L
.35154 .39266 L
.35271 .39268 L
.3538 .3927 L
.35496 .38627 L
.35625 .38627 L
.35742 .38627 L
.36173 .38627 L
.3815 .38627 L
.42157 .38627 L
.46012 .38627 L
.50112 .38627 L
.54061 .38627 L
.57858 .38627 L
.619 .38627 L
.65791 .38627 L
.69927 .38627 L
.73912 .38627 L
.77745 .38627 L
.81823 .38627 L
.8575 .38627 L
.89525 .38627 L
.93545 .38627 L
.97414 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`07oooo00<0I_l00000I_l0201Vo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00@00000I_l0I_l0I_l7oooo00@0003oooooool0I_l6oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0003ooooo
ool0;?ooo`L0I_l01000001Vo`1Vo`1Voc7oool00`000?ooooooo`0coooo00<0003oooooool0<ooo
o`030000oooooooo01Goool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_oo
o`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21
oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_
oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2I
oooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo
087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo
02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o
09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003ooooo
ool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`21oooo001Zoooo00?o09Woooooool07?ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool006[oool00ol0VOooooooo`0Koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo01_oool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006[oool00ol0VOooooooo`0Koooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool06ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001Zoooo00?o
09Woooooool07?ooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001Zoooo00?o09Wooooo
ool0;oooo`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool0
0ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_oo
o`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;ooo
o`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_oo
o`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21
oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_
oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2I
oooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool09oooo`D00003oooo00<0
003oooooool0POooo`00J_ooo`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00J_ooo`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo0`00087oool006[oool0
0ol0VOooooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo087oool006[oool00ol0VOoo
ooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0X
oooo0P0000Goool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`800022oooo001Z
oooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0
003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o
09Woooooool0;oooo`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool0
06[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`800022oooo001Zoooo00?o09Wooooo
ool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POoo
o`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;ooo
o`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOoo
ooooo`0Koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00J_ooo`03o`2I
oooooooo01goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00J_ooo`03o`2Ioooooooo01goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800004oooo0P0000?oool300001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000;oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.34309 .38627 L
.34772 .38627 L
.35028 .38627 L
.35271 .38627 L
.3538 .38627 L
.35496 .38627 L
s
.35496 .38627 m
.35516 .61803 L
s
0 .4 1 r
.02381 .3883 m
.06244 .38869 L
.10458 .3892 L
.14415 .38976 L
.18221 .39037 L
.22272 .39111 L
.26171 .39189 L
.30316 .39275 L
.32392 .39318 L
.33304 .39337 L
.34309 .39357 L
.34772 .39366 L
.35028 .3937 L
.35271 .39375 L
.3538 .39377 L
.35496 .39379 L
.35624 .38627 L
.35742 .38627 L
.36173 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00P0I_l00`00001Vo`1Vo`0706Ko00<0
0000I_l0I_l0101Vo`Coool00`000?ooooooo`08oooo00@0003oooooool0I_l6oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000aoooo00<0
003oooooool09?ooo`l0I_l01000001Vo`1Vo`1Voc7oool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POoo
o`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`21oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOoo
ooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_oo
o`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`030000
oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2I
oooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Z
oooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0
003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo
02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool07?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0Koooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo01_oool0
10000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006[oool00ol0VOooooooo`0K
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001Zoooo00?o09Wooooo
ool06oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001Z
oooo00?o09Woooooool07?ooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001Zoooo00?o
09Woooooool0;oooo`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool0
06[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool2
0000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Wooooo
ool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POoo
o`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_ooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`21oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOoo
ooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool20000P_ooo`00J_oo
o`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool09oooo`D00003
oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00J_ooo`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo0`00087oool0
06[oool00ol0VOooooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo087oool006[oool0
0ol0VOooooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo087oool006[oool00ol0VOoo
ooooo`0Xoooo0P0000Goool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`800022
oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_
oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Z
oooo00?o09Woooooool0;oooo`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo
087oool006[oool00ol0VOooooooo`0_oooo00<0003oooooool0POooo`00J_ooo`03o`2Ioooooooo
02ooool00`000?ooooooo`21oooo001Zoooo00?o09Woooooool0;oooo`800022oooo001Zoooo00?o
09Woooooool0;oooo`030000oooooooo087oool006[oool00ol0VOooooooo`0_oooo00<0003ooooo
ool0POooo`00J_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`21oooo001Zoooo00?o09Wooooo
ool0;oooo`800022oooo001Zoooo00?o09Woooooool0;oooo`030000oooooooo087oool006[oool0
0ol0VOooooooo`0Koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00J_oo
o`03o`2Ioooooooo01goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003ooooo
ool0POooo`00J_ooo`03o`2Ioooooooo01goool00`000?ooooooo`0:oooo00<0003oooooool00_oo
o`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?oo
o`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003ooooo
ool00005oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000?oool400000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.34309 .38627 L
.34772 .38627 L
.35271 .38627 L
.35513 .38627 L
.35632 .38627 L
.35742 .38627 L
s
.35742 .38627 m
.35757 .61803 L
s
0 .4 1 r
.02381 .38859 m
.06244 .38904 L
.10458 .38962 L
.14415 .39026 L
.18221 .39096 L
.22272 .3918 L
.26171 .39269 L
.30316 .39368 L
.32392 .39417 L
.33304 .39438 L
.34309 .39461 L
.34772 .39471 L
.35271 .39482 L
.35513 .39487 L
.35632 .3949 L
.35742 .39492 L
.35842 .38627 L
.35948 .38627 L
.36173 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00P0I_l00`00001Vo`1Vo`0406Ko0ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00D0003oooooooooool0I_l01Oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Ooo
o`030000oooooooo01[ooolI06Ko00<00000I_l0I_l00P1Voc3oool00`000?ooooooo`0coooo00<0
003oooooool0<oooo`030000oooooooo01Goool006_oool00ol0VOooooooo`0^oooo00<0003ooooo
ool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool0
0`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_oo
o`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_oo
o`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Jooo
o`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^
oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2I
oooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool06oooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo087oool006_oool00ol0VOooooooo`0Joooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo
01[oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006_oool00ol0VOoo
ooooo`0Joooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool06_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool06oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001[
oooo00?o09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo
087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo
02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003ooooo
ool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool0
0`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_oo
o`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool09_oo
o`D00003oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02Soool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02Soool00`000?ooooooo`03oooo0`00
087oool006_oool00ol0VOooooooo`0Xoooo00<0003oooooool00oooo`030000oooooooo087oool0
06_oool00ol0VOooooooo`0Xoooo00<0003oooooool00oooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0Woooo0P0000Goool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_oo
o`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOoo
ooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000
oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2I
oooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`800022oooo001[
oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0
003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool0
06_oool00ol0VOooooooo`0Joooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POoo
o`00Joooo`03o`2Ioooooooo01coool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00Joooo`03o`2Ioooooooo01coool00`000?ooooooo`0:oooo00<0003ooooo
ool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003ooooo
ool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.33304 .38627 L
.34309 .38627 L
.34772 .38627 L
.35271 .38627 L
.35513 .38627 L
.35742 .38627 L
.35842 .38627 L
.35948 .38627 L
s
.35948 .38627 m
.35966 .61803 L
s
0 .4 1 r
.02381 .38888 m
.06244 .38939 L
.10458 .39004 L
.14415 .39076 L
.18221 .39155 L
.22272 .3925 L
.26171 .3935 L
.30316 .39461 L
.32392 .39516 L
.33304 .3954 L
.34309 .39565 L
.34772 .39577 L
.35271 .39589 L
.35513 .39595 L
.35742 .39601 L
.35842 .39603 L
.35948 .39606 L
.36065 .38627 L
.36173 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00D0I_l3oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00D0003oooooooooool0I_l01Oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Ooo
o`030000oooooooo013ooolS06Ko00<00000I_l0I_l00P1Voc3oool00`000?ooooooo`0coooo00<0
003oooooool0<oooo`030000oooooooo01Goool006_oool00ol0VOooooooo`0^oooo00<0003ooooo
ool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool0
0`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_oo
o`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_oo
o`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Jooo
o`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^
oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2I
oooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool06oooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo087oool006_oool00ol0VOooooooo`0Joooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo
01[oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006_oool00ol0VOoo
ooooo`0Joooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool06_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool06oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001[
oooo00?o09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo
087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo
02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003ooooo
ool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_ooo`00Joooo`03o`2Ioooooooo02koool0
0`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool20000P_oo
o`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool09_oo
o`D00003oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02Soool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02Soool00`000?ooooooo`03oooo0`00
087oool006_oool00ol0VOooooooo`0Xoooo00<0003oooooool00oooo`030000oooooooo087oool0
06_oool00ol0VOooooooo`0Xoooo00<0003oooooool00oooo`030000oooooooo087oool006_oool0
0ol0VOooooooo`0Woooo0P0000Goool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_oo
o`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOoo
ooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21
oooo001[oooo00?o09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000
oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0003oooooool0POooo`00Joooo`03o`2I
oooooooo02koool00`000?ooooooo`21oooo001[oooo00?o09Woooooool0;_ooo`800022oooo001[
oooo00?o09Woooooool0;_ooo`030000oooooooo087oool006_oool00ol0VOooooooo`0^oooo00<0
003oooooool0POooo`00Joooo`03o`2Ioooooooo02koool00`000?ooooooo`21oooo001[oooo00?o
09Woooooool0;_ooo`800022oooo001[oooo00?o09Woooooool0;_ooo`030000oooooooo087oool0
06_oool00ol0VOooooooo`0Joooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POoo
o`00Joooo`03o`2Ioooooooo01coool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00Joooo`03o`2Ioooooooo01coool00`000?ooooooo`0:oooo00<0003ooooo
ool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003ooooo
ool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000?oool300001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo0`0000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.35271 .38627 L
.35742 .38627 L
.35948 .38627 L
.36057 .38627 L
.36173 .38627 L
s
.36173 .38627 m
.36191 .61803 L
s
0 .4 1 r
.02381 .38917 m
.06244 .38974 L
.10458 .39046 L
.14415 .39126 L
.18221 .39214 L
.22272 .39319 L
.26171 .3943 L
.30316 .39554 L
.32392 .39615 L
.34309 .3967 L
.35271 .39697 L
.35742 .39709 L
.35948 .39715 L
.36057 .39718 L
.36173 .39721 L
.36294 .38627 L
.36405 .38627 L
.36626 .38627 L
.37114 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00D0I_l3oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool00_ooo`0306Kooooooooo
00;oool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
01Goool0037oool00`000?ooooooo`0@oooo701Vo`Ooool00`000?ooooooo`02oooo00<0I_oooooo
ool0;Oooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00H?oo
o`d0I_l_oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo02goool20000P_ooo`00K?oo
o`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/oooo00?o09Woooooool0;Oooo`030000
oooooooo087oool006coool00ol0VOooooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2I
oooooooo02goool20000P_ooo`00K?ooo`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/
oooo00?o09Woooooool0;Oooo`030000oooooooo087oool006coool00ol0VOooooooo`0]oooo00<0
003oooooool0POooo`00K?ooo`03o`2Ioooooooo02goool20000P_ooo`00K?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`21oooo001/oooo00?o09Woooooool0;Oooo`030000oooooooo087oool0
06coool00ol0VOooooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo02goool2
0000P_ooo`00K?ooo`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/oooo00?o09Wooooo
ool06_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool006coool00ol0VOoo
ooooo`0Ioooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00K?ooo`03o`2Ioooooooo01Woool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
087oool006coool00ol0VOooooooo`0Ioooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`21oooo001/oooo00?o09Woooooool06Oooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`21oooo001/oooo00?o09Woooooool06_ooo`80000:oooo0`0000Coool0
0`000?ooooooo`21oooo001/oooo00?o09Woooooool0;Oooo`800022oooo001/oooo00?o09Wooooo
ool0;Oooo`030000oooooooo087oool006coool00ol0VOooooooo`0]oooo00<0003oooooool0POoo
o`00K?ooo`03o`2Ioooooooo02goool20000P_ooo`00K?ooo`03o`2Ioooooooo02goool00`000?oo
ooooo`21oooo001/oooo00?o09Woooooool0;Oooo`030000oooooooo087oool006coool00ol0VOoo
ooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo02goool20000P_ooo`00K?oo
o`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/oooo00?o09Woooooool0;Oooo`030000
oooooooo087oool006coool00ol0VOooooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2I
oooooooo02goool20000P_ooo`00K?ooo`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/
oooo00?o09Woooooool09Oooo`D00003oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`03oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo02Ooool0
0`000?ooooooo`03oooo0`00087oool006coool00ol0VOooooooo`0Woooo00<0003oooooool00ooo
o`030000oooooooo087oool006coool00ol0VOooooooo`0Woooo00<0003oooooool00oooo`030000
oooooooo087oool006coool00ol0VOooooooo`0Voooo0P0000Goool00`000?ooooooo`21oooo001/
oooo00?o09Woooooool0;Oooo`800022oooo001/oooo00?o09Woooooool0;Oooo`030000oooooooo
087oool006coool00ol0VOooooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`21oooo001/oooo00?o09Woooooool0;Oooo`800022oooo001/oooo00?o
09Woooooool0;Oooo`030000oooooooo087oool006coool00ol0VOooooooo`0]oooo00<0003ooooo
ool0POooo`00K?ooo`03o`2Ioooooooo02goool00`000?ooooooo`21oooo001/oooo00?o09Wooooo
ool0;Oooo`800022oooo001/oooo00?o09Woooooool0;Oooo`030000oooooooo087oool006coool0
0ol0VOooooooo`0]oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo02goool00`000?oo
ooooo`21oooo001/oooo00?o09Woooooool0;Oooo`800022oooo001/oooo00?o09Woooooool0;Ooo
o`030000oooooooo087oool006coool00ol0VOooooooo`0Ioooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo01_oool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00K?ooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029
oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@00
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.35271 .38627 L
.35742 .38627 L
.36173 .38627 L
.36284 .38627 L
.36405 .38627 L
s
.36405 .38627 m
.36423 .61803 L
s
0 .4 1 r
.02381 .38947 m
.06244 .39008 L
.10458 .39088 L
.14415 .39176 L
.18221 .39273 L
.22272 .39389 L
.26171 .39511 L
.30316 .39647 L
.32392 .39714 L
.34309 .39775 L
.35271 .39804 L
.35742 .39818 L
.36173 .3983 L
.36284 .39834 L
.36405 .39837 L
.3652 .38627 L
.36626 .38627 L
.37114 .38627 L
.3815 .38627 L
.42063 .38627 L
.46221 .38627 L
.50228 .38627 L
.54083 .38627 L
.58183 .38627 L
.62132 .38627 L
.65929 .38627 L
.69971 .38627 L
.73862 .38627 L
.77998 .38627 L
.81983 .38627 L
.85816 .38627 L
.89894 .38627 L
.93821 .38627 L
.97596 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0806Ko00<00000I_l0I_l01P1Vo`;oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool00oooo`0506Kooooooooo
oooo000000[oool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Ooo
o`030000oooooooo00KooolN06Ko3oooo`030000oooooooo00?oool00`1Vooooooooo`0/oooo00<0
003oooooool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo001Hoooo5P1Vobkoool0
0`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]oooo00?o09Wooooo
ool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POoo
o`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?oo
o`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOoo
ooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21
oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]oooo00?o09Woooooool0;?ooo`030000
oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2I
oooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]
oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0Ioooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo01Soool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001]oooo00?o
09Woooooool06?ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00KOoo
o`03o`2Ioooooooo01Soool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool0
06goool00ol0VOooooooo`0Hoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo087oool006goool00ol0VOooooooo`0Ioooo0P0000[oool300001?ooo`030000oooooooo
087oool006goool00ol0VOooooooo`0/oooo0P0008;oool006goool00ol0VOooooooo`0/oooo00<0
003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o
09Woooooool0;?ooo`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool0
06goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool0
0`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]oooo00?o09Wooooo
ool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POoo
o`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?oo
o`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOoo
ooooo`0Toooo1@0000?oool00`000?ooooooo`21oooo001]oooo00?o09Woooooool09_ooo`030000
oooooooo00?oool00`000?ooooooo`21oooo001]oooo00?o09Woooooool09_ooo`030000oooooooo
00?oool30000POooo`00KOooo`03o`2Ioooooooo02Koool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00KOooo`03o`2Ioooooooo02Koool00`000?ooooooo`03oooo00<0003oooooool0POoo
o`00KOooo`03o`2Ioooooooo02Goool200001Oooo`030000oooooooo087oool006goool00ol0VOoo
ooooo`0/oooo0P0008;oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOoo
o`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`030000
oooooooo087oool006goool00ol0VOooooooo`0/oooo0P0008;oool006goool00ol0VOooooooo`0/
oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]
oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo0P00
08;oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo
02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool0
06goool00ol0VOooooooo`0/oooo0P0008;oool006goool00ol0VOooooooo`0/oooo00<0003ooooo
ool0POooo`00KOooo`03o`2Ioooooooo01Soool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001]oooo00?o09Woooooool06_ooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool06_ooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool0
0`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool5000000?oool00000
00000`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?oo
o`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.35271 .38627 L
.36173 .38627 L
.36405 .38627 L
.3652 .38627 L
.36626 .38627 L
s
.36626 .38627 m
.36645 .61803 L
s
0 .4 1 r
.02381 .38976 m
.06244 .39043 L
.10458 .3913 L
.14415 .39226 L
.18221 .39332 L
.22272 .39458 L
.26171 .39591 L
.30316 .3974 L
.32392 .39814 L
.34309 .3988 L
.35271 .39911 L
.36173 .3994 L
.36405 .39947 L
.3652 .39951 L
.36626 .39954 L
.36748 .38627 L
.36812 .38627 L
.36881 .38627 L
.37114 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0706Ko00?oool0003oool02Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`03oooo00D0I_ooooooooooool0
00002_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000`oooo00<0
I_l00000I_l09@1Vo`ooool00`000?ooooooo`03oooo00<0I_ooooooool0;?ooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`00F?oooaH0I_l^oooo00<0003ooooo
ool0POooo`00KOooo`03o`2Ioooooooo02coool20000P_ooo`00KOooo`03o`2Ioooooooo02coool0
0`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool0
0ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool20000P_oo
o`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?oo
o`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOoo
o`03o`2Ioooooooo02coool20000P_ooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21
oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/
oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool20000P_ooo`00KOooo`03o`2I
oooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool06Oooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo087oool006goool00ol0VOooooooo`0Hoooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo
01Soool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006goool00ol0VOoo
ooooo`0Hoooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001]oooo00?o
09Woooooool06?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21
oooo001]oooo00?o09Woooooool06Oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001]
oooo00?o09Woooooool0;?ooo`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo
087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo
02coool20000P_ooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o
09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003ooooo
ool0POooo`00KOooo`03o`2Ioooooooo02coool20000P_ooo`00KOooo`03o`2Ioooooooo02coool0
0`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool0
0ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool20000P_oo
o`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool09?oo
o`D00003oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02Koool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02Koool00`000?ooooooo`03oooo0`00
087oool006goool00ol0VOooooooo`0Voooo00<0003oooooool00oooo`030000oooooooo087oool0
06goool00ol0VOooooooo`0Voooo00<0003oooooool00oooo`030000oooooooo087oool006goool0
0ol0VOooooooo`0Uoooo0P0000Goool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?oo
o`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOoo
ooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21
oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]oooo00?o09Woooooool0;?ooo`030000
oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0003oooooool0POooo`00KOooo`03o`2I
oooooooo02coool00`000?ooooooo`21oooo001]oooo00?o09Woooooool0;?ooo`800022oooo001]
oooo00?o09Woooooool0;?ooo`030000oooooooo087oool006goool00ol0VOooooooo`0/oooo00<0
003oooooool0POooo`00KOooo`03o`2Ioooooooo02coool00`000?ooooooo`21oooo001]oooo00?o
09Woooooool0;?ooo`800022oooo001]oooo00?o09Woooooool0;?ooo`030000oooooooo087oool0
06goool00ol0VOooooooo`0Hoooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POoo
o`00KOooo`03o`2Ioooooooo01[oool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00KOooo`03o`2Ioooooooo01[oool00`000?ooooooo`0:oooo00<0003ooooo
ool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003ooooo
ool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@000003oooo0000000000800003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000Koool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002_ooo`030000oooooooo00?oool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_oo
o`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.35271 .38627 L
.36173 .38627 L
.36405 .38627 L
.36626 .38627 L
.36748 .38627 L
.36817 .38627 L
s
.36817 .38627 m
.36827 .61803 L
s
0 .4 1 r
.02381 .39005 m
.06244 .39078 L
.10458 .39172 L
.14415 .39276 L
.18221 .39391 L
.22272 .39528 L
.26171 .39672 L
.30316 .39833 L
.32392 .39913 L
.34309 .39984 L
.35271 .40019 L
.36173 .4005 L
.36405 .40058 L
.36626 .40065 L
.36748 .4007 L
.36817 .40072 L
.36881 .38627 L
.36994 .38627 L
.37114 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0706Ko00?oool0003oool02Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`04oooo00@0I_ooooooool0000:
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0033oool00`1Vo`00
001Vo`0K06Ko6Oooo`030000oooooooo00Coool00`1Vooooooooo`0[oooo00<0003oooooool0<ooo
o`030000oooooooo03?oool00`000?ooooooo`0Eoooo001>oooo6`1Vo`Goool00`1Vooooooooo`0[
oooo00<0003oooooool0POooo`00JOooo`H0I_l]oooo0P0008;oool006koool00ol0VOooooooo`0[
oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P00
08;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool0
06koool00ol0VOooooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Wooooo
ool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P0008;oool006koool0
0ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01Soool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`21oooo001^oooo00?o09Woooooool05oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool006koool00ol0VOoo
ooooo`0Goooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001^oooo00?o
09Woooooool05oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo01Ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo01Soool200002_ooo`<00004oooo00<0003oooooool0POoo
o`00K_ooo`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOoo
ooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000
oooooooo087oool006koool00ol0VOooooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[
oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P00
08;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02?oool500000oooo`030000oooooooo087oool006koool00ol0VOooooooo`0Uoooo00<0003ooooo
ool00oooo`030000oooooooo087oool006koool00ol0VOooooooo`0Uoooo00<0003oooooool00ooo
o`<00021oooo001^oooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001^oooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool09?ooo`800005oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o
09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool0
0`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool0
0ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool20000P_oo
o`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:ooo
o`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21
oooo001^oooo00?o09Woooooool05oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo
087oool006koool00ol0VOooooooo`0Ioooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo087oool006koool00ol0VOooooooo`0Ioooo00<0003oooooool02_ooo`030000
oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000
oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00002oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool007Woool0
0`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.35271 .38627 L
.36173 .38627 L
.36626 .38627 L
.36757 .38627 L
.36881 .38627 L
.36992 .38627 L
s
.36992 .38627 m
.3701 .61803 L
s
0 .4 1 r
.02381 .39034 m
.06244 .39113 L
.10458 .39214 L
.14415 .39326 L
.18221 .3945 L
.22272 .39598 L
.26171 .39753 L
.30316 .39926 L
.32392 .40012 L
.34309 .4009 L
.35271 .40127 L
.36173 .4016 L
.36626 .40177 L
.36757 .40181 L
.36881 .40186 L
.36992 .4019 L
.37114 .38627 L
.37184 .38627 L
.3725 .38627 L
.37374 .38627 L
.37651 .38627 L
.3815 .38627 L
.42005 .38627 L
.46105 .38627 L
.50054 .38627 L
.53851 .38627 L
.57894 .38627 L
.61785 .38627 L
.65921 .38627 L
.69905 .38627 L
.73738 .38627 L
.77816 .38627 L
.81743 .38627 L
.85518 .38627 L
.89538 .38627 L
.93407 .38627 L
.97521 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0706Ko00?oool0003oool02Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`04oooo00@0I_ooooooool0000:
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0033oool00`1Vo`00
001Vo`0K06Ko6Oooo`030000oooooooo00Coool00`1Vooooooooo`0[oooo00<0003oooooool0<ooo
o`030000oooooooo03?oool00`000?ooooooo`0Eoooo001>oooo4P1Vo`koool00`1Vooooooooo`0[
oooo00<0003oooooool0POooo`00H?ooo`l0I_l]oooo0P0008;oool006koool00ol0VOooooooo`0[
oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P00
08;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool0
06koool00ol0VOooooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Wooooo
ool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P0008;oool006koool0
0ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01Soool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`21oooo001^oooo00?o09Woooooool05oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool006koool00ol0VOoo
ooooo`0Goooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001^oooo00?o
09Woooooool05oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo01Ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo01Soool200002_ooo`<00004oooo00<0003oooooool0POoo
o`00K_ooo`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOoo
ooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000
oooooooo087oool006koool00ol0VOooooooo`0[oooo0P0008;oool006koool00ol0VOooooooo`0[
oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo0P00
08;oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02?oool500000oooo`030000oooooooo087oool006koool00ol0VOooooooo`0Uoooo00<0003ooooo
ool00oooo`030000oooooooo087oool006koool00ol0VOooooooo`0Uoooo00<0003oooooool00ooo
o`<00021oooo001^oooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001^oooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001^
oooo00?o09Woooooool09?ooo`800005oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo
02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o
09Woooooool0:oooo`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo00<0003ooooo
ool0POooo`00K_ooo`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool0
0`000?ooooooo`21oooo001^oooo00?o09Woooooool0:oooo`030000oooooooo087oool006koool0
0ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo02_oool20000P_oo
o`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21oooo001^oooo00?o09Woooooool0:ooo
o`030000oooooooo087oool006koool00ol0VOooooooo`0[oooo00<0003oooooool0POooo`00K_oo
o`03o`2Ioooooooo02_oool20000P_ooo`00K_ooo`03o`2Ioooooooo02_oool00`000?ooooooo`21
oooo001^oooo00?o09Woooooool05oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo
087oool006koool00ol0VOooooooo`0Ioooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo087oool006koool00ol0VOooooooo`0Ioooo00<0003oooooool02_ooo`030000
oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000
oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00003oooo0`0000;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002_ooo`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.36173 .38627 L
.36626 .38627 L
.36876 .38627 L
.37114 .38627 L
.37178 .38627 L
.37247 .38627 L
s
.37247 .38627 m
.37259 .61803 L
s
0 .4 1 r
.02381 .39064 m
.06244 .39148 L
.10458 .39257 L
.14415 .39377 L
.18221 .39509 L
.22272 .39667 L
.26171 .39834 L
.30316 .4002 L
.32392 .40112 L
.34309 .40195 L
.36173 .40271 L
.36626 .40288 L
.36876 .40298 L
.37114 .40307 L
.37178 .40309 L
.37247 .40312 L
.37323 .38627 L
.37393 .38627 L
.37649 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0I_ooool000002_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Voooo2`1Vo`030000
06Ko06Ko0100I_lSoooo00<0003oooooool01Oooo`0306Kooooooooo02[oool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool004CooolD06Ko5oooo`0306Kooooooooo
02[oool00`000?ooooooo`21oooo001Hoooo601Vobcoool20000P_ooo`00Koooo`03o`2Ioooooooo
02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool0
06ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool2
0000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Wooooo
ool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POoo
o`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOoo
ooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Kooo
o`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool05oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Foooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00Koooo`03o`2I
oooooooo01Koool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool006ooool0
0ol0VOooooooo`0Foooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001_
oooo00?o09Woooooool05_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001_oooo00?o09Woooooool05oooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001_oooo00?o09Woooooool0:_ooo`800022oooo001_oooo00?o09Woooooool0:_ooo`030000
oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2I
oooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_
oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0
003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo
02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool0
06ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool2
0000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Wooooo
ool08_ooo`D00003oooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02Coool00`000?ooooooo`03
oooo0`00087oool006ooool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`030000oooooooo
087oool006ooool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`030000oooooooo087oool0
06ooool00ol0VOooooooo`0Soooo0P0000Goool00`000?ooooooo`21oooo001_oooo00?o09Wooooo
ool0:_ooo`800022oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool0
0ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`21oooo001_oooo00?o09Woooooool0:_ooo`800022oooo001_oooo00?o09Woooooool0:_oo
o`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Kooo
o`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`800022
oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Z
oooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_
oooo00?o09Woooooool0:_ooo`800022oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo
087oool006ooool00ol0VOooooooo`0Foooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00Koooo`03o`2Ioooooooo01Soool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo01Soool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@0000;oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.36173 .38627 L
.36626 .38627 L
.37114 .38627 L
.37257 .38627 L
.37328 .38627 L
.37393 .38627 L
s
.37393 .38627 m
.37412 .61803 L
s
0 .4 1 r
.02381 .39093 m
.06244 .39183 L
.10458 .39299 L
.14415 .39427 L
.18221 .39568 L
.22272 .39737 L
.26171 .39915 L
.30316 .40113 L
.32392 .40212 L
.34309 .403 L
.36173 .40381 L
.36626 .404 L
.37114 .4042 L
.37257 .40425 L
.37328 .40428 L
.37393 .40431 L
.37515 .38627 L
.3758 .38627 L
.37649 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1P1Vo`03000006Ko06Ko00L0I_l00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0I_ooool000002_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Voooo2`1Vo`030000
06Ko06Ko0100I_lSoooo00<0003oooooool01Oooo`0306Kooooooooo02[oool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool004CooolD06Ko5oooo`0306Kooooooooo
02[oool00`000?ooooooo`21oooo001Hoooo5P1Vo`03oooo06Kooooo02_oool20000P_ooo`00K_oo
o`80I_l/oooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21
oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Z
oooo0P0008;oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2I
oooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo
087oool006ooool00ol0VOooooooo`0Zoooo0P0008;oool006ooool00ol0VOooooooo`0Zoooo00<0
003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o
09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo0P0008;oool0
06ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo01Ooool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001_oooo00?o09Woooooool05_oo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool006ooool0
0ol0VOooooooo`0Foooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001_
oooo00?o09Woooooool05_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POoo
o`00Koooo`03o`2Ioooooooo01Koool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0POooo`00Koooo`03o`2Ioooooooo01Ooool200002_ooo`<00004oooo00<0003ooooo
ool0POooo`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool0
0ol0VOooooooo`0Zoooo0P0008;oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POoo
o`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_oo
o`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo0P0008;oool006ooool00ol0VOoo
ooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21
oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Z
oooo0P0008;oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2I
oooooooo02;oool500000oooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Toooo00<0
003oooooool00oooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Toooo00<0003ooooo
ool00oooo`<00021oooo001_oooo00?o09Woooooool09?ooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001_oooo00?o09Woooooool09?ooo`030000oooooooo00?oool00`000?ooooooo`21
oooo001_oooo00?o09Woooooool08oooo`800005oooo00<0003oooooool0POooo`00Koooo`03o`2I
oooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_
oooo00?o09Woooooool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0
003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo
02[oool00`000?ooooooo`21oooo001_oooo00?o09Woooooool0:_ooo`030000oooooooo087oool0
06ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POooo`00Koooo`03o`2Ioooooooo02[oool2
0000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?ooooooo`21oooo001_oooo00?o09Wooooo
ool0:_ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Zoooo00<0003oooooool0POoo
o`00Koooo`03o`2Ioooooooo02[oool20000P_ooo`00Koooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`21oooo001_oooo00?o09Woooooool05_ooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo087oool006ooool00ol0VOooooooo`0Hoooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo087oool006ooool00ol0VOooooooo`0Hoooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_oo
o`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D000001?ooo`00
0000000000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:
oooo00@0003oooooooooool300001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.36173 .38627 L
.37114 .38627 L
.37372 .38627 L
.37514 .38627 L
.37584 .38627 L
.37649 .38627 L
s
.37649 .38627 m
.37668 .61803 L
s
0 .4 1 r
.02381 .39122 m
.06244 .39218 L
.10458 .39341 L
.14415 .39477 L
.18221 .39628 L
.22272 .39807 L
.26171 .39997 L
.30316 .40207 L
.32392 .40312 L
.34309 .40406 L
.36173 .40492 L
.37114 .40533 L
.37372 .40544 L
.37514 .4055 L
.37584 .40552 L
.37649 .40555 L
.37774 .38627 L
.3784 .38627 L
.3791 .38627 L
.3815 .38627 L
.42308 .38627 L
.46315 .38627 L
.5017 .38627 L
.5427 .38627 L
.58219 .38627 L
.62016 .38627 L
.66059 .38627 L
.69949 .38627 L
.74085 .38627 L
.7807 .38627 L
.81903 .38627 L
.85981 .38627 L
.89908 .38627 L
.93683 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1@1Vo`03oooo0000oooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`06oooo00<0I_l0003oool02Ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Koooo5P1Vo`030000
06Ko06Ko00H0I_l]oooo00<0003oooooool01_ooo`0306Kooooooooo02Woool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool003[ooolN06Ko6?ooo`0306Kooooooooo
02Woool00`000?ooooooo`21oooo001Hoooo3@1Vo`_oool00`1Vooooooooo`0Yoooo0P0008;oool0
06Goool<06Ko:oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Wooooo
ool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Ooo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?oo
o`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022
oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0F
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo
01Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001`
oooo00?o09Woooooool05Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00L?ooo`03o`2Ioooooooo01Goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Eoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Foooo0P0000[oool300001?ooo`030000
oooooooo087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Y
oooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`
oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo
02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o
09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Wooooo
ool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Qoooo1@0000?oool00`000?ooooooo`21oooo001`oooo00?o09Woooooool08ooo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001`oooo00?o09Woooooool08oooo`030000
oooooooo00?oool30000POooo`00L?ooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00L?ooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02;oool200001Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POoo
o`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Ooo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21
oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Y
oooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2I
oooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0
003oooooool0POooo`00L?ooo`03o`2Ioooooooo01Goool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001`oooo00?o09Woooooool05oooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001`oooo00?o09Woooooool05oooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool500000ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003ooooo
ool00oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo
00002_ooo`030000oooooooo00Coool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00001joooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000?oool400000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.36173 .38627 L
.37114 .38627 L
.37372 .38627 L
.37649 .38627 L
.37783 .38627 L
.3791 .38627 L
s
.3791 .38627 m
.37928 .61803 L
s
0 .4 1 r
.02381 .39152 m
.06244 .39253 L
.10458 .39384 L
.14415 .39528 L
.18221 .39687 L
.22272 .39877 L
.26171 .40078 L
.30316 .40301 L
.32392 .40412 L
.34309 .40511 L
.36173 .40603 L
.37114 .40646 L
.37372 .40658 L
.37649 .4067 L
.37783 .40676 L
.3791 .40681 L
.38025 .38627 L
.3815 .38627 L
.42214 .38627 L
.46127 .38627 L
.50286 .38627 L
.54292 .38627 L
.58147 .38627 L
.62248 .38627 L
.66196 .38627 L
.69994 .38627 L
.74036 .38627 L
.77927 .38627 L
.82063 .38627 L
.86048 .38627 L
.8988 .38627 L
.93959 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1@1Vo`03oooo0000oooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`06oooo00?o09T0003oool02Ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Koooo5P1Vo`030000
06Ko06Ko00H0I_l]oooo00<0003oooooool01_ooo`03o`2I06Kooooo02Woool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool003[ooolD06Ko8_ooo`0306Kooooooooo
02Woool00`000?ooooooo`21oooo001>oooo4P1Voa3oool00`1Vooooooooo`0Yoooo0P0008;oool0
063ooolA06Ko:oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Wooooo
ool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Ooo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?oo
o`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022
oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0F
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo
01Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001`
oooo00?o09Woooooool05Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00L?ooo`03o`2Ioooooooo01Goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Eoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Foooo0P0000[oool300001?ooo`030000
oooooooo087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Y
oooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`
oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo
02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`800022oooo001`oooo00?o
09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Wooooo
ool0:Oooo`800022oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Qoooo1@0000?oool00`000?ooooooo`21oooo001`oooo00?o09Woooooool08ooo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001`oooo00?o09Woooooool08oooo`030000
oooooooo00?oool30000POooo`00L?ooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00L?ooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00L?ooo`03o`2Ioooooooo02;oool200001Oooo`030000oooooooo087oool0073oool0
0ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POoo
o`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Ooo
o`030000oooooooo087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`21
oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo087oool0073oool00ol0VOooooooo`0Y
oooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0003oooooool0POooo`00L?ooo`03o`2I
oooooooo02Woool00`000?ooooooo`21oooo001`oooo00?o09Woooooool0:Oooo`030000oooooooo
087oool0073oool00ol0VOooooooo`0Yoooo0P0008;oool0073oool00ol0VOooooooo`0Yoooo00<0
003oooooool0POooo`00L?ooo`03o`2Ioooooooo01Goool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001`oooo00?o09Woooooool05oooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001`oooo00?o09Woooooool05oooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool500000_oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007[oool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.32392 .38627 L
.34309 .38627 L
.36173 .38627 L
.37114 .38627 L
.37372 .38627 L
.37649 .38627 L
.37783 .38627 L
.3791 .38627 L
.38025 .38627 L
s
.38025 .38627 m
.38044 .61803 L
s
0 .4 1 r
.02381 .39181 m
.06244 .39288 L
.10458 .39426 L
.14415 .39579 L
.18221 .39747 L
.22272 .39948 L
.26171 .40159 L
.30316 .40395 L
.32392 .40512 L
.34309 .40617 L
.36173 .40714 L
.37114 .4076 L
.37372 .40772 L
.37649 .40785 L
.37783 .40791 L
.3791 .40797 L
.38025 .40802 L
.3815 .38627 L
.38215 .38627 L
.38283 .38627 L
.38405 .38627 L
.38681 .38627 L
.39182 .38627 L
.40117 .38627 L
.42214 .38627 L
.46012 .38627 L
.50054 .38627 L
.53945 .38627 L
.58081 .38627 L
.62066 .38627 L
.65899 .38627 L
.69977 .38627 L
.73903 .38627 L
.77678 .38627 L
.81699 .38627 L
.85567 .38627 L
.89681 .38627 L
.93644 .38627 L
.97455 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1@1Vo`03oooo0000oooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Koooo5P1Vo`030000
06Ko06Ko00H0I_l]oooo00<0003oooooool01oooo`0306Kooooooooo02Soool00`000?ooooooo`0c
oooo00<0003oooooool0<oooo`030000oooooooo01Goool003[ooolD06Ko8oooo`0306Kooooooooo
02Soool00`000?ooooooo`21oooo001>oooo4P1Voa7oool00`1Vooooooooo`0Xoooo0P0008;oool0
063ooolB06Ko:_ooo`030000oooooooo087oool0073oool206Ko:_ooo`030000oooooooo087oool0
077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool2
0000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POoo
o`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOoo
ooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOoo
o`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool05Oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Doooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00LOooo`03o`2I
oooooooo01Coool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool0077oool0
0ol0VOooooooo`0Doooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool05?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool05Oooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001aoooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?ooo`030000
oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2I
oooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0
003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo
02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0
077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool2
0000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool08?ooo`D00003oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02;oool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02;oool00`000?ooooooo`03
oooo0`00087oool0077oool00ol0VOooooooo`0Roooo00<0003oooooool00oooo`030000oooooooo
087oool0077oool00ol0VOooooooo`0Roooo00<0003oooooool00oooo`030000oooooooo087oool0
077oool00ol0VOooooooo`0Qoooo0P0000Goool00`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool0
0ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?oo
o`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOoo
o`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`800022
oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0X
oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo
087oool0077oool00ol0VOooooooo`0Doooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00LOooo`03o`2Ioooooooo01Koool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo01Koool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@000004oooo00000000
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool300001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00001joooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001j
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.37685 .38627 L
.37926 .38627 L
.3815 .38627 L
.38263 .38627 L
s
.38263 .38627 m
.38281 .61803 L
s
0 .4 1 r
.02381 .39211 m
.06244 .39323 L
.10458 .39469 L
.14415 .39629 L
.18221 .39806 L
.22272 .40018 L
.26171 .40241 L
.30316 .40489 L
.34309 .40723 L
.36136 .40823 L
.37176 .40876 L
.37685 .40901 L
.37926 .40913 L
.3815 .40924 L
.38263 .40929 L
.38384 .38627 L
.38453 .38627 L
.38518 .38627 L
.3864 .38627 L
.39106 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`02oooo1@1Vo`03oooo0000oooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<00000I_ooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000Koooo5@1Vo`03oooo
0000oooo03Coool00`000?ooooooo`07oooo00?o09T0I_ooool0:?ooo`030000oooooooo03?oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`00<?oooa@0I_l]oooo00<0I_ooooooool0:?oo
o`030000oooooooo087oool004CooolD06Ko6Oooo`0306Kooooooooo02Soool20000P_ooo`00F?oo
oa80I_l7oooo00<0I_ooooooool0:?ooo`030000oooooooo087oool006[oool806Ko:_ooo`030000
oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2I
oooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0
003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo
02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0
077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool2
0000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool05Oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0077oool00ol0VOoo
ooooo`0Doooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00LOooo`03o`2Ioooooooo01Coool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
087oool0077oool00ol0VOooooooo`0Doooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool05?ooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`21oooo001aoooo00?o09Woooooool05Oooo`80000:oooo0`0000Coool0
0`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Wooooo
ool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POoo
o`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOoo
ooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool20000P_ooo`00LOoo
o`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`030000
oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2I
oooooooo02Soool20000P_ooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool08?ooo`D00003oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo
02;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`03oooo0`00087oool0077oool00ol0VOooooooo`0Roooo00<0003oooooool00ooo
o`030000oooooooo087oool0077oool00ol0VOooooooo`0Roooo00<0003oooooool00oooo`030000
oooooooo087oool0077oool00ol0VOooooooo`0Qoooo0P0000Goool00`000?ooooooo`21oooo001a
oooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo
087oool0077oool00ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo
02Soool00`000?ooooooo`21oooo001aoooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o
09Woooooool0:?ooo`030000oooooooo087oool0077oool00ol0VOooooooo`0Xoooo00<0003ooooo
ool0POooo`00LOooo`03o`2Ioooooooo02Soool00`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?ooo`030000oooooooo087oool0077oool0
0ol0VOooooooo`0Xoooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`21oooo001aoooo00?o09Woooooool0:?ooo`800022oooo001aoooo00?o09Woooooool0:?oo
o`030000oooooooo087oool0077oool00ol0VOooooooo`0Doooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo01Koool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00LOooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029
oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1000
00?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0003oooooool01?ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.37685 .38627 L
.3815 .38627 L
.38384 .38627 L
.38448 .38627 L
.38517 .38627 L
s
.38517 .38627 m
.38535 .61803 L
s
0 .4 1 r
.02381 .3924 m
.06244 .39359 L
.10458 .39512 L
.14415 .3968 L
.18221 .39866 L
.22272 .40089 L
.26171 .40323 L
.30316 .40584 L
.34309 .4083 L
.36136 .40934 L
.37176 .4099 L
.37685 .41017 L
.3815 .4104 L
.38384 .41051 L
.38448 .41055 L
.38517 .41058 L
.3864 .38627 L
.38766 .38627 L
.38884 .38627 L
.39106 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`00001Vooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001KooolJ06Ko00?oool0003o
ool0=?ooo`030000oooooooo00Soool00`1Vooooooooo`0Woooo00<0003oooooool0<oooo`030000
oooooooo03?oool00`000?ooooooo`0Eoooo000`oooo501Vobkoool00`1Vooooooooo`0Woooo00<0
003oooooool0POooo`00A?oooa@0I_lJoooo00<0I_ooooooool09oooo`800022oooo001Hoooo2P1V
oa3oool00`1Vooooooooo`0Woooo00<0003oooooool0POooo`00H_oooa40I_lYoooo00<0003ooooo
ool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Wooooo
ool09oooo`800022oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool0
0ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`21oooo001boooo00?o09Woooooool09oooo`800022oooo001boooo00?o09Woooooool09ooo
o`030000oooooooo087oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_oo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Woooooool09oooo`800022
oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool00ol0VOooooooo`0D
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo
01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001b
oooo00?o09Woooooool04oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00L_ooo`03o`2Ioooooooo01?oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool007;oool00ol0VOooooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool007;oool00ol0VOooooooo`0Doooo0P0000[oool300001?ooo`030000
oooooooo087oool007;oool00ol0VOooooooo`0Woooo0P0008;oool007;oool00ol0VOooooooo`0W
oooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001b
oooo00?o09Woooooool09oooo`800022oooo001boooo00?o09Woooooool09oooo`030000oooooooo
087oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`21oooo001boooo00?o09Woooooool09oooo`800022oooo001boooo00?o
09Woooooool09oooo`030000oooooooo087oool007;oool00ol0VOooooooo`0Woooo00<0003ooooo
ool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Wooooo
ool09oooo`800022oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool0
0ol0VOooooooo`0Ooooo1@0000?oool00`000?ooooooo`21oooo001boooo00?o09Woooooool08Ooo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001boooo00?o09Woooooool08Oooo`030000
oooooooo00?oool30000POooo`00L_ooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00L_ooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00L_ooo`03o`2Ioooooooo023oool200001Oooo`030000oooooooo087oool007;oool0
0ol0VOooooooo`0Woooo0P0008;oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POoo
o`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Woooooool09ooo
o`030000oooooooo087oool007;oool00ol0VOooooooo`0Woooo0P0008;oool007;oool00ol0VOoo
ooooo`0Woooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21
oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool00ol0VOooooooo`0W
oooo0P0008;oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_ooo`03o`2I
oooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Woooooool09oooo`030000oooooooo
087oool007;oool00ol0VOooooooo`0Woooo0P0008;oool007;oool00ol0VOooooooo`0Woooo00<0
003oooooool0POooo`00L_ooo`03o`2Ioooooooo01?oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001boooo00?o09Woooooool05Oooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001boooo00?o09Woooooool05Oooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool400000_oo
o`D00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?oo
o`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.37685 .38627 L
.3815 .38627 L
.38384 .38627 L
.38508 .38627 L
.3864 .38627 L
.38767 .38627 L
s
.38767 .38627 m
.38784 .61803 L
s
0 .4 1 r
.02381 .3927 m
.06244 .39394 L
.10458 .39555 L
.14415 .39731 L
.18221 .39926 L
.22272 .40159 L
.26171 .40405 L
.30316 .40678 L
.34309 .40936 L
.36136 .41046 L
.37176 .41105 L
.37685 .41132 L
.3815 .41157 L
.38384 .41169 L
.38508 .41175 L
.3864 .41182 L
.38767 .41188 L
.38881 .38627 L
.38997 .38627 L
.39106 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?l0V@1Vo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001KooolJ06Ko00?oool0003o
ool0=?ooo`030000oooooooo00Soool00ol0V@1Vooooo`0Woooo00<0003oooooool0<oooo`030000
oooooooo03?oool00`000?ooooooo`0Eoooo000`oooo501Vobkoool00`1Vooooooooo`0Woooo00<0
003oooooool0POooo`00A?ooo`X0I_lToooo00<0I_ooooooool09oooo`800022oooo001>oooo501V
oa3oool00`1Vooooooooo`0Woooo00<0003oooooool0POooo`00H_oooa40I_lYoooo00<0003ooooo
ool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Wooooo
ool09oooo`800022oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool0
0ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`21oooo001boooo00?o09Woooooool09oooo`800022oooo001boooo00?o09Woooooool09ooo
o`030000oooooooo087oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POooo`00L_oo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001boooo00?o09Woooooool09oooo`800022
oooo001boooo00?o09Woooooool09oooo`030000oooooooo087oool007;oool00ol0VOooooooo`0D
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo
01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001b
oooo00?o09Woooooool04oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00L_ooo`03o`2Ioooooooo01?oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool007;oool00ol0VOooooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool007;oool00ol0VOooooooo`0Doooo0P0000[oool300001?ooo`030000
oooooooo087oool007;oool00ol0VOooooooo`0Woooo0P0008;oool007;oool00ol0VOooooooo`0W
oooo00<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`21oooo001b
oooo00?o09Woooooool09oooo`800022oooo001boooo00?o09Woooooool09oooo`030000oooooooo
087oool007;oool00ol0VOooooooo`0Woooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo
02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`800022oooo001coooo00?o
09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo00<0003ooooo
ool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Wooooo
ool09_ooo`800022oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Noooo1@0000?oool00`000?ooooooo`21oooo001coooo00?o09Woooooool08?oo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001coooo00?o09Woooooool08?ooo`030000
oooooooo00?oool30000POooo`00Loooo`03o`2Ioooooooo023oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00Loooo`03o`2Ioooooooo023oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00Loooo`03o`2Ioooooooo01ooool200001Oooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POoo
o`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_oo
o`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOoo
ooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21
oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0V
oooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2I
oooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo
087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0
003oooooool0POooo`00Loooo`03o`2Ioooooooo01;oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001coooo00?o09Woooooool05?ooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001coooo00?o09Woooooool05?ooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool400000_oo
o`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004
oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.37685 .38627 L
.3815 .38627 L
.38384 .38627 L
.3864 .38627 L
.38757 .38627 L
.38881 .38627 L
s
.38881 .38627 m
.38899 .61803 L
s
0 .4 1 r
.02381 .393 m
.06244 .3943 L
.10458 .39597 L
.14415 .39782 L
.18221 .39986 L
.22272 .4023 L
.26171 .40487 L
.30316 .40773 L
.34309 .41043 L
.36136 .41158 L
.37176 .41219 L
.37685 .41248 L
.3815 .41274 L
.38384 .41286 L
.3864 .413 L
.38757 .41306 L
.38881 .41312 L
.38999 .38627 L
.39106 .38627 L
.40134 .38627 L
.42237 .38627 L
.46243 .38627 L
.50098 .38627 L
.54199 .38627 L
.58147 .38627 L
.61945 .38627 L
.65987 .38627 L
.69878 .38627 L
.74014 .38627 L
.77998 .38627 L
.81831 .38627 L
.8591 .38627 L
.89836 .38627 L
.93611 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooo`1Vo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001KooolJ06Ko00?oool0003o
ool0=?ooo`030000oooooooo00Woool00`1Vooooooooo`0Voooo00<0003oooooool0<oooo`030000
oooooooo03?oool00`000?ooooooo`0Eoooo000`oooo501Vobooool00`1Vooooooooo`0Voooo00<0
003oooooool0POooo`00A?ooo`X0I_lUoooo00<0I_ooooooool09_ooo`800022oooo001>oooo501V
oa7oool00`1Vooooooooo`0Voooo00<0003oooooool0POooo`00H_ooo`/0I_l6oooo00<0I_oooooo
ool09_ooo`030000oooooooo087oool006goool706Ko:?ooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POoo
o`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_oo
o`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOoo
ooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21
oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0V
oooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2I
oooooooo01?oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001coooo00?o
09Woooooool04_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
087oool007?oool00ol0VOooooooo`0Boooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<00021oooo001coooo00?o09Woooooool04_ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0POooo`00Loooo`03o`2Ioooooooo01;oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo01?oool200002_ooo`<00004
oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2I
oooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo
087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0
003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o
09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool0
07?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POoo
o`00Loooo`03o`2Ioooooooo01koool500000oooo`030000oooooooo087oool007?oool00ol0VOoo
ooooo`0Poooo00<0003oooooool00oooo`030000oooooooo087oool007?oool00ol0VOooooooo`0P
oooo00<0003oooooool00oooo`<00021oooo001coooo00?o09Woooooool08?ooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001coooo00?o09Woooooool08?ooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001coooo00?o09Woooooool07oooo`800005oooo00<0003oooooool0POoo
o`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOoo
ooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Looo
o`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000
oooooooo087oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2I
oooooooo02Koool20000P_ooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001c
oooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo00<0
003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2Ioooooooo
02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool04_ooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Doooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Doooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool2
0000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool3
0000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`050000oooooooooooo000007[oool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004
oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.3815 .38627 L
.3864 .38627 L
.38881 .38627 L
.38999 .38627 L
.39106 .38627 L
s
.39106 .38627 m
.39124 .61803 L
s
0 .4 1 r
.02381 .39329 m
.06244 .39465 L
.10458 .3964 L
.14415 .39833 L
.18221 .40046 L
.22272 .40301 L
.26171 .4057 L
.30316 .40868 L
.34309 .4115 L
.36136 .4127 L
.37176 .41334 L
.3815 .41391 L
.3864 .41418 L
.38881 .41431 L
.38999 .41437 L
.39106 .41443 L
.3923 .38627 L
.39298 .38627 L
.39362 .38627 L
.39642 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool010000?ooool0V@1Vo`Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`005_oooa00I_l;oooo00<0
003oooooool0<oooo`030000oooooooo00Woool00ol0V@1Vooooo`0Voooo00<0003oooooool0<ooo
o`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Voooo501VocWoool00ol0V@1Vooooo`0V
oooo00<0003oooooool0POooo`00>_oooa@0I_lUoooo00<0I_ooooooool09_ooo`800022oooo001>
oooo2P1Voa_oool00`1Vooooooooo`0Voooo00<0003oooooool0POooo`00F?oooa80I_l9oooo00<0
I_ooooooool09_ooo`030000oooooooo087oool006[oool:06Ko:?ooo`030000oooooooo087oool0
07?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003ooooo
ool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Wooooo
ool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool0
0ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOoo
ooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Looo
o`03o`2Ioooooooo01?oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001c
oooo00?o09Woooooool04_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo087oool007?oool00ol0VOooooooo`0Boooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<00021oooo001coooo00?o09Woooooool04_ooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo01;oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo01?oool200002_oo
o`<00004oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Looo
o`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000
oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0V
oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001c
oooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo0P00
08;oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo
02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool0
07?oool00ol0VOooooooo`0Voooo0P0008;oool007?oool00ol0VOooooooo`0Voooo00<0003ooooo
ool0POooo`00Loooo`03o`2Ioooooooo01koool500000oooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Poooo00<0003oooooool00oooo`030000oooooooo087oool007?oool00ol0VOoo
ooooo`0Poooo00<0003oooooool00oooo`<00021oooo001coooo00?o09Woooooool08?ooo`030000
oooooooo00?oool00`000?ooooooo`21oooo001coooo00?o09Woooooool08?ooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001coooo00?o09Woooooool07oooo`800005oooo00<0003ooooo
ool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`21oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool0
0ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_oo
o`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool09_oo
o`030000oooooooo087oool007?oool00ol0VOooooooo`0Voooo00<0003oooooool0POooo`00Looo
o`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2Ioooooooo02Koool00`000?ooooooo`21
oooo001coooo00?o09Woooooool09_ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0V
oooo00<0003oooooool0POooo`00Loooo`03o`2Ioooooooo02Koool20000P_ooo`00Loooo`03o`2I
oooooooo02Koool00`000?ooooooo`21oooo001coooo00?o09Woooooool04_ooo`D00002oooo0P00
00Coool200001Oooo`030000oooooooo087oool007?oool00ol0VOooooooo`0Doooo00<0003ooooo
ool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool007?oool00ol0VOooooooo`0D
oooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo
00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P00
00[oool30000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00000oooo`@00004oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0
003oooooool01_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo00;oool500000oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002_ooo`050000
oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooo000000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Goool200000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.3815 .38627 L
.3864 .38627 L
.39106 .38627 L
.3923 .38627 L
.39298 .38627 L
.39362 .38627 L
s
.39362 .38627 m
.39374 .61803 L
s
0 .4 1 r
.02381 .39359 m
.06244 .39501 L
.10458 .39683 L
.14415 .39885 L
.18221 .40107 L
.22272 .40372 L
.26171 .40652 L
.30316 .40964 L
.34309 .41257 L
.36136 .41382 L
.37176 .41449 L
.3815 .41508 L
.3864 .41537 L
.39106 .41563 L
.3923 .4157 L
.39298 .41573 L
.39362 .41577 L
.39438 .38627 L
.39508 .38627 L
.39642 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool010000?ooooooo`1Vo`Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`005_oooa00I_l;oooo00<0
003oooooool0<oooo`030000oooooooo00[oool00`1Vooooooooo`0Uoooo00<0003oooooool0<ooo
o`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Voooo501Voc[oool00`1Vooooooooo`0U
oooo00<0003oooooool0POooo`00>_oooa@0I_lVoooo00<0I_ooooooool09Oooo`800022oooo001>
oooo2P1Voacoool00`1Vooooooooo`0Uoooo00<0003oooooool0POooo`00F?ooo`X0I_lBoooo00<0
I_ooooooool09Oooo`030000oooooooo087oool006;ooolC06Ko9oooo`030000oooooooo087oool0
07Coool00ol0VOooooooo`0Uoooo0P0008;oool007Coool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0POooo`00M?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`21oooo001doooo00?o09Wooooo
ool09Oooo`030000oooooooo087oool007Coool00ol0VOooooooo`0Uoooo0P0008;oool007Coool0
0ol0VOooooooo`0Uoooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`21oooo001doooo00?o09Woooooool09Oooo`030000oooooooo087oool007Coool00ol0VOoo
ooooo`0Uoooo0P0008;oool007Coool00ol0VOooooooo`0Uoooo00<0003oooooool0POooo`00M?oo
o`03o`2Ioooooooo01;oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001d
oooo00?o09Woooooool04Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo087oool007Coool00ol0VOooooooo`0Aoooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<00021oooo001doooo00?o09Woooooool04Oooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo017oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo01;oool200002_oo
o`<00004oooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo02Goool20000P_ooo`00M?oo
o`03o`2Ioooooooo02Goool00`000?ooooooo`21oooo001doooo00?o09Woooooool09Oooo`030000
oooooooo087oool007Coool00ol0VOooooooo`0Uoooo0P0008;oool007Coool00ol0VOooooooo`0U
oooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`21oooo001d
oooo00?o09Woooooool09Oooo`030000oooooooo087oool007Coool00ol0VOooooooo`0Uoooo0P00
08;oool007Coool00ol0VOooooooo`0Uoooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo
02Goool00`000?ooooooo`21oooo001doooo00?o09Woooooool09Oooo`030000oooooooo087oool0
07Coool00ol0VOooooooo`0Uoooo0P0008;oool007Coool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0POooo`00M?ooo`03o`2Ioooooooo01goool500000oooo`030000oooooooo087oool007Coool0
0ol0VOooooooo`0Ooooo00<0003oooooool00oooo`030000oooooooo087oool007Coool00ol0VOoo
ooooo`0Ooooo00<0003oooooool00oooo`<00021oooo001doooo00?o09Woooooool07oooo`030000
oooooooo00?oool00`000?ooooooo`21oooo001doooo00?o09Woooooool07oooo`030000oooooooo
00?oool00`000?ooooooo`21oooo001doooo00?o09Woooooool07_ooo`800005oooo00<0003ooooo
ool0POooo`00M?ooo`03o`2Ioooooooo02Goool20000P_ooo`00M?ooo`03o`2Ioooooooo02Goool0
0`000?ooooooo`21oooo001doooo00?o09Woooooool09Oooo`030000oooooooo087oool007Coool0
0ol0VOooooooo`0Uoooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo02Goool20000P_oo
o`00M?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`21oooo001doooo00?o09Woooooool09Ooo
o`030000oooooooo087oool007Coool00ol0VOooooooo`0Uoooo00<0003oooooool0POooo`00M?oo
o`03o`2Ioooooooo02Goool20000P_ooo`00M?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`21
oooo001doooo00?o09Woooooool09Oooo`030000oooooooo087oool007Coool00ol0VOooooooo`0U
oooo00<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo02Goool20000P_ooo`00M?ooo`03o`2I
oooooooo02Goool00`000?ooooooo`21oooo001doooo00?o09Woooooool04Oooo`D00002oooo0P00
00Coool200001Oooo`030000oooooooo087oool007Coool00ol0VOooooooo`0Coooo00<0003ooooo
ool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool007Coool00ol0VOooooooo`0C
oooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo
00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P00
00[oool30000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00000oooo`@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.3815 .38627 L
.3864 .38627 L
.39106 .38627 L
.39362 .38627 L
.39433 .38627 L
.39508 .38627 L
.39578 .38627 L
s
.39578 .38627 m
.39588 .61803 L
s
0 .4 1 r
.02381 .39389 m
.06244 .39537 L
.10458 .39727 L
.14415 .39936 L
.18221 .40167 L
.22272 .40444 L
.26171 .40735 L
.30316 .41059 L
.34309 .41365 L
.36136 .41495 L
.37176 .41565 L
.3815 .41626 L
.3864 .41656 L
.39106 .41683 L
.39362 .41697 L
.39433 .41701 L
.39508 .41705 L
.39578 .41709 L
.39642 .38627 L
.39764 .38627 L
.39895 .38627 L
.40134 .38627 L
.42237 .38627 L
.46337 .38627 L
.50286 .38627 L
.54083 .38627 L
.58125 .38627 L
.62016 .38627 L
.66152 .38627 L
.70137 .38627 L
.7397 .38627 L
.78048 .38627 L
.81975 .38627 L
.8575 .38627 L
.8977 .38627 L
.93639 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool01@000?ooooooooooo`1Vo`06
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001Koool@06Ko2ooo
o`030000oooooooo03?oool00`000?ooooooo`0;oooo00<0I_ooooooool09?ooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`009_oooa@0I_lkoooo00<0I_oooooo
ool09?ooo`030000oooooooo087oool003[oool:06Ko<Oooo`0306Kooooooooo02Coool20000P_oo
o`00A?oooa@0I_lMoooo00<0I_ooooooool09?ooo`030000oooooooo087oool005Soool:06Ko4ooo
o`0306Kooooooooo02Coool00`000?ooooooo`21oooo001Roooo3P1Vo`Goool00`1Vooooooooo`0T
oooo00<0003oooooool0POooo`00L?ooo`H0I_lVoooo0P0008;oool007Goool00ol0VOooooooo`0T
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001e
oooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P00
08;oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool0
07Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0Toooo00<0003ooooo
ool0POooo`00MOooo`03o`2Ioooooooo017oool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001eoooo00?o09Woooooool04?ooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0@oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<00021oooo001eoooo00?o09Woooooool04?ooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo013oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
017oool200002_ooo`<00004oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool2
0000P_ooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Wooooo
ool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool0
0ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOoo
ooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOoo
o`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000
oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0T
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo01coool500000oooo`030000oooooooo
087oool007Goool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000oooooooo087oool0
07Goool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`<00021oooo001eoooo00?o09Wooooo
ool07_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001eoooo00?o09Woooooool07_oo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001eoooo00?o09Woooooool07Oooo`800005
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_ooo`00MOooo`03o`2I
oooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo
087oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
02Coool20000P_ooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o
09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo00<0003ooooo
ool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_ooo`00MOooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool0
0ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_oo
o`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool04?oo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool007Goool00ol0VOooooooo`0B
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool007Goool0
0ol0VOooooooo`0Boooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_oo
o`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28
oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200000oooo`@00002oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`030000
oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000[oool010000?ooooooooooo`<00004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.3815 .38627 L
.39106 .38627 L
.39381 .38627 L
.39516 .38627 L
.39642 .38627 L
.39756 .38627 L
s
.39756 .38627 m
.39774 .61803 L
s
0 .4 1 r
.02381 .39419 m
.06244 .39572 L
.10458 .3977 L
.14415 .39988 L
.18221 .40228 L
.22272 .40515 L
.26171 .40818 L
.30316 .41155 L
.34309 .41473 L
.36136 .41608 L
.37176 .4168 L
.3815 .41744 L
.39106 .41803 L
.39381 .41819 L
.39516 .41827 L
.39642 .41834 L
.39756 .41841 L
.39877 .38627 L
.39947 .38627 L
.40012 .38627 L
.40134 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool01@000?ooooooooooo`1Vo`06
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001Koool@06Ko2ooo
o`030000oooooooo03?oool00`000?ooooooo`0;oooo00<0I_ooooooool09?ooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`009_oooa@0I_lkoooo00<0I_oooooo
ool09?ooo`030000oooooooo087oool003[oool:06Ko<Oooo`0306Kooooooooo02Coool20000P_oo
o`00A?ooo`X0I_lWoooo00<0I_ooooooool09?ooo`030000oooooooo087oool004kooolD06Ko4ooo
o`0306Kooooooooo02Coool00`000?ooooooo`21oooo001Roooo201Vo`_oool00`1Vooooooooo`0T
oooo00<0003oooooool0POooo`00J_ooo``0I_lVoooo0P0008;oool007Goool00ol0VOooooooo`0T
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001e
oooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P00
08;oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool0
07Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0Toooo00<0003ooooo
ool0POooo`00MOooo`03o`2Ioooooooo017oool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`21oooo001eoooo00?o09Woooooool04?ooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0@oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<00021oooo001eoooo00?o09Woooooool04?ooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo013oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
017oool200002_ooo`<00004oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool2
0000P_ooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Wooooo
ool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool0
0ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOoo
ooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOoo
o`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000
oooooooo087oool007Goool00ol0VOooooooo`0Toooo0P0008;oool007Goool00ol0VOooooooo`0T
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo01coool500000oooo`030000oooooooo
087oool007Goool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000oooooooo087oool0
07Goool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`<00021oooo001eoooo00?o09Wooooo
ool07_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001eoooo00?o09Woooooool07_oo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001eoooo00?o09Woooooool07Oooo`800005
oooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_ooo`00MOooo`03o`2I
oooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo
087oool007Goool00ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo
02Coool20000P_ooo`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o
09Woooooool09?ooo`030000oooooooo087oool007Goool00ol0VOooooooo`0Toooo00<0003ooooo
ool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_ooo`00MOooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`21oooo001eoooo00?o09Woooooool09?ooo`030000oooooooo087oool007Goool0
0ol0VOooooooo`0Toooo00<0003oooooool0POooo`00MOooo`03o`2Ioooooooo02Coool20000P_oo
o`00MOooo`03o`2Ioooooooo02Coool00`000?ooooooo`21oooo001eoooo00?o09Woooooool04?oo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool007Goool00ol0VOooooooo`0B
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo087oool007Goool0
0ol0VOooooooo`0Boooo00<0003oooooool02_ooo`030000oooooooo00;oool30000POooo`00R_oo
o`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28
oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200000oooo`@00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002_ooo`800003oooo100000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.36136 .38627 L
.37176 .38627 L
.3815 .38627 L
.39106 .38627 L
.39381 .38627 L
.39642 .38627 L
.39877 .38627 L
.39942 .38627 L
.4001 .38627 L
s
.4001 .38627 m
.40029 .61803 L
s
0 .4 1 r
.02381 .39449 m
.06244 .39608 L
.10458 .39813 L
.14415 .40039 L
.18221 .40288 L
.22272 .40587 L
.26171 .40901 L
.30316 .41251 L
.34309 .41581 L
.36136 .41721 L
.37176 .41796 L
.3815 .41863 L
.39106 .41924 L
.39381 .41941 L
.39642 .41956 L
.39877 .4197 L
.39942 .41973 L
.4001 .41977 L
.40134 .38627 L
.40203 .38627 L
.40276 .38627 L
.40406 .38627 L
.40702 .38627 L
.41237 .38627 L
.42237 .38627 L
.46034 .38627 L
.50076 .38627 L
.53967 .38627 L
.58103 .38627 L
.62088 .38627 L
.65921 .38627 L
.69999 .38627 L
.73925 .38627 L
.77701 .38627 L
.81721 .38627 L
.8559 .38627 L
.89704 .38627 L
.93666 .38627 L
.97477 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`02oooo00<0
I_ooooooool00oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000F
oooo401Vo`_oool00`000?ooooooo`0coooo00<0003oooooool03?ooo`0306Kooooooooo02?oool0
0`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool002Koool:06KoA_oo
o`0306Kooooooooo02?oool00`000?ooooooo`21oooo000`oooo501Voc;oool00`1Vooooooooo`0S
oooo0P0008;oool004Coool:06Ko:?ooo`0306Kooooooooo02?oool00`000?ooooooo`21oooo001>
oooo2P1Voakoool00`1Vooooooooo`0Soooo00<0003oooooool0POooo`00F?oooa80I_l<oooo00<0
I_ooooooool08oooo`030000oooooooo087oool006[oool=06Ko9Oooo`800022oooo001foooo00?o
09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo00<0003ooooo
ool0POooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Wooooo
ool08oooo`800022oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool0
0ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`21oooo001foooo00?o09Woooooool08oooo`800022oooo001foooo00?o09Woooooool08ooo
o`030000oooooooo087oool007Koool00ol0VOooooooo`0@oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001foooo00?o09Woooooool03oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00M_ooo`03o`2Ioooooooo00ooool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0?
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool007Koool0
0ol0VOooooooo`0@oooo0P0000[oool300001?ooo`030000oooooooo087oool007Koool00ol0VOoo
ooooo`0Soooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_oo
o`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`800022
oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0S
oooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001f
oooo00?o09Woooooool08oooo`800022oooo001foooo00?o09Woooooool08oooo`030000oooooooo
087oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo
02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`800022oooo001foooo00?o
09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Koooo1@0000?oool0
0`000?ooooooo`21oooo001foooo00?o09Woooooool07Oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001foooo00?o09Woooooool07Oooo`030000oooooooo00?oool30000POooo`00M_oo
o`03o`2Ioooooooo01goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00M_ooo`03o`2I
oooooooo01goool00`000?ooooooo`03oooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo
01coool200001Oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo0P0008;oool0
07Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool0
0`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool0
0ol0VOooooooo`0Soooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POoo
o`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08ooo
o`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo0P0008;oool007Koool00ol0VOoo
ooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21
oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0S
oooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2I
oooooooo00ooool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001foooo00?o
09Woooooool04Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001foooo00?o09Woooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000?oool400000oooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Woool00`000?ooooooo`02oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.39174 .38627 L
.39675 .38627 L
.39894 .38627 L
.40134 .38627 L
.40262 .38627 L
s
.40262 .38627 m
.4028 .61803 L
s
0 .4 1 r
.02381 .3948 m
.06244 .39644 L
.10458 .39857 L
.14415 .40091 L
.18221 .40349 L
.22272 .40659 L
.26171 .40985 L
.30316 .41347 L
.34309 .41689 L
.3815 .41981 L
.39174 .42049 L
.39675 .4208 L
.39894 .42093 L
.40134 .42107 L
.40262 .42115 L
.40381 .38627 L
.40494 .38627 L
.40616 .38627 L
.41134 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`02oooo00?o
09T0I_ooool00oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000F
oooo1@1VoaKoool00`000?ooooooo`0coooo00<0003oooooool03?ooo`03o`2I06Kooooo02?oool0
0`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool001_ooolE06KoA_oo
o`03o`2I06Kooooo02?oool00`000?ooooooo`21oooo000`oooo501Voc;oool00ol0V@1Vooooo`0S
oooo0P0008;oool004Coool:06Ko:?ooo`0306Kooooooooo02?oool00`000?ooooooo`21oooo001>
oooo2P1Voakoool00`1Vooooooooo`0Soooo00<0003oooooool0POooo`00F?ooo`X0I_lDoooo00<0
I_ooooooool08oooo`030000oooooooo087oool006;oool:06Ko2_ooo`0306Kooooooooo02?oool2
0000P_ooo`00K?ooo`/0I_lUoooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool0
0`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool0
0ol0VOooooooo`0Soooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POoo
o`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08ooo
o`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo0P0008;oool007Koool00ol0VOoo
ooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo013oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001foooo00?o09Woooooool03oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007Koool00ol0VOooooooo`0?
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001foooo00?o09Wooooo
ool03oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00M_ooo`03o`2I
oooooooo00ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00M_ooo`03o`2Ioooooooo013oool200002_ooo`<00004oooo00<0003oooooool0POooo`00M_oo
o`03o`2Ioooooooo02?oool20000P_ooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21
oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0S
oooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2I
oooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`030000oooooooo
087oool007Koool00ol0VOooooooo`0Soooo0P0008;oool007Koool00ol0VOooooooo`0Soooo00<0
003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o
09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo0P0008;oool0
07Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo01_oool5
00000oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Moooo00<0003oooooool00ooo
o`030000oooooooo087oool007Koool00ol0VOooooooo`0Moooo00<0003oooooool00oooo`<00021
oooo001foooo00?o09Woooooool07Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001f
oooo00?o09Woooooool07Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001foooo00?o
09Woooooool07?ooo`800005oooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool2
0000P_ooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Wooooo
ool08oooo`030000oooooooo087oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POoo
o`00M_ooo`03o`2Ioooooooo02?oool20000P_ooo`00M_ooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`21oooo001foooo00?o09Woooooool08oooo`030000oooooooo087oool007Koool00ol0VOoo
ooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2Ioooooooo02?oool20000P_ooo`00M_oo
o`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001foooo00?o09Woooooool08oooo`030000
oooooooo087oool007Koool00ol0VOooooooo`0Soooo00<0003oooooool0POooo`00M_ooo`03o`2I
oooooooo02?oool20000P_ooo`00M_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`21oooo001f
oooo00?o09Woooooool03oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07Koool00ol0VOooooooo`0Aoooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007Koool00ol0VOooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`@00002oooo0`0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00<0003oooooool01Oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo0`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000coool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.39174 .38627 L
.39675 .38627 L
.40134 .38627 L
.40252 .38627 L
.40381 .38627 L
s
.40381 .38627 m
.40399 .61803 L
s
0 .4 1 r
.02381 .3951 m
.06244 .3968 L
.10458 .39901 L
.14415 .40143 L
.18221 .40411 L
.22272 .40731 L
.26171 .41068 L
.30316 .41444 L
.34309 .41798 L
.3815 .421 L
.39174 .42171 L
.39675 .42203 L
.40134 .42231 L
.40252 .42238 L
.40381 .42246 L
.40503 .38627 L
.40616 .38627 L
.41134 .38627 L
.42237 .38627 L
.4615 .38627 L
.50308 .38627 L
.54314 .38627 L
.58169 .38627 L
.6227 .38627 L
.66219 .38627 L
.70016 .38627 L
.74058 .38627 L
.77949 .38627 L
.82085 .38627 L
.8607 .38627 L
.89903 .38627 L
.93981 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`03oooo00<0
I_ooooooool00_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000F
oooo1@1VoaKoool00`000?ooooooo`0coooo00<0003oooooool03Oooo`0306Kooooooooo02;oool0
0`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool001_ooolE06KoAooo
o`0306Kooooooooo02;oool00`000?ooooooo`21oooo000`oooo2P1Vocgoool00`1Vooooooooo`0R
oooo0P0008;oool003[ooolD06Ko:Oooo`0306Kooooooooo02;oool00`000?ooooooo`21oooo001>
oooo2P1Voaooool00`1Vooooooooo`0Roooo00<0003oooooool0POooo`00F?ooo`X0I_lEoooo00<0
I_ooooooool08_ooo`030000oooooooo087oool006;oool:06Ko2oooo`0306Kooooooooo02;oool2
0000P_ooo`00K?ooo``0I_lToooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool0
0ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_oo
o`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOoo
ooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo00ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001goooo00?o09Woooooool03_ooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0>
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001goooo00?o09Wooooo
ool03_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo00koool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo00ooool200002_ooo`<00004oooo00<0003oooooool0POooo`00Mooo
o`03o`2Ioooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21
oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0R
oooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo
087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0
003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o
09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool0
07Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo01[oool5
00000oooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Loooo00<0003oooooool00ooo
o`030000oooooooo087oool007Ooool00ol0VOooooooo`0Loooo00<0003oooooool00oooo`<00021
oooo001goooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001g
oooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001goooo00?o
09Woooooool06oooo`800005oooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool2
0000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Wooooo
ool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?oo
ooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOoo
ooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool20000P_ooo`00Mooo
o`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000
oooooooo087oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001g
oooo00?o09Woooooool03_ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07Ooool00ol0VOooooooo`0@oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007Ooool00ol0VOooooooo`0@oooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002_ooo`030000oooooooo
00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`00
00_oool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.39174 .38627 L
.40134 .38627 L
.40381 .38627 L
.40503 .38627 L
.40616 .38627 L
s
.40616 .38627 m
.40635 .61803 L
s
0 .4 1 r
.02381 .3954 m
.06244 .39717 L
.10458 .39944 L
.14415 .40195 L
.18221 .40472 L
.22272 .40803 L
.26171 .41152 L
.30316 .4154 L
.34309 .41907 L
.3815 .4222 L
.39174 .42292 L
.40134 .42355 L
.40381 .4237 L
.40503 .42377 L
.40616 .42384 L
.40745 .38627 L
.40814 .38627 L
.40887 .38627 L
.41134 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`03oooo00?o
09T0I_ooool00_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000F
oooo1@1VoaKoool00`000?ooooooo`0coooo00<0003oooooool03Oooo`03o`2I06Kooooo02;oool0
0`000?ooooooo`0coooo00<0003oooooool0<oooo`030000oooooooo01Goool001_ooolE06KoAooo
o`03o`2I06Kooooo02;oool00`000?ooooooo`21oooo000`oooo2P1Vocgoool00ol0V@1Vooooo`0R
oooo0P0008;oool003[oool:06Ko<oooo`0306Kooooooooo02;oool00`000?ooooooo`21oooo0014
oooo501Voaooool00`1Vooooooooo`0Roooo00<0003oooooool0POooo`00F?ooo`X0I_lEoooo00<0
I_ooooooool08_ooo`030000oooooooo087oool006;oool:06Ko2oooo`0306Kooooooooo02;oool2
0000P_ooo`00K?ooo``0I_lToooo00<0003oooooool0POooo`00Moooo`0306Kooooooooo02;oool0
0`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool0
0ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_oo
o`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOoo
ooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo00ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001goooo00?o09Woooooool03_ooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0>
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001goooo00?o09Wooooo
ool03_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo00koool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo00ooool200002_ooo`<00004oooo00<0003oooooool0POooo`00Mooo
o`03o`2Ioooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21
oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0R
oooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo
087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool007Ooool00ol0VOooooooo`0Roooo00<0
003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o
09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo0P0008;oool0
07Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo01[oool5
00000oooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Loooo00<0003oooooool00ooo
o`030000oooooooo087oool007Ooool00ol0VOooooooo`0Loooo00<0003oooooool00oooo`<00021
oooo001goooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001g
oooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001goooo00?o
09Woooooool06oooo`800005oooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool2
0000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Wooooo
ool08_ooo`030000oooooooo087oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POoo
o`00Moooo`03o`2Ioooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?oo
ooooo`21oooo001goooo00?o09Woooooool08_ooo`030000oooooooo087oool007Ooool00ol0VOoo
ooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2Ioooooooo02;oool20000P_ooo`00Mooo
o`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001goooo00?o09Woooooool08_ooo`030000
oooooooo087oool007Ooool00ol0VOooooooo`0Roooo00<0003oooooool0POooo`00Moooo`03o`2I
oooooooo02;oool20000P_ooo`00Moooo`03o`2Ioooooooo02;oool00`000?ooooooo`21oooo001g
oooo00?o09Woooooool03_ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07Ooool00ol0VOooooooo`0@oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007Ooool00ol0VOooooooo`0@oooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800003oooo1@0000;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.39174 .38627 L
.40134 .38627 L
.40616 .38627 L
.40755 .38627 L
.40887 .38627 L
s
.40887 .38627 m
.40904 .61803 L
s
0 .4 1 r
.02381 .39571 m
.06244 .39753 L
.10458 .39988 L
.14415 .40247 L
.18221 .40533 L
.22272 .40876 L
.26171 .41236 L
.30316 .41638 L
.34309 .42016 L
.3815 .4234 L
.39174 .42415 L
.40134 .42479 L
.40616 .42509 L
.40755 .42518 L
.40887 .42526 L
.41005 .38627 L
.41134 .38627 L
.42237 .38627 L
.46301 .38627 L
.50214 .38627 L
.54372 .38627 L
.58379 .38627 L
.62234 .38627 L
.66334 .38627 L
.70283 .38627 L
.7408 .38627 L
.78123 .38627 L
.82014 .38627 L
.8615 .38627 L
.90134 .38627 L
.93967 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00D0
I_ooooooooooool000002_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001Koool506Ko5_oo
o`030000oooooooo03?oool00`000?ooooooo`0>oooo00<0I_ooooooool08Oooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`006ooooaD0I_m8oooo00<0I_oooooo
ool08Oooo`030000oooooooo087oool0033oool:06Ko?_ooo`0306Kooooooooo027oool20000P_oo
o`00>_ooo`X0I_ldoooo00<0I_ooooooool08Oooo`030000oooooooo087oool004Coool:06Ko:_oo
o`0306Kooooooooo027oool00`000?ooooooo`21oooo001>oooo2P1Vob3oool00`1Vooooooooo`0Q
oooo00<0003oooooool0POooo`00F?ooo`X0I_lFoooo00<0I_ooooooool08Oooo`800022oooo001R
oooo4@1Vo`Goool00`1Vooooooooo`0Qoooo00<0003oooooool0POooo`00Loooo`H0I_lSoooo00<0
003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o
09Woooooool08Oooo`800022oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool0
0`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`800022oooo001hoooo00?o09Wooooo
ool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0>oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo00goool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001hoooo00?o09Woooooool03Ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00N?ooo`03o`2Ioooooooo
00goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0>oooo0P0000[oool300001?ooo`030000oooooooo087oool007Soool0
0ol0VOooooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POoo
o`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Ooo
o`800022oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21
oooo001hoooo00?o09Woooooool08Oooo`800022oooo001hoooo00?o09Woooooool08Oooo`030000
oooooooo087oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2I
oooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`800022oooo001h
oooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Ioooo1@00
00?oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool06oooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001hoooo00?o09Woooooool06oooo`030000oooooooo00?oool30000POoo
o`00N?ooo`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N?oo
o`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N?ooo`03o`2I
oooooooo01[oool200001Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Qoooo0P00
08;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo
027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003ooooo
ool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Wooooo
ool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Qoooo0P0008;oool007Soool0
0ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?oo
ooooo`21oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?oo
o`03o`2Ioooooooo00goool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001h
oooo00?o09Woooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001hoooo00?o09Woooooool03oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Coool200000oooo`@00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000oooooooo00Coool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.39174 .38627 L
.40134 .38627 L
.40616 .38627 L
.40755 .38627 L
.40887 .38627 L
.41005 .38627 L
s
.41005 .38627 m
.41024 .61803 L
s
0 .4 1 r
.02381 .39601 m
.06244 .39789 L
.10458 .40032 L
.14415 .403 L
.18221 .40595 L
.22272 .40949 L
.26171 .41321 L
.30316 .41735 L
.34309 .42126 L
.3815 .4246 L
.39174 .42537 L
.40134 .42604 L
.40616 .42635 L
.40755 .42644 L
.40887 .42652 L
.41005 .42659 L
.41134 .38627 L
.41209 .38627 L
.41279 .38627 L
.41411 .38627 L
.41706 .38627 L
.42237 .38627 L
.46092 .38627 L
.50192 .38627 L
.54141 .38627 L
.57938 .38627 L
.6198 .38627 L
.65871 .38627 L
.70007 .38627 L
.73992 .38627 L
.77825 .38627 L
.81903 .38627 L
.8583 .38627 L
.89605 .38627 L
.93625 .38627 L
.97494 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00D0
I_ooooooooooool000002_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool001Koool506Ko5_oo
o`030000oooooooo03?oool00`000?ooooooo`0>oooo00<0I_ooooooool08Oooo`030000oooooooo
03?oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`006oooo`/0I_mBoooo00<0I_oooooo
ool08Oooo`030000oooooooo087oool002KooolD06Ko?_ooo`0306Kooooooooo027oool20000P_oo
o`00>_ooo`X0I_ldoooo00<0I_ooooooool08Oooo`030000oooooooo087oool004Coool:06Ko:_oo
o`0306Kooooooooo027oool00`000?ooooooo`21oooo001>oooo2P1Vob3oool00`1Vooooooooo`0Q
oooo00<0003oooooool0POooo`00F?ooo`X0I_lFoooo00<0I_ooooooool08Oooo`800022oooo001R
oooo2P1Vo`coool00`1Vooooooooo`0Qoooo00<0003oooooool0POooo`00K?ooo`d0I_lSoooo00<0
003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o
09Woooooool08Oooo`800022oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool0
0`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`800022oooo001hoooo00?o09Wooooo
ool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0>oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo00goool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001hoooo00?o09Woooooool03Ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000POooo`00N?ooo`03o`2Ioooooooo
00goool010000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0>oooo0P0000[oool300001?ooo`030000oooooooo087oool007Soool0
0ol0VOooooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POoo
o`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Ooo
o`800022oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21
oooo001hoooo00?o09Woooooool08Oooo`800022oooo001hoooo00?o09Woooooool08Oooo`030000
oooooooo087oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2I
oooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`800022oooo001h
oooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Ioooo1@00
00?oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool06oooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001hoooo00?o09Woooooool06oooo`030000oooooooo00?oool30000POoo
o`00N?ooo`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N?oo
o`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N?ooo`03o`2I
oooooooo01[oool200001Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Qoooo0P00
08;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo
027oool00`000?ooooooo`21oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool0
07Soool00ol0VOooooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003ooooo
ool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?ooooooo`21oooo001hoooo00?o09Wooooo
ool08Oooo`030000oooooooo087oool007Soool00ol0VOooooooo`0Qoooo0P0008;oool007Soool0
0ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?ooo`03o`2Ioooooooo027oool00`000?oo
ooooo`21oooo001hoooo00?o09Woooooool08Oooo`030000oooooooo087oool007Soool00ol0VOoo
ooooo`0Qoooo0P0008;oool007Soool00ol0VOooooooo`0Qoooo00<0003oooooool0POooo`00N?oo
o`03o`2Ioooooooo00goool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001h
oooo00?o09Woooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`21oooo001hoooo00?o09Woooooool03oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08
oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00<0003oooooool00ooo
o`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40134 .38627 L
.40616 .38627 L
.40882 .38627 L
.41134 .38627 L
.41203 .38627 L
.41276 .38627 L
s
.41276 .38627 m
.41288 .61803 L
s
0 .4 1 r
.02381 .39632 m
.06244 .39826 L
.10458 .40076 L
.14415 .40352 L
.18221 .40657 L
.22272 .41022 L
.26171 .41406 L
.30316 .41833 L
.34309 .42236 L
.3815 .4258 L
.40134 .42729 L
.40616 .42761 L
.40882 .42778 L
.41134 .42794 L
.41203 .42798 L
.41276 .42803 L
.41357 .38627 L
.41432 .38627 L
.41703 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00@0
I_ooooooool0000:oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
03?oool00`000?ooooooo`0?oooo00<0I_ooooooool08?ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`005_oooa00I_mCoooo00<0I_ooooooool08?ooo`030000
oooooooo087oool002KooolD06Ko?oooo`0306Kooooooooo023oool20000P_ooo`00>_ooo`X0I_le
oooo00<0I_ooooooool08?ooo`030000oooooooo087oool004Coool:06Ko:oooo`0306Kooooooooo
023oool00`000?ooooooo`21oooo001>oooo2P1Vob7oool00`1Vooooooooo`0Poooo00<0003ooooo
ool0POooo`00F?ooo`X0I_lGoooo00<0I_ooooooool08?ooo`800022oooo001Roooo2P1Vo`goool0
0`1Vooooooooo`0Poooo00<0003oooooool0POooo`00K?ooo``0I_l00oooo`1Vooooo`0Qoooo00<0
003oooooool0POooo`00N?ooo`80I_lRoooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo
023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o
09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo00<0003ooooo
ool0POooo`00NOooo`03o`2Ioooooooo023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool0
0`000?ooooooo`21oooo001ioooo00?o09Woooooool03Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo087oool007Woool00ol0VOooooooo`0<oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo00coool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00087oool007Woool00ol0VOooooooo`0<oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001ioooo00?o09Woooooool03?oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`21oooo001ioooo00?o
09Woooooool03Oooo`80000:oooo0`0000Coool00`000?ooooooo`21oooo001ioooo00?o09Wooooo
ool08?ooo`800022oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool0
0ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool20000P_oo
o`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?oo
o`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOoo
o`03o`2Ioooooooo023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21
oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0P
oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool20000P_ooo`00NOooo`03o`2I
oooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool06?ooo`D00003oooo00<0
003oooooool0POooo`00NOooo`03o`2Ioooooooo01[oool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00NOooo`03o`2Ioooooooo01[oool00`000?ooooooo`03oooo0`00087oool007Woool0
0ol0VOooooooo`0Joooo00<0003oooooool00oooo`030000oooooooo087oool007Woool00ol0VOoo
ooooo`0Joooo00<0003oooooool00oooo`030000oooooooo087oool007Woool00ol0VOooooooo`0I
oooo0P0000Goool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?ooo`800022oooo001i
oooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo00<0
003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o
09Woooooool08?ooo`800022oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool0
07Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool0
0`000?ooooooo`21oooo001ioooo00?o09Woooooool08?ooo`800022oooo001ioooo00?o09Wooooo
ool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POoo
o`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?oo
o`800022oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOoo
ooooo`0<oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0POooo`00NOooo`03o`2I
oooooooo00koool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POoo
o`00NOooo`03o`2Ioooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021
oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000
oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800004oooo0P0000Goool300000_ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool01@000?ooooooooooo`00001joooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool010000?oo
ooooooooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool0000;oooo00@0003oooooool00002oooo00D0003oooooooooool00000N_ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`800005oooo0P0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40134 .38627 L
.40616 .38627 L
.41134 .38627 L
.41287 .38627 L
.41362 .38627 L
.41432 .38627 L
s
.41432 .38627 m
.41451 .61803 L
s
0 .4 1 r
.02381 .39662 m
.06244 .39863 L
.10458 .40121 L
.14415 .40405 L
.18221 .40719 L
.22272 .41095 L
.26171 .41491 L
.30316 .41931 L
.34309 .42346 L
.3815 .42701 L
.40134 .42854 L
.40616 .42888 L
.41134 .42921 L
.41287 .42931 L
.41362 .42936 L
.41432 .4294 L
.41562 .38627 L
.4163 .38627 L
.41703 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00Co
09T0I_ooool0000:oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
03?oool00`000?ooooooo`0?oooo00?o09T0I_ooool08?ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`005_oooa00I_mCoooo00?o09T0I_ooool08?ooo`030000
oooooooo087oool002Koool:06KoBOooo`03o`2I06Kooooo023oool20000P_ooo`00<?oooa@0I_le
oooo00?o09T0I_ooool08?ooo`030000oooooooo087oool004Coool:06Ko:oooo`0306Kooooooooo
023oool00`000?ooooooo`21oooo001>oooo2P1Vob7oool00`1Vooooooooo`0Poooo00<0003ooooo
ool0POooo`00F?ooo`X0I_lGoooo00<0I_ooooooool08?ooo`800022oooo001Roooo2P1Vo`goool0
0`1Vooooooooo`0Poooo00<0003oooooool0POooo`00K?ooo`P0I_l5oooo00<0I_ooooooool08?oo
o`030000oooooooo087oool007Coool606Ko8_ooo`030000oooooooo087oool007Woool00ol0VOoo
ooooo`0Poooo0P0008;oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOoo
o`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?ooo`030000
oooooooo087oool007Woool00ol0VOooooooo`0Poooo0P0008;oool007Woool00ol0VOooooooo`0P
oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo00goool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001ioooo00?o09Woooooool03?ooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0<oooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001ioooo00?o09Woooooool03?oo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo
00coool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00NOoo
o`03o`2Ioooooooo00goool200002_ooo`<00004oooo00<0003oooooool0POooo`00NOooo`03o`2I
oooooooo023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001i
oooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo0P00
08;oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo
023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool0
07Woool00ol0VOooooooo`0Poooo0P0008;oool007Woool00ol0VOooooooo`0Poooo00<0003ooooo
ool0POooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Wooooo
ool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo0P0008;oool007Woool0
0ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo01Soool500000ooo
o`030000oooooooo087oool007Woool00ol0VOooooooo`0Joooo00<0003oooooool00oooo`030000
oooooooo087oool007Woool00ol0VOooooooo`0Joooo00<0003oooooool00oooo`<00021oooo001i
oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001ioooo00?o
09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001ioooo00?o09Wooooo
ool06Oooo`800005oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool20000P_oo
o`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?oo
o`030000oooooooo087oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOoo
o`03o`2Ioooooooo023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21
oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo087oool007Woool00ol0VOooooooo`0P
oooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo023oool20000P_ooo`00NOooo`03o`2I
oooooooo023oool00`000?ooooooo`21oooo001ioooo00?o09Woooooool08?ooo`030000oooooooo
087oool007Woool00ol0VOooooooo`0Poooo00<0003oooooool0POooo`00NOooo`03o`2Ioooooooo
023oool20000P_ooo`00NOooo`03o`2Ioooooooo023oool00`000?ooooooo`21oooo001ioooo00?o
09Woooooool03?ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool007Woool0
0ol0VOooooooo`0>oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
087oool007Woool00ol0VOooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo00Soool0
0`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool010000?ooooooooooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40134 .38627 L
.41134 .38627 L
.41408 .38627 L
.4156 .38627 L
.41634 .38627 L
.41703 .38627 L
s
.41703 .38627 m
.41713 .61803 L
s
0 .4 1 r
.02381 .39693 m
.06244 .39899 L
.10458 .40165 L
.14415 .40458 L
.18221 .40781 L
.22272 .41168 L
.26171 .41576 L
.30316 .42029 L
.34309 .42457 L
.3815 .42823 L
.40134 .4298 L
.41134 .43049 L
.41408 .43067 L
.4156 .43076 L
.41634 .43081 L
.41703 .43085 L
.41768 .38627 L
.41837 .38627 L
.41982 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
I_ooool000002_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04?ooo`0306Kooooooooo01ooool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool@06KoE?ooo`0306Kooooooooo01ooool00`000?oo
ooooo`21oooo000Voooo2P1Vod[oool00`1Vooooooooo`0Ooooo0P0008;oool0033ooolD06Ko=_oo
o`0306Kooooooooo01ooool00`000?ooooooo`21oooo0014oooo2P1Vobcoool00`1Vooooooooo`0O
oooo00<0003oooooool0POooo`00C_ooo`P0I_lToooo00<0I_ooooooool07oooo`030000oooooooo
087oool005Koool506Ko7oooo`0306Kooooooooo01ooool20000P_ooo`00Foooo`L0I_lHoooo00<0
I_ooooooool07oooo`030000oooooooo087oool006;oool:06Ko3_ooo`0306Kooooooooo01ooool0
0`000?ooooooo`21oooo001/oooo3`1Vob7oool00`000?ooooooo`21oooo001joooo00?o09Wooooo
ool07oooo`800022oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool0
0ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`21oooo001joooo00?o09Woooooool07oooo`800022oooo001joooo00?o09Woooooool07ooo
o`030000oooooooo087oool007[oool00ol0VOooooooo`0<oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo00_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001joooo00?o09Woooooool02oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000POooo`00N_ooo`03o`2Ioooooooo00_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0;
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool007[oool0
0ol0VOooooooo`0<oooo0P0000[oool300001?ooo`030000oooooooo087oool007[oool00ol0VOoo
ooooo`0Ooooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_oo
o`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07oooo`800022
oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0O
oooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001j
oooo00?o09Woooooool07oooo`800022oooo001joooo00?o09Woooooool07oooo`030000oooooooo
087oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo
01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07oooo`800022oooo001joooo00?o
09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0Goooo1@0000?oool0
0`000?ooooooo`21oooo001joooo00?o09Woooooool06Oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001joooo00?o09Woooooool06Oooo`030000oooooooo00?oool30000POooo`00N_oo
o`03o`2Ioooooooo01Woool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N_ooo`03o`2I
oooooooo01Woool00`000?ooooooo`03oooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo
01Soool200001Oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0Ooooo0P0008;oool0
07[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool0
0`000?ooooooo`21oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool0
0ol0VOooooooo`0Ooooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POoo
o`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07ooo
o`030000oooooooo087oool007[oool00ol0VOooooooo`0Ooooo0P0008;oool007[oool00ol0VOoo
ooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21
oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0O
oooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2I
oooooooo00_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001joooo00?o
09Woooooool03Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001joooo00?o09Woooooool03Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
087oool008[oool00`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0
003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00<0003oooooool00`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40134 .38627 L
.41134 .38627 L
.41408 .38627 L
.4156 .38627 L
.41703 .38627 L
.41837 .38627 L
.41912 .38627 L
s
.41912 .38627 m
.41922 .61803 L
s
0 .4 1 r
.02381 .39724 m
.06244 .39936 L
.10458 .4021 L
.14415 .40511 L
.18221 .40844 L
.22272 .41242 L
.26171 .41661 L
.30316 .42128 L
.34309 .42568 L
.3815 .42944 L
.40134 .43107 L
.41134 .43178 L
.41408 .43196 L
.4156 .43205 L
.41703 .43214 L
.41837 .43223 L
.41912 .43227 L
.41982 .38627 L
.42105 .38627 L
.42237 .38627 L
.46395 .38627 L
.50401 .38627 L
.54257 .38627 L
.58357 .38627 L
.62306 .38627 L
.66103 .38627 L
.70145 .38627 L
.74036 .38627 L
.78172 .38627 L
.82157 .38627 L
.8599 .38627 L
.90068 .38627 L
.93994 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00?o
09T0I_l000002_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04?ooo`03o`2I06Kooooo01ooool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool@06KoE?ooo`03o`2I06Kooooo01ooool00`000?oo
ooooo`21oooo000Voooo2P1Vod[oool00ol0V@1Vooooo`0Ooooo0P0008;oool0033oool:06Ko@?oo
o`03o`2I06Kooooo01ooool00`000?ooooooo`21oooo000joooo2P1VocKoool00`1Vooooooooo`0O
oooo00<0003oooooool0POooo`00A?ooo`X0I_l/oooo00<0I_ooooooool07oooo`030000oooooooo
087oool004koool:06Ko8_ooo`0306Kooooooooo01ooool20000P_ooo`00F?ooo`X0I_lHoooo00<0
I_ooooooool07oooo`030000oooooooo087oool006;oool:06Ko3_ooo`0306Kooooooooo01ooool0
0`000?ooooooo`21oooo001/oooo2`1Vo`?oool00`1Vooooooooo`0Ooooo00<0003oooooool0POoo
o`00Moooo`@0I_lQoooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POoo
o`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07ooo
o`030000oooooooo087oool007[oool00ol0VOooooooo`0Ooooo0P0008;oool007[oool00ol0VOoo
ooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo00coool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001joooo00?o09Woooooool02oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007[oool00ol0VOooooooo`0;
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001joooo00?o09Wooooo
ool02oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00N_ooo`03o`2I
oooooooo00_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00N_ooo`03o`2Ioooooooo00coool200002_ooo`<00004oooo00<0003oooooool0POooo`00N_oo
o`03o`2Ioooooooo01ooool20000P_ooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21
oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0O
oooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2I
oooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07oooo`030000oooooooo
087oool007[oool00ol0VOooooooo`0Ooooo0P0008;oool007[oool00ol0VOooooooo`0Ooooo00<0
003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o
09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0Ooooo0P0008;oool0
07[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01Ooool5
00000oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0Ioooo00<0003oooooool00ooo
o`030000oooooooo087oool007[oool00ol0VOooooooo`0Ioooo00<0003oooooool00oooo`<00021
oooo001joooo00?o09Woooooool06Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001j
oooo00?o09Woooooool06Oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001joooo00?o
09Woooooool06?ooo`800005oooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool2
0000P_ooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Wooooo
ool07oooo`030000oooooooo087oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POoo
o`00N_ooo`03o`2Ioooooooo01ooool20000P_ooo`00N_ooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`21oooo001joooo00?o09Woooooool07oooo`030000oooooooo087oool007[oool00ol0VOoo
ooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01ooool20000P_ooo`00N_oo
o`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001joooo00?o09Woooooool07oooo`030000
oooooooo087oool007[oool00ol0VOooooooo`0Ooooo00<0003oooooool0POooo`00N_ooo`03o`2I
oooooooo01ooool20000P_ooo`00N_ooo`03o`2Ioooooooo01ooool00`000?ooooooo`21oooo001j
oooo00?o09Woooooool02oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07[oool00ol0VOooooooo`0=oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007[oool00ol0VOooooooo`0=oooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool00`000?oo
ooooo`03oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000?oool400000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40134 .38627 L
.41134 .38627 L
.41408 .38627 L
.41703 .38627 L
.41846 .38627 L
.41982 .38627 L
.42104 .38627 L
s
.42104 .38627 m
.42114 .61803 L
s
0 .4 1 r
.02381 .39755 m
.06244 .39973 L
.10458 .40255 L
.14415 .40565 L
.18221 .40906 L
.22272 .41316 L
.26171 .41747 L
.30316 .42227 L
.34309 .42679 L
.3815 .43066 L
.40134 .43233 L
.41134 .43306 L
.41408 .43325 L
.41703 .43344 L
.41846 .43353 L
.41982 .43362 L
.42104 .43369 L
.42173 .38627 L
.42237 .38627 L
.4615 .38627 L
.50308 .38627 L
.54314 .38627 L
.58169 .38627 L
.6227 .38627 L
.66219 .38627 L
.70016 .38627 L
.74058 .38627 L
.77949 .38627 L
.82085 .38627 L
.8607 .38627 L
.89903 .38627 L
.93981 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
I_l0003oool02Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04Oooo`0306Kooooooooo01koool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool@06KoEOooo`0306Kooooooooo01koool00`000?oo
ooooo`21oooo000Voooo2P1Vod_oool00`1Vooooooooo`0Noooo0P0008;oool0033oool:06Ko@Ooo
o`0306Kooooooooo01koool00`000?ooooooo`21oooo000joooo2P1VocOoool00`1Vooooooooo`0N
oooo00<0003oooooool0POooo`00A?ooo`X0I_l]oooo00<0I_ooooooool07_ooo`030000oooooooo
087oool004koool:06Ko8oooo`0306Kooooooooo01koool20000P_ooo`00F?ooo`X0I_lIoooo00<0
I_ooooooool07_ooo`030000oooooooo087oool006;oool:06Ko3oooo`0306Kooooooooo01koool0
0`000?ooooooo`21oooo001/oooo201Vo`Ooool00`1Vooooooooo`0Noooo00<0003oooooool0POoo
o`00M?ooo`P0I_lPoooo0P0008;oool007_oool00ol0VOooooooo`0Noooo00<0003oooooool0POoo
o`00Noooo`03o`2Ioooooooo01koool00`000?ooooooo`21oooo001koooo00?o09Woooooool07_oo
o`030000oooooooo087oool007_oool00ol0VOooooooo`0Noooo0P0008;oool007_oool00ol0VOoo
ooooo`0Noooo00<0003oooooool0POooo`00Noooo`03o`2Ioooooooo00_oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001koooo00?o09Woooooool02_ooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007_oool00ol0VOooooooo`0:
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001koooo00?o09Wooooo
ool02_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00Noooo`03o`2I
oooooooo00[oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00Noooo`03o`2Ioooooooo00_oool200002_ooo`<00004oooo00<0003oooooool0POooo`00Nooo
o`03o`2Ioooooooo01koool20000P_ooo`00Noooo`03o`2Ioooooooo01koool00`000?ooooooo`21
oooo001koooo00?o09Woooooool07_ooo`030000oooooooo087oool007_oool00ol0VOooooooo`0N
oooo0P0008;oool007_oool00ol0VOooooooo`0Noooo00<0003oooooool0POooo`00Noooo`03o`2I
oooooooo01koool00`000?ooooooo`21oooo001koooo00?o09Woooooool07_ooo`030000oooooooo
087oool007_oool00ol0VOooooooo`0Noooo0P0008;oool007_oool00ol0VOooooooo`0Noooo00<0
003oooooool0POooo`00Noooo`03o`2Ioooooooo01koool00`000?ooooooo`21oooo001koooo00?o
09Woooooool07_ooo`030000oooooooo087oool007_oool00ol0VOooooooo`0Noooo0P0008;oool0
07_oool00ol0VOooooooo`0Noooo00<0003oooooool0POooo`00Noooo`03o`2Ioooooooo01Koool5
00000oooo`030000oooooooo087oool007_oool00ol0VOooooooo`0Hoooo00<0003oooooool00ooo
o`030000oooooooo087oool007_oool00ol0VOooooooo`0Hoooo00<0003oooooool00oooo`<00021
oooo001koooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001k
oooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001koooo00?o
09Woooooool05oooo`800005oooo00<0003oooooool0POooo`00Noooo`03o`2Ioooooooo01koool2
0000P_ooo`00Noooo`03o`2Ioooooooo01koool00`000?ooooooo`21oooo001koooo00?o09Wooooo
ool07_ooo`030000oooooooo087oool007_oool00ol0VOooooooo`0Noooo00<0003oooooool0POoo
o`00Noooo`03o`2Ioooooooo01koool20000P_ooo`00Noooo`03o`2Ioooooooo01koool00`000?oo
ooooo`21oooo001koooo00?o09Woooooool07_ooo`030000oooooooo087oool007_oool00ol0VOoo
ooooo`0Noooo00<0003oooooool0POooo`00Noooo`03o`2Ioooooooo01koool20000P_ooo`00Nooo
o`03o`2Ioooooooo01koool00`000?ooooooo`21oooo001koooo00?o09Woooooool07_ooo`030000
oooooooo087oool007_oool00ol0VOooooooo`0Noooo00<0003oooooool0POooo`00Noooo`03o`2I
oooooooo01koool20000P_ooo`00Noooo`03o`2Ioooooooo01koool00`000?ooooooo`21oooo001k
oooo00?o09Woooooool02_ooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07_oool00ol0VOooooooo`0<oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007_oool00ol0VOooooooo`0<oooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool010000?oo
ooooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.41696 .38627 L
.41976 .38627 L
.42113 .38627 L
.42237 .38627 L
.42363 .38627 L
s
.42363 .38627 m
.42381 .61803 L
s
0 .4 1 r
.02381 .39786 m
.06244 .4001 L
.10458 .403 L
.14415 .40618 L
.18221 .40969 L
.22272 .4139 L
.26171 .41834 L
.30316 .42326 L
.34309 .42791 L
.3815 .43189 L
.40095 .43357 L
.41127 .43435 L
.41696 .43474 L
.41976 .43492 L
.42113 .43501 L
.42237 .43508 L
.42363 .43516 L
.42482 .38627 L
.42608 .38627 L
.42744 .38627 L
.43298 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04_ooo`0306Kooooooooo01goool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool506KoHOooo`0306Kooooooooo01goool00`000?oo
ooooo`21oooo000Koooo5@1Vodcoool00`1Vooooooooo`0Moooo0P0008;oool0033oool:06Ko@_oo
o`0306Kooooooooo01goool00`000?ooooooo`21oooo000joooo2P1VocSoool00`1Vooooooooo`0M
oooo00<0003oooooool0POooo`00A?ooo`X0I_l^oooo00<0I_ooooooool07Oooo`030000oooooooo
087oool004koool:06Ko9?ooo`0306Kooooooooo01goool20000P_ooo`00F?ooo`P0I_lLoooo00<0
I_ooooooool07Oooo`030000oooooooo087oool0063oool506Ko5oooo`0306Kooooooooo01goool0
0`000?ooooooo`21oooo001Uoooo1`1Voa3oool00`1Vooooooooo`0Moooo00<0003oooooool0POoo
o`00K?oooa40I_lOoooo0P0008;oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POoo
o`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool07Ooo
o`030000oooooooo087oool007coool00ol0VOooooooo`0Moooo0P0008;oool007coool00ol0VOoo
ooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo00[oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`21oooo001loooo00?o09Woooooool02Oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool007coool00ol0VOooooooo`09
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021oooo001loooo00?o09Wooooo
ool02Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0POooo`00O?ooo`03o`2I
oooooooo00Woool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POoo
o`00O?ooo`03o`2Ioooooooo00[oool200002_ooo`<00004oooo00<0003oooooool0POooo`00O?oo
o`03o`2Ioooooooo01goool20000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21
oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOooooooo`0M
oooo0P0008;oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2I
oooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool07Oooo`030000oooooooo
087oool007coool00ol0VOooooooo`0Moooo0P0008;oool007coool00ol0VOooooooo`0Moooo00<0
003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o
09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOooooooo`0Moooo0P0008;oool0
07coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01Goool5
00000oooo`030000oooooooo087oool007coool00ol0VOooooooo`0Goooo00<0003oooooool00ooo
o`030000oooooooo087oool007coool00ol0VOooooooo`0Goooo00<0003oooooool00oooo`<00021
oooo001loooo00?o09Woooooool05oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001l
oooo00?o09Woooooool05oooo`030000oooooooo00?oool00`000?ooooooo`21oooo001loooo00?o
09Woooooool05_ooo`800005oooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool2
0000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Wooooo
ool07Oooo`030000oooooooo087oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POoo
o`00O?ooo`03o`2Ioooooooo01goool20000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?oo
ooooo`21oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOoo
ooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool20000P_ooo`00O?oo
o`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool07Oooo`030000
oooooooo087oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2I
oooooooo01goool20000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001l
oooo00?o09Woooooool02Oooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo087oool0
07coool00ol0VOooooooo`0;oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo087oool007coool00ol0VOooooooo`0;oooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROooo`00R_ooo`030000oooooooo
00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool300001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002oooo`040000oooooooo00000_ooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.41696 .38627 L
.41976 .38627 L
.42237 .38627 L
.42363 .38627 L
.42482 .38627 L
.42548 .38627 L
s
.42548 .38627 m
.42559 .61803 L
s
0 .4 1 r
.02381 .39818 m
.06244 .40048 L
.10458 .40345 L
.14415 .40672 L
.18221 .41033 L
.22272 .41465 L
.26171 .4192 L
.30316 .42426 L
.34309 .42904 L
.3815 .43312 L
.40095 .43485 L
.41127 .43565 L
.41696 .43605 L
.41976 .43623 L
.42237 .4364 L
.42363 .43648 L
.42482 .43655 L
.42548 .43659 L
.42619 .38627 L
.42744 .38627 L
.43298 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04_ooo`0306Kooooooooo01goool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool506KoHOooo`0306Kooooooooo01goool00`000?oo
ooooo`21oooo000Koooo5@1Vodcoool00`1Vooooooooo`0Moooo0P0008;oool0033oool:06Ko@_oo
o`0306Kooooooooo01goool00`000?ooooooo`21oooo000joooo2P1VocSoool00`1Vooooooooo`0M
oooo00<0003oooooool0POooo`00A?ooo`X0I_l^oooo00<0I_ooooooool07Oooo`030000oooooooo
087oool004koool806Ko9_ooo`0306Kooooooooo01goool20000P_ooo`00E_ooo`D0I_lQoooo00<0
I_ooooooool07Oooo`030000oooooooo087oool005_oool706Ko6_ooo`0306Kooooooooo01goool0
0`000?ooooooo`21oooo001Roooo2P1Voa3oool00`1Vooooooooo`0Moooo00<0003oooooool0POoo
o`00K?ooo`/0I_l5oooo00<0I_ooooooool07Oooo`800022oooo001goooo1P1Voaooool00`000?oo
ooooo`21oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOoo
ooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool20000P_ooo`00O?oo
o`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool02_ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool007coool00ol0VOooooooo`09oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00O?ooo`03o`2I
oooooooo00Woool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool007coool0
0ol0VOooooooo`09oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001l
oooo00?o09Woooooool02Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001loooo00?o09Woooooool02_ooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001loooo00?o09Woooooool07Oooo`800022oooo001loooo00?o09Woooooool07Oooo`030000
oooooooo087oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2I
oooooooo01goool20000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001l
oooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOooooooo`0Moooo00<0
003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool20000P_ooo`00O?ooo`03o`2Ioooooooo
01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool0
07coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool2
0000P_ooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Wooooo
ool05Oooo`D00003oooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`03
oooo0`00087oool007coool00ol0VOooooooo`0Goooo00<0003oooooool00oooo`030000oooooooo
087oool007coool00ol0VOooooooo`0Goooo00<0003oooooool00oooo`030000oooooooo087oool0
07coool00ol0VOooooooo`0Foooo0P0000Goool00`000?ooooooo`21oooo001loooo00?o09Wooooo
ool07Oooo`800022oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool0
0ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool00`000?oo
ooooo`21oooo001loooo00?o09Woooooool07Oooo`800022oooo001loooo00?o09Woooooool07Ooo
o`030000oooooooo087oool007coool00ol0VOooooooo`0Moooo00<0003oooooool0POooo`00O?oo
o`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001loooo00?o09Woooooool07Oooo`800022
oooo001loooo00?o09Woooooool07Oooo`030000oooooooo087oool007coool00ol0VOooooooo`0M
oooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo01goool00`000?ooooooo`21oooo001l
oooo00?o09Woooooool07Oooo`800022oooo001loooo00?o09Woooooool07Oooo`030000oooooooo
087oool007coool00ol0VOooooooo`09oooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00O?ooo`03o`2Ioooooooo00_oool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo00_oool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`0000;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo1@0000?oool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000;oooo0P0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.41696 .38627 L
.42237 .38627 L
.42482 .38627 L
.42617 .38627 L
.42744 .38627 L
s
.42744 .38627 m
.42755 .61803 L
s
0 .4 1 r
.02381 .39849 m
.06244 .40085 L
.10458 .4039 L
.14415 .40726 L
.18221 .41096 L
.22272 .4154 L
.26171 .42007 L
.30316 .42526 L
.34309 .43016 L
.3815 .43436 L
.40095 .43613 L
.41127 .43695 L
.41696 .43736 L
.42237 .43772 L
.42482 .43788 L
.42617 .43796 L
.42744 .43803 L
.42816 .38627 L
.42894 .38627 L
.43031 .38627 L
.43298 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
0000I_ooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04oooo`0306Kooooooooo01coool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool506KoH_ooo`0306Kooooooooo01coool00`000?oo
ooooo`21oooo000Koooo5@1Vodgoool00`1Vooooooooo`0Loooo0P0008;oool0033oool:06Ko@ooo
o`0306Kooooooooo01coool00`000?ooooooo`21oooo000joooo2P1VocWoool00`1Vooooooooo`0L
oooo00<0003oooooool0POooo`00A?ooo`P0I_laoooo00<0I_ooooooool07?ooo`030000oooooooo
087oool004coool506Ko;?ooo`0306Kooooooooo01coool20000P_ooo`00DOooo`L0I_lUoooo00<0
I_ooooooool07?ooo`030000oooooooo087oool005Soool:06Ko6oooo`0306Kooooooooo01coool0
0`000?ooooooo`21oooo001Roooo2P1Voa7oool00`1Vooooooooo`0Loooo00<0003oooooool0POoo
o`00K?ooo`P0I_l9oooo00<0I_ooooooool07?ooo`800022oooo001doooo2P1Voakoool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOoo
ooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool20000P_ooo`00OOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool02Oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool007goool00ol0VOooooooo`08oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00OOooo`03o`2I
oooooooo00Soool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool007goool0
0ol0VOooooooo`08oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool02?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool02Oooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001moooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000
oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2I
oooooooo01coool20000P_ooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0
003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool20000P_ooo`00OOooo`03o`2Ioooooooo
01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool0
07goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool2
0000P_ooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Wooooo
ool05?ooo`D00003oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01Koool00`000?ooooooo`03
oooo0`00087oool007goool00ol0VOooooooo`0Foooo00<0003oooooool00oooo`030000oooooooo
087oool007goool00ol0VOooooooo`0Foooo00<0003oooooool00oooo`030000oooooooo087oool0
07goool00ol0VOooooooo`0Eoooo0P0000Goool00`000?ooooooo`21oooo001moooo00?o09Wooooo
ool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool0
0ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?oo
o`030000oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool07?ooo`800022
oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOooooooo`0L
oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000oooooooo
087oool007goool00ol0VOooooooo`08oooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00OOooo`03o`2Ioooooooo00[oool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo00[oool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`000003oooo00000000
00<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00008oooo1@0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool00009oooo00<0003oool000001?ooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000?oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.41696 .38627 L
.42237 .38627 L
.42482 .38627 L
.42744 .38627 L
.42821 .38627 L
.42894 .38627 L
.4296 .38627 L
s
.4296 .38627 m
.42971 .61803 L
s
0 .4 1 r
.02381 .39881 m
.06244 .40123 L
.10458 .40435 L
.14415 .4078 L
.18221 .4116 L
.22272 .41615 L
.26171 .42094 L
.30316 .42627 L
.34309 .4313 L
.3815 .4356 L
.40095 .43742 L
.41127 .43826 L
.41696 .43868 L
.42237 .43905 L
.42482 .43921 L
.42744 .43937 L
.42821 .43942 L
.42894 .43946 L
.4296 .4395 L
.43031 .38627 L
.43098 .38627 L
.4317 .38627 L
.43298 .38627 L
.44268 .38627 L
.46172 .38627 L
.49969 .38627 L
.54011 .38627 L
.57902 .38627 L
.62038 .38627 L
.66023 .38627 L
.69856 .38627 L
.73934 .38627 L
.77861 .38627 L
.81636 .38627 L
.85656 .38627 L
.89525 .38627 L
.93639 .38627 L
.97601 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
0000I_ooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool04oooo`0306Kooooooooo01coool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool506KoH_ooo`0306Kooooooooo01coool00`000?oo
ooooo`21oooo000Koooo2`1VoeOoool00`1Vooooooooo`0Loooo0P0008;oool002KooolD06Ko@ooo
o`0306Kooooooooo01coool00`000?ooooooo`21oooo000joooo1`1Voccoool00`1Vooooooooo`0L
oooo00<0003oooooool0POooo`00@Oooo`H0I_lfoooo00<0I_ooooooool07?ooo`030000oooooooo
087oool004Ooool706Ko;oooo`0306Kooooooooo01coool20000P_ooo`00C_ooo`X0I_lUoooo00<0
I_ooooooool07?ooo`030000oooooooo087oool005Soool:06Ko6oooo`0306Kooooooooo01coool0
0`000?ooooooo`21oooo001Roooo201Voa?oool00`1Vooooooooo`0Loooo00<0003oooooool0POoo
o`00J_ooo`D0I_l>oooo00<0I_ooooooool07?ooo`800022oooo001_oooo3`1Voakoool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOoo
ooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool20000P_ooo`00OOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool02Oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo087oool007goool00ol0VOooooooo`08oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00OOooo`03o`2I
oooooooo00Soool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00087oool007goool0
0ol0VOooooooo`08oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool02?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool02Oooo`80000:oooo0`0000Coool00`000?ooooooo`21
oooo001moooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000
oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2I
oooooooo01coool20000P_ooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0
003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool20000P_ooo`00OOooo`03o`2Ioooooooo
01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool0
07goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool2
0000P_ooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Wooooo
ool05?ooo`D00003oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`03oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01Koool00`000?ooooooo`03
oooo0`00087oool007goool00ol0VOooooooo`0Foooo00<0003oooooool00oooo`030000oooooooo
087oool007goool00ol0VOooooooo`0Foooo00<0003oooooool00oooo`030000oooooooo087oool0
07goool00ol0VOooooooo`0Eoooo0P0000Goool00`000?ooooooo`21oooo001moooo00?o09Wooooo
ool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool0
0ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool00`000?oo
ooooo`21oooo001moooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?oo
o`030000oooooooo087oool007goool00ol0VOooooooo`0Loooo00<0003oooooool0POooo`00OOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001moooo00?o09Woooooool07?ooo`800022
oooo001moooo00?o09Woooooool07?ooo`030000oooooooo087oool007goool00ol0VOooooooo`0L
oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo01coool00`000?ooooooo`21oooo001m
oooo00?o09Woooooool07?ooo`800022oooo001moooo00?o09Woooooool07?ooo`030000oooooooo
087oool007goool00ol0VOooooooo`08oooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00OOooo`03o`2Ioooooooo00[oool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0POooo`00OOooo`03o`2Ioooooooo00[oool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00021oooo002:oooo00<0003oooooool02?ooo`800029oooo002:oooo00<0
003oooooool02?ooo`030000oooooooo08Soool008Woool200002_ooo`<00028oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`000003oooo00000000
00800003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`040000oooooooo00001_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002?ooo`D00002oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002Oooo`030000oooo000000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000?oool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.41696 .38627 L
.42237 .38627 L
.42744 .38627 L
.42883 .38627 L
.43031 .38627 L
.43103 .38627 L
.43171 .38627 L
s
.43171 .38627 m
.4319 .61803 L
s
0 .4 1 r
.02381 .39912 m
.06244 .40161 L
.10458 .40481 L
.14415 .40834 L
.18221 .41224 L
.22272 .4169 L
.26171 .42182 L
.30316 .42728 L
.34309 .43243 L
.3815 .43684 L
.40095 .43871 L
.41127 .43957 L
.41696 .44 L
.42237 .44038 L
.42744 .44071 L
.42883 .44079 L
.43031 .44088 L
.43103 .44093 L
.43171 .44096 L
.43298 .38627 L
.43416 .38627 L
.4354 .38627 L
.43764 .38627 L
.44268 .38627 L
.46172 .38627 L
.49969 .38627 L
.54011 .38627 L
.57902 .38627 L
.62038 .38627 L
.66023 .38627 L
.69856 .38627 L
.73934 .38627 L
.77861 .38627 L
.81636 .38627 L
.85656 .38627 L
.89525 .38627 L
.93639 .38627 L
.97601 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oool0I_l02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?ooooooo`0c
oooo00<0003oooooool05?ooo`0306Kooooooooo01_oool00`000?ooooooo`0coooo00<0003ooooo
ool0<oooo`030000oooooooo01Goool001Koool506KoHoooo`0306Kooooooooo01_oool00`000?oo
ooooo`21oooo000Koooo2`1VoeSoool00`1Vooooooooo`0Koooo0P0008;oool002Koool:06KoC_oo
o`0306Kooooooooo01_oool00`000?ooooooo`21oooo000`oooo2P1VodCoool00`1Vooooooooo`0K
oooo00<0003oooooool0POooo`00>_ooo`X0I_ljoooo00<0I_ooooooool06oooo`030000oooooooo
087oool004Coool:06Ko<?ooo`0306Kooooooooo01_oool20000P_ooo`00C_ooo`X0I_lVoooo00<0
I_ooooooool06oooo`030000oooooooo087oool005Soool806Ko7_ooo`0306Kooooooooo01_oool0
0`000?ooooooo`21oooo001Poooo1@1VoaWoool00`1Vooooooooo`0Koooo00<0003oooooool0POoo
o`00IOooo`L0I_lBoooo00<0I_ooooooool06oooo`800022oooo001/oooo2`1Vo`Ooool00`1Voooo
ooooo`0Koooo00<0003oooooool0POooo`00Moooo`P0I_lMoooo00<0003oooooool0POooo`00O_oo
o`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06oooo`800022
oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`08
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo
00Ooool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21oooo001n
oooo00?o09Woooooool01oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000POoo
o`00O_ooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
087oool007koool00ol0VOooooooo`07oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo087oool007koool00ol0VOooooooo`08oooo0P0000[oool300001?ooo`030000
oooooooo087oool007koool00ol0VOooooooo`0Koooo0P0008;oool007koool00ol0VOooooooo`0K
oooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001n
oooo00?o09Woooooool06oooo`800022oooo001noooo00?o09Woooooool06oooo`030000oooooooo
087oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo
01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06oooo`800022oooo001noooo00?o
09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0Koooo00<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Wooooo
ool06oooo`800022oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool007koool0
0ol0VOooooooo`0Coooo1@0000?oool00`000?ooooooo`21oooo001noooo00?o09Woooooool05Ooo
o`030000oooooooo00?oool00`000?ooooooo`21oooo001noooo00?o09Woooooool05Oooo`030000
oooooooo00?oool30000POooo`00O_ooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00O_ooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo01Coool200001Oooo`030000oooooooo087oool007koool0
0ol0VOooooooo`0Koooo0P0008;oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POoo
o`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06ooo
o`030000oooooooo087oool007koool00ol0VOooooooo`0Koooo0P0008;oool007koool00ol0VOoo
ooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21
oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0K
oooo0P0008;oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2I
oooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06oooo`030000oooooooo
087oool007koool00ol0VOooooooo`0Koooo0P0008;oool007koool00ol0VOooooooo`0Koooo00<0
003oooooool0POooo`00O_ooo`03o`2Ioooooooo00Ooool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`21oooo001noooo00?o09Woooooool02Oooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`21oooo001noooo00?o09Woooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P0008Woool0
08[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`0008Soool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool300000_oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`040000oooooooo00000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002?ooo`D00003oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oool000000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000_oool200000oooo`800003oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.42237 .38627 L
.42781 .38627 L
.43049 .38627 L
.43179 .38627 L
.43298 .38627 L
.43413 .38627 L
s
.43413 .38627 m
.4343 .61803 L
s
0 .4 1 r
.02381 .39944 m
.06244 .40199 L
.10458 .40527 L
.14415 .40889 L
.18221 .41288 L
.22272 .41766 L
.26171 .42269 L
.30316 .42829 L
.34309 .43357 L
.3815 .43809 L
.40095 .44001 L
.41127 .44089 L
.42237 .44172 L
.42781 .44208 L
.43049 .44224 L
.43179 .44232 L
.43298 .44239 L
.43413 .44246 L
.43522 .38627 L
.43637 .38627 L
.43762 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00@0
003ooooo09T0I_l7oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
03?oool00`000?ooooooo`0Doooo00?o09T0I_ooool06oooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`005_ooo`D0I_mSoooo00?o09T0I_ooool06oooo`030000
oooooooo087oool001_oool;06KoF?ooo`03o`2I06Kooooo01_oool20000P_ooo`009_ooo`X0I_m>
oooo00?o09T0I_ooool06oooo`030000oooooooo087oool0033oool:06KoA?ooo`03o`2I06Kooooo
01_oool00`000?ooooooo`21oooo000joooo2P1Voc[oool00`1Vooooooooo`0Koooo00<0003ooooo
ool0POooo`00A?ooo`X0I_l`oooo00<0I_ooooooool06oooo`800022oooo001>oooo201VobSoool0
0`1Vooooooooo`0Koooo00<0003oooooool0POooo`00E_ooo`D0I_lSoooo00<0I_ooooooool06ooo
o`030000oooooooo087oool005_oool706Ko7?ooo`0306Kooooooooo01_oool00`000?ooooooo`21
oooo001Roooo2P1Voa;oool00`1Vooooooooo`0Koooo0P0008;oool006coool806Ko2_ooo`0306Ko
oooooooo01_oool00`000?ooooooo`21oooo001doooo2`1Voagoool00`000?ooooooo`21oooo001n
oooo00?o09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0Koooo0P00
08;oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo
00Soool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo001noooo00?o09Wooooo
ool01oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo087oool0
07koool00ol0VOooooooo`07oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00021
oooo001noooo00?o09Woooooool01oooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo00Soool200002_ooo`<00004oooo00<0
003oooooool0POooo`00O_ooo`03o`2Ioooooooo01_oool20000P_ooo`00O_ooo`03o`2Ioooooooo
01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool0
07koool00ol0VOooooooo`0Koooo0P0008;oool007koool00ol0VOooooooo`0Koooo00<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Wooooo
ool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0Koooo0P0008;oool007koool0
0ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`21oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOoo
ooooo`0Koooo0P0008;oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_oo
o`03o`2Ioooooooo01?oool500000oooo`030000oooooooo087oool007koool00ol0VOooooooo`0E
oooo00<0003oooooool00oooo`030000oooooooo087oool007koool00ol0VOooooooo`0Eoooo00<0
003oooooool00oooo`<00021oooo001noooo00?o09Woooooool05Oooo`030000oooooooo00?oool0
0`000?ooooooo`21oooo001noooo00?o09Woooooool05Oooo`030000oooooooo00?oool00`000?oo
ooooo`21oooo001noooo00?o09Woooooool05?ooo`800005oooo00<0003oooooool0POooo`00O_oo
o`03o`2Ioooooooo01_oool20000P_ooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21
oooo001noooo00?o09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0K
oooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo01_oool20000P_ooo`00O_ooo`03o`2I
oooooooo01_oool00`000?ooooooo`21oooo001noooo00?o09Woooooool06oooo`030000oooooooo
087oool007koool00ol0VOooooooo`0Koooo00<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo
01_oool20000P_ooo`00O_ooo`03o`2Ioooooooo01_oool00`000?ooooooo`21oooo001noooo00?o
09Woooooool06oooo`030000oooooooo087oool007koool00ol0VOooooooo`0Koooo00<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo01_oool20000P_ooo`00O_ooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`21oooo001noooo00?o09Woooooool01oooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo087oool007koool00ol0VOooooooo`09oooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo087oool007koool00ol0VOooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000POooo`00R_ooo`030000oooooooo00Soool20000ROoo
o`00R_ooo`030000oooooooo00Soool00`000?ooooooo`28oooo0029oooo0P0000[oool30000R?oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00003
oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00<0003oooooool00ooo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002?ooo`D000000oooo`000000000300000oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooo000000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000Coool200000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.42237 .38627 L
.42781 .38627 L
.43049 .38627 L
.43298 .38627 L
.43522 .38627 L
.43648 .38627 L
s
.43648 .38627 m
.43665 .61803 L
s
0 .4 1 r
.02381 .39976 m
.06244 .40237 L
.10458 .40573 L
.14415 .40944 L
.18221 .41352 L
.22272 .41842 L
.26171 .42358 L
.30316 .42931 L
.34309 .43472 L
.3815 .43935 L
.40095 .44131 L
.41127 .44221 L
.42237 .44306 L
.42781 .44343 L
.43049 .4436 L
.43298 .44375 L
.43522 .44388 L
.43648 .44395 L
.43762 .38627 L
.43887 .38627 L
.44023 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00@0
003oooooool0I_l7oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000oooooooo
03?oool00`000?ooooooo`0Eoooo00<0I_ooooooool06_ooo`030000oooooooo03?oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`005_ooo`D0I_mToooo00<0I_ooooooool06_ooo`030000
oooooooo087oool001_oool;06KoFOooo`0306Kooooooooo01[oool20000P_ooo`009_ooo`X0I_m?
oooo00<0I_ooooooool06_ooo`030000oooooooo087oool0033oool:06KoAOooo`0306Kooooooooo
01[oool00`000?ooooooo`21oooo000joooo2P1Voc_oool00`1Vooooooooo`0Joooo00<0003ooooo
ool0POooo`00A?ooo`X0I_laoooo00<0I_ooooooool06_ooo`800022oooo001>oooo201VobWoool0
0`1Vooooooooo`0Joooo00<0003oooooool0POooo`00E_ooo`D0I_lToooo00<0I_ooooooool06_oo
o`030000oooooooo087oool005_oool706Ko7Oooo`0306Kooooooooo01[oool00`000?ooooooo`21
oooo001Roooo2P1Voa?oool00`1Vooooooooo`0Joooo0P0008;oool006coool806Ko2oooo`0306Ko
oooooooo01[oool00`000?ooooooo`21oooo001doooo2P1Vo`03oooo06Kooooo01_oool00`000?oo
ooooo`21oooo001moooo0`1Voacoool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_oo
o`800022oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOoo
ooooo`07oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Ooooo`03o`2I
oooooooo00Koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001ooooo00?o09Woooooool01_ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000POooo`00Ooooo`03o`2Ioooooooo00Koool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo087oool007ooool00ol0VOooooooo`06oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo087oool007ooool00ol0VOooooooo`07oooo0P0000[oool300001?oo
o`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOoo
ooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21
oooo001ooooo00?o09Woooooool06_ooo`800022oooo001ooooo00?o09Woooooool06_ooo`030000
oooooooo087oool007ooool00ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2I
oooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_ooo`800022oooo001o
oooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo00<0
003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o
09Woooooool06_ooo`800022oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool0
07ooool00ol0VOooooooo`0Boooo1@0000?oool00`000?ooooooo`21oooo001ooooo00?o09Wooooo
ool05?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool05?oo
o`030000oooooooo00?oool30000POooo`00Ooooo`03o`2Ioooooooo01Coool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00Ooooo`03o`2Ioooooooo01?oool200001Oooo`030000oooooooo087oool0
07ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0Joooo00<0003ooooo
ool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Wooooo
ool06_ooo`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool0
0ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`21oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOoo
ooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Oooo
o`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_ooo`030000
oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0J
oooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo00Koool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001ooooo00?o09Woooooool02?ooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001ooooo00?o09Woooooool02?ooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P00
08Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`00
08Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool3
00000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`040000oooooooo
00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002?ooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000_oool200000oooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.42237 .38627 L
.42781 .38627 L
.43298 .38627 L
.43522 .38627 L
.43646 .38627 L
.43762 .38627 L
.43828 .38627 L
s
.43828 .38627 m
.43839 .61803 L
s
0 .4 1 r
.02381 .40008 m
.06244 .40275 L
.10458 .40619 L
.14415 .40999 L
.18221 .41417 L
.22272 .41918 L
.26171 .42446 L
.30316 .43033 L
.34309 .43587 L
.3815 .44061 L
.40095 .44261 L
.41127 .44354 L
.42237 .44441 L
.42781 .44479 L
.43298 .44511 L
.43522 .44525 L
.43646 .44532 L
.43762 .44538 L
.43828 .44542 L
.43899 .38627 L
.44024 .38627 L
.44268 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00D0
003ooooooooo09T0I_l01_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`03o`2I06Kooooo01[oool00`000?ooooooo`0coooo00<0
003oooooool0<oooo`030000oooooooo01Goool007ooool00ol0V@1Vooooo`0Joooo00<0003ooooo
ool0POooo`005_oooa00I_mIoooo00?o09T0I_ooool06_ooo`800022oooo000Voooo2P1Vodooool0
0ol0V@1Vooooo`0Joooo00<0003oooooool0POooo`00<?ooo`X0I_m5oooo00?o09T0I_ooool06_oo
o`030000oooooooo087oool003[oool:06Ko>oooo`03o`2I06Kooooo01[oool00`000?ooooooo`21
oooo0014oooo201Voc?oool00`1Vooooooooo`0Joooo0P0008;oool004coool506Ko;_ooo`0306Ko
oooooooo01[oool00`000?ooooooo`21oooo001Aoooo1`1VobOoool00`1Vooooooooo`0Joooo00<0
003oooooool0POooo`00F?ooo`P0I_lOoooo00<0I_ooooooool06_ooo`030000oooooooo087oool0
063oool506Ko6_ooo`0306Kooooooooo01[oool20000P_ooo`00IOooo`L0I_lCoooo00<0I_oooooo
ool06_ooo`030000oooooooo087oool006coool;06Ko2?ooo`0306Kooooooooo01[oool00`000?oo
ooooo`21oooo001goooo2@1Voacoool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_oo
o`800022oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOoo
ooooo`07oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00Ooooo`03o`2I
oooooooo00Koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo001ooooo00?o09Woooooool01_ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000POooo`00Ooooo`03o`2Ioooooooo00Koool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo087oool007ooool00ol0VOooooooo`06oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo087oool007ooool00ol0VOooooooo`07oooo0P0000[oool300001?oo
o`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOoo
ooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21
oooo001ooooo00?o09Woooooool06_ooo`800022oooo001ooooo00?o09Woooooool06_ooo`030000
oooooooo087oool007ooool00ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2I
oooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_ooo`800022oooo001o
oooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo00<0
003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o
09Woooooool06_ooo`800022oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool0
07ooool00ol0VOooooooo`0Boooo1@0000?oool00`000?ooooooo`21oooo001ooooo00?o09Wooooo
ool05?ooo`030000oooooooo00?oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool05?oo
o`030000oooooooo00?oool30000POooo`00Ooooo`03o`2Ioooooooo01Coool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00Ooooo`03o`2Ioooooooo01?oool200001Oooo`030000oooooooo087oool0
07ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0Joooo00<0003ooooo
ool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Wooooo
ool06_ooo`030000oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool0
0ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`21oooo001ooooo00?o09Woooooool06_ooo`030000oooooooo087oool007ooool00ol0VOoo
ooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0Joooo00<0003oooooool0POooo`00Oooo
o`03o`2Ioooooooo01[oool00`000?ooooooo`21oooo001ooooo00?o09Woooooool06_ooo`030000
oooooooo087oool007ooool00ol0VOooooooo`0Joooo0P0008;oool007ooool00ol0VOooooooo`0J
oooo00<0003oooooool0POooo`00Ooooo`03o`2Ioooooooo00Koool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo001ooooo00?o09Woooooool02?ooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo001ooooo00?o09Woooooool02?ooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P00
08Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`00
08Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool3
000000Coool0000000000004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`040000
oooooooo00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002?ooo`D000001Oooo`000?ooooooo`000004oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002oooo`800003oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.41127 .38627 L
.42237 .38627 L
.42781 .38627 L
.43298 .38627 L
.43762 .38627 L
.43889 .38627 L
.43959 .38627 L
.44024 .38627 L
s
.44024 .38627 m
.44044 .61803 L
s
0 .4 1 r
.02381 .4004 m
.06244 .40313 L
.10458 .40666 L
.14415 .41054 L
.18221 .41482 L
.22272 .41995 L
.26171 .42535 L
.30316 .43136 L
.34309 .43703 L
.3815 .44187 L
.40095 .44393 L
.41127 .44487 L
.42237 .44576 L
.42781 .44615 L
.43298 .44649 L
.43762 .44676 L
.43889 .44683 L
.43959 .44687 L
.44024 .4469 L
.44152 .38627 L
.44268 .38627 L
.46172 .38627 L
.50027 .38627 L
.54127 .38627 L
.58076 .38627 L
.61873 .38627 L
.65915 .38627 L
.69806 .38627 L
.73942 .38627 L
.77927 .38627 L
.8176 .38627 L
.85838 .38627 L
.89765 .38627 L
.9354 .38627 L
.9756 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00D0
003oooooooooool0I_l01_ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool0037oool00`000?oo
ooooo`0coooo00<0003oooooool05_ooo`0306Kooooooooo01Woool00`000?ooooooo`0coooo00<0
003oooooool0<oooo`030000oooooooo01Goool0083oool00`1Vooooooooo`0Ioooo00<0003ooooo
ool0POooo`005_oooa00I_mJoooo00<0I_ooooooool06Oooo`800022oooo000Voooo2P1Voe3oool0
0`1Vooooooooo`0Ioooo00<0003oooooool0POooo`00<?ooo`X0I_m6oooo00<0I_ooooooool06Ooo
o`030000oooooooo087oool003[oool706Ko?oooo`0306Kooooooooo01Woool00`000?ooooooo`21
oooo0011oooo1P1VocWoool00`1Vooooooooo`0Ioooo0P0008;oool004Ooool706Ko<_ooo`0306Ko
oooooooo01Woool00`000?ooooooo`21oooo001>oooo2P1VobSoool00`1Vooooooooo`0Ioooo00<0
003oooooool0POooo`00F?ooo`P0I_lPoooo00<0I_ooooooool06Oooo`030000oooooooo087oool0
063oool506Ko6oooo`0306Kooooooooo01Woool20000P_ooo`00IOooo`L0I_lDoooo00<0I_oooooo
ool06Oooo`030000oooooooo087oool006coool806Ko3?ooo`0306Kooooooooo01Woool00`000?oo
ooooo`21oooo001doooo3@1Voa_oool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Ooo
o`800022oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOoo
ooooo`06oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0POooo`00P?ooo`03o`2I
oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`21
oooo0020oooo00?o09Woooooool01Oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000POooo`00P?ooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo087oool0083oool00ol0VOooooooo`05oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo087oool0083oool00ol0VOooooooo`06oooo0P0000[oool300001?oo
o`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo0P0008;oool0083oool00ol0VOoo
ooooo`0Ioooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21
oooo0020oooo00?o09Woooooool06Oooo`800022oooo0020oooo00?o09Woooooool06Oooo`030000
oooooooo087oool0083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?ooo`03o`2I
oooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`800022oooo0020
oooo00?o09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo00<0
003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o
09Woooooool06Oooo`800022oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo087oool0
083oool00ol0VOooooooo`0Aoooo1@0000?oool00`000?ooooooo`21oooo0020oooo00?o09Wooooo
ool04oooo`030000oooooooo00?oool00`000?ooooooo`21oooo0020oooo00?o09Woooooool04ooo
o`030000oooooooo00?oool30000POooo`00P?ooo`03o`2Ioooooooo01?oool00`000?ooooooo`03
oooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo01?oool00`000?ooooooo`03oooo00<0
003oooooool0POooo`00P?ooo`03o`2Ioooooooo01;oool200001Oooo`030000oooooooo087oool0
083oool00ol0VOooooooo`0Ioooo0P0008;oool0083oool00ol0VOooooooo`0Ioooo00<0003ooooo
ool0POooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o09Wooooo
ool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo0P0008;oool0083oool0
0ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool00`000?oo
ooooo`21oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOoo
ooooo`0Ioooo0P0008;oool0083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?oo
o`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`030000
oooooooo087oool0083oool00ol0VOooooooo`0Ioooo0P0008;oool0083oool00ol0VOooooooo`0I
oooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo00Goool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`21oooo0020oooo00?o09Woooooool01oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`21oooo0020oooo00?o09Woooooool01oooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool00`000?ooooooo`08oooo0P00
08Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?ooo`00ROooo`80000:oooo0`00
08Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool3
00000oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool500000oooo`030000oooooooo
00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00Soool010000?ooooooo`0000Goool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002Oooo`030000oooo000000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000;oool4
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.42237 .38627 L
.43215 .38627 L
.43755 .38627 L
.44021 .38627 L
.44151 .38627 L
.44268 .38627 L
s
.44268 .38627 m
.44286 .61803 L
s
0 .4 1 r
.02381 .40072 m
.06244 .40352 L
.10458 .40712 L
.14415 .41109 L
.18221 .41547 L
.22272 .42072 L
.26171 .42625 L
.30316 .43239 L
.34309 .43819 L
.3815 .44315 L
.40095 .44525 L
.42237 .44713 L
.43215 .44781 L
.43755 .44814 L
.44021 .44829 L
.44151 .44836 L
.44268 .44842 L
.44387 .38627 L
.44498 .38627 L
.44744 .38627 L
.45262 .38627 L
.46172 .38627 L
.50027 .38627 L
.54127 .38627 L
.58076 .38627 L
.61873 .38627 L
.65915 .38627 L
.69806 .38627 L
.73942 .38627 L
.77927 .38627 L
.8176 .38627 L
.85838 .38627 L
.89765 .38627 L
.9354 .38627 L
.9756 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00H0
003ooooooooooooo09T0I_l5oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00<Oooo`030000
oooooooo03?oool00`000?ooooooo`0Foooo00?o09T0I_ooool06Oooo`030000oooooooo03?oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`00P?ooo`03o`2I06Kooooo01Woool00`000?oo
ooooo`21oooo000Foooo401Voe[oool00ol0V@1Vooooo`0Ioooo0P0008;oool002Koool:06KoD?oo
o`03o`2I06Kooooo01Woool00`000?ooooooo`21oooo000`oooo2P1VodKoool00ol0V@1Vooooo`0I
oooo00<0003oooooool0POooo`00>_ooo`L0I_looooo00?o09T0I_ooool06Oooo`030000oooooooo
087oool0047oool606Ko>Oooo`0306Kooooooooo01Woool20000P_ooo`00Aoooo`L0I_lboooo00<0
I_ooooooool06Oooo`030000oooooooo087oool004koool806Ko:_ooo`0306Kooooooooo01Woool0
0`000?ooooooo`21oooo001Foooo1@1VobGoool00`1Vooooooooo`0Ioooo00<0003oooooool0POoo
o`00Foooo`L0I_lNoooo00<0I_ooooooool06Oooo`800022oooo001Roooo2P1VoaCoool00`1Voooo
ooooo`0Ioooo00<0003oooooool0POooo`00K?ooo`P0I_l<oooo00<0I_ooooooool06Oooo`030000
oooooooo087oool007Coool906Ko0oooo`0306Kooooooooo01Woool00`000?ooooooo`21oooo001m
oooo101Voa_oool20000P_ooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020
oooo00?o09Woooooool01_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo087oool0
083oool00ol0VOooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0POooo`00P?ooo`03o`2Ioooooooo00Goool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`00087oool0083oool00ol0VOooooooo`05oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`21oooo0020oooo00?o09Woooooool01Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`21oooo0020oooo00?o09Woooooool01_ooo`80000:
oooo0`0000Coool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`800022oooo0020
oooo00?o09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo00<0
003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool20000P_ooo`00P?ooo`03o`2Ioooooooo
01Woool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo087oool0
083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool2
0000P_ooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o09Wooooo
ool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POoo
o`00P?ooo`03o`2Ioooooooo01Woool20000P_ooo`00P?ooo`03o`2Ioooooooo01Woool00`000?oo
ooooo`21oooo0020oooo00?o09Woooooool04Oooo`D00003oooo00<0003oooooool0POooo`00P?oo
o`03o`2Ioooooooo01?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`03o`2I
oooooooo01?oool00`000?ooooooo`03oooo0`00087oool0083oool00ol0VOooooooo`0Coooo00<0
003oooooool00oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Coooo00<0003ooooo
ool00oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0Boooo0P0000Goool00`000?oo
ooooo`21oooo0020oooo00?o09Woooooool06Oooo`800022oooo0020oooo00?o09Woooooool06Ooo
o`030000oooooooo087oool0083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?oo
o`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`800022
oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`0I
oooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo01Woool00`000?ooooooo`21oooo0020
oooo00?o09Woooooool06Oooo`800022oooo0020oooo00?o09Woooooool06Oooo`030000oooooooo
087oool0083oool00ol0VOooooooo`0Ioooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo
01Woool00`000?ooooooo`21oooo0020oooo00?o09Woooooool06Oooo`800022oooo0020oooo00?o
09Woooooool06Oooo`030000oooooooo087oool0083oool00ol0VOooooooo`05oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0POooo`00P?ooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00021oooo002:oooo00<0003ooooo
ool02?ooo`800029oooo002:oooo00<0003oooooool02?ooo`030000oooooooo08Soool008Woool2
00002_ooo`<00028oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800005oooo0`0000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000_oool0
10000?ooooooo`0000;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Soool5000000Goool0003oooooool000001?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooo`000002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002oooo`800003oooo0P00
00?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.42237 .38627 L
.43215 .38627 L
.43755 .38627 L
.44021 .38627 L
.44151 .38627 L
.44268 .38627 L
.44387 .38627 L
s
.44387 .38627 m
.44403 .61803 L
s
0 .4 1 r
.02381 .40105 m
.06244 .40391 L
.10458 .40759 L
.14415 .41165 L
.18221 .41613 L
.22272 .4215 L
.26171 .42714 L
.30316 .43343 L
.34309 .43935 L
.3815 .44442 L
.40095 .44657 L
.42237 .44849 L
.43215 .44919 L
.43755 .44953 L
.44021 .44968 L
.44151 .44975 L
.44268 .44981 L
.44387 .44987 L
.44498 .38627 L
.44616 .38627 L
.44744 .38627 L
.45262 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool00_ooo`0306Kooooooooo00?oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0<oooo`030000oooooooo01Ooool00`1Vooooooooo`0Hoooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo0021oooo00<0I_ooooooool06?oo
o`030000oooooooo087oool001Koool@06KoFoooo`0306Kooooooooo01Soool20000P_ooo`009_oo
o`X0I_mAoooo00<0I_ooooooool06?ooo`030000oooooooo087oool0033oool806KoBOooo`0306Ko
oooooooo01Soool00`000?ooooooo`21oooo000hoooo101VodGoool00`1Vooooooooo`0Hoooo00<0
003oooooool0POooo`00??ooo`P0I_lmoooo00<0I_ooooooool06?ooo`800022oooo0014oooo2P1V
oc?oool00`1Vooooooooo`0Hoooo00<0003oooooool0POooo`00C_ooo`P0I_l[oooo00<0I_oooooo
ool06?ooo`030000oooooooo087oool005Koool506Ko9_ooo`0306Kooooooooo01Soool00`000?oo
ooooo`21oooo001Koooo1`1Voaooool00`1Vooooooooo`0Hoooo0P0008;oool006;oool806Ko5ooo
o`0306Kooooooooo01Soool00`000?ooooooo`21oooo001Zoooo1@1Voa;oool00`1Vooooooooo`0H
oooo00<0003oooooool0POooo`00Koooo`X0I_l8oooo00<0I_ooooooool06?ooo`030000oooooooo
087oool007Woool906Ko6_ooo`800022oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo
087oool0087oool00ol0VOooooooo`05oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00POooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo0021oooo00?o09Woooooool01?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00POooo`03o`2Ioooooooo00Coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool0087oool00ol0VOooooooo`04oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`05
oooo0P0000[oool300001?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P00
08;oool0087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo
01Soool00`000?ooooooo`21oooo0021oooo00?o09Woooooool06?ooo`800022oooo0021oooo00?o
09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o09Wooooo
ool06?ooo`800022oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo087oool0087oool0
0ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`21oooo0021oooo00?o09Woooooool06?ooo`800022oooo0021oooo00?o09Woooooool06?oo
o`030000oooooooo087oool0087oool00ol0VOooooooo`0@oooo1@0000?oool00`000?ooooooo`21
oooo0021oooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo0021
oooo00?o09Woooooool04_ooo`030000oooooooo00?oool30000POooo`00POooo`03o`2Ioooooooo
01;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo017oool200001Ooo
o`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0087oool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21
oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0H
oooo0P0008;oool0087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2I
oooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo
087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0087oool00ol0VOooooooo`0Hoooo00<0
003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o
09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0
087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo00Coool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo0021oooo00?o09Woooooool01_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo0021oooo00?o
09Woooooool01_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Goool3000000Coool0000000000004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo1@00
00;oool300001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool0
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000_oool200000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
.2 1 0 r
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
.97619 .38627 L
.02381 .38627 L
F
0 g
.02381 .37005 m
.04262 .367 L
.06244 .36318 L
.10458 .35252 L
.14264 .33906 L
.18314 .31954 L
.22214 .29455 L
.26358 .2605 L
.30351 .22076 L
.34193 .17832 L
.38279 .13381 L
.40311 .11431 L
.42214 .09893 L
.44037 .08761 L
.45061 .08296 L
.45998 .07988 L
.46474 .07876 L
.46736 .07828 L
.46982 .07791 L
.47213 .07764 L
.47334 .07752 L
.47462 .07742 L
.4757 .07736 L
.47688 .0773 L
.47796 .07727 L
.47896 .07726 L
.48025 .07726 L
.48098 .07727 L
.48165 .07728 L
.48289 .07733 L
.4842 .0774 L
.48537 .07749 L
.48646 .07758 L
.48897 .07786 L
.49166 .07826 L
.49413 .07871 L
.49969 .08003 L
.50443 .08148 L
.50949 .08335 L
.51861 .08754 L
.53931 .10063 L
.56066 .11853 L
.58081 .13844 L
.61928 .18066 L
.6602 .22561 L
.6996 .26418 L
.73749 .29492 L
.77783 .32057 L
.81665 .33913 L
.85793 .35352 L
Mistroke
.89769 .36339 L
.93593 .37015 L
.97619 .37516 L
Mfstroke
1 0 .6 r
.02381 .38627 m
.06244 .38627 L
.10458 .38627 L
.14415 .38627 L
.18221 .38627 L
.22272 .38627 L
.26171 .38627 L
.30316 .38627 L
.34309 .38627 L
.3815 .38627 L
.40095 .38627 L
.42237 .38627 L
.43215 .38627 L
.43755 .38627 L
.44021 .38627 L
.44268 .38627 L
.44498 .38627 L
.44627 .38627 L
s
.44627 .38627 m
.44644 .61803 L
s
0 .4 1 r
.02381 .40137 m
.06244 .40429 L
.10458 .40806 L
.14415 .41221 L
.18221 .41679 L
.22272 .42227 L
.26171 .42805 L
.30316 .43447 L
.34309 .44053 L
.3815 .44571 L
.40095 .4479 L
.42237 .44987 L
.43215 .45058 L
.43755 .45092 L
.44021 .45108 L
.44268 .45121 L
.44498 .45133 L
.44627 .45139 L
.44744 .38627 L
.44872 .38627 L
.45011 .38627 L
.45262 .38627 L
.46172 .38627 L
.50272 .38627 L
.54221 .38627 L
.58018 .38627 L
.6206 .38627 L
.65951 .38627 L
.70087 .38627 L
.74072 .38627 L
.77905 .38627 L
.81983 .38627 L
.8591 .38627 L
.89685 .38627 L
.93705 .38627 L
.97574 .38627 L
.97619 .38627 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.55291 0.21164 0.386271 0.154508 [
[.12963 .37377 -6 -9 ]
[.12963 .37377 6 0 ]
[.34127 .37377 -6 -9 ]
[.34127 .37377 6 0 ]
[.76455 .37377 -3 -9 ]
[.76455 .37377 3 0 ]
[.97619 .37377 -3 -9 ]
[.97619 .37377 3 0 ]
[.54041 0 -24 -4.5 ]
[.54041 0 0 4.5 ]
[.54041 .07725 -12 -4.5 ]
[.54041 .07725 0 4.5 ]
[.54041 .15451 -24 -4.5 ]
[.54041 .15451 0 4.5 ]
[.54041 .23176 -12 -4.5 ]
[.54041 .23176 0 4.5 ]
[.54041 .30902 -24 -4.5 ]
[.54041 .30902 0 4.5 ]
[.54041 .46353 -18 -4.5 ]
[.54041 .46353 0 4.5 ]
[.54041 .54078 -6 -4.5 ]
[.54041 .54078 0 4.5 ]
[.54041 .61803 -18 -4.5 ]
[.54041 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 .38627 m
.12963 .39252 L
s
[(-2)] .12963 .37377 0 1 Mshowa
.34127 .38627 m
.34127 .39252 L
s
[(-1)] .34127 .37377 0 1 Mshowa
.76455 .38627 m
.76455 .39252 L
s
[(1)] .76455 .37377 0 1 Mshowa
.97619 .38627 m
.97619 .39252 L
s
[(2)] .97619 .37377 0 1 Mshowa
.125 Mabswid
.17196 .38627 m
.17196 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.25661 .38627 m
.25661 .39002 L
s
.29894 .38627 m
.29894 .39002 L
s
.3836 .38627 m
.3836 .39002 L
s
.42593 .38627 m
.42593 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.51058 .38627 m
.51058 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.63757 .38627 m
.63757 .39002 L
s
.67989 .38627 m
.67989 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.80688 .38627 m
.80688 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.89153 .38627 m
.89153 .39002 L
s
.93386 .38627 m
.93386 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.04497 .38627 m
.04497 .39002 L
s
.00265 .38627 m
.00265 .39002 L
s
.25 Mabswid
0 .38627 m
1 .38627 L
s
.55291 0 m
.55916 0 L
s
[(-2.5)] .54041 0 1 0 Mshowa
.55291 .07725 m
.55916 .07725 L
s
[(-2)] .54041 .07725 1 0 Mshowa
.55291 .15451 m
.55916 .15451 L
s
[(-1.5)] .54041 .15451 1 0 Mshowa
.55291 .23176 m
.55916 .23176 L
s
[(-1)] .54041 .23176 1 0 Mshowa
.55291 .30902 m
.55916 .30902 L
s
[(-0.5)] .54041 .30902 1 0 Mshowa
.55291 .46353 m
.55916 .46353 L
s
[(0.5)] .54041 .46353 1 0 Mshowa
.55291 .54078 m
.55916 .54078 L
s
[(1)] .54041 .54078 1 0 Mshowa
.55291 .61803 m
.55916 .61803 L
s
[(1.5)] .54041 .61803 1 0 Mshowa
.125 Mabswid
.55291 .01545 m
.55666 .01545 L
s
.55291 .0309 m
.55666 .0309 L
s
.55291 .04635 m
.55666 .04635 L
s
.55291 .0618 m
.55666 .0618 L
s
.55291 .09271 m
.55666 .09271 L
s
.55291 .10816 m
.55666 .10816 L
s
.55291 .12361 m
.55666 .12361 L
s
.55291 .13906 m
.55666 .13906 L
s
.55291 .16996 m
.55666 .16996 L
s
.55291 .18541 m
.55666 .18541 L
s
.55291 .20086 m
.55666 .20086 L
s
.55291 .21631 m
.55666 .21631 L
s
.55291 .24721 m
.55666 .24721 L
s
.55291 .26266 m
.55666 .26266 L
s
.55291 .27812 m
.55666 .27812 L
s
.55291 .29357 m
.55666 .29357 L
s
.55291 .32447 m
.55666 .32447 L
s
.55291 .33992 m
.55666 .33992 L
s
.55291 .35537 m
.55666 .35537 L
s
.55291 .37082 m
.55666 .37082 L
s
.55291 .40172 m
.55666 .40172 L
s
.55291 .41717 m
.55666 .41717 L
s
.55291 .43262 m
.55666 .43262 L
s
.55291 .44807 m
.55666 .44807 L
s
.55291 .47898 m
.55666 .47898 L
s
.55291 .49443 m
.55666 .49443 L
s
.55291 .50988 m
.55666 .50988 L
s
.55291 .52533 m
.55666 .52533 L
s
.55291 .55623 m
.55666 .55623 L
s
.55291 .57168 m
.55666 .57168 L
s
.55291 .58713 m
.55666 .58713 L
s
.55291 .60258 m
.55666 .60258 L
s
.25 Mabswid
.55291 0 m
.55291 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo100000?oool200001?ooo`800029oooo0028oooo00<0003oooooool02Ooo
o`040000oooooooo0000R?ooo`00ROooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`00
087oool008;oool400001?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo087oool0
08Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0POooo`00ROoo
o`80000:oooo0`0000Coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000oooooooo087oool009coool2
0000P_ooo`00W?ooo`030000oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo00<0
003oooooool0POooo`00W?ooo`800022oooo002Loooo00<0003oooooool0POooo`00W?ooo`030000
oooooooo087oool009coool00`000?ooooooo`21oooo002Loooo0P0008;oool009coool00`000?oo
ooooo`21oooo002Doooo100000Coool00`000?ooooooo`21oooo002Doooo00<0003oooooool01Ooo
o`030000oooooooo087oool008Coool<00001Oooo`030000oooooooo00Coool30000POooo`00P_oo
o`80000:<ol01@0000?oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00P?ooo`80000A
<ol00P0000;oool00`000?ooooooo`02oooo00<0003oooooool0POooo`00O_ooo`80000E<ol00P00
00Goool00`000?ooooooo`21oooo001loooo0P0001Pco`0200001?ooo`800022oooo001koooo00<0
000co`0co`006S?o00050000oooooooooooo000008?oool007[oool00`0003?o03?o000L<ol000@0
003oooooool00023oooo001hoooo0P00020co`0010000?ooo`00000008;oool007Ooool00`0003?o
03?o000Q<ol00P0008?oool007Koool00`0003?o03?o000S<ol00P0008;oool007Goool00`0003?o
03?o000T<ol000<0000co`000000POooo`00M?ooo`030000<ol0<ol002Dco`02000000<co`00003o
ool0Ooooo`00Loooo`030000<ol0<ol002Hco`001@0003?o03?o03?o0000001ooooo001boooo00<0
000co`0co`009c?o00030000<ol0<ol0008co`000`000?ooooooo`1loooo001aoooo00<0000co`0c
o`00:3?o00030000<ol0<ol000<co`000`000?ooooooo`1koooo001`oooo00<0000co`0co`00:C?o
00800005<ol000<0003oooooool0N_ooo`00Koooo`030000<ol0<ol002Xco`000`0003?o03?o0005
<ol000<0003oooooool0NOooo`00K_ooo`030000<ol0<ol001Lco`0500000S?o00800004<ol00P00
00Dco`000`0003?o03?o0006<ol000<0003oooooool0N?ooo`00KOooo`030000<ol0<ol001Xco`00
0`0003?o03?o0007<ol000@0000co`0co`000004<ol000<0000co`0co`001c?o00030000oooooooo
07Ooool006coool00`0003?o03?o000K<ol000<0000co`0co`002S?o00030000<ol0<ol0008co`03
000023?o00030000oooooooo07Koool006coool00`0003?o03?o000C<ol0100000@co`000`0003?o
03?o0008<ol00P0000Dco`000`0003?o03?o0009<ol000<0003oooooool0MOooo`00Joooo`030000
<ol0<ol001`co`000`0003?o03?o0008<ol000<0000co`0co`0013?o00030000<ol0<ol000Tco`00
0`000?ooooooo`1eoooo001Zoooo00<0000co`0co`0073?o0080000:<ol00`0000@co`000`0003?o
03?o000:<ol000<0003oooooool0M?ooo`00JOooo`030000<ol0<ol0030co`02000033?o00030000
oooooooo07?oool006Soool00`0003?o03?o000a<ol000<0000co`0co`0033?o00030000oooooooo
07;oool006Ooool00`0003?o03?o000b<ol000<0000co`0co`003C?o00030000oooooooo077oool0
06Koool00`0003?o03?o000c<ol000<0000co`0co`003S?o00030000oooooooo073oool006Goool0
0`0003?o03?o000d<ol00P00010co`000`000?ooooooo`1_oooo001Toooo00<0000co`0co`00=C?o
00030000<ol0<ol0010co`000`000?ooooooo`1^oooo001Soooo00<0000co`0co`00=S?o00030000
<ol0<ol0014co`000`000?ooooooo`1]oooo001Roooo00<0000co`0co`00=c?o00030000<ol0<ol0
018co`000`000?ooooooo`1/oooo001Roooo00<0000co`0co`00=c?o0080000D<ol000<0003ooooo
ool0Joooo`00HOooo`030000<ol0<ol003Pco`000`0003?o03?o000D<ol000<0003oooooool0J_oo
o`00H?ooo`030000<ol0<ol003Tco`000`0003?o03?o000E<ol000<0003oooooool0JOooo`00Gooo
o`030000<ol0<ol003Xco`000`0003?o03?o000F<ol000<0003oooooool0J?ooo`00G_ooo`030000
<ol0<ol003/co`02000063?o00030000oooooooo06Ooool005goool00`0003?o03?o000l<ol000<0
000co`0co`0063?o00030000oooooooo06Koool005coool00`0003?o03?o000e<ol01@0000<co`00
0`0003?o03?o000I<ol000<0003oooooool0IOooo`00Foooo`030000<ol0<ol003Pco`000`0003?o
03?o0003<ol000<0000co`0co`006S?o00030000oooooooo06Coool005[oool00`0003?o03?o000i
<ol000<0000co`0co`000c?o00<0000K<ol000<0003oooooool0Hoooo`00FOooo`030000<ol0<ol0
038co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000L<ol000<0003oooooool0H_oo
o`00F?ooo`030000<ol0<ol003/co`000`0003?o03?o0003<ol000<0000co`0co`007C?o00030000
oooooooo067oool005Ooool00`0003?o03?o000k<ol00P0000Dco`000`0003?o03?o000N<ol000<0
003oooooool0H?ooo`00E_ooo`030000<ol0<ol004<co`02000083?o00030000oooooooo05ooool0
05Goool00`0003?o03?o0014<ol000<0000co`0co`0083?o00030000oooooooo05koool005Coool0
0`0003?o03?o0015<ol000<0000co`0co`008C?o00030000oooooooo05goool005?oool00`0003?o
03?o0016<ol000<0000co`0co`008S?o00030000oooooooo05coool005;oool00`0003?o03?o0017
<ol00P0002@co`000`000?ooooooo`1Koooo001Aoooo00<0000co`0co`00B3?o00030000<ol0<ol0
02@co`000`000?ooooooo`1Joooo001@oooo00<0000co`0co`00BC?o00030000<ol0<ol002Dco`00
0`000?ooooooo`1Ioooo001?oooo00<0000co`0co`00BS?o00030000<ol0<ol002Hco`000`000?oo
ooooo`1Hoooo001=oooo0P0004dco`020000:3?o0080001Hoooo001<oooo00<0000co`0co`00CC?o
00030000<ol0<ol002Tco`000`000?ooooooo`1Eoooo001;oooo00<0000co`0co`00CS?o00030000
<ol0<ol002Xco`000`000?ooooooo`1Doooo001:oooo00<0000co`0co`00Cc?o0080000/<ol000<0
003oooooool0Doooo`00BOooo`030000<ol0<ol0050co`000`0003?o03?o000/<ol000<0003ooooo
ool0D_ooo`00Aoooo`800010<ol00P0000@co`02000013?o00800005<ol000<0000co`0co`00;C?o
0080001Boooo0015oooo0P00044co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o000_<ol00P00053oool004Coool00`0003?o03?o0011<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000a<ol000<0003oooooool0COooo`00@_ooo`80000n<ol01000
008co`00100003?o03?o000000Tco`0200001C?o00030000<ol0<ol0038co`020000COooo`00@?oo
o`800016<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol003@co`02
0000Boooo`00?_ooo`800019<ol00P0000Xco`03000013?o00030000<ol0<ol003Hco`000`000?oo
ooooo`18oooo000loooo0P0005hco`020000>3?o00800018oooo000joooo0P00060co`000`0003?o
03?o000i<ol00P0004Koool003Soool20000HS?o00030000<ol0<ol003/co`020000A?ooo`00=_oo
o`80001T<ol000<0000co`0co`00?C?o00800012oooo000coooo0`0006Hco`020000@3?o00<0000o
oooo000`oooo1P00038co`050000;c?o00030000<ol0<ol0034co`05000033?o00<0000Roooo1000
01Koool002goool300000S?o00030000<ol0<ol003Dco`000`0003?o03?o000_<ol000<0000co`0c
o`00<c?o00030000<ol0<ol000lco`0200008?ooo`030000oooooooo01Ooool002[oool300001S?o
00030000<ol0<ol003@co`000`0003?o03?o000_<ol000<0000co`0co`00<c?o00030000<ol0<ol0
014co`0300007_ooo`030000oooooooo01Koool002Koool400000S?o00@00004<ol000<0000co`0c
o`00:c?o00@00004<ol000<0000co`0co`00;c?o0080000d<ol000<0000co`0co`0053?o00@0000K
oooo00<0003oooooool05Oooo`008_ooo`@0000<<ol000@0000co`0co`00000d<ol000<0000co`0c
o`00;c?o00030000<ol0<ol003<co`000`0003?o03?o000H<ol01@0001Coool010000?ooooooo`00
01Koool001koool400004C?o0080000d<ol00P00034co`000`0003?o03?o000b<ol00P0001lco`05
00004?ooo`80000Goooo000Ioooo1@0007hco`000`0003?o03?o001H<ol01@0002Coool001Koool3
0000Pc?o0080001N<ol01`0001goool001Kooon6<ol000<0000co`0co`00I3?o00H0000Goooo000F
ooooQS?o00030000<ol0<ol006Tco`0Hoooo000FooooQS?o00030000<ol0<ol006Tco`0Hoooo000@
ooooo`00017oool0017oool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool00_ooo`03o`2I06Kooooo00?oool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000a
oooo00<0003oooooool0<oooo`030000oooooooo01Ooool00ol0V@1Vooooo`0Hoooo00<0003ooooo
ool0<oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo0021oooo00?o09T0I_ooool06?oo
o`030000oooooooo087oool001Koool506KoI_ooo`03o`2I06Kooooo01Soool20000P_ooo`006ooo
o`/0I_mKoooo00?o09T0I_ooool06?ooo`030000oooooooo087oool002Koool:06KoDOooo`03o`2I
06Kooooo01Soool00`000?ooooooo`21oooo000`oooo2P1VodOoool00ol0V@1Vooooo`0Hoooo00<0
003oooooool0POooo`00>_ooo`X0I_lmoooo00?o09T0I_ooool06?ooo`800022oooo0014oooo201V
ocGoool00`1Vooooooooo`0Hoooo00<0003oooooool0POooo`00C?ooo`D0I_l`oooo00<0I_oooooo
ool06?ooo`030000oooooooo087oool0057oool706Ko:Oooo`0306Kooooooooo01Soool00`000?oo
ooooo`21oooo001Hoooo201Vob7oool00`1Vooooooooo`0Hoooo0P0008;oool0063oool506Ko7?oo
o`0306Kooooooooo01Soool00`000?ooooooo`21oooo001Uoooo1`1VoaGoool00`1Vooooooooo`0H
oooo00<0003oooooool0POooo`00K?ooo`P0I_l=oooo00<0I_ooooooool06?ooo`030000oooooooo
087oool007Coool>06Ko6_ooo`800022oooo0021oooo00<0I_ooooooool06?ooo`030000oooooooo
087oool0087oool00ol0VOooooooo`05oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0POooo`00POooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`21oooo0021oooo00?o09Woooooool01?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000POooo`00POooo`03o`2Ioooooooo00Coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo087oool0087oool00ol0VOooooooo`04oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`05
oooo0P0000[oool300001?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P00
08;oool0087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo
01Soool00`000?ooooooo`21oooo0021oooo00?o09Woooooool06?ooo`800022oooo0021oooo00?o
09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o09Wooooo
ool06?ooo`800022oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo087oool0087oool0
0ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`21oooo0021oooo00?o09Woooooool06?ooo`800022oooo0021oooo00?o09Woooooool06?oo
o`030000oooooooo087oool0087oool00ol0VOooooooo`0@oooo1@0000?oool00`000?ooooooo`21
oooo0021oooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?ooooooo`21oooo0021
oooo00?o09Woooooool04_ooo`030000oooooooo00?oool30000POooo`00POooo`03o`2Ioooooooo
01;oool00`000?ooooooo`03oooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`03oooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo017oool200001Ooo
o`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0087oool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21
oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0H
oooo0P0008;oool0087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2I
oooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o09Woooooool06?ooo`030000oooooooo
087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0087oool00ol0VOooooooo`0Hoooo00<0
003oooooool0POooo`00POooo`03o`2Ioooooooo01Soool00`000?ooooooo`21oooo0021oooo00?o
09Woooooool06?ooo`030000oooooooo087oool0087oool00ol0VOooooooo`0Hoooo0P0008;oool0
087oool00ol0VOooooooo`0Hoooo00<0003oooooool0POooo`00POooo`03o`2Ioooooooo00Coool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`21oooo0021oooo00?o09Woooooool01_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`21oooo0021oooo00?o
09Woooooool01_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00087oool008[oool0
0`000?ooooooo`08oooo0P0008Woool008[oool00`000?ooooooo`08oooo00<0003oooooool0R?oo
o`00ROooo`80000:oooo0`0008Soool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000_oool00`000?ooooooo`02oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000
oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`00
00;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.92355, \
-2.61489, 0.0186351, 0.0255258}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.92355, -2.61489, 0.0186351, 0.0255258}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{707, 774},
WindowMargins->{{Automatic, 159}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 162, 4, 96, "Title"],
Cell[1892, 58, 1262, 33, 296, "Text"],
Cell[3157, 93, 120, 4, 49, "Text"],
Cell[3280, 99, 353, 9, 19, "Input",
  CellOpen->False],
Cell[3636, 110, 163, 4, 49, "Text"],
Cell[3802, 116, 93, 1, 30, "Input"],
Cell[3898, 119, 108, 1, 49, "Text"],
Cell[4009, 122, 281, 6, 19, "Input",
  CellOpen->False],
Cell[4293, 130, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4370, 134, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4448, 138, 373, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[4846, 154, 655, 11, 130, "Input"],

Cell[CellGroupData[{
Cell[5526, 169, 27447, 1165, 186, 15770, 1016, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32976, 1336, 27556, 1170, 186, 15851, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60535, 2508, 27482, 1166, 186, 15785, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88020, 3676, 27504, 1167, 186, 15799, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[115527, 4845, 27490, 1167, 186, 15801, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[143020, 6014, 27556, 1169, 186, 15831, 1020, "GraphicsData", \
"PostScript", "Graphics"],
Cell[170579, 7185, 27527, 1167, 186, 15798, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[198109, 8354, 27522, 1169, 186, 15833, 1020, "GraphicsData", \
"PostScript", "Graphics"],
Cell[225634, 9525, 27388, 1166, 186, 15813, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[253025, 10693, 27447, 1167, 186, 15815, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[280475, 11862, 27550, 1169, 186, 15833, 1020, "GraphicsData", \
"PostScript", "Graphics"],
Cell[308028, 13033, 27590, 1170, 186, 15849, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[335621, 14205, 27627, 1172, 186, 15882, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[363251, 15379, 27557, 1168, 186, 15816, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[390811, 16549, 27608, 1172, 186, 15883, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[418422, 17723, 27620, 1172, 186, 15862, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[446045, 18897, 27667, 1174, 186, 15914, 1025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[473715, 20073, 27604, 1171, 186, 15867, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[501322, 21246, 27468, 1170, 186, 15864, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[528793, 22418, 27590, 1174, 186, 15926, 1026, "GraphicsData", \
"PostScript", "Graphics"],
Cell[556386, 23594, 27611, 1173, 186, 15898, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[584000, 24769, 27639, 1174, 186, 15914, 1025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[611642, 25945, 27634, 1173, 186, 15897, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[639279, 27120, 27637, 1173, 186, 15900, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[666919, 28295, 27655, 1176, 186, 15942, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[694577, 29473, 27607, 1173, 186, 15894, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[722187, 30648, 27604, 1172, 186, 15879, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[749794, 31822, 27621, 1176, 186, 15940, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[777418, 33000, 27431, 1169, 186, 15860, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[804852, 34171, 27564, 1172, 186, 15892, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[832419, 35345, 27711, 1181, 186, 16022, 1032, "GraphicsData", \
"PostScript", "Graphics"],
Cell[860133, 36528, 27599, 1175, 186, 15943, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[887735, 37705, 27608, 1177, 186, 15972, 1029, "GraphicsData", \
"PostScript", "Graphics"],
Cell[915346, 38884, 27578, 1176, 186, 15962, 1028, "GraphicsData", \
"PostScript", "Graphics"],
Cell[942927, 40062, 27526, 1175, 186, 15955, 1028, "GraphicsData", \
"PostScript", "Graphics"],
Cell[970456, 41239, 27561, 1176, 186, 15974, 1029, "GraphicsData", \
"PostScript", "Graphics"],
Cell[998020, 42417, 27521, 1176, 186, 15974, 1029, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1025544, 43595, 27434, 1173, 186, 15940, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1052981, 44770, 30358, 1267, 186, 18167, 1112, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1083342, 46039, 27075, 1161, 186, 15597, 1015, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1110420, 47202, 27120, 1163, 186, 15626, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1137543, 48367, 27146, 1164, 186, 15631, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1164692, 49533, 27154, 1164, 186, 15648, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1191849, 50699, 27169, 1163, 186, 15614, 1016, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1219021, 51864, 27253, 1166, 186, 15662, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1246277, 53032, 27288, 1176, 186, 15838, 1030, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1273568, 54210, 27134, 1180, 186, 15943, 1037, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1300705, 55392, 26206, 1170, 186, 15979, 1039, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1326914, 56564, 25694, 1166, 186, 16022, 1042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1352611, 57732, 26641, 1178, 186, 16042, 1043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1379255, 58912, 27821, 1193, 186, 16035, 1043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1407079, 60107, 27866, 1194, 186, 16056, 1044, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1434948, 61303, 27917, 1194, 186, 16038, 1043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1462868, 62499, 28035, 1197, 186, 16071, 1045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1490906, 63698, 28168, 1197, 186, 16042, 1043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1519077, 64897, 28455, 1205, 186, 16122, 1048, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1547535, 66104, 28646, 1205, 186, 16091, 1046, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1576184, 67311, 28875, 1209, 186, 16109, 1047, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1605062, 68522, 29022, 1210, 186, 16086, 1046, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1634087, 69734, 29524, 1217, 186, 16102, 1047, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1663614, 70953, 29851, 1222, 186, 16117, 1048, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1693514, 72181, 668, 11, 130, "Input"],

Cell[CellGroupData[{
Cell[1694207, 72196, 26564, 1064, 186, 14300, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1720774, 73262, 26703, 1067, 186, 14334, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1747480, 74331, 26636, 1065, 186, 14299, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1774119, 75398, 26685, 1067, 186, 14332, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1800807, 76467, 26658, 1065, 186, 14305, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1827468, 77534, 26666, 1066, 186, 14321, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1854137, 78602, 26697, 1068, 186, 14352, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1880837, 79672, 26672, 1067, 186, 14335, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1907512, 80741, 26675, 1068, 186, 14350, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1934190, 81811, 26693, 1068, 186, 14352, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1960886, 82881, 26554, 1066, 186, 14347, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1987443, 83949, 26656, 1067, 186, 14331, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2014102, 85018, 26749, 1072, 186, 14404, 915, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2040854, 86092, 26629, 1064, 186, 14284, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2067486, 87158, 26633, 1065, 186, 14304, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2094122, 88225, 26625, 1065, 186, 14321, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2120750, 89292, 26629, 1067, 186, 14353, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2147382, 90361, 26655, 1066, 186, 14335, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2174040, 91429, 26606, 1063, 186, 14273, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2200649, 92494, 26633, 1064, 186, 14288, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2227285, 93560, 26501, 1063, 186, 14302, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2253789, 94625, 26609, 1065, 186, 14313, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2280401, 95692, 26674, 1069, 186, 14382, 913, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2307078, 96763, 26563, 1062, 186, 14267, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2333644, 97827, 26598, 1065, 186, 14318, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2360245, 98894, 26573, 1064, 186, 14297, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2386821, 99960, 26585, 1067, 186, 14362, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2413409, 101029, 26612, 1068, 186, 14364, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2440024, 102099, 26570, 1065, 186, 14314, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2466597, 103166, 26556, 1064, 186, 14300, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2493156, 104232, 26479, 1064, 186, 14329, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2519638, 105298, 26530, 1064, 186, 14315, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2546171, 106364, 26549, 1065, 186, 14334, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2572723, 107431, 26557, 1065, 186, 14334, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2599283, 108498, 26589, 1067, 186, 14362, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2625875, 109567, 26530, 1064, 186, 14315, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2652408, 110633, 26471, 1063, 186, 14304, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2678882, 111698, 26549, 1067, 186, 14366, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2705434, 112767, 26552, 1066, 186, 14353, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2731989, 113835, 26629, 1069, 186, 14398, 914, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2758621, 114906, 26409, 1063, 186, 14332, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2785033, 115971, 26536, 1066, 186, 14345, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2811572, 117039, 26512, 1064, 186, 14317, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2838087, 118105, 26506, 1065, 186, 14335, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2864596, 119172, 26493, 1064, 186, 14335, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2891092, 120238, 26460, 1064, 186, 14334, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2917555, 121304, 26492, 1067, 186, 14382, 913, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2944050, 122373, 26450, 1064, 186, 14332, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2970503, 123439, 26497, 1066, 186, 14367, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2997003, 124507, 26453, 1064, 186, 14335, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3023459, 125573, 25688, 1038, 186, 13809, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3049150, 126613, 26044, 1049, 186, 13938, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3075197, 127664, 26095, 1052, 186, 13985, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3101295, 128718, 26124, 1054, 186, 14022, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3127422, 129774, 26089, 1053, 186, 14003, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3153514, 130829, 26113, 1054, 186, 14015, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3179630, 131885, 26113, 1053, 186, 13999, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3205746, 132940, 26093, 1051, 186, 13967, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3231842, 133993, 26104, 1051, 186, 13970, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3257949, 135046, 26115, 1052, 186, 13985, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3284067, 136100, 25993, 1049, 186, 13952, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3310063, 137151, 26103, 1050, 186, 13957, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3336169, 138203, 26068, 1050, 186, 13950, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3362240, 139255, 26076, 1051, 186, 13970, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3388319, 140308, 26115, 1054, 186, 14017, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3414437, 141364, 26089, 1051, 186, 13971, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3440529, 142417, 26100, 1051, 186, 13966, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3466632, 143470, 26103, 1051, 186, 13969, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3492738, 144523, 26068, 1049, 186, 13938, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3518809, 145574, 26186, 1057, 186, 14068, 903, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3544998, 146633, 26030, 1051, 186, 13985, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3571031, 147686, 26144, 1053, 186, 13998, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3597178, 148741, 26167, 1054, 186, 14017, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3623348, 149797, 26131, 1052, 186, 13981, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3649482, 150851, 26131, 1053, 186, 13997, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3675616, 151906, 26173, 1054, 186, 14015, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3701792, 152962, 26208, 1056, 186, 14033, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3728003, 154020, 26201, 1055, 186, 14018, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3754207, 155077, 26272, 1059, 186, 14081, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3780482, 156138, 26129, 1050, 186, 13938, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3806614, 157190, 26003, 1048, 186, 13917, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3832620, 158240, 26144, 1050, 186, 13937, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3858767, 159292, 26114, 1048, 186, 13907, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3884884, 160342, 26200, 1054, 186, 14001, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3911087, 161398, 26114, 1050, 186, 13956, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3937204, 162450, 26146, 1051, 186, 13955, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3963353, 163503, 26145, 1051, 186, 13954, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3989501, 164556, 26177, 1052, 186, 13970, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4015681, 165610, 26162, 1051, 186, 13955, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4041846, 166663, 26207, 1055, 186, 14016, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4068056, 167720, 26118, 1055, 186, 14032, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4094177, 168777, 26233, 1055, 186, 14018, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4120413, 169834, 26276, 1059, 186, 14077, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4146692, 170895, 26275, 1059, 186, 14080, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4172970, 171956, 26242, 1056, 186, 14035, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4199215, 173014, 26238, 1056, 186, 14035, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4225456, 174072, 26267, 1057, 186, 14052, 902, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4251726, 175131, 26256, 1056, 186, 14033, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4277985, 176189, 26226, 1054, 186, 14003, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4304214, 177245, 26287, 1057, 186, 14035, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4330504, 178304, 26175, 1055, 186, 14033, 901, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

