(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2945112,     120788]*)
(*NotebookOutlinePosition[   2945855,     120813]*)
(*  CellTagsIndexPosition[   2945811,     120809]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING IN FRONT OF A POSITIVE DELTA-FUNCTION \
NONHOMOGENEITY", "Text",
  CellFrame->True,
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  v[x]  ",
    FontSize->12],
  StyleBox["is a delta-function of strength  c0, positive or negative, \
located at  x=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  The potential has one bound state if  c0<0  and no bound states \
if  c0>0.\n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" <0, is in front of  the nonhomogeneity and needs to be \
specified. ",
    FontSize->12],
  StyleBox["\n\nThe transmission coefficient, left reflection coefficient, \
and right reflection coefficient, respectively, are denoted by  T[k],  L[k],  \
R[k].\n\nThe tail of the wave is denoted by  g[x,t].\n\nThe focusing moment \
is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, c0, x0, g];\)\), "\[IndentingNewLine]", 
    \(\(v[x_] = \ c0\ \ DiracDelta[x]\ ;\)\), "\n", 
    \(\(T[k_] = k/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(L[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(R[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the strength of the potential, c0, a positive number;
also specify the focusing location  x0, a negative number, next:\
\>", "Text",\

  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\(c0 = 1\) \)\(;\)\(\ \ \)\(x0 = \(-1\)\)\(;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\n\)\(g[x_, 
          t_] = \ \(-\ \((c0/
                2)\)\)\ \((UnitStep[
                  x]\ \ UnitStep[\(-x\) + x0 + 
                    t]\ E^\((c0 \((x - x0 - t)\)/2)\) + 
              UnitStep[\(-x\)]\ UnitStep[
                  x + x0 + 
                    t]\ \ E^\((\(-c0\) \((x + x0 + t)\)/
                        2)\))\);\)\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-3\), \ 
              3}, \ PlotRange -> {\(-1\), 1}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-3\), \ 3}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-3\), \ 3}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1}]}, \[IndentingNewLine]\ {t, \ \(-1.9\), \ 3.9, 0.05}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03523 .30902 L
.03754 .30902 L
.03881 .30902 L
.03953 .30902 L
s
.03953 .30902 m
.0396 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool01@000?ooooooooooool0V@03oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00D0
003ooooooooooooo09T08oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`006_oo
o`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?
oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1b
oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000J
oooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo
08koool001[oool00ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo
07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o
09Woooooool0L_ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1boooo00<0003ooooo
ool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Wooooo
ool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool0
0ol0VOooooooo`1Ioooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>
oooo000Joooo00?o09Woooooool0F?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0F?ooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool001[oool0
0ol0VOooooooo`1Hoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`006_ooo`03o`2Ioooooooo05Soool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo
05Woool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo000Joooo00?o09Wooooo
ool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool0
0ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?oo
ooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_oo
o`030000oooooooo08koool001[oool00ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_oo
o`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?
oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1b
oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000J
oooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo
08koool001[oool00ol0VOooooooo`1Ooooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`006_ooo`03o`2Ioooooooo05koool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0G_ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`006_ooo`03o`2Ioooooooo05koool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool001[oool00ol0VOooooooo`1Noooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1O
oooo0P0000[oool300001?ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1boooo0P00
08ooool001[oool00ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo
07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o
09Woooooool0L_ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1boooo00<0003ooooo
ool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Wooooo
ool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool0
0ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool00`000?oo
ooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`80002?oooo000Joooo00?o09Woooooool0L_oo
o`030000oooooooo08koool001[oool00ol0VOooooooo`1Ioooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool001[oool00ol0VOooooooo`1Hoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo000Joooo00?o09Woooooool0F?ooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool001[oool00ol0VOooooooo`1Hoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool001[oool00ol0VOoo
ooooo`1Hoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo08koool001[oool00ol0VOooooooo`1Ioooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool20000Soooo`006_ooo`03o`2I
oooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo
08koool001[oool00ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo
07;oool20000Soooo`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o
09Woooooool0L_ooo`030000oooooooo08koool001[oool00ol0VOooooooo`1boooo00<0003ooooo
ool0S_ooo`006_ooo`03o`2Ioooooooo07;oool20000Soooo`006_ooo`03o`2Ioooooooo07;oool0
0`000?ooooooo`2>oooo000Joooo00?o09Woooooool0L_ooo`030000oooooooo08koool001[oool0
0ol0VOooooooo`1boooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo07;oool20000Sooo
o`006_ooo`03o`2Ioooooooo07;oool00`000?ooooooo`2>oooo000Joooo00?o09Woooooool0J_oo
o`D00003oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo06coool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`006_ooo`03o`2Ioooooooo06coool00`000?ooooooo`03oooo0`00
08koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Soool300001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-6.04337, 1.32095, 0.024893, 0.0127866}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-6.04337, 1.32095, 0.024893, 0.0127866}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04517 .30902 L
.04642 .30902 L
.04758 .30902 L
s
.04758 .30902 m
.04764 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`03oooo00?o09Woool000001ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool00oooo`03o`2Ioooooooo01ooool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
01coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool2
0000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000Loooo00?o09Wooooo
ool0L?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_oo
o`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?oo
ooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOoo
ooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?oo
o`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000
oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2I
oooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000L
oooo00?o09Woooooool0Eoooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`007?ooo`03o`2Ioooooooo05Koool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo05Koool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000L
oooo00?o09Woooooool0E_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool001coool00ol0VOooooooo`1Foooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool001coool00ol0VOoo
ooooo`1Goooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`007?ooo`03o`2I
oooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000L
oooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0
003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo
073oool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000oooooooo08koool0
01coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool2
0000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000Loooo00?o09Wooooo
ool0L?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_oo
o`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?oo
ooooo`2>oooo000Loooo00?o09Woooooool0GOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool001coool00ol0VOooooooo`1Loooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo05coool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool001coool00ol0VOooooooo`1Loooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0G?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Loooo00?o09Wooooo
ool0GOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0L?oo
o`80002?oooo000Loooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOoo
ooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?oo
o`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000
oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2I
oooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000L
oooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo00<0
003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool20000Soooo`007?ooo`03o`2Ioooooooo
073oool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0Eoooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0E_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`007?ooo`03o`2Ioooooooo05Koool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Loooo00?o09Woooooool0E_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Loooo00?o
09Woooooool0E_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0Eoooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo0P0008ooool001coool0
0ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool00`000?oo
ooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOoo
ooooo`1`oooo0P0008ooool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?oo
o`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000Loooo00?o09Woooooool0L?ooo`030000
oooooooo08koool001coool00ol0VOooooooo`1`oooo0P0008ooool001coool00ol0VOooooooo`1`
oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo073oool00`000?ooooooo`2>oooo000L
oooo00?o09Woooooool0L?ooo`030000oooooooo08koool001coool00ol0VOooooooo`1`oooo0P00
08ooool001coool00ol0VOooooooo`1`oooo00<0003oooooool0S_ooo`007?ooo`03o`2Ioooooooo
06Soool500000oooo`030000oooooooo08koool001coool00ol0VOooooooo`1Zoooo00<0003ooooo
ool00oooo`030000oooooooo08koool001coool00ol0VOooooooo`1Zoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool0
0`000?ooooooo`08oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.0503 .30902 L
.05288 .30902 L
.05405 .30902 L
.05528 .30902 L
s
.05528 .30902 m
.05535 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo01goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
01koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool2
0000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000Noooo00?o09Wooooo
ool0K_ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_oo
o`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOoo
ooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_oo
o`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000
oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2I
oooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000N
oooo00?o09Woooooool0EOooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`007_ooo`03o`2Ioooooooo05Coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo05Coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000N
oooo00?o09Woooooool0E?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool001koool00ol0VOooooooo`1Doooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool001koool00ol0VOoo
ooooo`1Eoooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`007_ooo`03o`2I
oooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000N
oooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0
003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo
06koool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000oooooooo08koool0
01koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool2
0000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000Noooo00?o09Wooooo
ool0K_ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_oo
o`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`2>oooo000Noooo00?o09Woooooool0Foooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool001koool00ol0VOooooooo`1Joooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo05[oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool001koool00ol0VOooooooo`1Joooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0F_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Noooo00?o09Wooooo
ool0Foooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0K_oo
o`80002?oooo000Noooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOoo
ooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_oo
o`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000
oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2I
oooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000N
oooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo00<0
003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool20000Soooo`007_ooo`03o`2Ioooooooo
06koool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0EOooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0E?oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`007_ooo`03o`2Ioooooooo05Coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Noooo00?o09Woooooool0E?ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Noooo00?o
09Woooooool0E?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0EOooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo0P0008ooool001koool0
0ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool00`000?oo
ooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOoo
ooooo`1^oooo0P0008ooool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_oo
o`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000Noooo00?o09Woooooool0K_ooo`030000
oooooooo08koool001koool00ol0VOooooooo`1^oooo0P0008ooool001koool00ol0VOooooooo`1^
oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo06koool00`000?ooooooo`2>oooo000N
oooo00?o09Woooooool0K_ooo`030000oooooooo08koool001koool00ol0VOooooooo`1^oooo0P00
08ooool001koool00ol0VOooooooo`1^oooo00<0003oooooool0S_ooo`007_ooo`03o`2Ioooooooo
06Koool500000oooo`030000oooooooo08koool001koool00ol0VOooooooo`1Xoooo00<0003ooooo
ool00oooo`030000oooooooo08koool001koool00ol0VOooooooo`1Xoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Coool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.05746 .30902 L
.06005 .30902 L
.06119 .30902 L
.06244 .30902 L
s
.06244 .30902 m
.06257 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo09T01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01oooo`03o`2Ioooooooo01_oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool2
0000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000Poooo00?o09Wooooo
ool0K?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_oo
o`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?oo
ooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOoo
ooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?oo
o`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000
oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2I
oooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000P
oooo00?o09Woooooool0Doooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`008?ooo`03o`2Ioooooooo05;oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo05;oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000P
oooo00?o09Woooooool0D_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool0023oool00ol0VOooooooo`1Boooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0023oool00ol0VOoo
ooooo`1Coooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`008?ooo`03o`2I
oooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000P
oooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0
003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo
06coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000oooooooo08koool0
023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool2
0000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000Poooo00?o09Wooooo
ool0K?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_oo
o`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?oo
ooooo`2>oooo000Poooo00?o09Woooooool0FOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool0023oool00ol0VOooooooo`1Hoooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo05Soool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool0023oool00ol0VOooooooo`1Hoooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0F?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Poooo00?o09Wooooo
ool0FOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0K?oo
o`80002?oooo000Poooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOoo
ooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?oo
o`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000
oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2I
oooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000P
oooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo00<0
003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool20000Soooo`008?ooo`03o`2Ioooooooo
06coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0Doooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0D_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`008?ooo`03o`2Ioooooooo05;oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Poooo00?o09Woooooool0D_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Poooo00?o
09Woooooool0D_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0Doooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo0P0008ooool0023oool0
0ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool00`000?oo
ooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOoo
ooooo`1/oooo0P0008ooool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?oo
o`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000Poooo00?o09Woooooool0K?ooo`030000
oooooooo08koool0023oool00ol0VOooooooo`1/oooo0P0008ooool0023oool00ol0VOooooooo`1/
oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo06coool00`000?ooooooo`2>oooo000P
oooo00?o09Woooooool0K?ooo`030000oooooooo08koool0023oool00ol0VOooooooo`1/oooo0P00
08ooool0023oool00ol0VOooooooo`1/oooo00<0003oooooool0S_ooo`008?ooo`03o`2Ioooooooo
06Coool500000oooo`030000oooooooo08koool0023oool00ol0VOooooooo`1Voooo00<0003ooooo
ool00oooo`030000oooooooo08koool0023oool00ol0VOooooooo`1Voooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo
00Woool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00Coool0
0`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0
003oooooool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002Oooo`@00003
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.06244 .30902 L
.06525 .30902 L
.0679 .30902 L
.06905 .30902 L
.07027 .30902 L
.07091 .30902 L
s
.07091 .30902 m
.07098 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00D0003ooooooooooooo
09T00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool02Oooo`03o`2Ioooooooo01Woool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo
06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003ooooo
ool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Sooo
o`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>
oooo000Roooo00?o09Woooooool0DOooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo053oool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo
053oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>
oooo000Roooo00?o09Woooooool0D?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool002;oool00ol0VOooooooo`1@oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Aoooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>
oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Z
oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2I
oooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo
08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo
06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003ooooo
ool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0Eoooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Foooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo05Koool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool002;oool00ol0VOooooooo`1Foooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0E_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0Eoooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Roooo00?o09Wooooo
ool0J_ooo`80002?oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Sooo
o`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>
oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Z
oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2I
oooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0DOooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Roooo00?o09Wooooo
ool0D?ooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo053oool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Roooo00?o09Woooooool0D?oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000R
oooo00?o09Woooooool0D?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0DOooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo0P0008ooool0
02;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo0P0008ooool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_oo
o`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo0P0008ooool002;oool00ol0VOoo
ooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>
oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Z
oooo0P0008ooool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2I
oooooooo06;oool500000oooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Toooo00<0
003oooooool00oooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Toooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool2
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000Woool400000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.06747 .30902 L
.07286 .30902 L
.07547 .30902 L
.07675 .30902 L
.07793 .30902 L
.07901 .30902 L
s
.07901 .30902 m
.07912 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool00ooo
o`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool02oooo`03o`2Ioooooooo01Ooool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
02Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool2
0000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Wooooo
ool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_oo
o`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0Coooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`009?ooo`03o`2Ioooooooo04koool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo04koool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000T
oooo00?o09Woooooool0C_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool002Coool00ol0VOooooooo`1>oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1?oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo
06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool0
02Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool2
0000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Wooooo
ool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_oo
o`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0EOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Doooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo05Coool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool002Coool00ol0VOooooooo`1Doooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0E?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Toooo00?o09Wooooo
ool0EOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?oo
o`80002?oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo
06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0Coooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0C_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo04koool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Toooo00?o09Woooooool0C_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0C_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0Coooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1X
oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo0P00
08ooool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo
063oool500000oooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Roooo00<0003ooooo
ool00oooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Roooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`<00004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool0
0`000?ooooooo`07oooo0`0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`<00003oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.07216 .30902 L
.0775 .30902 L
.08255 .30902 L
.08542 .30902 L
.0862 .30902 L
.08703 .30902 L
s
.08703 .30902 m
.0871 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo01Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
02Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool2
0000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000Voooo00?o09Wooooo
ool0I_ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_oo
o`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?oo
ooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOoo
ooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_oo
o`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000
oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2I
oooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000V
oooo00?o09Woooooool0COooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`009_ooo`03o`2Ioooooooo04coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo04coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000V
oooo00?o09Woooooool0C?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool002Koool00ol0VOooooooo`1<oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002Koool00ol0VOoo
ooooo`1=oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`009_ooo`03o`2I
oooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000V
oooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0
003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo
06Koool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000oooooooo08koool0
02Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool2
0000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000Voooo00?o09Wooooo
ool0I_ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_oo
o`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?oo
ooooo`2>oooo000Voooo00?o09Woooooool0Doooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool002Koool00ol0VOooooooo`1Boooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo05;oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool002Koool00ol0VOooooooo`1Boooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0D_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Voooo00?o09Wooooo
ool0Doooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0I_oo
o`80002?oooo000Voooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOoo
ooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_oo
o`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000
oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2I
oooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000V
oooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo00<0
003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool20000Soooo`009_ooo`03o`2Ioooooooo
06Koool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0COooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0C?oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`009_ooo`03o`2Ioooooooo04coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Voooo00?o09Woooooool0C?ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Voooo00?o
09Woooooool0C?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0COooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo0P0008ooool002Koool0
0ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool00`000?oo
ooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOoo
ooooo`1Voooo0P0008ooool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_oo
o`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000Voooo00?o09Woooooool0I_ooo`030000
oooooooo08koool002Koool00ol0VOooooooo`1Voooo0P0008ooool002Koool00ol0VOooooooo`1V
oooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo06Koool00`000?ooooooo`2>oooo000V
oooo00?o09Woooooool0I_ooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Voooo0P00
08ooool002Koool00ol0VOooooooo`1Voooo00<0003oooooool0S_ooo`009_ooo`03o`2Ioooooooo
05koool500000oooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Poooo00<0003ooooo
ool00oooo`030000oooooooo08koool002Koool00ol0VOooooooo`1Poooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Coool00`000?ooooooo`07oooo0`0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09109 .30902 L
.09258 .30902 L
.09324 .30902 L
.09396 .30902 L
s
.09396 .30902 m
.09409 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000ooooo`2I00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool03oooo`03o`2Ioooooooo01?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool2
0000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Wooooo
ool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_oo
o`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2I
oooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0Boooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00:?ooo`03o`2Ioooooooo04[oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo04[oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000X
oooo00?o09Woooooool0B_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1:oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1;oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00:?ooo`03o`2I
oooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool2
0000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Wooooo
ool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_oo
o`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`2>oooo000Xoooo00?o09Woooooool0DOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1@oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo053oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool002Soool00ol0VOooooooo`1@oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0D?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Xoooo00?o09Wooooo
ool0DOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`80002?oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2I
oooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0Boooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0B_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo04[oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Xoooo00?o09Woooooool0B_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Xoooo00?o
09Woooooool0B_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0Boooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool0
0ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P00
08ooool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo
05coool500000oooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Noooo00<0003ooooo
ool00oooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Noooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02_ooo`030000oooooooo00?oool0
0`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0
003oooooool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002
oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09396 .30902 L
.09682 .30902 L
.09952 .30902 L
.1007 .30902 L
.10195 .30902 L
.1026 .30902 L
s
.1026 .30902 m
.10267 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`050000ooooooooooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool04Oooo`03o`2Ioooooooo017oool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo
06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Sooo
o`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0BOooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo04Soool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo
04Soool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>
oooo000Zoooo00?o09Woooooool0B?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool002[oool00ol0VOooooooo`18oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`19oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1R
oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo
08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo
06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0Coooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1>oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo04koool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool002[oool00ol0VOooooooo`1>oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0C_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0Coooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Zoooo00?o09Wooooo
ool0H_ooo`80002?oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Sooo
o`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1R
oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0BOooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000Zoooo00?o09Wooooo
ool0B?ooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo04Soool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000Zoooo00?o09Woooooool0B?oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000Z
oooo00?o09Woooooool0B?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0BOooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool0
02[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_oo
o`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOoo
ooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1R
oooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo05[oool500000oooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Loooo00<0
003oooooool00oooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Loooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool2
00001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool00ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.09905 .30902 L
.10458 .30902 L
.10708 .30902 L
.10972 .30902 L
.11039 .30902 L
.1111 .30902 L
s
.1111 .30902 m
.11118 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool04oooo`03o`2Ioooooooo00ooool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
02coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool2
0000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Wooooo
ool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_oo
o`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0Aoooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00;?ooo`03o`2Ioooooooo04Koool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04Koool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000/
oooo00?o09Woooooool0A_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool002coool00ol0VOooooooo`16oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`17oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo
063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool0
02coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool2
0000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Wooooo
ool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_oo
o`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0COooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool002coool00ol0VOooooooo`1<oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04coool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool002coool00ol0VOooooooo`1<oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0C?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000/oooo00?o09Wooooo
ool0COooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?oo
o`80002?oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo
063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0Aoooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0A_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04Koool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000/oooo00?o09Woooooool0A_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0A_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0Aoooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo0P0008ooool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1P
oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo0P00
08ooool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo
05Soool500000oooo`030000oooooooo08koool002coool00ol0VOooooooo`1Joooo00<0003ooooo
ool00oooo`030000oooooooo08koool002coool00ol0VOooooooo`1Joooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Ooo
o`<00002oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`0:oooo00@0
003oooooool00002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Eoooo00<0003oooooool01oooo`D00004oooo00<0003oooooool00_ooo`030000
oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000G
oooo00<0003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0MOooo`00M_ooo`030000oooooooo01Ooool200002oooo`800003oooo0`0000;oool00`000?oo
ooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.1128 .30902 L
.11531 .30902 L
.11758 .30902 L
.11872 .30902 L
s
.11872 .30902 m
.11885 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo00goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
02koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool2
0000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Wooooo
ool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_oo
o`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0AOooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00;_ooo`03o`2Ioooooooo04Coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04Coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000^
oooo00?o09Woooooool0A?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool002koool00ol0VOooooooo`14oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`15oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo
05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool0
02koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool2
0000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Wooooo
ool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_oo
o`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0Boooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool002koool00ol0VOooooooo`1:oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04[oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool002koool00ol0VOooooooo`1:oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0B_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000^oooo00?o09Wooooo
ool0Boooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_oo
o`80002?oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo
05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0AOooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0A?oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04Coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000^oooo00?o09Woooooool0A?ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0A?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0AOooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo0P0008ooool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1N
oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo0P00
08ooool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo
05Koool500000oooo`030000oooooooo08koool002koool00ol0VOooooooo`1Hoooo00<0003ooooo
ool00oooo`030000oooooooo08koool002koool00ol0VOooooooo`1Hoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Ooo
o`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02_ooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo
00Ooool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Soool00`000?ooo`000003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.11992 .30902 L
.1226 .30902 L
.12377 .30902 L
.12507 .30902 L
.12627 .30902 L
s
.12627 .30902 m
.12638 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool05oooo`03o`2Ioooooooo00_oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool2
0000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Wooooo
ool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_oo
o`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?oo
ooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2I
oooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0@oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00<?ooo`03o`2Ioooooooo04;oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04;oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000`
oooo00?o09Woooooool0@_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool0033oool00ol0VOooooooo`12oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`13oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00<?ooo`03o`2I
oooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool2
0000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Wooooo
ool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_oo
o`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?oo
ooooo`2>oooo000`oooo00?o09Woooooool0BOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool0033oool00ol0VOooooooo`18oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04Soool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool0033oool00ol0VOooooooo`18oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0B?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000`oooo00?o09Wooooo
ool0BOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`80002?oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2I
oooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0@oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0@_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04;oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000`oooo00?o09Woooooool0@_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000`oooo00?o
09Woooooool0@_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0@oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool0
0ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?oo
ooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P00
08ooool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo
05Coool500000oooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Foooo00<0003ooooo
ool00oooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Foooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00Coool0
0`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0
003oooooool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.11992 .30902 L
.12507 .30902 L
.12986 .30902 L
.13117 .30902 L
.13256 .30902 L
.13375 .30902 L
s
.13375 .30902 m
.13388 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool01@000?ooooooooooool0V@03oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool06Oooo`03o`2Ioooooooo00Woool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo
05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Sooo
o`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0@Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo043oool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo
043oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>
oooo000boooo00?o09Woooooool0@?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool003;oool00ol0VOooooooo`10oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`11oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1J
oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo
08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo
05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0Aoooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool003;oool00ol0VOooooooo`16oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo04Koool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool003;oool00ol0VOooooooo`16oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0A_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0Aoooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000boooo00?o09Wooooo
ool0F_ooo`80002?oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Sooo
o`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1J
oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0@Oooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000boooo00?o09Wooooo
ool0@?ooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo043oool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000boooo00?o09Woooooool0@?oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000b
oooo00?o09Woooooool0@?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0@Oooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool0
03;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_oo
o`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1J
oooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05;oool500000oooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Doooo00<0
003oooooool00oooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Doooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool2
00001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13506 .30902 L
.13942 .30902 L
.14061 .30902 L
.14188 .30902 L
s
.14188 .30902 m
.14199 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`03oooo00?o09Woool000001oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool06oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
03Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool2
0000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Wooooo
ool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_oo
o`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0?oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00=?ooo`03o`2Ioooooooo03koool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo03koool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000d
oooo00?o09Woooooool0?_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool003Coool00ol0VOooooooo`0noooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`0ooooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo
05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool0
03Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool2
0000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Wooooo
ool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_oo
o`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0AOooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool003Coool00ol0VOooooooo`14oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo04Coool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool003Coool00ol0VOooooooo`14oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0A?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000doooo00?o09Wooooo
ool0AOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?oo
o`80002?oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo
05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0?oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0?_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo03koool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000doooo00?o09Woooooool0?_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0?_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0?oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1H
oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo0P00
08ooool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo
053oool500000oooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Boooo00<0003ooooo
ool00oooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Boooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`@00003oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00<0
003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000
oooooooo00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14635 .30902 L
.14868 .30902 L
.1499 .30902 L
.15059 .30902 L
s
.15059 .30902 m
.15066 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo00Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
03Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool2
0000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Wooooo
ool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_oo
o`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0?Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00=_ooo`03o`2Ioooooooo03coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo03coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000f
oooo00?o09Woooooool0??ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool003Koool00ol0VOooooooo`0loooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`0moooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo
05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool0
03Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool2
0000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Wooooo
ool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_oo
o`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0@oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool003Koool00ol0VOooooooo`12oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo04;oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool003Koool00ol0VOooooooo`12oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0@_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000foooo00?o09Wooooo
ool0@oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_oo
o`80002?oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo
05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0?Oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0??oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo03coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000foooo00?o09Woooooool0??ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0??ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0?Oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1F
oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo0P00
08ooool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo
04koool500000oooo`030000oooooooo08koool003Koool00ol0VOooooooo`1@oooo00<0003ooooo
ool00oooo`030000oooooooo08koool003Koool00ol0VOooooooo`1@oooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`030000oooooooo
00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.1536 .30902 L
.15586 .30902 L
.15709 .30902 L
.15825 .30902 L
s
.15825 .30902 m
.15835 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo09T01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool07oooo`03o`2Ioooooooo00?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool2
0000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Wooooo
ool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_oo
o`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2I
oooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0>oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00>?ooo`03o`2Ioooooooo03[oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo03[oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000h
oooo00?o09Woooooool0>_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool003Soool00ol0VOooooooo`0joooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`0koooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00>?ooo`03o`2I
oooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool2
0000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Wooooo
ool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_oo
o`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`2>oooo000hoooo00?o09Woooooool0@Oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool003Soool00ol0VOooooooo`10oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo043oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool003Soool00ol0VOooooooo`10oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0@?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000hoooo00?o09Wooooo
ool0@Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`80002?oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2I
oooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0>oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0>_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo03[oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo000hoooo00?o09Woooooool0>_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo000hoooo00?o
09Woooooool0>_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0>oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool0
0ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P00
08ooool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo
04coool500000oooo`030000oooooooo08koool003Soool00ol0VOooooooo`1>oooo00<0003ooooo
ool00oooo`030000oooooooo08koool003Soool00ol0VOooooooo`1>oooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`D00002oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00D0
003oooooooooool000000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool00ooo
o`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002
oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.15825 .30902 L
.16254 .30902 L
.16494 .30902 L
.16615 .30902 L
s
.16615 .30902 m
.16621 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool08Oooo`05o`2Ioooooooooooo000002Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?
oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1B
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo
05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Wooooo
ool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`0ioooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>
oooo000joooo00?o09Woooooool0>?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0>?ooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool003[oool0
0ol0VOooooooo`0hoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo03Soool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo
03Woool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo000joooo00?o09Wooooo
ool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?
oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1B
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`0ooooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo03koool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0?_ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00>_ooo`03o`2Ioooooooo03koool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool003[oool00ol0VOooooooo`0noooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003[oool00ol0VOooooooo`0o
oooo0P0000[oool300001?ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo0P00
08ooool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo
05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Wooooo
ool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`0ioooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool003[oool00ol0VOooooooo`0hoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0>?ooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool003[oool00ol0VOooooooo`0hoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`0hoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`0ioooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_ooo`03o`2I
oooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo
05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Sooo
o`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0B_oo
o`D00003oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo04coool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo04coool00`000?ooooooo`03oooo0`00
08koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo1@00
00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000Doooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.16254 .30902 L
.16783 .30902 L
.17044 .30902 L
.17158 .30902 L
.17284 .30902 L
.17396 .30902 L
s
.17396 .30902 m
.17407 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`03o`2Ioooo0000
00Soool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool08oooo`03o`2Ioooo000002Soool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00??ooo`03o`2Ioooooooo
053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Wooooo
ool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?
oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`0g
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0=_ooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0=_ooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool003coool00ol0VOooooooo`0f
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00??ooo`03o`2Ioooooooo03Koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo03Ooool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?
oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@
oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo
053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Wooooo
ool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`0moooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo03coool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0??ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00??ooo`03o`2Ioooooooo03coool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo08koool003coool00ol0VOooooooo`0loooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo08koool003coool00ol0VOooooooo`0moooo0P0000[oool3
00001?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo0P0008ooool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?
oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@
oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`0goooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool003coool00ol0VOooooooo`0foooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0=_ooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool003coool00ol0VOooooooo`0foooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool003coool00ol0VOooooooo`0foooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`0goooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Sooo
o`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>
oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@
oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2I
oooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0B?ooo`D00003oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo04[oool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo04[oool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000
oooooooo01Goool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0003oooooool00_oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.17735 .30902 L
.17986 .30902 L
.18109 .30902 L
.18221 .30902 L
s
.18221 .30902 m
.18233 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00?_ooo`03o`2Ioooooooo
04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Wooooo
ool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?
oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`0e
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0=?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0=?ooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool003koool00ol0VOooooooo`0d
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00?_ooo`03o`2Ioooooooo03Coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo03Goool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?
oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>
oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo
08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo
04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Wooooo
ool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`0koooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo03[oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0>_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00?_ooo`03o`2Ioooooooo03[oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo08koool003koool00ol0VOooooooo`0joooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo08koool003koool00ol0VOooooooo`0koooo0P0000[oool3
00001?ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo0P0008ooool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?
oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>
oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo
08koool003koool00ol0VOooooooo`0eoooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool003koool00ol0VOooooooo`0doooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0=?ooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool003koool00ol0VOooooooo`0doooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool003koool00ol0VOooooooo`0doooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool003koool00ol0VOooooooo`0eoooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Sooo
o`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>
oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>
oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2I
oooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0A_ooo`D00003oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04Soool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04Soool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool02?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0001Coool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo01Ooool200002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.18221 .30902 L
.18475 .30902 L
.18744 .30902 L
.18855 .30902 L
.18974 .30902 L
s
.18974 .30902 m
.18987 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000ooooo`2I02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00@?ooo`03o`2Ioooooooo
04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o
09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Wooooo
ool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool0
0ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?oo
ooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?oo
o`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?
oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`0c
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo0010oooo00?o
09Woooooool0<_ooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0<_ooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0043oool00ol0VOooooooo`0b
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00@?ooo`03o`2Ioooooooo03;oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo03?oool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?
oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010
oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo
08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo
04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o
09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Wooooo
ool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool0
0ol0VOooooooo`0ioooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo03Soool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo0010oooo00?o09Woooooool0>?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00@?ooo`03o`2Ioooooooo03Soool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo08koool0043oool00ol0VOooooooo`0hoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`0ioooo0P0000[oool3
00001?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo0P0008ooool0043oool0
0ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?oo
ooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?oo
o`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?
oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010
oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo
08koool0043oool00ol0VOooooooo`0coooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool0043oool00ol0VOooooooo`0boooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo0010
oooo00?o09Woooooool0<_ooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool0043oool00ol0VOooooooo`0boooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool0043oool00ol0VOooooooo`0boooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool0043oool00ol0VOooooooo`0coooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04coool20000Soooo`00@?ooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool0
0ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool20000Sooo
o`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?oo
o`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04coool20000Soooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>
oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool20000Soooo`00@?ooo`03o`2I
oooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0A?ooo`D00003oooo00<0
003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool01@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo
01?oool010000?ooooooo`0000Woool300001Oooo`030000oooooooo00;oool00`000?ooooooo`1d
oooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.18221 .30902 L
.18703 .30902 L
.19227 .30902 L
.19467 .30902 L
.19598 .30902 L
.19721 .30902 L
.19826 .30902 L
s
.19826 .30902 m
.19837 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000oooooooo
ooooo`2I00Coool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`050000ooooooooooooo`2I02Coool00`000?ooooooo`0Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?
oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012
oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo
08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Wooooo
ool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`0aoooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>
oooo0012oooo00?o09Woooooool0<?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0<?ooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool004;oool0
0ol0VOooooooo`0`oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo033oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
037oool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo0012oooo00?o09Wooooo
ool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?
oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012
oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo
08koool004;oool00ol0VOooooooo`0goooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo03Koool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0=_ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00@_ooo`03o`2Ioooooooo03Koool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool004;oool00ol0VOooooooo`0foooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004;oool00ol0VOooooooo`0g
oooo0P0000[oool300001?ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo0P00
08ooool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Wooooo
ool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`0aoooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool004;oool00ol0VOooooooo`0`oooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0<?ooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool004;oool00ol0VOooooooo`0`oooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool004;oool00ol0VOoo
ooooo`0`oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`0aoooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo
08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Sooo
o`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0@_oo
o`D00003oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04Coool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04Coool00`000?ooooooo`03oooo0`00
08koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00009oooo0`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
01;oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.19721 .30902 L
.20178 .30902 L
.20433 .30902 L
.20562 .30902 L
s
.20562 .30902 m
.20569 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00?oool01?l0VOooooooo`0000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool00oooo`03o`2Ioooooooo023oool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?oo
o`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool004Coool00ol0VOoo
ooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>
oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000
oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2I
oooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014
oooo00?o09Woooooool0B?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0
003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o
09Woooooool0B?ooo`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool0
04Coool00ol0VOooooooo`0_oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo0014oooo00?o09Woooooool0;_ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0;_oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0
04Coool00ol0VOooooooo`0^oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo02koool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00A?ooo`03o`2I
oooooooo02ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo0014oooo00?o
09Woooooool0B?ooo`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool0
04Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool0
0`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014oooo00?o09Wooooo
ool0B?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0003oooooool0S_oo
o`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?oo
o`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool004Coool00ol0VOoo
ooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>
oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000
oooooooo08koool004Coool00ol0VOooooooo`0eoooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo03Coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0=?ooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000S_ooo`00A?ooo`03o`2Ioooooooo03Coool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool004Coool00ol0VOooooooo`0doooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004Coool00ol0VOoo
ooooo`0eoooo0P0000[oool300001?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`18
oooo0P0008ooool004Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2I
oooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014
oooo00?o09Woooooool0B?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0
003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o
09Woooooool0B?ooo`80002?oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool0
04Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool0
0`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`80002?oooo0014oooo00?o09Wooooo
ool0B?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`0_oooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool004Coool00ol0VOooooooo`0^
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo0014oooo00?o09Woooooool0;_ooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool004Coool00ol0VOooooooo`0^oooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool004Coool0
0ol0VOooooooo`0^oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`0_oooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool20000Soooo`00A?oo
o`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`030000
oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2I
oooooooo04Soool20000Soooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014
oooo00?o09Woooooool0B?ooo`030000oooooooo08koool004Coool00ol0VOooooooo`18oooo00<0
003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool20000Soooo`00A?ooo`03o`2Ioooooooo
04Soool00`000?ooooooo`2>oooo0014oooo00?o09Woooooool0B?ooo`030000oooooooo08koool0
04Coool00ol0VOooooooo`18oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04Soool2
0000Soooo`00A?ooo`03o`2Ioooooooo04Soool00`000?ooooooo`2>oooo0014oooo00?o09Wooooo
ool0@?ooo`D00003oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04;oool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00A?ooo`03o`2Ioooooooo04;oool00`000?ooooooo`03
oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOoo
o`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@00
01;oool010000?ooooooo`0000Woool200001?ooo`800004oooo00<0003oooooool0MOooo`00MOoo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_oo
o`800004oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21019 .30902 L
.2114 .30902 L
.21274 .30902 L
.21394 .30902 L
s
.21394 .30902 m
.21405 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00ol0V@000?ooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo00Goool00ol0VOooooooo`0Noooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
04Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool2
0000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Wooooo
ool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_oo
o`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_oo
o`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000
oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016
oooo00?o09Woooooool0;Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00A_ooo`03o`2Ioooooooo02coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo02coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo0016
oooo00?o09Woooooool0;?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool004Koool00ol0VOooooooo`0/oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`0]oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016
oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo
04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool0
04Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool2
0000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Wooooo
ool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_oo
o`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`2>oooo0016oooo00?o09Woooooool0<oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool004Koool00ol0VOooooooo`0boooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo03;oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool004Koool00ol0VOooooooo`0boooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0<_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0016oooo00?o09Wooooo
ool0<oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_oo
o`80002?oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_oo
o`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000
oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016
oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo
04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0;Oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0;?oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo02coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo0016oooo00?o09Woooooool0;?ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo0016oooo00?o
09Woooooool0;?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0;Oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo0P0008ooool004Koool0
0ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_oo
o`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000
oooooooo08koool004Koool00ol0VOooooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16
oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016
oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo0P00
08ooool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo
03koool500000oooo`030000oooooooo08koool004Koool00ol0VOooooooo`10oooo00<0003ooooo
ool00oooo`030000oooooooo08koool004Koool00ol0VOooooooo`10oooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Boooo00@0003oooooool00009oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21274 .30902 L
.21753 .30902 L
.21884 .30902 L
.22022 .30902 L
.22141 .30902 L
s
.22141 .30902 m
.22154 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?l0VOooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo00Ooool00ol0VOooooooo`0Loooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
04Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool2
0000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018oooo00?o09Wooooo
ool0A?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_oo
o`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOoo
ooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?oo
o`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000
oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2I
oooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018
oooo00?o09Woooooool0:oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00B?ooo`03o`2Ioooooooo02[oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo02[oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo0018
oooo00?o09Woooooool0:_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool004Soool00ol0VOooooooo`0Zoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool004Soool00ol0VOoo
ooooo`0[oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00B?ooo`03o`2I
oooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018
oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0
003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo
04Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000oooooooo08koool0
04Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool2
0000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018oooo00?o09Wooooo
ool0A?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_oo
o`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`2>oooo0018oooo00?o09Woooooool0<Oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool004Soool00ol0VOooooooo`0`oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo033oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool004Soool00ol0VOooooooo`0`oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0<?ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0018oooo00?o09Wooooo
ool0<Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0A?oo
o`80002?oooo0018oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOoo
ooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?oo
o`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000
oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2I
oooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018
oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo00<0
003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool20000Soooo`00B?ooo`03o`2Ioooooooo
04Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0:oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0:_oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo02[oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo0018oooo00?o09Woooooool0:_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo0018oooo00?o
09Woooooool0:_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0:oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo0P0008ooool004Soool0
0ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOoo
ooooo`14oooo0P0008ooool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?oo
o`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018oooo00?o09Woooooool0A?ooo`030000
oooooooo08koool004Soool00ol0VOooooooo`14oooo0P0008ooool004Soool00ol0VOooooooo`14
oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo04Coool00`000?ooooooo`2>oooo0018
oooo00?o09Woooooool0A?ooo`030000oooooooo08koool004Soool00ol0VOooooooo`14oooo0P00
08ooool004Soool00ol0VOooooooo`14oooo00<0003oooooool0S_ooo`00B?ooo`03o`2Ioooooooo
03coool500000oooo`030000oooooooo08koool004Soool00ol0VOooooooo`0noooo00<0003ooooo
ool00oooo`030000oooooooo08koool004Soool00ol0VOooooooo`0noooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`800009
oooo100000?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.22272 .30902 L
.22738 .30902 L
.22852 .30902 L
.22974 .30902 L
s
.22974 .30902 m
.22981 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool010000?ooooooool0V@Coool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool02Oooo`03o`2Ioooooooo01[oool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_oo
o`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool004[oool00ol0VOoo
ooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>
oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000
oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2I
oooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:
oooo00?o09Woooooool0@_ooo`030000oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0
003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o
09Woooooool0@_ooo`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool0
04[oool00ol0VOooooooo`0Yoooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo001:oooo00?o09Woooooool0:?ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0:?oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0
04[oool00ol0VOooooooo`0Xoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo02Soool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00B_ooo`03o`2I
oooooooo02Woool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001:oooo00?o
09Woooooool0@_ooo`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool0
04[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool0
0`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:oooo00?o09Wooooo
ool0@_ooo`030000oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0003oooooool0S_oo
o`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_oo
o`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool004[oool00ol0VOoo
ooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>
oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000
oooooooo08koool004[oool00ol0VOooooooo`0_oooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo02koool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0;_ooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000S_ooo`00B_ooo`03o`2Ioooooooo02koool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool004[oool00ol0VOooooooo`0^oooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004[oool00ol0VOoo
ooooo`0_oooo0P0000[oool300001?ooo`030000oooooooo08koool004[oool00ol0VOooooooo`12
oooo0P0008ooool004[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2I
oooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:
oooo00?o09Woooooool0@_ooo`030000oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0
003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o
09Woooooool0@_ooo`80002?oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool0
04[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool0
0`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`80002?oooo001:oooo00?o09Wooooo
ool0@_ooo`030000oooooooo08koool004[oool00ol0VOooooooo`0Yoooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool004[oool00ol0VOooooooo`0X
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo001:oooo00?o09Woooooool0:?ooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool004[oool00ol0VOooooooo`0Xoooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool004[oool0
0ol0VOooooooo`0Xoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool004[oool00ol0VOooooooo`0Yoooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool20000Soooo`00B_oo
o`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`030000
oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2I
oooooooo04;oool20000Soooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:
oooo00?o09Woooooool0@_ooo`030000oooooooo08koool004[oool00ol0VOooooooo`12oooo00<0
003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool20000Soooo`00B_ooo`03o`2Ioooooooo
04;oool00`000?ooooooo`2>oooo001:oooo00?o09Woooooool0@_ooo`030000oooooooo08koool0
04[oool00ol0VOooooooo`12oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo04;oool2
0000Soooo`00B_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`2>oooo001:oooo00?o09Wooooo
ool0>_ooo`D00003oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo03coool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00B_ooo`03o`2Ioooooooo03coool00`000?ooooooo`03
oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000N_ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`800009oooo1000
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23496 .30902 L
.2364 .30902 L
.23711 .30902 L
.23775 .30902 L
s
.23775 .30902 m
.23787 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`02oooo00Co09Woooooool00007oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool02oooo`03o`2Ioooooooo01Soool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00C?ooo`03o`2Ioooooooo043oool00`000?ooooooo`2>oooo001<oooo00?o09Woooooool0@?oo
o`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000oooooooo08koool004coool00ol0VOoo
ooooo`10oooo00<0003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo043oool00`000?ooooooo`2>
oooo001<oooo00?o09Woooooool0@?ooo`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000
oooooooo08koool004coool00ol0VOooooooo`10oooo00<0003oooooool0S_ooo`00C?ooo`03o`2I
oooooooo043oool00`000?ooooooo`2>oooo001<oooo00?o09Woooooool0@?ooo`80002?oooo001<
oooo00?o09Woooooool0@?ooo`030000oooooooo08koool004coool00ol0VOooooooo`10oooo00<0
003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo043oool00`000?ooooooo`2>oooo001<oooo00?o
09Woooooool0@?ooo`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000oooooooo08koool0
04coool00ol0VOooooooo`0Woooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo001<oooo00?o09Woooooool09_ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001<oooo00?o09Woooooool09_oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0
04coool00ol0VOooooooo`0Voooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo02Koool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00C?ooo`03o`2I
oooooooo02Ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001<oooo00?o
09Woooooool0@?ooo`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000oooooooo08koool0
04coool00ol0VOooooooo`10oooo00<0003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo043oool0
0`000?ooooooo`2>oooo001<oooo00?o09Woooooool0@?ooo`80002?oooo001<oooo00?o09Wooooo
ool0@?ooo`030000oooooooo08koool004coool00ol0VOooooooo`10oooo00<0003oooooool0S_oo
o`00C?ooo`03o`2Ioooooooo043oool00`000?ooooooo`2>oooo001<oooo00?o09Woooooool0@?oo
o`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000oooooooo08koool004coool00ol0VOoo
ooooo`10oooo00<0003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo043oool00`000?ooooooo`2>
oooo001<oooo00?o09Woooooool0@?ooo`80002?oooo001<oooo00?o09Woooooool0@?ooo`030000
oooooooo08koool004coool00ol0VOooooooo`0]oooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00C?ooo`03o`2Ioooooooo02coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0:oooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000S_ooo`00COooo`03o`2Ioooooooo02_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool004goool00ol0VOooooooo`0[oooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0/oooo0P0000[oool300001?ooo`030000oooooooo08koool004goool00ol0VOooooooo`0o
oooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`80002?oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`80002?oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool0
04goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`80002?oooo001=oooo00?o09Wooooo
ool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0Voooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool004goool00ol0VOooooooo`0U
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool09Oooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool004goool00ol0VOooooooo`0Uoooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0Uoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool004goool00ol0VOooooooo`0Voooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo
03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool0
04goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool2
0000Soooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Wooooo
ool0=oooo`D00003oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03Woool00`000?ooooooo`03
oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOoo
o`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003
oooo0`0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@00
01;oool010000?ooooooo`0000Soool300001?ooo`800004oooo00<0003oooooool0MOooo`00MOoo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool3
00000oooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24016 .30902 L
.24276 .30902 L
.24392 .30902 L
.24502 .30902 L
s
.24502 .30902 m
.24515 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`04oooo00?o09T0003oool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo00goool00ol0VOooooooo`0Foooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
04koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool2
0000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>oooo00?o09Wooooo
ool0?_ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_oo
o`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOoo
ooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_oo
o`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000
oooooooo08koool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2I
oooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>
oooo00?o09Woooooool09Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00C_ooo`03o`2Ioooooooo02Coool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo02Coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001>
oooo00?o09Woooooool09?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool004koool00ol0VOooooooo`0Toooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool004koool00ol0VOoo
ooooo`0Uoooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00C_ooo`03o`2I
oooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>
oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo00<0
003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo
03koool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000oooooooo08koool0
04koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool2
0000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>oooo00?o09Wooooo
ool0?_ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_oo
o`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`2>oooo001>oooo00?o09Woooooool0:oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool004koool00ol0VOooooooo`0Zoooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo02[oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool004koool00ol0VOooooooo`0Zoooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0:_ooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001>oooo00?o09Wooooo
ool0:oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0?_oo
o`80002?oooo001>oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOoo
ooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_oo
o`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000
oooooooo08koool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2I
oooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>
oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo00<0
003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool20000Soooo`00C_ooo`03o`2Ioooooooo
03koool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool09Oooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool09?oo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo02Coool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001>oooo00?o09Woooooool09?ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001>oooo00?o
09Woooooool09?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool09Oooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo0P0008ooool004koool0
0ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOoo
ooooo`0noooo0P0008ooool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_oo
o`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>oooo00?o09Woooooool0?_ooo`030000
oooooooo08koool004koool00ol0VOooooooo`0noooo0P0008ooool004koool00ol0VOooooooo`0n
oooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo03koool00`000?ooooooo`2>oooo001>
oooo00?o09Woooooool0?_ooo`030000oooooooo08koool004koool00ol0VOooooooo`0noooo0P00
08ooool004koool00ol0VOooooooo`0noooo00<0003oooooool0S_ooo`00C_ooo`03o`2Ioooooooo
03Koool500000oooo`030000oooooooo08koool004koool00ol0VOooooooo`0hoooo00<0003ooooo
ool00oooo`030000oooooooo08koool004koool00ol0VOooooooo`0hoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Boooo00@0003oooooool00008oooo0`0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.24276 .30902 L
.24754 .30902 L
.25016 .30902 L
.25144 .30902 L
.25261 .30902 L
.25368 .30902 L
s
.25368 .30902 m
.25378 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003ooooo09T01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo013oool00ol0VOooooooo`0Coooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool2
0000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Wooooo
ool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_oo
o`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2I
oooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool08_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00DOooo`03o`2Ioooooooo027oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo027oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001A
oooo00?o09Woooooool08Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0Qoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0Roooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00DOooo`03o`2I
oooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool2
0000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Wooooo
ool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_oo
o`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2>oooo001Aoooo00?o09Woooooool0:?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0Woooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo02Ooool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool0057oool00ol0VOooooooo`0Woooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool09oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Aoooo00?o09Wooooo
ool0:?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`80002?oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2I
oooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool08_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool08Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo027oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Aoooo00?o09Woooooool08Oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Aoooo00?o
09Woooooool08Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool08_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo0P0008ooool0057oool0
0ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo0P00
08ooool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo
03?oool500000oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0eoooo00<0003ooooo
ool00oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0eoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000_oool00`000?ooooooo`03
oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002Oooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`<00003
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.25666 .30902 L
.2593 .30902 L
.26045 .30902 L
.26171 .30902 L
s
.26171 .30902 m
.26184 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo01;oool00ol0VOooooooo`0Aoooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo
03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Sooo
o`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool08?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo01ooool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo
01ooool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>
oooo001Coooo00?o09Woooooool07oooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0Ooooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0Poooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo
08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo
03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool09_ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0Uoooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo02Goool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool005?oool00ol0VOooooooo`0Uoooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool09Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool09_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Coooo00?o09Wooooo
ool0>Oooo`80002?oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Sooo
o`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool08?ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Coooo00?o09Wooooo
ool07oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo01ooool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Coooo00?o09Woooooool07ooo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001C
oooo00?o09Woooooool07oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool08?ooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool0
05?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_oo
o`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOoo
ooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0i
oooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo037oool500000oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0coooo00<0
003oooooool00oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0coooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool2
00001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.26171 .30902 L
.26425 .30902 L
.26698 .30902 L
.26778 .30902 L
.26855 .30902 L
.26923 .30902 L
s
.26923 .30902 m
.26931 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool00_ooo`04o`2Ioooooooo00001oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool04oooo`03o`2Ioooooooo013oool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?oo
o`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool005Coool00ol0VOoo
ooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>
oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000
oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2I
oooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001D
oooo00?o09Woooooool0>?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0
003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o
09Woooooool0>?ooo`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool0
05Coool00ol0VOooooooo`0Ooooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo001Doooo00?o09Woooooool07_ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool07_oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0
05Coool00ol0VOooooooo`0Noooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo01koool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00E?ooo`03o`2I
oooooooo01ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Doooo00?o
09Woooooool0>?ooo`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool0
05Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool0
0`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001Doooo00?o09Wooooo
ool0>?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_oo
o`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?oo
o`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool005Coool00ol0VOoo
ooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>
oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000
oooooooo08koool005Coool00ol0VOooooooo`0Uoooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo02Coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool09?ooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000S_ooo`00E?ooo`03o`2Ioooooooo02Coool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool005Coool00ol0VOooooooo`0Toooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005Coool00ol0VOoo
ooooo`0Uoooo0P0000[oool300001?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0h
oooo0P0008ooool005Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2I
oooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001D
oooo00?o09Woooooool0>?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0
003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o
09Woooooool0>?ooo`80002?oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool0
05Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool0
0`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`80002?oooo001Doooo00?o09Wooooo
ool0>?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0Ooooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool005Coool00ol0VOooooooo`0N
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo001Doooo00?o09Woooooool07_ooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool005Coool00ol0VOooooooo`0Noooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool005Coool0
0ol0VOooooooo`0Noooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0Ooooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool20000Soooo`00E?oo
o`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`030000
oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2I
oooooooo03Soool20000Soooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001D
oooo00?o09Woooooool0>?ooo`030000oooooooo08koool005Coool00ol0VOooooooo`0hoooo00<0
003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool20000Soooo`00E?ooo`03o`2Ioooooooo
03Soool00`000?ooooooo`2>oooo001Doooo00?o09Woooooool0>?ooo`030000oooooooo08koool0
05Coool00ol0VOooooooo`0hoooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03Soool2
0000Soooo`00E?ooo`03o`2Ioooooooo03Soool00`000?ooooooo`2>oooo001Doooo00?o09Wooooo
ool0<?ooo`D00003oooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03;oool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00E?ooo`03o`2Ioooooooo03;oool00`000?ooooooo`03
oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOoo
o`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005
oooo0`0000;oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002ooo
o`040000oooooooo00000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`D00004oooo00<0003oooooool00_oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool00ooo
o`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000_oool200000oooo`<00002
oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27279 .30902 L
.27513 .30902 L
.27643 .30902 L
.27765 .30902 L
s
.27765 .30902 m
.27772 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo01Koool00ol0VOooooooo`0=oooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
05Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool2
0000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Wooooo
ool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_oo
o`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool07?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00Eoooo`03o`2Ioooooooo01_oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo01_oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001G
oooo00?o09Woooooool06oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool005Ooool00ol0VOooooooo`0Koooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0Loooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo
03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool0
05Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool2
0000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Wooooo
ool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_oo
o`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool08_ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0Qoooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo027oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool005Ooool00ol0VOooooooo`0Qoooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool08Oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Goooo00?o09Wooooo
ool08_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Ooo
o`80002?oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo
03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool07?ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool06ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo01_oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Goooo00?o09Woooooool06oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool06oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool07?ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0e
oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo0P00
08ooool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo
02goool500000oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0_oooo00<0003ooooo
ool00oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0_oooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Ooo
o`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00D0003ooooo
ooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool00008oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28025 .30902 L
.28302 .30902 L
.28425 .30902 L
.28542 .30902 L
s
.28542 .30902 m
.28548 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo01Soool00ol0VOooooooo`0;oooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool2
0000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Wooooo
ool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_oo
o`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2I
oooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool06_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00FOooo`03o`2Ioooooooo01Woool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo01Woool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001I
oooo00?o09Woooooool06Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0Ioooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0Joooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00FOooo`03o`2I
oooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool2
0000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Wooooo
ool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_oo
o`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`2>oooo001Ioooo00?o09Woooooool08?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0Ooooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo01ooool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool005Woool00ol0VOooooooo`0Ooooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool07oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Ioooo00?o09Wooooo
ool08?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`80002?oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2I
oooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool06_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool06Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo01Woool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Ioooo00?o09Woooooool06Oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Ioooo00?o
09Woooooool06Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool06_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo0P0008ooool005Woool0
0ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo0P00
08ooool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo
02_oool500000oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0]oooo00<0003ooooo
ool00oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0]oooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:
oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29088 .30902 L
.29224 .30902 L
.29349 .30902 L
s
.29349 .30902 m
.2936 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00?oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo01[oool00ol0VOooooooo`09oooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo
037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Sooo
o`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool06?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01Ooool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo
01Ooool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>
oooo001Koooo00?o09Woooooool05oooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0Goooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0Hoooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0a
oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo
08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo
037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool07_ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0Moooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool005_oool00ol0VOooooooo`0Moooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool07_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Koooo00?o09Wooooo
ool0<Oooo`80002?oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Sooo
o`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0a
oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool06?ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Koooo00?o09Wooooo
ool05oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01Ooool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Koooo00?o09Woooooool05ooo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001K
oooo00?o09Woooooool05oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool06?ooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool0
05_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_oo
o`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOoo
ooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0a
oooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo02Woool500000oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0[oooo00<0
003oooooool00oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0[oooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool2
00001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29349 .30902 L
.29809 .30902 L
.29935 .30902 L
.30004 .30902 L
.3007 .30902 L
s
.3007 .30902 m
.30083 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00;oool01?l0VOoo
ooooo`0000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool06oooo`03o`2Ioooooooo00Soool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?oo
o`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool005coool00ol0VOoo
ooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>
oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000
oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2I
oooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001L
oooo00?o09Woooooool0<?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0
003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o
09Woooooool0<?ooo`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool0
05coool00ol0VOooooooo`0Goooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo001Loooo00?o09Woooooool05_ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool05_oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0
05coool00ol0VOooooooo`0Foooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo01Koool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00G?ooo`03o`2I
oooooooo01Ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Loooo00?o
09Woooooool0<?ooo`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool0
05coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool0
0`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001Loooo00?o09Wooooo
ool0<?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0003oooooool0S_oo
o`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?oo
o`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool005coool00ol0VOoo
ooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>
oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000
oooooooo08koool005coool00ol0VOooooooo`0Moooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo01coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool07?ooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000S_ooo`00G?ooo`03o`2Ioooooooo01coool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool005coool00ol0VOooooooo`0Loooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005coool00ol0VOoo
ooooo`0Moooo0P0000[oool300001?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0`
oooo0P0008ooool005coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2I
oooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001L
oooo00?o09Woooooool0<?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0
003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o
09Woooooool0<?ooo`80002?oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool0
05coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool0
0`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`80002?oooo001Loooo00?o09Wooooo
ool0<?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0Goooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool005coool00ol0VOooooooo`0F
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo001Loooo00?o09Woooooool05_ooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool005coool00ol0VOooooooo`0Foooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool005coool0
0ol0VOooooooo`0Foooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0Goooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool20000Soooo`00G?oo
o`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`030000
oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2I
oooooooo033oool20000Soooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001L
oooo00?o09Woooooool0<?ooo`030000oooooooo08koool005coool00ol0VOooooooo`0`oooo00<0
003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool20000Soooo`00G?ooo`03o`2Ioooooooo
033oool00`000?ooooooo`2>oooo001Loooo00?o09Woooooool0<?ooo`030000oooooooo08koool0
05coool00ol0VOooooooo`0`oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo033oool2
0000Soooo`00G?ooo`03o`2Ioooooooo033oool00`000?ooooooo`2>oooo001Loooo00?o09Wooooo
ool0:?ooo`D00003oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo02[oool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00G?ooo`03o`2Ioooooooo02[oool00`000?ooooooo`03
oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOoo
o`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003
oooo100000?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
s
.30919 .30902 m
.30927 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo01koool00ol0VOooooooo`05oooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
05ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool2
0000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Wooooo
ool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_oo
o`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool05?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00Goooo`03o`2Ioooooooo01?oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01?oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001O
oooo00?o09Woooooool04oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool005ooool00ol0VOooooooo`0Coooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0Doooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo
02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool0
05ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool2
0000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Wooooo
ool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_oo
o`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool06_ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0Ioooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01Woool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool005ooool00ol0VOooooooo`0Ioooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool06Oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Ooooo00?o09Wooooo
ool06_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Ooo
o`80002?oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo
02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool05?ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool04ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01?oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Ooooo00?o09Woooooool04oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool05?ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]
oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo0P00
08ooool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo
02Goool500000oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0Woooo00<0003ooooo
ool00oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0Woooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003ooooo
ool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P00
00?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31304 .30902 L
.31454 .30902 L
.31597 .30902 L
.31725 .30902 L
s
.31725 .30902 m
.31733 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ool0V@05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo023oool00ol0VOooooooo`03oooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool2
0000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Wooooo
ool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_oo
o`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOoo
o`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2I
oooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool04_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00HOooo`03o`2Ioooooooo017oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo017oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001Q
oooo00?o09Woooooool04Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool0067oool00ol0VOooooooo`0Aoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0Boooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00HOooo`03o`2I
oooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0
003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo
02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool2
0000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Wooooo
ool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_oo
o`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`2>oooo001Qoooo00?o09Woooooool06?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0Goooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo01Ooool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool0067oool00ol0VOooooooo`0Goooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool05oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Qoooo00?o09Wooooo
ool06?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:ooo
o`80002?oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOoo
o`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2I
oooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0
003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOooo`03o`2Ioooooooo
02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool04_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool04Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00HOooo`03o`2Ioooooooo017oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Qoooo00?o09Woooooool04Oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Qoooo00?o
09Woooooool04Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool04_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool0
0ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOoo
o`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[
oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo0P00
08ooool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo
02?oool500000oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0Uoooo00<0003ooooo
ool00oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0Uoooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`D00002oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32145 .30902 L
.32263 .30902 L
.32392 .30902 L
.32509 .30902 L
s
.32509 .30902 m
.32519 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool01@000?oo
ooooooooool0V@03oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02;oool01Ol0VOooooooooooo`00000Woooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Hooo
o`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?
oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Y
oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001S
oooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo
08koool006?oool00ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo
02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o
09Woooooool0:Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Wooooo
ool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool0
0ol0VOooooooo`0@oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>
oooo001Soooo00?o09Woooooool03oooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool03oooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006?oool0
0ol0VOooooooo`0?oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo
013oool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Soooo00?o09Wooooo
ool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool0
0ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Ooo
o`030000oooooooo08koool006?oool00ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hooo
o`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?
oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Y
oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001S
oooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo
08koool006?oool00ol0VOooooooo`0Foooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00Hoooo`03o`2Ioooooooo01Goool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool05Oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00Hoooo`03o`2Ioooooooo01Goool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Eoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006?oool00ol0VOooooooo`0F
oooo0P0000[oool300001?ooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Yoooo0P00
08ooool006?oool00ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo
02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o
09Woooooool0:Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Wooooo
ool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool0
0ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`80002?oooo001Soooo00?o09Woooooool0:Ooo
o`030000oooooooo08koool006?oool00ol0VOooooooo`0@oooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0?oooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo001Soooo00?o09Woooooool03oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool006?oool00ol0VOooooooo`0?oooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool006?oool00ol0VOoo
ooooo`0?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo08koool006?oool00ol0VOooooooo`0@oooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool20000Soooo`00Hoooo`03o`2I
oooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo
08koool006?oool00ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo
02Woool20000Soooo`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o
09Woooooool0:Oooo`030000oooooooo08koool006?oool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool20000Soooo`00Hoooo`03o`2Ioooooooo02Woool0
0`000?ooooooo`2>oooo001Soooo00?o09Woooooool0:Oooo`030000oooooooo08koool006?oool0
0ol0VOooooooo`0Yoooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02Woool20000Sooo
o`00Hoooo`03o`2Ioooooooo02Woool00`000?ooooooo`2>oooo001Soooo00?o09Woooooool08Ooo
o`D00003oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02?oool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00Hoooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo0`00
08koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@00
00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.32831 .30902 L
.33073 .30902 L
.33193 .30902 L
.33304 .30902 L
s
.33304 .30902 m
.33317 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`03oooo00?o09Woool000001oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Coool00ol0VOooo`00000Woooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00IOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o
09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo00<0003ooooo
ool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Wooooo
ool09oooo`80002?oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool0
0ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o09Woooooool09ooo
o`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOoo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?
oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0>
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001Uoooo00?o
09Woooooool03Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool03Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006Goool00ol0VOooooooo`0=
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00IOooo`03o`2Ioooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo00koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?
oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0W
oooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001U
oooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo
08koool006Goool00ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o
09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo00<0003ooooo
ool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Wooooo
ool09oooo`80002?oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool0
0ol0VOooooooo`0Doooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00IOoo
o`03o`2Ioooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001Uoooo00?o09Woooooool04oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00IOooo`03o`2Ioooooooo01?oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo08koool006Goool00ol0VOooooooo`0Coooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo08koool006Goool00ol0VOooooooo`0Doooo0P0000[oool3
00001?ooo`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo0P0008ooool006Goool0
0ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o09Woooooool09ooo
o`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOoo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`80002?
oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0W
oooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001U
oooo00?o09Woooooool09oooo`80002?oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo
08koool006Goool00ol0VOooooooo`0>oooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0=oooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo001U
oooo00?o09Woooooool03Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool006Goool00ol0VOooooooo`0=oooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0=oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool006Goool00ol0VOooooooo`0>oooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool20000Soooo`00IOooo`03o`2Ioooooooo02Ooool0
0`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool0
0ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool20000Sooo
o`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool09ooo
o`030000oooooooo08koool006Goool00ol0VOooooooo`0Woooo00<0003oooooool0S_ooo`00IOoo
o`03o`2Ioooooooo02Ooool20000Soooo`00IOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`2>
oooo001Uoooo00?o09Woooooool09oooo`030000oooooooo08koool006Goool00ol0VOooooooo`0W
oooo00<0003oooooool0S_ooo`00IOooo`03o`2Ioooooooo02Ooool20000Soooo`00IOooo`03o`2I
oooooooo02Ooool00`000?ooooooo`2>oooo001Uoooo00?o09Woooooool07oooo`D00003oooo00<0
003oooooool0S_ooo`00IOooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00IOooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0
003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?oo
o`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22045) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33823 .30902 L
.33953 .30902 L
.34076 .30902 L
s
.34076 .30902 m
.34087 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22045) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool001Woool200009Ooo
o`@0000Toooo1@0002;oool00`000?ooooooo`0Soooo1@0002?oool400009Oooo`80000Hoooo000H
oooo00@0003oooooool0000Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Goool010000?ooooooo`0001Ooool0
01[oool00`000?ooooooo`0Toooo00<0003oooooool09_ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Koool00`000?ooooooo`0Foooo000B
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
oooooooo01Goool001Soool010000?ooooooo`0002Coool010000?ooooooo`0002Koool00`000?oo
ooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02?oool010000?ooooooo`0002Coool0
10000?ooooooo`0001Ooool001Woool200009_ooo`80000Voooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009_ooo`80000Hoooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000Aooooo@0001;oool001Ooool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Foooo000Goooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool05_ooo`00Ioooo`03o`2Ioooooooo
02Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Oooo`80002?oooo001Woooo00?o
09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o09Wooooo
ool09Oooo`80002?oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool0
0ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`2>oooo001Woooo00?o09Woooooool09Oooo`80002?oooo001Woooo00?o09Woooooool09Ooo
o`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Iooo
o`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Oooo`80002?
oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0<
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001Woooo00?o
09Woooooool02oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool02oooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006Ooool00ol0VOooooooo`0;
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00Ioooo`03o`2Ioooooooo00_oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo00coool200002_oo
o`800004oooo0`0000Coool20000Soooo`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>
oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0U
oooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool20000Soooo`00Ioooo`03o`2I
oooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo
08koool006Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo
02Goool20000Soooo`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o
09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool20000Soooo`00Ioooo`03o`2Ioooooooo02Goool0
0`000?ooooooo`2>oooo001Woooo00?o09Woooooool04_ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool006Ooool00ol0VOooooooo`0Aoooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo017oool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0008koool006Ooool00ol0VOooooooo`0Aoooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool04Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Woooo00?o
09Woooooool04_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Woooo00?o09Wooooo
ool09Oooo`80002?oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool0
0ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`2>oooo001Woooo00?o09Woooooool09Oooo`80002?oooo001Woooo00?o09Woooooool09Ooo
o`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Iooo
o`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Oooo`80002?
oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0U
oooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001W
oooo00?o09Woooooool09Oooo`80002?oooo001Woooo00?o09Woooooool03?ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Woooo00?o09Wooooo
ool02oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo00_oool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001Woooo00?o09Woooooool02ooo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001W
oooo00?o09Woooooool02oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool03?ooo`800009oooo1000
00?oool300001?ooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo0P0008ooool0
06Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool0
0`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool0
0ol0VOooooooo`0Uoooo0P0008ooool006Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_oo
o`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>oooo001Woooo00?o09Woooooool09Ooo
o`030000oooooooo08koool006Ooool00ol0VOooooooo`0Uoooo0P0008ooool006Ooool00ol0VOoo
ooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2Ioooooooo02Goool00`000?ooooooo`2>
oooo001Woooo00?o09Woooooool09Oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0U
oooo0P0008ooool006Ooool00ol0VOooooooo`0Uoooo00<0003oooooool0S_ooo`00Ioooo`03o`2I
oooooooo01goool500000oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0Ooooo00<0
003oooooool00oooo`030000oooooooo08koool006Ooool00ol0VOooooooo`0Ooooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001Ooooo00<0003oooooool0G?ooo`030000
oooooooo05ooool005koool00`000?ooooooo`08oooo00<0003oooooool0Doooo`030000oooooooo
05koool005koool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`05oooo100000?oool2
00000oooo`@00002oooo100000?oool200001Oooo`<00002oooo0P0000Goool01@000?oooooooooo
o`000003oooo1@0000;oool200004Oooo`030000oooooooo05koool005koool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool00`000?ooooooo`09oooo00<0
003oooooool00oooo`030000oooooooo00?oool010000?ooooooo`0000Goool010000?ooooooo`00
00;oool00`000?ooooooo`03oooo00<0003oool000001_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`0>oooo00<0003oooooool0G_ooo`00GOooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`02oooo00@0
003oooooool00002oooo1@0000Coool00`000?ooooooo`04oooo00<0003oooooool01Oooo`050000
oooooooooooo000000;oool00`000?ooooooo`0?oooo00<0003oooooool0GOooo`00G_ooo`030000
oooooooo00D0000=oooo00<0003oooooool02Oooo`030000oooooooo00?oool01@000?oooooooooo
o`000002oooo00@0003oooooool00002oooo00@0003oooooooooool200001_ooo`030000oooo0000
00Koool01@000?ooooooooooo`000002oooo00<0003oooooool03_ooo`030000oooooooo05koool0
05koool01@000?ooooooooooo`00000>oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000
oooooooo00Coool01@000?ooooooooooo`000005oooo00D0003oooooooooool000000_ooo`030000
oooooooo00Coool200000_ooo`<00003oooo00<0003oooooool0G_ooo`00Goooo`030000oooooooo
013oool200002_ooo`800004oooo0P0000Coool200001Oooo`800003oooo0`0000goool200001?oo
o`800003oooo0`0000;oool01P000?ooooooo`000?ooo`0000;oool00`000?ooooooo`1Ooooo002f
oooo00<0003oooooool00P0006Goool00;Goool200000_ooo`<0001Toooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.58295, \
-1.05774, 0.0249737, 0.012828}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.58295, -1.05774, 0.0249737, 0.012828}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34309 .30902 L
.34566 .30902 L
.34693 .30902 L
.34811 .30902 L
.34918 .30902 L
s
.34918 .30902 m
.34929 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003ooooo09T01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooool0V@0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00JOooo`03o`2Ioooooooo
02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o
09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo00<0003ooooo
ool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Wooooo
ool08oooo`80002?oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool0
0ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o09Woooooool08ooo
o`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOoo
o`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?
oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0:
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001Yoooo00?o
09Woooooool02Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool02Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006Woool00ol0VOooooooo`09
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00JOooo`03o`2Ioooooooo00Woool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo00[oool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?
oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0S
oooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Y
oooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo
08koool006Woool00ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo
02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o
09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo00<0003ooooo
ool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Wooooo
ool08oooo`80002?oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool0
0ol0VOooooooo`0@oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00JOoo
o`03o`2Ioooooooo00ooool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001Yoooo00?o09Woooooool03oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00JOooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo08koool006Woool00ol0VOooooooo`0?oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo08koool006Woool00ol0VOooooooo`0@oooo0P0000[oool3
00001?ooo`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo0P0008ooool006Woool0
0ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o09Woooooool08ooo
o`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOoo
o`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`80002?
oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0S
oooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Y
oooo00?o09Woooooool08oooo`80002?oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo
08koool006Woool00ol0VOooooooo`0:oooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool006Woool00ol0VOooooooo`09oooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo001Y
oooo00?o09Woooooool02Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool006Woool00ol0VOooooooo`09oooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool006Woool00ol0VOooooooo`09oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool006Woool00ol0VOooooooo`0:oooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00JOooo`03o`2Ioooooooo02?oool20000Soooo`00JOooo`03o`2Ioooooooo02?oool0
0`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool0
0ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool20000Sooo
o`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool08ooo
o`030000oooooooo08koool006Woool00ol0VOooooooo`0Soooo00<0003oooooool0S_ooo`00JOoo
o`03o`2Ioooooooo02?oool20000Soooo`00JOooo`03o`2Ioooooooo02?oool00`000?ooooooo`2>
oooo001Yoooo00?o09Woooooool08oooo`030000oooooooo08koool006Woool00ol0VOooooooo`0S
oooo00<0003oooooool0S_ooo`00JOooo`03o`2Ioooooooo02?oool20000Soooo`00JOooo`03o`2I
oooooooo02?oool00`000?ooooooo`2>oooo001Yoooo00?o09Woooooool06oooo`D00003oooo00<0
003oooooool0S_ooo`00JOooo`03o`2Ioooooooo01goool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00JOooo`03o`2Ioooooooo01goool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35028 .30902 L
.35271 .30902 L
.35496 .30902 L
.35624 .30902 L
s
.35624 .30902 m
.35636 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool01@000?ooooooooooool0V@0Soooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Jooo
o`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?
oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Q
oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[
oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo
08koool006_oool00ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo
027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o
09Woooooool08Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Qoooo00<0003ooooo
ool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Wooooo
ool08Oooo`80002?oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool0
0ol0VOooooooo`08oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>
oooo001[oooo00?o09Woooooool01oooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool01oooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006_oool0
0ol0VOooooooo`07oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00Joooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo
00Soool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001[oooo00?o09Wooooo
ool08Oooo`80002?oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool0
0ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?oo
ooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o09Woooooool08Ooo
o`030000oooooooo08koool006_oool00ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Jooo
o`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?
oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Q
oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[
oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo
08koool006_oool00ol0VOooooooo`0>oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00Joooo`03o`2Ioooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool03Oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00Joooo`03o`2Ioooooooo00goool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0=oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006_oool00ol0VOooooooo`0>
oooo0P0000[oool300001?ooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Qoooo0P00
08ooool006_oool00ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo
027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o
09Woooooool08Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Qoooo00<0003ooooo
ool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Wooooo
ool08Oooo`80002?oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool0
0ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool00`000?oo
ooooo`2>oooo001[oooo00?o09Woooooool08Oooo`80002?oooo001[oooo00?o09Woooooool08Ooo
o`030000oooooooo08koool006_oool00ol0VOooooooo`08oooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`07oooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo001[oooo00?o09Woooooool01oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool006_oool00ol0VOooooooo`07oooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool006_oool00ol0VOoo
ooooo`07oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo08koool006_oool00ol0VOooooooo`08oooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool20000Soooo`00Joooo`03o`2I
oooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo
08koool006_oool00ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo
027oool20000Soooo`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o
09Woooooool08Oooo`030000oooooooo08koool006_oool00ol0VOooooooo`0Qoooo00<0003ooooo
ool0S_ooo`00Joooo`03o`2Ioooooooo027oool20000Soooo`00Joooo`03o`2Ioooooooo027oool0
0`000?ooooooo`2>oooo001[oooo00?o09Woooooool08Oooo`030000oooooooo08koool006_oool0
0ol0VOooooooo`0Qoooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo027oool20000Sooo
o`00Joooo`03o`2Ioooooooo027oool00`000?ooooooo`2>oooo001[oooo00?o09Woooooool06Ooo
o`D00003oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo01_oool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00Joooo`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo0`00
08koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@00
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.35742 .30902 L
.36173 .30902 L
.36284 .30902 L
.36405 .30902 L
s
.36405 .30902 m
.36417 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool00oooo`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`03oooo00?o09Woooooool07oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
06goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool2
0000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]oooo00?o09Wooooo
ool07oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_oo
o`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOoo
ooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOoo
o`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000
oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2I
oooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]
oooo00?o09Woooooool01_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00KOooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo00Goool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001]
oooo00?o09Woooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool006goool00ol0VOooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool006goool00ol0VOoo
ooooo`06oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00KOooo`03o`2I
oooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]
oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0
003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo
01ooool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000oooooooo08koool0
06goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool2
0000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]oooo00?o09Wooooo
ool07oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_oo
o`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`2>oooo001]oooo00?o09Woooooool03?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool006goool00ol0VOooooooo`0;oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo00_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool006goool00ol0VOooooooo`0;oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool02oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001]oooo00?o09Wooooo
ool03?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool07ooo
o`80002?oooo001]oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOoo
ooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOoo
o`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000
oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2I
oooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]
oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo00<0
003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool20000Soooo`00KOooo`03o`2Ioooooooo
01ooool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool01_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool01Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00KOooo`03o`2Ioooooooo00Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001]oooo00?o09Woooooool01Oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001]oooo00?o
09Woooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool01_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo0P0008ooool006goool0
0ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOoo
ooooo`0Ooooo0P0008ooool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOoo
o`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]oooo00?o09Woooooool07oooo`030000
oooooooo08koool006goool00ol0VOooooooo`0Ooooo0P0008ooool006goool00ol0VOooooooo`0O
oooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo01ooool00`000?ooooooo`2>oooo001]
oooo00?o09Woooooool07oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ooooo0P00
08ooool006goool00ol0VOooooooo`0Ooooo00<0003oooooool0S_ooo`00KOooo`03o`2Ioooooooo
01Ooool500000oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ioooo00<0003ooooo
ool00oooo`030000oooooooo08koool006goool00ol0VOooooooo`0Ioooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`D00002oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool00ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.36626 .30902 L
.36876 .30902 L
.37114 .30902 L
.37178 .30902 L
.37247 .30902 L
s
.37247 .30902 m
.37255 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`05oooo00?o09Woooooool07Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
06ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool2
0000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_oooo00?o09Wooooo
ool07Oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_oo
o`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?oo
ooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOoo
ooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Kooo
o`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000
oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2I
oooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_
oooo00?o09Woooooool01?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00Koooo`03o`2Ioooooooo00?oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo00?oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001_
oooo00?o09Woooooool00oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo08koool006ooool00ol0VOooooooo`03oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool006ooool00ol0VOoo
ooooo`04oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Koooo`03o`2I
oooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_
oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0
003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo
01goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000oooooooo08koool0
06ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool2
0000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_oooo00?o09Wooooo
ool07Oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_oo
o`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?oo
ooooo`2>oooo001_oooo00?o09Woooooool02_ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo08koool006ooool00ol0VOooooooo`09oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo00Woool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool006ooool00ol0VOooooooo`09oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool02Oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001_oooo00?o09Wooooo
ool02_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool07Ooo
o`80002?oooo001_oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOoo
ooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Kooo
o`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000
oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2I
oooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_
oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo00<0
003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool20000Soooo`00Koooo`03o`2Ioooooooo
01goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool01?ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool00ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00Koooo`03o`2Ioooooooo00?oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001_oooo00?o09Woooooool00oooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001_oooo00?o
09Woooooool00oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool01?ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo0P0008ooool006ooool0
0ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool00`000?oo
ooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOoo
ooooo`0Moooo0P0008ooool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Kooo
o`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_oooo00?o09Woooooool07Oooo`030000
oooooooo08koool006ooool00ol0VOooooooo`0Moooo0P0008ooool006ooool00ol0VOooooooo`0M
oooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo01goool00`000?ooooooo`2>oooo001_
oooo00?o09Woooooool07Oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Moooo0P00
08ooool006ooool00ol0VOooooooo`0Moooo00<0003oooooool0S_ooo`00Koooo`03o`2Ioooooooo
01Goool500000oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Goooo00<0003ooooo
ool00oooo`030000oooooooo08koool006ooool00ol0VOooooooo`0Goooo00<0003oooooool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00Coool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.37114 .30902 L
.37372 .30902 L
.37649 .30902 L
.37783 .30902 L
.3791 .30902 L
.38025 .30902 L
s
.38025 .30902 m
.38037 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`07oooo00?o09Woooooool06oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool2
0000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Wooooo
ool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_oo
o`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOoo
ooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOoo
o`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000
oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001a
oooo00?o09Woooooool00_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00LOooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`06oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo08koool0077oool01Ol0VOoooooooooo
o`000002oooo00<0003oooooool01oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
08koool0077oool01Ol0VOooooooooooo`000002oooo00<0003oooooool02?ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo08koool0077oool01Ol0VOooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool00_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0
077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_oo
o`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06ooo
o`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOoo
ooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo00Soool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool01oooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo08koool0077oool00ol0VOooooooo`07
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0002>oooo001aoooo00?o09Wooooo
ool01oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo00Ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00LOooo`03o`2Ioooooooo00Soool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0K
oooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0
077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo00;oool2
00001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00LOoo
o`05o`2Ioooooooooooo000000;oool00`000?ooooooo`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`2>oooo001aoooo00Go09Woooooooooool000000_oo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001a
oooo00Go09Woooooooooool000000_ooo`030000oooooooo00Woool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00LOooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`06
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`02oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0K
oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo
01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003ooooo
ool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`2>oooo001aoooo00?o09Woooooool04oooo`D00003oooo00<0003oooooool0S_oo
o`00LOooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800003oooo100000?oool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.3864 .30902 L
.38757 .30902 L
.38881 .30902 L
s
.38881 .30902 m
.38893 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00?oool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`09oooo00?o09Woooooool06Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool007?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo
01Woool20000Soooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o
09Woooooool06Oooo`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0003ooooo
ool0S_ooo`00Loooo`03o`2Ioooooooo01Woool20000Soooo`00Loooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`2>oooo001coooo00?o09Woooooool06Oooo`030000oooooooo08koool007?oool0
0ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool20000Sooo
o`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o09Woooooool06Ooo
o`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Looo
o`03o`2Ioooooooo01Woool20000Soooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>
oooo001coooo00?o09Woooooool00P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2>oooo001coooo00?o09Woool000000_ooo`030000oooooooo00Koool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooo000000;oool0
0`000?ooooooo`07oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00Looo
o`03o`2Ioooo000000;oool00`000?ooooooo`08oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00Loooo`03o`2Ioooo000000;oool00`000?ooooooo`06oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007?oool00ol0VOooooooo`02
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001coooo00?o09Woooooool06Ooo
o`80002?oooo001coooo00?o09Woooooool06Oooo`030000oooooooo08koool007?oool00ol0VOoo
ooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>
oooo001coooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o09Woooooool06Oooo`030000
oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2I
oooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o09Woooooool06Oooo`80002?oooo001c
oooo00?o09Woooooool06Oooo`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0
003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o
09Woooooool06Oooo`80002?oooo001coooo00?o09Woooooool06Oooo`030000oooooooo08koool0
07?oool00ol0VOooooooo`06oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_oo
o`00Loooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`2>oooo001coooo00?o09Woooooool01Oooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00Loooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo08koool007?oool00ol0VOooooooo`05oooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo08koool007?oool00ol0VOooooooo`06oooo0P00
00[oool300001?ooo`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo0P0008ooool0
07?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`2>oooo001coooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o09Wooooo
ool06Oooo`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_oo
o`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o09Woooooool06Ooo
o`80002?oooo001coooo00?o09Woooooool06Oooo`030000oooooooo08koool007?oool00ol0VOoo
ooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>
oooo001coooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o09Woooooool06Oooo`030000
oooooooo08koool007?oool00ol0VOooooooo`0200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooo000000;oool00`000?ooooooo`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo001c
oooo00?o09Woool000000_ooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<0002>oooo001coooo00?o09Woool000000_ooo`030000oooooooo00Woool010000?oo
ooooooooo`800005oooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooo000000;oool00`000?oo
ooooo`06oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0
07?oool00ol0VOooooooo`0200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`2>oooo001c
oooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o09Woooooool06Oooo`030000oooooooo
08koool007?oool00ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo
01Woool00`000?ooooooo`2>oooo001coooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o
09Woooooool06Oooo`030000oooooooo08koool007?oool00ol0VOooooooo`0Ioooo00<0003ooooo
ool0S_ooo`00Loooo`03o`2Ioooooooo01Woool00`000?ooooooo`2>oooo001coooo00?o09Wooooo
ool06Oooo`80002?oooo001coooo00?o09Woooooool06Oooo`030000oooooooo08koool007?oool0
0ol0VOooooooo`0Ioooo00<0003oooooool0S_ooo`00Loooo`03o`2Ioooooooo01Woool00`000?oo
ooooo`2>oooo001coooo00?o09Woooooool06Oooo`80002?oooo001coooo00?o09Woooooool06Ooo
o`030000oooooooo08koool007?oool00ol0VOooooooo`0Aoooo1@0000?oool00`000?ooooooo`2>
oooo001coooo00?o09Woooooool04oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001c
oooo00?o09Woooooool04oooo`030000oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool0000;
oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.39106 .30902 L
.39381 .30902 L
.39516 .30902 L
.39642 .30902 L
s
.39642 .30902 m
.39654 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0;oooo00?o09Woooooool05oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
07Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool2
0000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Wooooo
ool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOoo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000
oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001e
oooo00?o09T0000000001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0008koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo08koool007Goool00ol0V@000000000:oooo0P00
00Coool300001?ooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool0
07Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool0
0ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo00Coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool00oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
08koool007Goool00ol0VOooooooo`03oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0002>oooo001eoooo00?o09Woooooool00oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0S_ooo`00MOooo`03o`2Ioooooooo00?oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo00Coool200002_ooo`<00004
oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0
003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool0
07Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool0
0ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2I0000000000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo08koool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00MOooo`03o`2I
0000000000Woool400000oooo`<00004oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003ooooo
ool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool0
0ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool20000Sooo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOoo
o`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool03oooo`D00003oooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo017oool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
017oool00`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.39675 .30902 L
.40134 .30902 L
.40252 .30902 L
.40381 .30902 L
s
.40381 .30902 m
.40393 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0=oooo00?o09Woooooool05Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool2
0000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Wooooo
ool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_oo
o`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOoo
ooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2I
oooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003ooooo09T00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
08koool007Goool010000?ooool0V@0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<0002>oooo001eoooo00@0003ooooo09T0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00MOooo`040000ooooo`2I00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo
01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool2
0000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Wooooo
ool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_oo
o`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOoo
ooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool00_ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo08koool007Ooool01Ol0VOooooooooooo`000002
oooo00<0003oooooool01_ooo`040000oooooooo00001?ooo`030000oooooooo08koool007Ooool0
1Ol0VOooooooooooo`000002oooo00<0003oooooool02Oooo`030000oooooooo00;oool30000S_oo
o`00Moooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`07oooo0P0000Goool00`000?oo
ooooo`2>oooo001goooo00Go09Woooooooooool000000_ooo`030000oooooooo00Ooool00`000?oo
ooooo`04oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo00;oool200002_ooo`<00004
oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2I
oooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo
08koool007Ooool00ol0VOooooooo`0Eoooo0P0008ooool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo0P0008ooool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo0P0008ooool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_oo
o`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>
oooo001eoooo00@0003ooooo09T0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`2>oooo001eoooo00@0003ooooo09T0000:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool30000S_ooo`00MOooo`040000ooooo`2I00002oooo`040000oooooooo
oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003ooooo09T00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001g
oooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Wooooo
ool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_oo
o`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Ooo
o`80002?oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOoo
ooooo`0=oooo1@0000?oool00`000?ooooooo`2>oooo001goooo00?o09Woooooool03oooo`030000
oooooooo00?oool00`000?ooooooo`2>oooo001goooo00?o09Woooooool03oooo`030000oooooooo
00?oool30000S_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028
oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P00
00Goool300000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000_oool01@000?oooooooooo
o`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Soool500000oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.40616 .30902 L
.40882 .30902 L
.41013 .30902 L
.41134 .30902 L
.41203 .30902 L
s
.41203 .30902 m
.4121 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooool0V@05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0?oooo00?o09Woooooool04oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
07Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool2
0000Soooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001ioooo00?o09Wooooo
ool04oooo`030000oooooooo08koool007Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_oo
o`00NOooo`03o`2Ioooooooo01?oool20000Soooo`00NOooo`03o`2Ioooooooo01?oool00`000?oo
ooooo`2>oooo001ioooo00?o09Woooooool04oooo`030000oooooooo08koool007Woool00ol0VOoo
ooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool20000Soooo`00NOoo
o`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001ioooo00?o09Woooooool04oooo`030000
oooooooo08koool007Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2I
oooooooo01?oool20000Soooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001f
oooo0P000004ooooo`2Ioooooooo0P0000?oool400000oooo`800005oooo00<0003oooooool0S_oo
o`00MOooo`050000oooooooo0000o`2I00Ooool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`050000oooooooo0000o`2I00Soool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0002>oooo001eoooo00D0003oooooool0003o09T02Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool01@000?ooooooo`000?l0V@07
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007Koool2
000000?ooooo09Woool01oooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001ioooo00?o
09Woooooool04oooo`80002?oooo001ioooo00?o09Woooooool04oooo`030000oooooooo08koool0
07Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`2>oooo001ioooo00?o09Woooooool04oooo`80002?oooo001ioooo00?o09Wooooo
ool04oooo`030000oooooooo08koool007Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_oo
o`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001ioooo00?o09Woooooool04ooo
o`80002?oooo001ioooo00?o09Woooooool04oooo`030000oooooooo08koool007Woool00ol0VOoo
ooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>
oooo001ioooo00?o09Woooooool04oooo`80002?oooo001ioooo00?o09Woooooool04oooo`030000
oooooooo08koool007Woool00ol0VOooooooo`0200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`2>oooo001ioooo00?o09Woool000000_ooo`030000oooooooo00Koool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001ioooo00?o09Woool000000_ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo0`0008koool007Woool00ol0VOooo`000002oooo00<0003oooooool01ooo
o`800005oooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooo000000;oool00`000?ooooooo`07
oooo00<0003oooooool01?ooo`030000oooooooo08koool007Woool00ol0VOooooooo`0200002_oo
o`<00004oooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool20000Soooo`00NOoo
o`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001ioooo00?o09Woooooool04oooo`030000
oooooooo08koool007Woool00ol0VOooooooo`0Coooo0P0008ooool007Woool00ol0VOooooooo`0C
oooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001i
oooo00?o09Woooooool04oooo`030000oooooooo08koool007Woool00ol0VOooooooo`0Coooo0P00
08ooool007Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo
01?oool00`000?ooooooo`2>oooo001ioooo00?o09Woooooool04oooo`030000oooooooo08koool0
07Woool00ol0VOooooooo`0Coooo0P0008ooool007Woool00ol0VOooooooo`0Coooo00<0003ooooo
ool0S_ooo`00M_ooo`8000001?ooool0VOooooooo`800005oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`050000oooooooo0000o`2I00Woool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool007Goool01@000?ooooooo`00
0?l0V@09oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000S_ooo`00MOooo`050000
oooooooo0000o`2I00[oool010000?ooooooooooo`800005oooo00<0003oooooool0S_ooo`00MOoo
o`050000oooooooo0000o`2I00Ooool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0S_ooo`00M_ooo`8000000oooool0VOooo`06oooo100000?oool300001?ooo`030000
oooooooo08koool007Woool00ol0VOooooooo`0Coooo0P0008ooool007Woool00ol0VOooooooo`0C
oooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001i
oooo00?o09Woooooool04oooo`030000oooooooo08koool007Woool00ol0VOooooooo`0Coooo0P00
08ooool007Woool00ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo
01?oool00`000?ooooooo`2>oooo001ioooo00?o09Woooooool04oooo`030000oooooooo08koool0
07Woool00ol0VOooooooo`0Coooo0P0008ooool007Woool00ol0VOooooooo`0Coooo00<0003ooooo
ool0S_ooo`00NOooo`03o`2Ioooooooo01?oool00`000?ooooooo`2>oooo001ioooo00?o09Wooooo
ool04oooo`030000oooooooo08koool007Woool00ol0VOooooooo`0Coooo0P0008ooool007Woool0
0ol0VOooooooo`0Coooo00<0003oooooool0S_ooo`00NOooo`03o`2Ioooooooo00_oool500000ooo
o`030000oooooooo08koool007Woool00ol0VOooooooo`0=oooo00<0003oooooool00oooo`030000
oooooooo08koool007Woool00ol0VOooooooo`0=oooo00<0003oooooool00oooo`<0002>oooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00@0003oooooool00002oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00008oooo1@0000Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.41134 .30902 L
.41408 .30902 L
.41703 .30902 L
.41846 .30902 L
.41917 .30902 L
.41982 .30902 L
s
.41982 .30902 m
.41994 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool01@000?ooooooooooool0V@03
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Aoooo00?o09Woooooool04Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o
09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool0
0`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool0
0ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Sooo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Ooo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Nooo
o`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001foooo0P0000?oool00ol0V@0000000003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000;oool00ol0VOooooooo`03oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo08koool007Goool010000?ooooooo`0000;oool0
0ol0VOooooooo`04oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00MOoo
o`040000oooooooo00000_ooo`03o`2Ioooooooo00Goool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`2>oooo001eoooo00@0003oooooool00002oooo00?o09Woooooool00oooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000?oool0
0ol0VOooooooo`04oooo0P0000Coool300001?ooo`030000oooooooo08koool007_oool00ol0VOoo
ooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Nooo
o`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000
oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0A
oooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001k
oooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P00
08ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool0
07_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2I0000000000Coool200001?ooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo08koool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0008koool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00Noooo`03o`2I0000000000[oool300001?oo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`80002?oooo001koooo00?o09Woooooool04Oooo`030000
oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`80002?oooo001k
oooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0
003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o
09Woooooool04Oooo`80002?oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool0
07Koool200000oooo`03o`2I0000000000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`2>oooo001eoooo00@0003oooooool00002oooo00?o09Woooooool01Oooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo
00000_ooo`03o`2Ioooooooo00Goool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>
oooo001eoooo00@0003oooooool00002oooo00?o09Woooooool01_ooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00002oooo00?o09Woooooool00ooo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P00
00?oool00ol0VOooooooo`03oooo100000?oool300001?ooo`030000oooooooo08koool007_oool0
0ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_oo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Ooo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0A
oooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo
08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0
003oooooool0S_ooo`00Noooo`03o`2Ioooooooo00Woool500000oooo`030000oooooooo08koool0
07_oool00ol0VOooooooo`0;oooo00<0003oooooool00oooo`030000oooooooo08koool007_oool0
0ol0VOooooooo`0;oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?oo
o`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001l
oooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0
003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002oooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Woool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0A
oooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.42237 .30902 L
.42482 .30902 L
.42617 .30902 L
.42744 .30902 L
.42816 .30902 L
s
.42816 .30902 m
.42824 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`03oooo00?o
09Woool000001oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Coooo00?o09Woooooool03oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool2
0000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_oo
o`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOoo
o`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000
oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool00004oooo00Go09Woooooooooool000001Oooo`040000oooooooo00001?ooo`030000
oooooooo08koool007Goool010000?ooooooo`0000Coool00ol0VOooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00001?ooo`03o`2I
oooooooo00?oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool00004oooo00Go09Woooooooooool000000_ooo`050000oooooooooooo000000Koool0
0`000?ooooooo`2>oooo001foooo0P0000Goool00ol0VOooooooo`02oooo0P0000Coool300001?oo
o`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>
oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?
oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo
08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo08koool007_oool010000?ooool0V@0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001koooo00@0003ooooo09T0000;oooo00<0003oooooool00_oo
o`<0002>oooo001koooo00@0003ooooo09T00009oooo0P0000Goool00`000?ooooooo`2>oooo001k
oooo00@0003ooooo09T00009oooo00<0003oooooool01?ooo`030000oooooooo08koool007coool2
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool20000Sooo
o`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03ooo
o`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>
oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?
oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo
08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`2>oooo001eoooo00@0003oooooool00004oooo00?o09Woooooool00oooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_ooo`00MOooo`040000
oooooooo00001?ooo`03o`2Ioooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001eoooo00@0003oooooool00004oooo00?o09Woooooool01?ooo`040000oooooooo
oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00004oooo00Go09Wooooo
ooooool000000_ooo`050000oooooooooooo000000Koool00`000?ooooooo`2>oooo001foooo0P00
00Goool01?l0VOooooooooooo`@00003oooo0`0000Coool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool03oooo`80002?oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`80002?oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_oo
o`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03ooo
o`80002?oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>
oooo001moooo00?o09Woooooool03oooo`80002?oooo001moooo00?o09Woooooool03oooo`030000
oooooooo08koool007goool00ol0VOooooooo`07oooo1@0000?oool00`000?ooooooo`2>oooo001m
oooo00?o09Woooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool02Oooo`030000oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002oooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43049 .30902 L
.43298 .30902 L
.43522 .30902 L
.43648 .30902 L
s
.43648 .30902 m
.43659 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo00?o09Woooooool03Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
07ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool2
0000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Wooooo
ool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_oo
o`00Ooooo`03o`2Ioooooooo00goool20000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOoo
ooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool20000Soooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2I
oooooooo00goool20000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001f
oooo0P0000Coool2000000?ooooo09Woool0100000?oool200001Oooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000Koool00ol0VOooo`000005oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00001_ooo`04o`2Ioooooooo00001oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00001_ooo`05o`2Ioooooooooooo0000
00Coool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Koool00ol0VOoo
o`000002oooo00D0003oooooooooool000001_ooo`030000oooooooo08koool007Koool200001ooo
o`03o`2Ioooooooo00800004oooo0`0000Coool00`000?ooooooo`2>oooo001ooooo00?o09Wooooo
ool03Oooo`80002?oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool03Oooo`80002?oooo001ooooo00?o09Woooooool03Ooo
o`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`80002?
oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=
oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool03Oooo`80002?oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo
08koool007coool2000000Cooooo09Woooooool200001?ooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`050000oooooooo0000o`2I00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001koooo00D0003oooooool0003o09T02_ooo`030000oooooooo00;oool30000S_ooo`00Nooo
o`050000oooooooo0000o`2I00Soool200001Oooo`030000oooooooo08koool007_oool01@000?oo
ooooo`000?l0V@08oooo00<0003oooooool01?ooo`030000oooooooo08koool007coool2000000?o
oooo09Woool01oooo`<00004oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool2
0000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Wooooo
ool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool007ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOoo
ooooo`0=oooo0P0008ooool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool007ooool00ol0VOooooooo`0=
oooo00<0003oooooool0S_ooo`00M_ooo`800004oooo0P000003ooooo`2Ioooo00;oool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00006oooo00Go
09Woooooooooool000000oooo`040000oooooooo00001?ooo`030000oooooooo08koool007Goool0
10000?ooooooo`0000Koool01Ol0VOooooooooooo`000006oooo00<0003oooooool00_ooo`<0002>
oooo001eoooo00@0003oooooool00006oooo00?o09Woooooool00_ooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00006oooo00?o09Woool000000_oo
o`050000oooooooooooo000000Koool00`000?ooooooo`2>oooo001foooo0P0000Ooool00ol0VOoo
o`00000300000oooo`<00004oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool2
0000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Wooooo
ool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_oo
o`00Ooooo`03o`2Ioooooooo00goool20000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOoo
ooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool20000Soooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2I
oooooooo00goool20000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool01Oooo`D00003oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
00001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000
oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`00
00;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44151 .30902 L
.44268 .30902 L
.44387 .30902 L
s
.44387 .30902 m
.44398 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003ooooo09T01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Goooo00?o09Woooooool02oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool2
0000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_oo
o`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POoo
o`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00ol0V@000?ooo`06oooo00<0003oooooool00_oo
o`<0002>oooo001eoooo00@0003oooooool00008oooo00?o09Woool000001?ooo`800005oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool00ol0V@0000000004oooo0`00
00Coool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o
09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool0
0ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o09Woooooool02ooo
o`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POoo
o`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`80002?
oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool007coool200000oooo`03o`2I
0000000000Coool200001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000;oool0
0ol0VOooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000
oooooooo00000_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`02oooo0`0008koool007_oool0
10000?ooooooo`0000;oool00ol0VOooooooo`04oooo0P0000Goool00`000?ooooooo`2>oooo001k
oooo00@0003oooooool00002oooo00?o09Woooooool01?ooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo001loooo0P0000?oool00ol0VOooooooo`04oooo0`0000Coool00`000?ooooooo`2>
oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021
oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0
003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo
00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0
087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool2
0000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00000oooo`03o`2Ioooo000000Coool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000Soool00ol0VOooo`000003oooo00@0003oooooool00004oooo00<0003oooooool0S_oo
o`00MOooo`040000oooooooo00002?ooo`03o`2Ioooo000000Koool00`000?ooooooo`02oooo0`00
08koool007Goool010000?ooooooo`0000Soool01?l0VOooooooo`0000?oool200001Oooo`030000
oooooooo08koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;
oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021
oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P00
08ooool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo
00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0
087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool0
0ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00?oool500000ooo
o`030000oooooooo08koool0087oool00ol0VOooooooo`05oooo00<0003oooooool00oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`05oooo00<0003oooooool00oooo`<0002>oooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?oo
o`<00004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44268 .30902 L
.44744 .30902 L
.44874 .30902 L
.45013 .30902 L
.45143 .30902 L
s
.45143 .30902 m
.45155 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00D0
003ooooooooooooo09T00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Ioooo00?o09Woooooool02Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Sooo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Pooo
o`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001e
oooo00@0003oooooool00008oooo00<0003ooooo09T00oooo`040000oooooooo00001?ooo`030000
oooooooo08koool007Goool010000?ooooooo`0000Woool00`000?l0VOooo`05oooo00<0003ooooo
ool00_ooo`<0002>oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000ooooo`2I00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Sooo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00001?ooo`05o`2Ioooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo
00001?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`02oooo0`0008koool007_oool010000?oo
ooooo`0000Coool00ol0VOooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0
003oooooool00004oooo00?o09Woooooool00_ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001loooo0P0000Goool00ol0VOooooooo`02oooo0`0000Coool00`000?ooooooo`2>oooo0023
oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Sooo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo001foooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>
oooo001eoooo00@0003oooooool0000:oooo00?o09T0003oool00_ooo`800005oooo00<0003ooooo
ool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000ooooo`2I00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Sooo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Pooo
o`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00Co09Woooooooooool500000oooo`030000
oooooooo08koool008?oool00ol0VOooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`03oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0
003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.44268 .30902 L
.44778 .30902 L
.45262 .30902 L
.45697 .30902 L
.45816 .30902 L
.45943 .30902 L
s
.45943 .30902 m
.45955 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool00oooo`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Koooo00?o09Woooooool01oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool2
0000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Wooooo
ool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool20000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOoo
ooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool20000Soooo`00QOoo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000
oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2I
oooooooo00Ooool20000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@000000ol0VOooooooo`0200001Oooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000Soool01`000?ooooooooooool0VOooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo08koool007Goool010000?ooooooo`0000Woool010000?ooooooool0
V@Coool00`000?ooooooo`02oooo0`0008koool007Goool010000?ooooooo`0000[oool00`000?oo
ool0V@02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00D0
003oooooool0003o09T00_ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P00
00[oool2000000Cooooo09Woooooool300001?ooo`030000oooooooo08koool008Goool00ol0VOoo
ooooo`07oooo0P0008ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOoo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000
oooooooo08koool008Goool00ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOooooooo`07
oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025
oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo0P00
08ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool0
08Goool00ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOooooooo`07oooo00<0003ooooo
ool0S_ooo`00O?ooo`800004oooo0P000004ooooo`2Ioooooooo0P0000Goool00`000?ooooooo`2>
oooo001koooo00@0003oooooool00006oooo00?o09Woool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00006oooo00?o09Woooooool00_ooo`030000
oooooooo00;oool30000S_ooo`00Noooo`040000oooooooo00001_ooo`03o`2Ioooooooo00800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00001_ooo`04o`2Ioooooooo00001_oo
o`030000oooooooo08koool007coool200001oooo`03o`2Ioooooooo00<00004oooo00<0003ooooo
ool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool20000Soooo`00QOooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool0
0ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01ooo
o`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOoo
ooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>
oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07
oooo0P0008ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00M_ooo`800004
oooo0P0000Goool00`000?ooool0V@02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool0000:oooo00D0003ooooo09Woool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo001eoooo00@0003oooooool0000:oooo00<0003ooooo09T01?ooo`030000oooooooo
00;oool30000S_ooo`00MOooo`040000oooooooo00002oooo`040000o`2Ioooooooo0P0000Goool0
0`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00D0003oooooool0003o09T00_oo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool4000000?o09Wooooo
ool00`0000Coool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`80002?oooo0025
oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0
003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o
09Woooooool01oooo`80002?oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool0
08Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`80002?oooo0025oooo00?o09Wooooo
ool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01ooo
o`80002?oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOoo
o`00000400000oooo`030000oooooooo08koool008Goool01Ol0VOooooooooooo`000005oooo00<0
003oooooool0S_ooo`00QOooo`05o`2Ioooooooooooo000000Goool30000S_ooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00@0003ooooo
ooooool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Woool400000oooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46388 .30902 L
.46618 .30902 L
.46687 .30902 L
.46751 .30902 L
s
.46751 .30902 m
.46763 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Moooo00?o09Woooooool01Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool2
0000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@00002oooo00?o09T0000000001Oooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00;oool01?l0VOoo
ooooo`0000Coool30000S_ooo`00MOooo`040000oooooooo00002_ooo`050000ooooooooooooo`2I
00800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`03o`2I0000oooo00Goool00`000?ooooooo`2>oooo001foooo0P0000[oool200000ooo
o`04o`2I0000000000001?ooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P00
08ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00O?oo
o`800004oooo0P0000?oool00ol0V@0000000005oooo00<0003oooooool0S_ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo08koool007_oool010000?oo
ooooo`0000Soool01?l0VOooooooo`0000Coool30000S_ooo`00Noooo`040000oooooooo00002?oo
o`03o`2I0000000000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00?o
09T0003oool01Oooo`030000oooooooo08koool007coool200002Oooo`04o`2I0000000000001?oo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
07Koool200001?ooo`800005oooo00D0003ooooooooooooo09T00P0000Goool00`000?ooooooo`2>
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`2>oooo001eoooo00@0003oooooool0000:oooo00D0003ooooooooooooo
09T00_ooo`030000oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00002oooo`040000
ooooooooo`2I0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00?o09T0003oool01Oooo`030000oooooooo08koool007Koool200002Ooo
o`@00002oooo00Co09T0000000000004oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Sooo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo1@0000?oool00`000?ooooooo`2>oooo0027oooo00?o09Woool000001Oooo`030000
oooooooo08koool008Ooool00ol0VOooo`000005oooo0`0008koool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00009
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.47106 .30902 L
.47329 .30902 L
.47451 .30902 L
.47567 .30902 L
s
.47567 .30902 m
.47578 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Ooooo00?o09Woooooool00oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool2
0000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000ooooo`2I00001?ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00?o09T0003oool00ooo
o`<0002>oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
o`2Ioooo00Coool00`000?ooooooo`2>oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool2
0000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000ooooo`2I00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000[oool00ol0V@000?ooo`03oooo0`00
08koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool0
10000?ooooooo`0000Woool00`000?l0VOooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool2
0000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool007Goool010000?ooooooo`0000[oool020000?ooooooooooo`000?ooool0V@00
00Coool00`000?ooooooo`2>oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00ooo
o`03o`2I0000oooo00?oool30000S_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooo
oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003o09Woool01?ooo`030000oooooooo08koool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o
09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Ooool500000ooo
o`030000oooooooo08koool008Woool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`030000oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000
oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Woool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47994 .30902 L
.48231 .30902 L
.483 .30902 L
.48364 .30902 L
s
.48364 .30902 m
.48376 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`050000ooooooooooooo`2I00?oool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Qoooo00Go09Woooooooooool0
00009oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Co09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`04o`2Ioooooooooooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool0
08_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00M_oo
o`800004oooo0P0000?oool400000oooo`8000000oooool0VOooo`02oooo00<0003oooooool0S_oo
o`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool01@000?ooooooo`000?l0V@03
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?l0VOooo`02oooo0`0008koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P000003ooooo`2Ioooo00;oool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00@0003ooooooooo09T3oooo00<0003oooooool0S_ooo`00M_oo
o`80000:oooo0P0000Coool3000000Go09Woooooooooool00000T?ooo`00Roooo`04o`2Ioooooooo
oooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool0
08_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Co09Woooooooooool20000Soooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`04o`2Ioooooooooooo0P0008ooool008_oool01Ol0VOoo
ooooooooo`00002@oooo001loooo0P0000Coool200001?ooo`8000000oooool0VOooo`02oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`050000oooooooo0000o`2I00?oool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool0000;oooo00<0003o09Woool00_ooo`<0002>
oooo001koooo00@0003oooooool00009oooo0P000003ooooo`2Ioooo00;oool00`000?ooooooo`2>
oooo001koooo00@0003oooooool00009oooo00@0003ooooooooo09T3oooo00<0003oooooool0S_oo
o`00O?ooo`80000:oooo0`000005o`2Ioooooooooooo0000093oool008_oool01?l0VOoooooooooo
o`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000
093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?oo
o`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;
oooo00Co09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool0
1Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`04o`2I
oooooooooooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool2000000?ooooo09Woool00_ooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003o09Woool00_oo
o`030000oooooooo08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0
003o09Woool00_ooo`<0002>oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
000000?ooooo09Woool00_ooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool010000?ooooooool0V@?oool00`000?ooooooo`2>oooo001foooo0P00
00Woool400000oooo`<000001Ol0VOooooooooooo`00002@oooo002;oooo00Co09Woooooooooool2
0000Soooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`04o`2Ioooooooooooo0P0008ooool0
08_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Co09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008Ooool500000oooo`030000oooooooo08koool008Woool00`000?ooool0V@03
oooo00<0003oooooool0S_ooo`00ROooo`030000ooooo`2I00?oool30000S_ooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009oooo0`0000Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.48778 .30902 L
.48904 .30902 L
.49018 .30902 L
.4913 .30902 L
s
.4913 .30902 m
.4914 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Soooo00?o09Woool000009oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00SOooo`03o`2Ioooo0000
093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool0
08goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool0
08goool00ol0VOooo`00002@oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000?oool0
0ol0VOooo`00002@oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00000_ooo`03o`2Ioooo0000093oool007Goool010000?ooooooo`0000Woool00`000?oo
ooooo`05oooo00D0003ooooooooo09Woool00`0008koool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000?oool00ol0VOooo`00002@oooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`03o`2Ioooo0000093oool007Koool2
00002_ooo`800004oooo0`0000;oool00ol0VOooo`00002@oooo002=oooo00Co09Woool00000002?
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00Co09Woool00000002?
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00O?oo
o`800004oooo0P0000Coool200000oooo`03o`2Ioooo0000093oool007_oool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool00ol0VOooo`00002@oooo001koooo00@0003oooooool0000;
oooo00D0003ooooooooo09Woool00`0008koool007_oool010000?ooooooo`0000Woool200000ooo
o`03o`2Ioooo0000093oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`02oooo00?o
09Woool00000T?ooo`00O?ooo`80000:oooo0`0000;oool00ol0VOooo`00002@oooo002=oooo00Co
09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool0
08goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool0
0ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool0
08goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200000oooo`03o`2Ioooo0000093oool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00H0003ooooooooo09Woool0002@oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`050000ooooooooo`2Ioooo00<0002>
oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200000oooo`03o`2Ioooo0000
093oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`02
oooo00?o09Woool00000T?ooo`00M_ooo`800009oooo100000?oool300000_ooo`03o`2Ioooo0000
093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool0
08goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool0
08goool00ol0VOooo`00002@oooo0027oooo1@000004ooooo`2Ioooo0000T?ooo`00ROooo`070000
ooooooooooooo`2Ioooo0000093oool008Woool01P000?ooooooooooool0VOooo`<0002>oooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002Oooo`<00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
s
.49955 .30902 m
.49968 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006?oo
o`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo02Koool010000?ooooooo`0001Koool0
01Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009ooo
o`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0002Coool00`000?ooooooo`0T
oooo0P0002Koool200009oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001e
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo08koool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_oo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
08koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003ooooo
ool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Sooo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Qoooo`D00003oooo00<0
003oooooool0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00<0
003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ooooo00<0003oooooool07?oo
o`030000oooooooo07ooool007koool00`000?ooooooo`08oooo00<0003oooooool04oooo`030000
oooooooo07koool007koool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool0O_oo
o`00OOooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000
oooooooo07goool007koool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool00`000?oo
ooooo`1noooo001noooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool00`000?oo
ooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0003oooooool0Ooooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49955 .30902 L
.50205 .30902 L
.50471 .30902 L
.50601 .30902 L
.50722 .30902 L
s
.50722 .30902 m
.50733 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.48778 .30902 L
.48904 .30902 L
.49018 .30902 L
.4913 .30902 L
.49235 .15465 L
.49346 .15519 L
.49466 .15577 L
.49722 .157 L
.49834 .15753 L
.49955 .15811 L
.50077 .15796 L
.50192 .15741 L
.50447 .15619 L
.50562 .15563 L
.50685 .15504 L
.5079 .15453 L
.50906 .30902 L
.50971 .30902 L
.51041 .30902 L
.51165 .30902 L
.51444 .30902 L
.51949 .30902 L
.54055 .30902 L
.57866 .30902 L
.61922 .30902 L
.65827 .30902 L
.69977 .30902 L
.73975 .30902 L
.77822 .30902 L
.81913 .30902 L
.85854 .30902 L
.89642 .30902 L
.93676 .30902 L
.97559 .30902 L
.97619 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool01@000?ooooooo`1Vooooo`03
0000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000?oool206Ko00<00000I_l0
I_l0S_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00;oool01@1Vooooo`000?oo
o`1Vo`2>oooo001loooo0P0000[oool300000_ooo`0506Kooooo0000oooo06Ko08koool008goool0
1@1Vooooo`000000001Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOooo`0506Ko
oooo0000oooo06Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0
00000000I_l0S_ooo`00SOooo`0506Kooooo0000oooo06Ko08koool008goool01@1Vooooo`000?oo
o`1Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000000006Ko
08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_oo
o`00SOooo`0506Kooooo0000oooo06Ko08koool008goool01@1Vooooo`000000001Vo`2>oooo002=
oooo00D0I_ooool0003oool0I_l0S_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800003
oooo00D0I_ooool0003oool0I_l0S_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000;oool01@1Vooooo`000?ooo`1Vo`2>oooo001eoooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`050000oooooooo06Kooooo00<0002>oooo001_oooo1000
00;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000?oool01@1Vooooo`000?oo
o`1Vo`2>oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool00_ooo`0506Kooooo0000oooo06Ko08koool007Koool200002_ooo`800004oooo0`0000;oool0
1@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool000000000I_l0S_ooo`00SOooo`0506Ko
oooo0000oooo06Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0
003oool0I_l0S_ooo`006?ooo`80000Uoooo100002Goool500008?ooo`0506Kooooo0000000006Ko
02?oool500008oooo`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?oo
ooooo`0Xoooo00<0003oooooool08?ooo`0506Kooooo0000oooo06Ko02Goool00`000?ooooooo`0S
oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Oooo`030000oooooooo02Coool0
0`000?ooooooo`0Woooo00<0003oooooool08?ooo`0506Kooooo0000oooo06Ko02Goool00`000?oo
ooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Oooo`030000
oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000oooooooo023oool0
1@1Vooooo`000?ooo`1Vo`0Uoooo00<0003oooooool09Oooo`030000oooooooo02Ooool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0000Woooo00<0003ooooo
ool08?ooo`0506Kooooo0000000006Ko02Goool00`000?ooooooo`0Soooo00@0003oooooool0000U
oooo00@0003oooooool0000Foooo000Hoooo0P0002Koool200009oooo`80000Roooo00D0I_ooool0
003oool0I_l09?ooo`80000Voooo0P0002Ooool200005oooo`00SOooo`0506Kooooo0000oooo06Ko
08koool008goool01@1Vooooo`000000001Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_oo
o`00SOooo`0506Kooooo0000oooo06Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo000@
ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo09T09Oooo`030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000ooooo`2I08koool008ooool2
000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo0P000003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool2000000?o09Woooooool0S?ooo`00Sooo
o`030000ooooo`2I08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000
ooooo`2I08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003ooooo09T0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0`0008koool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooool0V@2>oooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000ooooo`2I08koool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I
08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo09T0S_ooo`00Noooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000ooooo`2I08koool007_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000ooooo`2I08koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003ooooo09T0S_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooool0V@2>oooo002?oooo0P00
0003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000
ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I
08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool007Koool2
00001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo09T0S_ooo`00MOoo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003ooooo09T0S_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003ooooo09T0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooool0V@2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P00
0003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`030000ooooo`2I08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000
ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Sooo
o`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Qoooo`D00003oooo00<0
003ooooo09T0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0029oooo00<0
003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`00
00Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.5095 .30902 L
.51188 .30902 L
.51318 .30902 L
.51441 .30902 L
.51555 .30902 L
s
.51555 .30902 m
.51568 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47994 .30902 L
.48231 .30902 L
.483 .30902 L
.48364 .30902 L
.48484 .15485 L
.48549 .15517 L
.48618 .1555 L
.48741 .1561 L
.49018 .15743 L
.49499 .15971 L
.49736 .16082 L
.4984 .1613 L
.49955 .16184 L
.5007 .16172 L
.50193 .16115 L
.50451 .15994 L
.50903 .1578 L
.51155 .1566 L
.51288 .15596 L
.51427 .15529 L
.5155 .15469 L
.51619 .30902 L
.51684 .30902 L
.51919 .30902 L
.53752 .30902 L
.57657 .30902 L
.61807 .30902 L
.65805 .30902 L
.69651 .30902 L
.73743 .30902 L
.77684 .30902 L
.81472 .30902 L
.85506 .30902 L
.89389 .30902 L
.93516 .30902 L
Mistroke
.97492 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`00001Vooooo`02oooo0`00
0003oooo06Kooooo08_oool007Goool400000_ooo`040000oooooooo00002Oooo`8000000oooo`1V
o`1Vo`02oooo00<0003oool0I_l00P1Vohcoool007_oool010000?ooooooo`0000Woool01@000?oo
ooooo`1Vooooo`0206Ko00D00000I_ooooooool0I_l0S?ooo`00O?ooo`80000:oooo0`00000506Ko
oooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00@0I_ooooooooooool200000_oo
o`0306Kooooooooo08[oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_oo
o`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00D0I_oooooo
ooooool000000oooo`0306Kooooooooo08[oool008_oool0101Vooooooooooooo`800002oooo00<0
I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;
oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool01@1Voooooooooooo
o`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0406Kooooooooooooo0P0000;oool00`1Voooo
ooooo`2:oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool0
1@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo0000
00?oool00`1Vooooooooo`2:oooo002;oooo00@0I_ooooooooooool200000_ooo`0306Kooooooooo
08[oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00M_ooo`800004
oooo0P0000?oool400000oooo`8000000oooo`1Vooooo`02oooo00D0003oooooooooool0I_l0S?oo
o`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool01@000?ooooooo`00001Vo`03
oooo00D0003oooooooooool0I_l0S?ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`00001Vooooo`02oooo0`000003oooo06Kooooo08_oool006ooool400000_ooo`040000
oooooooo00002_ooo`030000oooooooo00;oool2000000?oool0I_ooool00_ooo`050000oooooooo
oooo06Ko08coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool010000?oo
ooooo`1Vo`?oool01@000?ooooooooooo`1Vo`2<oooo001foooo0P0000[oool200001?ooo`<00000
1@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0406Kooooooooooooo0P00
00;oool00`1Vooooooooo`2:oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo
08[oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0506Ko
oooooooooooo000000?oool00`1Vooooooooo`2:oooo000Hoooo0P0002Goool400009Oooo`D0000N
oooo00@0I_ooooooooooool200000_ooo`0306Kooooooooo01ooool500008oooo`@0000Voooo0P00
01Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Xoooo00<0003oooooool07_oo
o`0506Kooooooooooooo000000?oool00`1Vooooooooo`0Qoooo00<0003oooooool08oooo`030000
oooooooo02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003ooooo
ool09oooo`030000oooooooo01koool01@1Vooooooooooooo`000003oooo00<0I_ooooooool08Ooo
o`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005
oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003ooooo
ool07_ooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`0Qoooo00<0003oooooool09Ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0
003oooooool0000Woooo00<0003oooooool07_ooo`0406Kooooooooooooo0P0000;oool00`1Voooo
ooooo`0Qoooo00<0003oooooool08oooo`040000oooooooo00009Oooo`040000oooooooo00005_oo
o`006?ooo`80000Voooo0P0002Ooool200008?ooo`0506Kooooooooooooo000000?oool00`1Voooo
ooooo`0Poooo0P0002Koool200009oooo`80000Goooo002;oooo00D0I_ooooooooooool000000ooo
o`0306Kooooooooo08[oool008_oool0101Vooooooooooooo`800002oooo00<0I_ooooooool0R_oo
o`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00D0I_oooooo
ooooool000000oooo`0306Kooooooooo08[oool008_oool01@1Vooooooooooooo`000003oooo00<0
I_ooooooool0R_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`050000oooooooo
ooooo`2I02?oool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08ooool01@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool0
1@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oo
ooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00D0003ooooooooooooo
09T0S?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool01@000?ooooooooooool0V@2<oooo001eoooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool3000000?ooooo09Woool0Roooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`050000ooooooooooooo`2I08coool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00D0003ooooo
oooooooo09T0S?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`050000ooooooooooooo`2I
08coool008ooool200000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool0
08ooool200000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool2
00000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_oo
o`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo001loooo0P0000Coool2
00001?ooo`800005oooo00D0003ooooooooooooo09T0S?ooo`00Noooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`050000ooooooooooooo`2I08coool007_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`000003ooooo`2Ioooo08_oool007_oool010000?ooooooo`00
00Woool200001Oooo`050000ooooooooooooo`2I08coool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00D0003ooooooooooooo09T0S?ooo`00O?ooo`80000:oooo0`0000Coool0
1@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_oo
o`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2I
oooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo
08[oool008ooool01@000?ooooooooooool0V@2<oooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`050000ooooooooooooo`2I08coool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`050000ooooooooooooo`2I
08coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<000000oooool0VOooo`2;oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001Oooo`050000ooooooooooooo`2I08coool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00D0003ooooooooooooo09T0S?ooo`00M_ooo`800009
oooo100000?oool300001?ooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2I
oooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo
08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?oo
o`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo08[oool0
08ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Sooo
o`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo08[oool008ooool0
1@000?ooooooooooool0V@2<oooo0027oooo1@0000?oool01@000?ooooooooooool0V@2<oooo0029
oooo00<0003oooooool00oooo`050000ooooooooooooo`2I08coool008Woool00`000?ooooooo`03
oooo0`000003ooooo`2Ioooo08_oool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000_ooo`800003oooo1@0000;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`030000
oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`09oooo00<0003ooooo
ool00_ooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000ooo
o`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51441 .30902 L
.51896 .30902 L
.52148 .30902 L
.52221 .30902 L
.52289 .30902 L
s
.52289 .30902 m
.52302 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.47106 .30902 L
.47329 .30902 L
.47451 .30902 L
.47567 .30902 L
.47674 .15478 L
.47791 .15534 L
.47994 .15632 L
.49008 .16112 L
.49504 .16341 L
.4972 .1644 L
.49834 .16492 L
.49955 .16547 L
.50078 .16532 L
.50191 .16481 L
.50414 .16379 L
.50906 .16152 L
.51444 .159 L
.51707 .15775 L
.51949 .1566 L
.52184 .15547 L
.52302 .15489 L
.52431 .30902 L
.52561 .30902 L
.527 .30902 L
.5295 .30902 L
.54055 .30902 L
.58205 .30902 L
.62203 .30902 L
.6605 .30902 L
.70142 .30902 L
.74082 .30902 L
.77871 .30902 L
.81905 .30902 L
.85787 .30902 L
.89915 .30902 L
Mistroke
.93891 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000[oool00`1Vo`000?ooo`03oooo0`00
00?oool00`1Vooooooooo`28oooo001eoooo100000;oool010000?ooooooo`0000Woool2000000<0
I_ooooooool00_ooo`040000oooooooooooo0`1Voh[oool007_oool010000?ooooooo`0000Woool0
0`00001Vooooo`0406Ko00@0003oool0I_l0I_l2oooo00<0I_ooooooool0R?ooo`00O?ooo`80000:
oooo0`0000?oool00`1Vo`00001Vo`04oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo
00?oool200001?ooo`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03oooo00<0003ooooo
ool00oooo`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03oooo00<0003oooooool00ooo
o`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Ko
oooooooo08Soool008Woool00`1Vooooooooo`03oooo0P0000Coool00`1Vooooooooo`28oooo0029
oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_oooooo
ool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00ooo
o`800004oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03
oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0
I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0I_oooooo
ool0R?ooo`00ROooo`0306Kooooooooo00?oool200001?ooo`0306Kooooooooo08Soool008Woool0
0`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo08Soool007Koool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo001e
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooo06Ko00001?ooo`030000
oooooooo00?oool00`1Vooooooooo`28oooo001eoooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`0306Ko0000oooo00?oool300000oooo`0306Kooooooooo08Soool006ooool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo00?oool0
0`1Vooooooooo`28oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
0000I_ooool01?ooo`030000oooooooo00?oool00`1Vooooooooo`28oooo001foooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool00`1Voooo
ooooo`03oooo0P0000Coool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000
oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo
00?oool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool0
0`1Vooooooooo`28oooo000Hoooo0P0002Goool400009Oooo`D0000Loooo00<0I_ooooooool00ooo
o`800004oooo00<0I_ooooooool07Oooo`D0000Soooo100002Koool200005oooo`005oooo`040000
oooooooo00009?ooo`030000oooooooo02Soool00`000?ooooooo`0Loooo00<0I_ooooooool00ooo
o`030000oooooooo00?oool00`1Vooooooooo`0Ooooo00<0003oooooool08oooo`030000oooooooo
02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09ooo
o`030000oooooooo01coool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo
01ooool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool4
00001Oooo`030000oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000
oooooooo01coool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo01ooool0
0`000?ooooooo`0Uoooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?oo
ooooo`0002Coool010000?ooooooo`0002Ooool00`000?ooooooo`0Loooo00<0I_ooooooool00ooo
o`800004oooo00<0I_ooooooool07oooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0001koool00`1Vooooooooo`03
oooo00<0003oooooool00oooo`0306Kooooooooo01koool200009_ooo`80000Woooo0P0001Ooool0
08Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool0
0`1Vooooooooo`03oooo0P0000Coool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00ooo
o`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000
oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo
00?oool00`1Vooooooooo`28oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`03oooo00?o
09Woool000001oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool00oooo`03o`2Ioooooooo01ooool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000?oool00ol0VOoo
ooooo`28oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool00oooo`03o`2Ioooooooo08Soool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool300000oooo`03o`2Ioooooooo08Soool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo0P00
00Coool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0000?oool00ol0VOooooooo`28oooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool0
0`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?oo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Qooo
o`D00003oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008Woool00`000?ooooooo`03
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008Woool00`000?ooooooo`03oooo0`00
00?oool00ol0VOooooooo`28oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Ooo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?oo
ooooo`09oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo0000017oool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.51896 .30902 L
.52455 .30902 L
.52731 .30902 L
.52865 .30902 L
.52986 .30902 L
.53105 .30902 L
s
.53105 .30902 m
.53116 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46388 .30902 L
.46618 .30902 L
.46687 .30902 L
.46751 .30902 L
.46871 .15473 L
.46984 .15528 L
.47106 .15587 L
.47994 .16009 L
.49008 .16478 L
.49504 .16701 L
.4972 .16797 L
.49834 .16848 L
.49955 .16901 L
.50078 .16887 L
.50191 .16837 L
.50414 .16738 L
.50906 .16517 L
.51949 .16036 L
.52431 .15809 L
.52684 .15688 L
.5295 .1556 L
.53092 .15491 L
.53173 .15452 L
.53248 .30902 L
.53379 .30902 L
.5352 .30902 L
.54055 .30902 L
.58205 .30902 L
.62203 .30902 L
.6605 .30902 L
.70142 .30902 L
.74082 .30902 L
.77871 .30902 L
.81905 .30902 L
.85787 .30902 L
.89915 .30902 L
Mistroke
.93891 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000Soool0101Vooooooooo`0000Coool3
00001Oooo`0306Kooooooooo08Koool007Goool400000_ooo`040000oooooooo00002?ooo`0306Ko
0000000000Goool00`000?ooooooo`03oooo0`1VohSoool007_oool010000?ooooooo`0000Soool0
101Vo`00001Vo`1Vo`Coool010000?ooooooooooo`80I_l2oooo00<0I_ooooooool0Q_ooo`00O?oo
o`800009oooo00@0I_l000000000000406Ko00@0003oool0I_l0I_l4oooo00<0I_ooooooool0Q_oo
o`00Qoooo`0306Kooooooooo00Coool00`1Vo`0000000006oooo00<0I_ooooooool0Q_ooo`00Qooo
o`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Ko
oooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo
00Goool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool2
00001_ooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01Ooo
o`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Ko
oooooooo08Koool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo
08Koool008Ooool00`1Vooooooooo`05oooo0P0000Koool00`1Vooooooooo`26oooo0027oooo00<0
I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027oooo00<0I_oooooo
ool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Ooo
o`030000oooooooo00Goool00`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`800006
oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0
I_ooooooool0Q_ooo`00M_ooo`800004oooo0P0000?oool400000_ooo`0306Ko0000000000Goool0
0`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`05oooo00<0I_ooooooool0Q_oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00;oool0101Vooooooooo`0000Coool3
00001Oooo`0306Kooooooooo08Koool006ooool400000_ooo`040000oooooooo00002_ooo`050000
oooooooooooo06Ko00800005oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool00`1Vo`000?ooo`05oooo00<0003ooooo
ool01Oooo`0306Kooooooooo08Koool007Koool200002_ooo`800003oooo00@0I_l0000000000004
oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05oooo0P00
00Koool00`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool0
0`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Voooo
ooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26
oooo000Hoooo0P0002Goool400009Oooo`D0000Joooo00<0I_ooooooool01Oooo`800006oooo00<0
I_ooooooool06oooo`D0000Soooo100002Koool200005oooo`005oooo`040000oooooooo00009?oo
o`030000oooooooo02Soool00`000?ooooooo`0Joooo00<0I_ooooooool01Oooo`030000oooooooo
00Goool00`1Vooooooooo`0Moooo00<0003oooooool08oooo`030000oooooooo02Koool010000?oo
ooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo
01[oool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo01goool00`000?oo
ooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Oooo`030000
oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000oooooooo01[oool0
0`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo01goool00`000?ooooooo`0U
oooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool0
10000?ooooooo`0002Ooool00`000?ooooooo`0Joooo00<0I_ooooooool01Oooo`800006oooo00<0
I_ooooooool07Oooo`030000oooooooo02?oool010000?ooooooo`0002Goool010000?ooooooo`00
01Koool001Soool200009_ooo`80000Woooo0P0001coool00`1Vooooooooo`05oooo00<0003ooooo
ool01Oooo`0306Kooooooooo01coool200009_ooo`80000Woooo0P0001Ooool008Ooool00`1Voooo
ooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05
oooo0P0000Koool00`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo
00Goool00`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool0
0`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Voooo
ooooo`26oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01Oooo`03o`2I
oooooooo01goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Wooooo
ool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_oo
o`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006
oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000Goool00ol0VOooooooo`26oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool01Ooo
o`03o`2Ioooooooo08Koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006
oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo
00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool0
08ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Wooooo
ool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_oo
o`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool300001Oooo`03o`2Ioooooooo08Koool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo00Goool00ol0VOooooooo`26oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo0P0000Koool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006
oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo
00Goool00ol0VOooooooo`26oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo00Goool00ol0VOooooooo`26oooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0000Goool00ol0VOooooooo`26oooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo00Goool00ol0VOooooooo`26oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
00Goool00ol0VOooooooo`26oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool200001_oo
o`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05
oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool200001_ooo`03o`2Ioooooooo
08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Qoooo`D00003oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008Woool00`000?ooooooo`03oooo0`0000Goool00ol0VOoo
ooooo`26oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000ooo
o`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02?ooo`030000oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.51896 .30902 L
.52455 .30902 L
.52986 .30902 L
.53463 .30902 L
.53594 .30902 L
.53733 .30902 L
.53865 .30902 L
s
.53865 .30902 m
.53877 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.44268 .30902 L
.44778 .30902 L
.45262 .30902 L
.45697 .30902 L
.45816 .30902 L
.45943 .30902 L
.46063 .15466 L
.46172 .15519 L
.48258 .16497 L
.49174 .16907 L
.49424 .17017 L
.49693 .17134 L
.49824 .1719 L
.49947 .17244 L
.50058 .17242 L
.50178 .1719 L
.52053 .16355 L
.52552 .16125 L
.53082 .15876 L
.53534 .15661 L
.53658 .15601 L
.53792 .15537 L
.53918 .15475 L
.54033 .30902 L
.54161 .30902 L
.54282 .30902 L
.54507 .30902 L
.55014 .30902 L
.55926 .30902 L
.57996 .30902 L
.61842 .30902 L
.65934 .30902 L
.69875 .30902 L
.73663 .30902 L
.77697 .30902 L
.8158 .30902 L
.85707 .30902 L
Mistroke
.89683 .30902 L
.93508 .30902 L
.97578 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000Koool00`1Vooooooooo`02oooo00<0
003oooooool00_ooo`<00007oooo00<0I_ooooooool0Q?ooo`00MOooo`@00002oooo00@0003ooooo
ool00006oooo0`1Vo`800005oooo00<0003oooooool01Oooo`<0I_n6oooo001koooo00@0003ooooo
ool00006oooo00D0I_ooooooool00000I_l01Oooo`030000oooooooo00?oool206Ko0_ooo`0306Ko
oooooooo08Coool007coool200001oooo`0306Kooooooooo00<000001@1Vooooooooooooo`000003
oooo0P1Vo`Coool00`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01?ooo`<0I_l200000P1V
o`Koool00`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01_ooo`0306Ko000006Ko00Soool0
0`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Ooool00`1Voooo
ooooo`24oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Ooool00`1Vooooooooo`24
oooo0025oooo00<0I_ooooooool01oooo`800008oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Ko
oooooooo00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo
00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool0
0`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool200002?oo
o`0306Kooooooooo08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Ko
oooooooo08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo
08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0
08Goool00`1Vooooooooo`07oooo0P0000Soool00`1Vooooooooo`24oooo0025oooo00<0I_oooooo
ool01oooo`030000oooooooo00Ooool00`1Vooooooooo`24oooo001foooo0P0000Coool200000ooo
o`@000000`1Vooooooooo`0200001Oooo`030000oooooooo00Ooool00`1Vooooooooo`24oooo001e
oooo00@0003oooooool00008oooo00L0003oooooooooool0I_ooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00MOooo`040000oooooooo00002Ooo
o`040000oooooooo06Ko1?ooo`030000oooooooo00;oool300001oooo`0306Kooooooooo08Coool0
06ooool400000_ooo`040000oooooooo00002_ooo`030000oooo06Ko00;oool200001Oooo`030000
oooooooo00Ooool00`1Vooooooooo`24oooo001eoooo00@0003oooooool00008oooo00D0003ooooo
ool00000I_l00_ooo`030000oooooooo00Coool00`000?ooooooo`07oooo00<0I_ooooooool0Q?oo
o`00M_ooo`80000:oooo0P000004oooo06Kooooooooo0`0000Coool00`000?ooooooo`07oooo00<0
I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool200002?ooo`0306Kooooooooo08Coool0
08Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool008Goool0
0`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool008Goool00`1Voooo
ooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool001Soool200009Oooo`@0000U
oooo1@0001Soool00`1Vooooooooo`07oooo0P0000Soool00`1Vooooooooo`0Ioooo1@0002?oool4
00009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000
oooooooo01Soool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo01_oool0
0`000?ooooooo`0Soooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Oooo`030000
oooooooo02Coool00`000?ooooooo`0Woooo00<0003oooooool06?ooo`0306Kooooooooo00Ooool0
0`000?ooooooo`07oooo00<0I_ooooooool06oooo`030000oooooooo02Coool00`000?ooooooo`0W
oooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0
003oooooool07_ooo`@00004oooo00<0003oooooool06?ooo`0306Kooooooooo00Ooool00`000?oo
ooooo`07oooo00<0I_ooooooool06oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00<0
003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009oooo`030000
oooooooo01Soool00`1Vooooooooo`07oooo0P0000Soool00`1Vooooooooo`0Koooo00<0003ooooo
ool08oooo`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P00
02Ooool200006_ooo`0306Kooooooooo00Ooool00`000?ooooooo`07oooo00<0I_ooooooool06_oo
o`80000Voooo0P0002Ooool200005oooo`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`07
oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool200002?ooo`0306Kooooooooo
08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0
08Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool008Goool0
0`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Goool00`000?ooooooo`07oooo00?o09Woooooool06oooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool300001oooo`03o`2Ioooooooo08Coool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00007oooo00?o09Wooooo
ool0Q?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool007coool200002_ooo`<00004oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300001oooo`03o`2I
oooooooo08Coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo0027oooo1@0000?oool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00ROooo`030000oooooooo00?oool300001oooo`03o`2Ioooooooo08Coool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800003oooo100000?oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool00oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Soool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53057 .30902 L
.53984 .30902 L
.54444 .30902 L
.54576 .30902 L
.54701 .30902 L
s
.54701 .30902 m
.54712 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44268 .30902 L
.44744 .30902 L
.44874 .30902 L
.45013 .30902 L
.45143 .30902 L
.45262 .15463 L
.45379 .15519 L
.45487 .15572 L
.45731 .15689 L
.46172 .15899 L
.48214 .16833 L
.49211 .17268 L
.4944 .17366 L
.49683 .1747 L
.49891 .17557 L
.50009 .17599 L
.5012 .17552 L
.50571 .17362 L
.51061 .17151 L
.51953 .16759 L
.52891 .16335 L
.53423 .16089 L
.53918 .15856 L
.54393 .15629 L
.5453 .15563 L
.54659 .15501 L
.54775 .30902 L
.54901 .30902 L
.55936 .30902 L
.57786 .30902 L
.61878 .30902 L
.65818 .30902 L
.69607 .30902 L
.73641 .30902 L
.77524 .30902 L
.81651 .30902 L
Mistroke
.85627 .30902 L
.89452 .30902 L
.93522 .30902 L
.9744 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000Coool00`1Vooooooooo`04oooo00<0
003oooooool00_ooo`<00009oooo00<0I_ooooooool0P_ooo`00MOooo`@00002oooo00@0003ooooo
ool00004oooo0`1Vo`;oool200001Oooo`030000oooooooo00Ooool306KoQ?ooo`00Noooo`040000
oooooooo00001?ooo`0306Kooooooooo0080I_l00`000?ooooooo`04oooo00<0003oooooool01?oo
o`<0I_l2oooo00<0I_ooooooool0P_ooo`00O?ooo`800005oooo00<0I_ooooooool00_ooo`<00004
oooo00<0003oooooool00oooo`0306Kooooooooo00?oool00`1Vooooooooo`22oooo0023oooo00<0
I_ooooooool01?ooo`80I_l3oooo0P0000?oool00`1Vooooooooo`04oooo00<0I_ooooooool0P_oo
o`00Poooo`0306Kooooooooo00Koool306Ko00<00000I_l0I_l00P1Vo`Ooool00`1Vooooooooo`22
oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`22oooo0023
oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`22oooo0023oooo00<0
I_ooooooool02Oooo`80000:oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool0
0`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?oo
ooooo`09oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09
oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool200002_ooo`0306Kooooooooo
08;oool008?oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool0
08?oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008?oool0
0`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008?oool00`1Voooo
ooooo`09oooo0P0000[oool00`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`030000
oooooooo00Woool00`1Vooooooooo`22oooo001foooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00MOooo`040000oooooooo00002?oo
o`030000oooo06Ko00?oool010000?ooooooo`0000Coool00`000?ooooooo`09oooo00<0I_oooooo
ool0P_ooo`00MOooo`040000oooooooo00002Oooo`03000006Kooooo00Goool00`000?ooooooo`02
oooo0`0000Woool00`1Vooooooooo`22oooo001_oooo100000;oool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooo06Ko00000oooo`030000oooooooo00Coool00`000?oo
ooooo`09oooo00<0I_ooooooool0P_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo00Woool00`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`80000:oooo00<0
I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_oooooo
ool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_ooooooool0P_oo
o`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`006?oo
o`80000Uoooo100002Goool500005_ooo`0306Kooooooooo00Woool200002_ooo`0306Kooooooooo
01Ooool500008oooo`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?oo
ooooo`0Xoooo00<0003oooooool05_ooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0
I_ooooooool06Oooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00@0003oooooool0000F
oooo000Ioooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Foooo00<0
I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`0Ioooo00<0003oooooool09?oo
o`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0L
oooo100000Coool00`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0Foooo00<0I_oooooo
ool02Oooo`030000oooooooo00Woool00`1Vooooooooo`0Ioooo00<0003oooooool09Oooo`030000
oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003ooooo
ool0000Woooo00<0003oooooool05_ooo`0306Kooooooooo00Woool200002_ooo`0306Kooooooooo
01Woool00`000?ooooooo`0Soooo00@0003oooooool0000Uoooo00@0003oooooool0000Foooo000H
oooo0P0002Koool200009oooo`80000Hoooo00<0I_ooooooool02Oooo`030000oooooooo00Woool0
0`1Vooooooooo`0Hoooo0P0002Koool200009oooo`80000Goooo0023oooo00<0I_ooooooool02Ooo
o`030000oooooooo00Woool00`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`80000:
oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0
I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_oooooo
ool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_ooooooool0P_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00?oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Woool00ol0VOoo
ooooo`0Ioooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo
08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00M_oo
o`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool007Goool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<00009oooo00?o09Woooooool0P_ooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001foooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo
08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0000Woool00ol0VOooooooo`22oooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Wooooo
ool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00MOooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<00009oooo00?o09Woooooool0P_ooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22
oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Ooool500000oooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo0029oooo00<0003oooooool00oooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo0029oooo00<0003oooooool00oooo`<00009oooo00?o09Wooooo
ool0P_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55195 .30902 L
.55338 .30902 L
.55408 .30902 L
.55472 .30902 L
s
.55472 .30902 m
.55485 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44151 .30902 L
.44268 .30902 L
.44387 .30902 L
.44498 .15477 L
.44616 .15534 L
.44744 .15596 L
.45262 .15844 L
.46172 .16269 L
.48126 .17143 L
.49162 .17584 L
.4946 .17709 L
.49743 .17826 L
.49866 .17876 L
.49996 .1793 L
.50064 .17905 L
.50139 .17874 L
.50272 .1782 L
.52314 .16951 L
.54221 .16087 L
.54712 .15856 L
.54981 .15728 L
.5523 .15608 L
.5534 .15555 L
.55444 .15505 L
.55563 .30902 L
.55672 .30902 L
.56155 .30902 L
.58241 .30902 L
.62088 .30902 L
.6618 .30902 L
.7012 .30902 L
.73909 .30902 L
.77943 .30902 L
.81825 .30902 L
.85953 .30902 L
Mistroke
.89929 .30902 L
.93753 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000;oool00`1Vooooooooo`06oooo00<0
003oooooool00_ooo`<0000;oooo00<0I_ooooooool0P?ooo`00MOooo`@00002oooo00@0003ooooo
ool00002oooo0`1Vo`Coool200001Oooo`030000oooooooo00Woool306KoP_ooo`00Noooo`040000
oooooooo00000_ooo`0306Kooooooooo0080I_l2oooo00<0003oooooool01?ooo`030000oooooooo
00Ooool206Ko0_ooo`0306Kooooooooo083oool007coool200000oooo`0306Kooooooooo00;oool2
06Ko0`0000Coool00`000?ooooooo`05oooo0P1Vo`Coool00`1Vooooooooo`20oooo0021oooo00<0
I_ooooooool01?ooo`80I_l5oooo0P0000?oool306Ko1_ooo`0306Kooooooooo083oool0087oool0
0`1Vooooooooo`06oooo0P1Vo`?oool00`000?ooooooo`0206Ko2Oooo`0306Kooooooooo083oool0
087oool00`1Vooooooooo`08oooo0`1Vo`03000006Ko06Ko00_oool00`1Vooooooooo`20oooo0021
oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0021oooo00<0
I_ooooooool02oooo`80000<oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool0
0`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool00`000?oo
ooooo`0;oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool00`000?ooooooo`0;
oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool200003?ooo`0306Kooooooooo
083oool0087oool00`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo083oool0
087oool00`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool0
0`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Voooo
ooooo`0;oooo0P0000coool00`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000
oooooooo00_oool00`1Vooooooooo`20oooo001foooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00MOooo`040000oooooooo00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0;oooo00<0I_oooooo
ool0P?ooo`00MOooo`040000oooooooo00002?ooo`0306Ko0000oooo00Koool00`000?ooooooo`02
oooo0`0000_oool00`1Vooooooooo`20oooo001_oooo100000;oool010000?ooooooo`0000Soool0
0`1Vooooo`000004oooo0P0000Goool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0;oooo00<0I_ooooooool0P?ooo`00M_ooo`800009oooo00<0I_l0000000001?ooo`<00004
oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Vooooooooo`0;oooo0P00
00coool00`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool0
0`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Voooo
ooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20
oooo000Hoooo0P0002Goool400009Oooo`D0000Doooo00<0I_ooooooool02oooo`80000<oooo00<0
I_ooooooool05Oooo`D0000Soooo100002Koool200005oooo`005oooo`040000oooooooo00009?oo
o`030000oooooooo02Soool00`000?ooooooo`0Doooo00<0I_ooooooool02oooo`030000oooooooo
00_oool00`1Vooooooooo`0Goooo00<0003oooooool08oooo`030000oooooooo02Koool010000?oo
ooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo
01Coool00`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo01Ooool00`000?oo
ooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Oooo`030000
oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000oooooooo01Coool0
0`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo01Ooool00`000?ooooooo`0U
oooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool0
10000?ooooooo`0002Ooool00`000?ooooooo`0Doooo00<0I_ooooooool02oooo`80000<oooo00<0
I_ooooooool05oooo`030000oooooooo02?oool010000?ooooooo`0002Goool010000?ooooooo`00
01Koool001Soool200009_ooo`80000Woooo0P0001Koool00`1Vooooooooo`0;oooo00<0003ooooo
ool02oooo`0306Kooooooooo01Koool200009_ooo`80000Woooo0P0001Ooool0087oool00`1Voooo
ooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Vooooooooo`0;
oooo0P0000coool00`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo
00_oool00`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool0
0`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Voooo
ooooo`20oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00ooo
o`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool02oooo`03o`2I
oooooooo01Ooool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000_oool00ol0VOooooooo`20oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool300002oooo`03o`2Ioooooooo083oool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P0000coool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0000_oool00ol0VOooooooo`20oooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?oo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Qoooo`D00003oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03oooo0`0000_oool00ol0VOoo
ooooo`20oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo
00[oool010000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool00ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55436 .30902 L
.55712 .30902 L
.55972 .30902 L
.56092 .30902 L
.56218 .30902 L
.56285 .30902 L
s
.56285 .30902 m
.56292 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43049 .30902 L
.43298 .30902 L
.43522 .30902 L
.43648 .30902 L
.43762 .15505 L
.43887 .15565 L
.44023 .15631 L
.44268 .15748 L
.46172 .1663 L
.48126 .17483 L
.49162 .17913 L
.4946 .18035 L
.49743 .18149 L
.49866 .18198 L
.49996 .1825 L
.50064 .18226 L
.50139 .18196 L
.50272 .18143 L
.52314 .17295 L
.54221 .16453 L
.55163 .16017 L
.55677 .15774 L
.55928 .15655 L
.56155 .15545 L
.56285 .15482 L
.56407 .30902 L
.56535 .30902 L
.56675 .30902 L
.57243 .30902 L
.58241 .30902 L
.62333 .30902 L
.66273 .30902 L
.70062 .30902 L
.74096 .30902 L
.77978 .30902 L
.82106 .30902 L
Mistroke
.86082 .30902 L
.89907 .30902 L
.93976 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool01@000?ooooooo`00001Vo`0:oooo00<0003oooooool00_oo
o`<0000=oooo00<0I_ooooooool0O_ooo`00MOooo`@00002oooo00@0003oooooool0000306Ko1_oo
o`800005oooo00<0003oooooool02oooo`<0I_n0oooo001koooo00D0003oooooool00000I_l00_oo
o`80I_l4oooo00<0003oooooool01?ooo`030000oooooooo00[oool0101Vooooooooo`1Voh3oool0
07coool2000000?oool0I_ooool00oooo`<0I_l01?ooo`000000000000Coool00`000?ooooooo`07
oooo0`1Vo`?oool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool01Oooo`80I_l6oooo0P00
00Koool206Ko1_ooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`07oooo0`1Vo`?oool0
0`000?ooooooo`02oooo0`1Vo`Soool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool02_oo
o`80I_l01?ooo`000?ooooooo`80I_l;oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo
00coool0101Vo`00001Vo`1Vo`goool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Ooo
o`80000>oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=
oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=oooo00<0
I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=oooo00<0I_oooooo
ool0O_ooo`00Ooooo`0306Kooooooooo00goool200003_ooo`0306Kooooooooo07koool007ooool0
0`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Voooo
ooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`0=
oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`0=oooo0P00
00koool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool0
0`1Vooooooooo`1noooo001foooo0P0000Coool2000000?oool0I_ooool0100000?oool200001Ooo
o`030000oooooooo00goool00`1Vooooooooo`1noooo001eoooo00@0003oooooool00006oooo00<0
I_ooool000001Oooo`040000oooooooo00001?ooo`030000oooooooo00goool00`1Vooooooooo`1n
oooo001eoooo00@0003oooooool00006oooo00@0I_ooooooool00007oooo00<0003oooooool00_oo
o`<0000=oooo00<0I_ooooooool0O_ooo`00Koooo`@00002oooo00@0003oooooool00006oooo00D0
I_ooooooooooool000001?ooo`800005oooo00<0003oooooool03Oooo`0306Kooooooooo07koool0
07Goool010000?ooooooo`0000Koool00`1Vooooo`000002oooo00D0003oooooooooool000001_oo
o`030000oooooooo00goool00`1Vooooooooo`1noooo001foooo0P0000Ooool00`1Vooooooooo`02
00001?ooo`<00004oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Voooo
ooooo`0=oooo0P0000koool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000
oooooooo00goool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo
00goool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool0
0`1Vooooooooo`1noooo000Hoooo0P0002Goool400009Oooo`D0000Boooo00<0I_ooooooool03Ooo
o`80000>oooo00<0I_ooooooool04oooo`D0000Soooo100002Koool200005oooo`005oooo`040000
oooooooo00009?ooo`030000oooooooo02Soool00`000?ooooooo`0Boooo00<0I_ooooooool03Ooo
o`030000oooooooo00goool00`1Vooooooooo`0Eoooo00<0003oooooool08oooo`030000oooooooo
02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09ooo
o`030000oooooooo01;oool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo
01Goool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool4
00001Oooo`030000oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000
oooooooo01;oool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo01Goool0
0`000?ooooooo`0Uoooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?oo
ooooo`0002Coool010000?ooooooo`0002Ooool00`000?ooooooo`0Boooo00<0I_ooooooool03Ooo
o`80000>oooo00<0I_ooooooool05Oooo`030000oooooooo02?oool010000?ooooooo`0002Goool0
10000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0001Coool00`1Vooooooooo`0=
oooo00<0003oooooool03Oooo`0306Kooooooooo01Coool200009_ooo`80000Woooo0P0001Ooool0
07ooool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool0
0`1Vooooooooo`0=oooo0P0000koool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Ooo
o`030000oooooooo00goool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000
oooooooo00goool00`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo
00goool00`1Vooooooooo`1noooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo01Goool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Wooooo
ool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000goool00ol0VOoo
ooooo`1noooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool300003Oooo`03o`2Ioooooooo07koool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo00goool00ol0VOooooooo`1noooo001l
oooo0P0000[oool300001?ooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo0P00
00koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Wooooo
ool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0000goool00ol0VOooooooo`1noooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo00goool00ol0VOooooooo`1n
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo00goool00ol0VOooooooo`1noooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo
07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool200003_ooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Wooooo
ool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_oo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Qooo
o`D00003oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Woool00`000?ooooooo`03
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Woool00`000?ooooooo`03oooo0`00
00goool00ol0VOooooooo`1noooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00[oool01@000?oo
ooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55972 .30902 L
.56446 .30902 L
.56706 .30902 L
.56834 .30902 L
.56951 .30902 L
.57063 .30902 L
s
.57063 .30902 m
.57075 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.42237 .30902 L
.42482 .30902 L
.42617 .30902 L
.42744 .30902 L
.42816 .30902 L
.42894 .15469 L
.42966 .15504 L
.43031 .15535 L
.43298 .15664 L
.44268 .16123 L
.46172 .16983 L
.48214 .1785 L
.49211 .18254 L
.4944 .18344 L
.49683 .1844 L
.49891 .18522 L
.50009 .1856 L
.5012 .18517 L
.50571 .1834 L
.51061 .18144 L
.51953 .17781 L
.53918 .16943 L
.54901 .16504 L
.55936 .16027 L
.56363 .15826 L
.5682 .15607 L
.56955 .15542 L
.57082 .1548 L
.57196 .30902 L
.5732 .30902 L
.57786 .30902 L
.61878 .30902 L
.65818 .30902 L
.69607 .30902 L
.73641 .30902 L
.77524 .30902 L
.81651 .30902 L
Mistroke
.85627 .30902 L
.89452 .30902 L
.93522 .30902 L
.9744 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooo`1Vo`0000_oool00`000?ooooooo`02oooo0`00
00ooool00`1Vooooooooo`1loooo001eoooo100000;oool010000?ooo`1Vo`0000Woool200001Ooo
o`030000oooooooo00goool306KoO_ooo`00Noooo`040000oooo06Ko00000`1Vo`Koool00`000?oo
ooooo`04oooo00<0003oooooool02oooo`80I_l2oooo00<0I_ooooooool0O?ooo`00O?ooo`800004
oooo0P1Vo`Coool300001?ooo`030000oooooooo00Woool206Ko1?ooo`0306Kooooooooo07coool0
07goool00`1Vooooooooo`04oooo0`1Vo`Soool200001oooo`<0I_l6oooo00<0I_ooooooool0O?oo
o`00OOooo`0306Kooooooooo00Ooool206Ko1_ooo`030000oooooooo00Coool206Ko2Oooo`0306Ko
oooooooo07coool007goool00`1Vooooooooo`09oooo0`1Vo`?oool00`000?ooooooo`02oooo0P1V
o`_oool00`1Vooooooooo`1loooo001moooo00<0I_ooooooool03?ooo`80I_l01?ooo`000?oooooo
o`80I_l=oooo00<0I_ooooooool0O?ooo`00OOooo`0306Kooooooooo00koool0101Vo`000000001V
o`ooool00`1Vooooooooo`1loooo001moooo00<0I_ooooooool03oooo`030000oooooooo00ooool0
0`1Vooooooooo`1loooo001moooo00<0I_ooooooool03oooo`030000oooooooo00ooool00`1Voooo
ooooo`1loooo001moooo00<0I_ooooooool03oooo`030000oooooooo00ooool00`1Vooooooooo`1l
oooo001moooo00<0I_ooooooool03oooo`80000@oooo00<0I_ooooooool0O?ooo`00OOooo`0306Ko
oooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOooo`0306Kooooooooo
00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOooo`0306Kooooooooo00ooool0
0`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOooo`0306Kooooooooo00ooool200004?oo
o`0306Kooooooooo07coool007goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`0306Ko
oooooooo07coool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
00ooool00`1Vooooooooo`1loooo001eoooo00@0003oooooool00004oooo00D0I_ooooooooooool0
00001Oooo`040000oooooooo00001?ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo001e
oooo00@0003oooooool00004oooo00<0I_ooooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0000ooool00`1Vooooooooo`1loooo001_oooo100000;oool010000?ooooooo`00
00Coool00`1Vooooooooo`03oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool03ooo
o`0306Kooooooooo07coool007Goool010000?ooooooo`0000Coool01@1Vooooooooooooo`000002
oooo00D0003oooooooooool000001_ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo001f
oooo0P0000Goool00`1Vooooooooo`02oooo0P0000Coool300001?ooo`030000oooooooo00ooool0
0`1Vooooooooo`1loooo001moooo00<0I_ooooooool03oooo`80000@oooo00<0I_ooooooool0O?oo
o`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOoo
o`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOooo`0306Ko
oooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`006?ooo`80000Uoooo1000
02Goool500004?ooo`0306Kooooooooo00ooool200004?ooo`0306Kooooooooo017oool500008ooo
o`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Xoooo00<0
003oooooool04?ooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool04ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Ioooo00<0
003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0@oooo00<0I_ooooooool03ooo
o`030000oooooooo00ooool00`1Vooooooooo`0Coooo00<0003oooooool09?ooo`030000oooooooo
02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool0
0`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0@oooo00<0I_ooooooool03oooo`030000
oooooooo00ooool00`1Vooooooooo`0Coooo00<0003oooooool09Oooo`030000oooooooo02Ooool0
0`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0000Woooo00<0
003oooooool04?ooo`0306Kooooooooo00ooool200004?ooo`0306Kooooooooo01?oool00`000?oo
ooooo`0Soooo00@0003oooooool0000Uoooo00@0003oooooool0000Foooo000Hoooo0P0002Koool2
00009oooo`80000Boooo00<0I_ooooooool03oooo`030000oooooooo00ooool00`1Vooooooooo`0B
oooo0P0002Koool200009oooo`80000Goooo001moooo00<0I_ooooooool03oooo`030000oooooooo
00ooool00`1Vooooooooo`1loooo001moooo00<0I_ooooooool03oooo`80000@oooo00<0I_oooooo
ool0O?ooo`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?oo
o`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00OOoo
o`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`004?ooool0000A
oooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooool0V@05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00ooool00ol0VOooooooo`0Coooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00M_ooo`800004oooo0P0000?oool4
00000oooo`800005oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool007Goool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<0000?oooo00?o09Woooooool0O?ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo001e
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo001foooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool2
00004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00O?ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo001koooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0000ooool00ol0VOoo
ooooo`1loooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool2
00004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000?oooo00?o
09Woooooool0O?ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?
oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00
013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008Ooool500000oooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo0029oooo00<0003oooooool00oooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo0029oooo00<0003oooooool00oooo`<0000?oooo00?o09Woooooool0O?ooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool300000_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00[oool010000?ooooooo`0000;oool01@000?oooooooooo
o`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07
oooo1@0000Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool0
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000;oooo0P0000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.56817 .30902 L
.57355 .30902 L
.57618 .30902 L
.57734 .30902 L
.57861 .30902 L
.57931 .30902 L
s
.57931 .30902 m
.57937 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.41134 .30902 L
.41408 .30902 L
.41703 .30902 L
.41846 .30902 L
.41917 .30902 L
.41982 .30902 L
.42104 .1547 L
.42168 .15502 L
.42237 .15535 L
.46395 .17421 L
.4741 .17845 L
.48482 .18279 L
.49397 .18638 L
.49648 .18734 L
.49786 .18787 L
.49916 .18837 L
.50038 .18854 L
.5017 .18804 L
.50401 .18715 L
.54257 .17142 L
.56234 .16258 L
.57232 .1579 L
.57506 .15659 L
.5765 .1559 L
.57801 .15517 L
.57865 .15485 L
.57934 .15452 L
.58009 .30902 L
.58079 .30902 L
.58335 .30902 L
.62484 .30902 L
.66483 .30902 L
.70329 .30902 L
.74421 .30902 L
.78361 .30902 L
.8215 .30902 L
.86184 .30902 L
.90067 .30902 L
.94194 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool01000001Vooooo`0000_oool00`000?ooooooo`02oooo0`00
017oool00`1Vooooooooo`1joooo001eoooo100000;oool010000?ooo`1Vo`0000Woool200001Ooo
o`030000oooooooo00ooool306KoO?ooo`00Noooo`040000oooooooo00000P1Vo`Ooool00`000?oo
ooooo`04oooo00<0003oooooool03Oooo`80I_l2oooo00<0I_ooooooool0N_ooo`00Noooo`0306Ko
0000000000?oool206Ko1Oooo`<00004oooo00<0003oooooool02oooo`80I_l4oooo00<0I_oooooo
ool0N_ooo`00Noooo`0306Kooooooooo00Goool206Ko2_ooo`80000:oooo0P1Vo`Koool00`1Voooo
ooooo`1joooo001koooo00<0I_ooooooool01oooo`80I_l8oooo00<0003oooooool01oooo`80I_l8
oooo00<0I_ooooooool0N_ooo`00Noooo`0306Kooooooooo00Woool306Ko1Oooo`030000oooooooo
00Goool206Ko2_ooo`0306Kooooooooo07[oool007_oool00`1Vooooooooo`0<oooo0P1Vo`?oool0
0`000?ooooooo`02oooo0`1Vo`coool00`1Vooooooooo`1joooo001koooo00<0I_ooooooool03_oo
o`80I_l01?ooo`0000000?ooo`80I_l?oooo00<0I_ooooooool0N_ooo`00Noooo`0306Kooooooooo
013oool0101Vo`00001Vo`1Voa7oool00`1Vooooooooo`1joooo001koooo00<0I_ooooooool04Ooo
o`030000oooooooo017oool00`1Vooooooooo`1joooo001koooo00<0I_ooooooool04Oooo`030000
oooooooo017oool00`1Vooooooooo`1joooo001koooo00<0I_ooooooool04Oooo`80000Boooo00<0
I_ooooooool0N_ooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0N_ooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_oo
o`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Nooo
o`0306Kooooooooo017oool200004_ooo`0306Kooooooooo07[oool007_oool00`1Vooooooooo`0A
oooo00<0003oooooool04Oooo`0306Kooooooooo07[oool007Koool200000oooo`0306Ko00000000
00?oool400000oooo`800005oooo00<0003oooooool04Oooo`0306Kooooooooo07[oool007Goool0
10000?ooooooo`0000;oool00`1Vooooooooo`03oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo017oool00`1Vooooooooo`1joooo001eoooo00@0003oooooool00002
oooo00<0I_ooooooool01?ooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00017oool0
0`1Vooooooooo`1joooo001_oooo100000;oool010000?ooooooo`0000;oool00`1Vooooooooo`05
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool04Oooo`0306Kooooooooo07[oool0
07Goool010000?ooooooo`0000;oool00`1Vooooooooo`03oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo017oool00`1Vooooooooo`1joooo001foooo0P0000?oool0
0`1Vooooooooo`04oooo0P0000Coool300001?ooo`030000oooooooo017oool00`1Vooooooooo`1j
oooo001koooo00<0I_ooooooool04Oooo`80000Boooo00<0I_ooooooool0N_ooo`00Noooo`0306Ko
oooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Noooo`0306Kooooooooo
017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Noooo`0306Kooooooooo017oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`006?ooo`80000Uoooo100002Goool500003_oo
o`0306Kooooooooo017oool200004_ooo`0306Kooooooooo00ooool500008oooo`@0000Voooo0P00
01Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Xoooo00<0003oooooool03_oo
o`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool04Oooo`030000oooooooo
02?oool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool09?oo
o`030000oooooooo02Ooool00`000?ooooooo`0>oooo00<0I_ooooooool04Oooo`030000oooooooo
017oool00`1Vooooooooo`0Aoooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?oo
ooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0N
oooo100000Coool00`000?ooooooo`0>oooo00<0I_ooooooool04Oooo`030000oooooooo017oool0
0`1Vooooooooo`0Aoooo00<0003oooooool09Oooo`030000oooooooo02Ooool00`000?ooooooo`0D
oooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0000Woooo00<0003oooooool03_oo
o`0306Kooooooooo017oool200004_ooo`0306Kooooooooo017oool00`000?ooooooo`0Soooo00@0
003oooooool0000Uoooo00@0003oooooool0000Foooo000Hoooo0P0002Koool200009oooo`80000@
oooo00<0I_ooooooool04Oooo`030000oooooooo017oool00`1Vooooooooo`0@oooo0P0002Koool2
00009oooo`80000Goooo001koooo00<0I_ooooooool04Oooo`030000oooooooo017oool00`1Voooo
ooooo`1joooo001koooo00<0I_ooooooool04Oooo`80000Boooo00<0I_ooooooool0N_ooo`00Nooo
o`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Noooo`0306Ko
oooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Noooo`0306Kooooooooo
017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool01@000?ooooooooooool0V@03oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo017oool00ol0VOooooooo`0Aoooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool04Oooo`03o`2I
oooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0A
oooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?
oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo
07[oool008ooool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo
017oool00ol0VOooooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool0
08ooool200004_ooo`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0Aoooo00?o09Wooooo
ool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?oooo00<0003ooooo
ool04Oooo`03o`2Ioooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo07[oool008ooool0
0`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool04Oooo`03o`2I
oooooooo07[oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000Aoooo00?o09Woooooool0N_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo017oool00ol0VOooooooo`1joooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
017oool00ol0VOooooooo`1joooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool04Oooo`03o`2Ioooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo07[oool008ooool0
0`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOoo
ooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool200004_oo
o`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Sooo
o`030000oooooooo017oool00ol0VOooooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2I
oooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0A
oooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?
oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo
07[oool008ooool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo017oool00ol0VOooooooo`1joooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00017oool00ol0VOooooooo`1j
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Aoooo00?o09Wooooo
ool0N_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0A
oooo00?o09Woooooool0N_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Aoooo00?o
09Woooooool0N_ooo`00Soooo`80000Boooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo
017oool00ol0VOooooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool0
08ooool200004_ooo`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0Aoooo00?o09Wooooo
ool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?oooo00<0003ooooo
ool04Oooo`03o`2Ioooooooo07[oool008ooool200004_ooo`03o`2Ioooooooo07[oool008ooool0
0`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOoo
ooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool200004_oo
o`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Aoooo00?o
09Woooooool0N_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000Aoooo00?o09Wooooo
ool0N_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`0Aoooo00?o09Woooooool0N_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?
oooo0P0001;oool00ol0VOooooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo
07[oool008ooool00`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo
017oool00ol0VOooooooo`1joooo002?oooo0P0001;oool00ol0VOooooooo`1joooo002?oooo00<0
003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool00`000?ooooooo`0Aoooo00?o09Wooooo
ool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOooooooo`1joooo002?oooo0P0001;oool0
0ol0VOooooooo`1joooo002?oooo00<0003oooooool04Oooo`03o`2Ioooooooo07[oool008ooool0
0`000?ooooooo`0Aoooo00?o09Woooooool0N_ooo`00Soooo`030000oooooooo017oool00ol0VOoo
ooooo`1joooo002?oooo0P0001;oool00ol0VOooooooo`1joooo002?oooo00<0003oooooool04Ooo
o`03o`2Ioooooooo07[oool008Ooool500000oooo`030000oooooooo017oool00ol0VOooooooo`1j
oooo0029oooo00<0003oooooool00oooo`030000oooooooo017oool00ol0VOooooooo`1joooo0029
oooo00<0003oooooool00oooo`<0000Aoooo00?o09Woooooool0N_ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02_ooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo0P00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo
00Soool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.56817 .30902 L
.57861 .30902 L
.58157 .30902 L
.58436 .30902 L
.58558 .30902 L
.58686 .30902 L
s
.58686 .30902 m
.58693 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.40616 .30902 L
.40882 .30902 L
.41013 .30902 L
.41134 .30902 L
.41203 .30902 L
.41276 .15454 L
.41358 .15494 L
.41432 .15529 L
.41703 .1566 L
.42237 .15914 L
.46243 .17691 L
.48081 .18434 L
.49124 .18837 L
.49386 .18936 L
.49634 .19029 L
.49856 .19112 L
.49982 .19159 L
.50098 .19129 L
.50213 .19087 L
.5032 .19047 L
.50565 .18955 L
.51061 .18767 L
.52092 .18366 L
.54199 .17506 L
.56046 .16703 L
.57093 .16227 L
.57604 .1599 L
.58067 .1577 L
.58307 .15656 L
.58432 .15595 L
.58566 .15531 L
.58682 .15474 L
.58811 .30902 L
.58927 .30902 L
.59036 .30902 L
.60071 .30902 L
.62181 .30902 L
.66064 .30902 L
.70191 .30902 L
Mistroke
.74167 .30902 L
.77992 .30902 L
.82062 .30902 L
.8598 .30902 L
.90143 .30902 L
.94155 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007Woool00`1Vooooo`000002oooo00<0003oooooool02Oooo`030000
oooooooo00;oool300004oooo`0306Kooooooooo07Soool007Goool400000P1Vo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool04Oooo`<0I_mjoooo001ioooo00<0I_ooool000000P1V
o`030000oooooooo00Ooool00`000?ooooooo`04oooo00<0003oooooool03_ooo`<0I_l2oooo00<0
I_ooooooool0N?ooo`00NOooo`0306Kooooooooo0080000206Ko2?ooo`<00004oooo00<0003ooooo
ool03?ooo`80I_l5oooo00<0I_ooooooool0N?ooo`00NOooo`0306Kooooooooo00Coool206Ko3Ooo
o`80000;oooo0P1Vo`Ooool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool01_ooo`80I_l;
oooo00<0003oooooool02?ooo`80I_l9oooo00<0I_ooooooool0N?ooo`00NOooo`0306Kooooooooo
00Soool306Ko2?ooo`030000oooooooo00Koool206Ko2oooo`0306Kooooooooo07Soool007Woool0
0`1Vooooooooo`0;oooo0P1Vo`Koool00`000?ooooooo`04oooo0P1Vo`goool00`1Vooooooooo`1h
oooo001ioooo00<0I_ooooooool03Oooo`<0I_l3oooo0P0000?oool206Ko3oooo`0306Kooooooooo
07Soool007Woool00`1Vooooooooo`0@oooo0`1Vo`03000006Ko06Ko0080I_lAoooo00<0I_oooooo
ool0N?ooo`00NOooo`0306Kooooooooo01?oool00`000?ooooooo`0Coooo00<0I_ooooooool0N?oo
o`00NOooo`0306Kooooooooo01?oool00`000?ooooooo`0Coooo00<0I_ooooooool0N?ooo`00NOoo
o`0306Kooooooooo01?oool200005?ooo`0306Kooooooooo07Soool007Woool00`1Vooooooooo`0C
oooo00<0003oooooool04oooo`0306Kooooooooo07Soool007Woool00`1Vooooooooo`0Coooo00<0
003oooooool04oooo`0306Kooooooooo07Soool007Woool00`1Vooooooooo`0Coooo00<0003ooooo
ool04oooo`0306Kooooooooo07Soool007Woool00`1Vooooooooo`0Coooo0P0001Coool00`1Voooo
ooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01?oool00`1Vooooooooo`1h
oooo001foooo0P000004oooo06Kooooooooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool04oooo`0306Kooooooooo07Soool007Goool01@000?ooooooo`00001Vo`07oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo01?oool00`1Vooooooooo`1hoooo001e
oooo00D0003oooooool00000I_l02?ooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
01?oool00`1Vooooooooo`1hoooo001_oooo100000;oool01@000?ooooooo`00001Vo`09oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool04oooo`0306Kooooooooo07Soool007Goool0
1@000?ooooooo`00001Vo`07oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo01?oool00`1Vooooooooo`1hoooo001foooo0P000003oooo06Kooooo00Ooool200001?oo
o`<00004oooo00<0003oooooool04oooo`0306Kooooooooo07Soool007Woool00`1Vooooooooo`0C
oooo0P0001Coool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo
01?oool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01?oool0
0`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01?oool00`1Voooo
ooooo`1hoooo000Hoooo0P0002Goool400009Oooo`D0000<oooo00<0I_ooooooool04oooo`80000D
oooo00<0I_ooooooool03Oooo`D0000Soooo100002Koool200005oooo`005oooo`040000oooooooo
00009?ooo`030000oooooooo02Soool00`000?ooooooo`0<oooo00<0I_ooooooool04oooo`030000
oooooooo01?oool00`1Vooooooooo`0?oooo00<0003oooooool08oooo`030000oooooooo02Koool0
10000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000
oooooooo00coool00`1Vooooooooo`0Coooo00<0003oooooool04oooo`0306Kooooooooo00ooool0
0`000?ooooooo`0Toooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Ooo
o`030000oooooooo01coool400001?ooo`030000oooooooo01koool400001?ooo`030000oooooooo
00coool00`1Vooooooooo`0Coooo00<0003oooooool04oooo`0306Kooooooooo00ooool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
02Coool010000?ooooooo`0002Ooool00`000?ooooooo`0<oooo00<0I_ooooooool04oooo`80000D
oooo00<0I_ooooooool03oooo`030000oooooooo02?oool010000?ooooooo`0002Goool010000?oo
ooooo`0001Koool001Soool200009_ooo`80000Woooo0P0000koool00`1Vooooooooo`0Coooo00<0
003oooooool04oooo`0306Kooooooooo00koool200009_ooo`80000Woooo0P0001Ooool007Woool0
0`1Vooooooooo`0Coooo00<0003oooooool04oooo`0306Kooooooooo07Soool007Woool00`1Voooo
ooooo`0Coooo0P0001Coool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000
oooooooo01?oool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo
01?oool00`1Vooooooooo`1hoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01?oool0
0`1Vooooooooo`1hoooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool04ooo
o`03o`2Ioooooooo00ooool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
01Goool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?oo
o`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00MOooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001?oool00ol0VOooooooo`1h
oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo07Soool007Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool007Koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool300004oooo`03o`2Ioooooooo07Soool007_oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001koooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001loooo0P00
00[oool300001?ooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?oo
o`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo001foooo0P0000Coool200001Oooo`030000oooooooo
00;oool200001Oooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001eoooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool0
0`000?ooooooo`02oooo0`0001?oool00ol0VOooooooo`1hoooo001eoooo00@0003oooooool0000;
oooo00@0003oooooooooool200001Oooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001e
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo001foooo0P0000Woool400000oooo`<00004oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2Ioooooooo07Soool0
08ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool2
00005?ooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2Ioooooooo07Soool008ooool00`000?oo
ooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Qoooo`D00003
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008Woool00`000?ooooooo`03oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008Woool00`000?ooooooo`03oooo0`0001?oool0
0ol0VOooooooo`1hoooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03oooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
oooooooo00Soool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.57861 .30902 L
.58392 .30902 L
.58957 .30902 L
.59232 .30902 L
.59367 .30902 L
.59491 .30902 L
s
.59491 .30902 m
.59502 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.39675 .30902 L
.40134 .30902 L
.40252 .30902 L
.40381 .30902 L
.40503 .15464 L
.40616 .15519 L
.41134 .15768 L
.42237 .16284 L
.4615 .17979 L
.48147 .18767 L
.48694 .18975 L
.49272 .1919 L
.49511 .19278 L
.49766 .19371 L
.49841 .19398 L
.49913 .19424 L
.49977 .19447 L
.50046 .19439 L
.50112 .19415 L
.50182 .1939 L
.50308 .19344 L
.54314 .17789 L
.56284 .1695 L
.58089 .16133 L
.59032 .15688 L
.59261 .15578 L
.59387 .15517 L
.59506 .1546 L
.59573 .30902 L
.59646 .30902 L
.59774 .30902 L
.60024 .30902 L
.6211 .30902 L
.66202 .30902 L
.70142 .30902 L
.73931 .30902 L
.77965 .30902 L
.81847 .30902 L
.85975 .30902 L
Mistroke
.89951 .30902 L
.93775 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007Ooool01@1Vooooooooooooo`000002oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool300005Oooo`0306Kooooooooo07Koool007Goool4000000<0I_ooool0
00000_ooo`030000oooooooo00Ooool200001Oooo`030000oooooooo01?oool306KoN?ooo`00Mooo
o`0506Kooooooooo06Ko000000;oool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000
oooooooo017oool206Ko0_ooo`0306Kooooooooo07Koool007Ooool00`1Vooooooooo`02oooo0P00
00[oool300001?ooo`030000oooooooo00ooool206Ko1?ooo`0306Kooooooooo07Koool007Ooool0
0`1Vooooooooo`04oooo0P1Vo`ooool200003Oooo`<0I_l6oooo00<0I_ooooooool0M_ooo`00Mooo
o`0306Kooooooooo00Koool206Ko3Oooo`030000oooooooo00[oool206Ko2Oooo`0306Kooooooooo
07Koool007Ooool00`1Vooooooooo`08oooo0P1Vo`_oool00`000?ooooooo`07oooo0`1Vo`_oool0
0`1Vooooooooo`1foooo001goooo00<0I_ooooooool02_ooo`<0I_l8oooo00<0003oooooool01Ooo
o`80I_l>oooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo00goool206Ko1_ooo`800003
oooo0`1Voa3oool00`1Vooooooooo`1foooo001goooo00<0I_ooooooool03oooo`@0I_l2oooo00<0
003oooooool00P1Voa?oool00`1Vooooooooo`1foooo001goooo00<0I_ooooooool04oooo`80I_l0
0`00001Vo`1Vo`0Eoooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?oo
ooooo`0Eoooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool200005_ooo`0306Ko
oooooooo07Koool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`0306Kooooooooo
07Koool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`0306Kooooooooo07Koool0
07Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`0306Kooooooooo07Koool007Ooool0
0`1Vooooooooo`0Eoooo0P0001Koool00`1Vooooooooo`1foooo001goooo00<0I_ooooooool05Ooo
o`030000oooooooo01Goool00`1Vooooooooo`1foooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00MOooo`040000oooo06Ko
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Eoooo00<0
I_ooooooool0M_ooo`00MOooo`040000oooo06Ko00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0001Goool00`1Vooooooooo`1foooo001_oooo100000;oool010000?ooo`1Vo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_oo
o`00MOooo`040000oooo06Ko00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo01Goool00`1Vooooooooo`1foooo001goooo00<0I_ooooooool05Oooo`80000F
oooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0
I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0I_oooooo
ool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_oo
o`006?ooo`80000Uoooo100002Goool500002_ooo`0306Kooooooooo01Goool200005_ooo`0306Ko
oooooooo00_oool500008oooo`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool0
0`000?ooooooo`0Xoooo00<0003oooooool02_ooo`0306Kooooooooo01Goool00`000?ooooooo`0E
oooo00<0I_ooooooool03Oooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00@0003ooooo
ool0000Foooo000Ioooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0:
oooo00<0I_ooooooool05Oooo`030000oooooooo01Goool00`1Vooooooooo`0=oooo00<0003ooooo
ool09?ooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?oo
ooooo`0Loooo100000Coool00`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0:oooo00<0
I_ooooooool05Oooo`030000oooooooo01Goool00`1Vooooooooo`0=oooo00<0003oooooool09Ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0
003oooooool0000Woooo00<0003oooooool02_ooo`0306Kooooooooo01Goool200005_ooo`0306Ko
oooooooo00goool00`000?ooooooo`0Soooo00@0003oooooool0000Uoooo00@0003oooooool0000F
oooo000Hoooo0P0002Koool200009oooo`80000<oooo00<0I_ooooooool05Oooo`030000oooooooo
01Goool00`1Vooooooooo`0<oooo0P0002Koool200009oooo`80000Goooo001goooo00<0I_oooooo
ool05Oooo`030000oooooooo01Goool00`1Vooooooooo`1foooo001goooo00<0I_ooooooool05Ooo
o`80000Foooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0E
oooo00<0I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0
I_ooooooool0M_ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0I_oooooo
ool0M_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo01Goool00ol0VOoo
ooooo`0=oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool200005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_oo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00M_oo
o`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool007Goool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Eoooo00?o09Woooooool0M_ooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo01Goool00ol0VOooooooo`1foooo001foooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_oo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool200005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0001Goool00ol0VOooooooo`1foooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000Foooo00?o09Wooooo
ool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_oo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00MOooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<0000Eoooo00?o09Woooooool0M_ooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008Ooool500000oooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00oooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00oooo`<0000Eoooo00?o09Wooooo
ool0M_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool3
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool01oooo`040000oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003_ooo`030000oooooooo00Ooool300001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59405 .30902 L
.59698 .30902 L
.59975 .30902 L
.60102 .30902 L
.60237 .30902 L
.60307 .30902 L
s
.60307 .30902 m
.60315 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.39106 .30902 L
.39381 .30902 L
.39516 .30902 L
.39642 .30902 L
.39756 .15487 L
.39877 .15545 L
.40134 .15669 L
.42237 .16645 L
.46395 .18395 L
.4741 .18789 L
.48482 .19191 L
.49397 .19524 L
.49648 .19613 L
.49786 .19662 L
.49916 .19709 L
.50038 .19725 L
.5017 .19678 L
.50401 .19596 L
.54257 .18136 L
.56195 .17332 L
.57225 .16885 L
.58335 .16386 L
.58849 .16149 L
.59391 .15895 L
.59854 .15675 L
.59981 .15614 L
.60116 .15549 L
.60244 .15487 L
.6036 .30902 L
.60479 .30902 L
.60604 .30902 L
.60829 .30902 L
.61338 .30902 L
.62261 .30902 L
.6605 .30902 L
.70084 .30902 L
.73966 .30902 L
.78094 .30902 L
Mistroke
.8207 .30902 L
.85895 .30902 L
.89964 .30902 L
.93883 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007Goool00`1Vooooooooo`03oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Goooo00<0I_ooooooool0M?ooo`00MOooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`0Eoooo0`1VogKoool007Goool00`1Vooooooooo`02
06Ko00Goool0003oooooool000002Oooo`030000oooooooo00Coool00`000?ooooooo`0Coooo0P1V
o`;oool00`1Vooooooooo`1doooo001eoooo00<0I_ooooooool00_ooo`80I_l200002_ooo`<00004
oooo00<0003oooooool04Oooo`80I_l4oooo00<0I_ooooooool0M?ooo`00MOooo`0306Kooooooooo
00Goool206Ko4?ooo`80000@oooo0P1Vo`Koool00`1Vooooooooo`1doooo001eoooo00<0I_oooooo
ool01oooo`80I_l>oooo00<0003oooooool03?ooo`<0I_l8oooo00<0I_ooooooool0M?ooo`00MOoo
o`0306Kooooooooo00Woool206Ko3?ooo`030000oooooooo00[oool206Ko2oooo`0306Kooooooooo
07Coool007Goool00`1Vooooooooo`0;oooo0P1Vo`[oool00`000?ooooooo`07oooo0`1Vo`goool0
0`1Vooooooooo`1doooo001eoooo00<0I_ooooooool03Oooo`80I_l8oooo0P0000Koool206Ko4?oo
o`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0?oooo0`1Vo`Goool00`000?ooooooo`02
oooo0`1Voa;oool00`1Vooooooooo`1doooo001eoooo00<0I_ooooooool04_ooo`80I_l3oooo00<0
003oooooool00P1VoaGoool00`1Vooooooooo`1doooo001eoooo00<0I_ooooooool05?ooo`<0I_l0
0`00001Vo`1Vo`0Goooo00<0I_ooooooool0M?ooo`00MOooo`0306Kooooooooo01Ooool200006?oo
o`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05oooo`0306Ko
oooooooo07Coool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05oooo`0306Kooooooooo
07Coool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05oooo`0306Kooooooooo07Coool0
07Goool00`1Vooooooooo`0Goooo0P0001Soool00`1Vooooooooo`1doooo001eoooo00<0I_oooooo
ool05oooo`030000oooooooo01Ooool00`1Vooooooooo`1doooo001eoooo00<0I_l0000000001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo01Ooool00`1Vooooooooo`1doooo001e
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000
oooooooo01Ooool00`1Vooooooooo`1doooo001eoooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool300005oooo`0306Kooooooooo07Coool006ooool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01Ooool0
0`1Vooooooooo`1doooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo01Ooool00`1Vooooooooo`1doooo001eoooo00<0I_l00000
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Goooo00<0I_ooooooool0M?ooo`00MOoo
o`0306Kooooooooo01Ooool200006?ooo`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0G
oooo00<0003oooooool05oooo`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0Goooo00<0
003oooooool05oooo`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0Goooo00<0003ooooo
ool05oooo`0306Kooooooooo07Coool001Soool200009Oooo`@0000Uoooo1@0000Soool00`1Voooo
ooooo`0Goooo0P0001Soool00`1Vooooooooo`09oooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo00Soool00`1Voooo
ooooo`0Goooo00<0003oooooool05oooo`0306Kooooooooo00_oool00`000?ooooooo`0Soooo00<0
003oooooool09_ooo`040000oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?oo
ooooo`0Woooo00<0003oooooool02?ooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00<0
I_ooooooool02oooo`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0003oooooool05Ooo
o`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004
oooo00<0003oooooool02?ooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00<0I_oooooo
ool02oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005ooo
o`040000oooooooo00009?ooo`040000oooooooo00009oooo`030000oooooooo00Soool00`1Voooo
ooooo`0Goooo0P0001Soool00`1Vooooooooo`0;oooo00<0003oooooool08oooo`040000oooooooo
00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P0002Ooool200002_ooo`0306Ko
oooooooo01Ooool00`000?ooooooo`0Goooo00<0I_ooooooool02_ooo`80000Voooo0P0002Ooool2
00005oooo`00MOooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00<0I_ooooooool0M?oo
o`00MOooo`0306Kooooooooo01Ooool200006?ooo`0306Kooooooooo07Coool007Goool00`1Voooo
ooooo`0Goooo00<0003oooooool05oooo`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0G
oooo00<0003oooooool05oooo`0306Kooooooooo07Coool007Goool00`1Vooooooooo`0Goooo00<0
003oooooool05oooo`0306Kooooooooo07Coool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Goooo00?o09Woooooool02oooo`030000oooooooo02Goool00`000?ooooooo`0V
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo001eoooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001e
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300005ooo
o`03o`2Ioooooooo07Coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool007coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001koooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000Goooo00?o09Woooooool0M?ooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool007coool200002_ooo`<00004oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08ooool200006?ooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool300005oooo`03o`2Ioooooooo07Coool007Goool0
10000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool05oooo`03o`2I
oooooooo07Coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`80000Hoooo00?o
09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`80000Hoooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo0027oooo1@0000?oool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00ROooo`030000oooooooo
00?oool300005oooo`03o`2Ioooooooo07Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000
oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000koool00`000?ooooooo`07oooo0`0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`<00003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.60756 .30902 L
.60891 .30902 L
.61016 .30902 L
s
.61016 .30902 m
.61028 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.3864 .30902 L
.38757 .30902 L
.38881 .30902 L
.38999 .15504 L
.39106 .15556 L
.40134 .16045 L
.42237 .16997 L
.46243 .18646 L
.48081 .19335 L
.49124 .19709 L
.49386 .19801 L
.49634 .19887 L
.49856 .19964 L
.49982 .20007 L
.50098 .1998 L
.50213 .1994 L
.5032 .19903 L
.50565 .19818 L
.51061 .19644 L
.52092 .19272 L
.54199 .18474 L
.58067 .16863 L
.60071 .15949 L
.60559 .15717 L
.60826 .15589 L
.60958 .15525 L
.61079 .15466 L
.61149 .30902 L
.61223 .30902 L
.61378 .30902 L
.6165 .30902 L
.62181 .30902 L
.6597 .30902 L
.70004 .30902 L
.73886 .30902 L
.78014 .30902 L
Mistroke
.8199 .30902 L
.85815 .30902 L
.89884 .30902 L
.93803 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007?oool00`1Vooooooooo`05oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Ioooo00<0I_ooooooool0L_ooo`00Loooo`80I_l400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool06?ooo`80I_mdoooo001coooo00<0I_ooool0
I_l00P1Vo`?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool05_oo
o`80I_l00oooo`1Vooooo`1coooo001coooo00<0I_ooooooool00_ooo`80I_l2oooo0P0000[oool3
00001?ooo`030000oooooooo01?oool306Ko0oooo`0306Kooooooooo07;oool007?oool00`1Voooo
ooooo`04oooo0`1Voa;oool200004Oooo`<0I_l6oooo00<0I_ooooooool0L_ooo`00Loooo`0306Ko
oooooooo00Ooool206Ko4?ooo`030000oooooooo00koool206Ko2Oooo`0306Kooooooooo07;oool0
07?oool00`1Vooooooooo`09oooo0`1Vo`goool00`000?ooooooo`0<oooo0P1Vo`_oool00`1Voooo
ooooo`1boooo001coooo00<0I_ooooooool03?ooo`80I_l;oooo00<0003oooooool02_ooo`80I_l=
oooo00<0I_ooooooool0L_ooo`00Loooo`0306Kooooooooo00koool306Ko2?ooo`800008oooo0`1V
o`ooool00`1Vooooooooo`1boooo001coooo00<0I_ooooooool04Oooo`80I_l6oooo00<0003ooooo
ool01?ooo`<0I_lBoooo00<0I_ooooooool0L_ooo`00Loooo`0306Kooooooooo01?oool306Ko0ooo
o`030000oooooooo00;oool206Ko5Oooo`0306Kooooooooo07;oool007?oool00`1Vooooooooo`0F
oooo0`1Vo`03000006Ko06Ko0080I_lGoooo00<0I_ooooooool0L_ooo`00Loooo`0306Kooooooooo
01Woool200006_ooo`0306Kooooooooo07;oool007?oool00`1Vooooooooo`0Ioooo00<0003ooooo
ool06Oooo`0306Kooooooooo07;oool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Ooo
o`0306Kooooooooo07;oool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Ko
oooooooo07;oool007?oool00`1Vooooooooo`0Ioooo0P0001[oool00`1Vooooooooo`1boooo001c
oooo00<0I_ooooooool06Oooo`030000oooooooo01Woool00`1Vooooooooo`1boooo001coooo00<0
I_ooooooool00P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Ioooo00<0
I_ooooooool0L_ooo`00Loooo`0306Kooooo000000;oool00`000?ooooooo`06oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo01Woool00`1Vooooooooo`1boooo001c
oooo00<0I_ooool000000_ooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000Ioooo00<0I_ooooooool0L_ooo`00Koooo`@000000`1Vooooo`000002oooo00<0
003oooooool02?ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01Woool00`1Voooo
ooooo`1boooo001coooo00<0I_ooool000000_ooo`030000oooooooo00Koool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007?oool0
0`1Vooooooooo`0200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Ioooo00<0I_oooooo
ool0L_ooo`00Loooo`0306Kooooooooo01Woool200006_ooo`0306Kooooooooo07;oool007?oool0
0`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007?oool00`1Voooo
ooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007?oool00`1Vooooooooo`0I
oooo00<0003oooooool06Oooo`0306Kooooooooo07;oool001Soool200009Oooo`@0000Uoooo1@00
00Koool00`1Vooooooooo`0Ioooo0P0001[oool00`1Vooooooooo`07oooo1@0002?oool400009_oo
o`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`030000oooooooo
00Koool00`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo00Woool00`000?oo
ooooo`0Soooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Oooo`030000oooooooo
02Coool00`000?ooooooo`0Woooo00<0003oooooool01_ooo`0306Kooooooooo01Woool00`000?oo
ooooo`0Ioooo00<0I_ooooooool02Oooo`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0
003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003ooooo
ool07_ooo`@00004oooo00<0003oooooool01_ooo`0306Kooooooooo01Woool00`000?ooooooo`0I
oooo00<0I_ooooooool02Oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00<0003ooooo
ool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009oooo`030000oooooooo
00Koool00`1Vooooooooo`0Ioooo0P0001[oool00`1Vooooooooo`09oooo00<0003oooooool08ooo
o`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P0002Ooool2
00002?ooo`0306Kooooooooo01Woool00`000?ooooooo`0Ioooo00<0I_ooooooool02?ooo`80000V
oooo0P0002Ooool200005oooo`00Loooo`0306Kooooooooo01Woool00`000?ooooooo`0Ioooo00<0
I_ooooooool0L_ooo`00Loooo`0306Kooooooooo01Woool200006_ooo`0306Kooooooooo07;oool0
07?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007?oool0
0`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007?oool00`1Voooo
ooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo07;oool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000oooooooo
ooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Goool00`000?ooooooo`0Ioooo00?o09Woooooool02Oooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01Woool0
0ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?oooo00<0003ooooo
ool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_oo
o`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOoo
ooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?oo
ooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1b
oooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2I
oooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`030000
oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?
oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo01Woool00ol0VOooooooo`1boooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01Woool0
0ol0VOooooooo`1boooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool300006Oooo`03o`2Ioooooooo07;oool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0Ioooo00?o09Woooooool0L_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?
oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o
09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P00
01[oool00ol0VOooooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool0
08ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool0
0ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?oooo00<0003ooooo
ool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_oo
o`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOoo
ooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo01Woool00ol0VOooooooo`1b
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Ioooo00?o09Wooooo
ool0L_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool06Oooo`03o`2I
oooooooo07;oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool06Oooo`03o`2Ioooooooo07;oool007coool200002_ooo`<00004oooo00<0003oooooool06Ooo
o`03o`2Ioooooooo07;oool008ooool200006_ooo`03o`2Ioooooooo07;oool008ooool00`000?oo
ooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1b
oooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2I
oooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`030000
oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P0001[oool00ol0VOooooooo`1boooo002?
oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o
09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1boooo002?oooo0P00
01[oool00ol0VOooooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool06Ooo
o`03o`2Ioooooooo07;oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo01Woool00ol0VOooooooo`1boooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300006Oooo`03o`2I
oooooooo07;oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool06Oooo`03o`2Ioooooooo07;oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Ioooo00?o09Woooooool0L_oo
o`00Soooo`80000Joooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOoo
ooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?oo
ooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`80000Joooo00?o09Woooooool0L_ooo`00Sooo
o`030000oooooooo01Woool00ol0VOooooooo`1boooo002?oooo00<0003oooooool06Oooo`03o`2I
oooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o09Woooooool0L_ooo`00Soooo`80000J
oooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo01Woool00ol0VOooooooo`1boooo002?
oooo00<0003oooooool06Oooo`03o`2Ioooooooo07;oool008ooool00`000?ooooooo`0Ioooo00?o
09Woooooool0L_ooo`00Soooo`80000Joooo00?o09Woooooool0L_ooo`00Soooo`030000oooooooo
01Woool00ol0VOooooooo`1boooo0027oooo1@0000?oool00`000?ooooooo`0Ioooo00?o09Wooooo
ool0L_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Ioooo00?o09Woooooool0L_oo
o`00ROooo`030000oooooooo00?oool300006Oooo`03o`2Ioooooooo07;oool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800005oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool00`000?oo
ooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`050000oooooooooooo000007goool007_oool01@000?ooooooooooo`00000Aoooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.61016 .30902 L
.61278 .30902 L
.61524 .30902 L
.61745 .30902 L
.61869 .30902 L
s
.61869 .30902 m
.6188 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.37114 .30902 L
.37372 .30902 L
.37649 .30902 L
.37783 .30902 L
.3791 .30902 L
.38025 .30902 L
.3815 .15477 L
.38215 .15509 L
.38283 .15542 L
.38405 .15601 L
.38681 .15733 L
.39182 .15971 L
.40117 .16404 L
.42214 .17331 L
.46012 .18861 L
.48126 .19637 L
.49128 .19987 L
.49568 .20137 L
.49689 .20178 L
.49819 .20222 L
.49941 .20263 L
.50054 .20264 L
.50162 .20228 L
.5028 .20188 L
.50518 .20108 L
.51011 .19939 L
.52052 .19573 L
.53945 .18877 L
.5607 .18045 L
.58001 .17239 L
.58965 .16818 L
.60009 .16346 L
.60489 .16125 L
.60996 .15887 L
.61429 .15681 L
.61548 .15624 L
.61675 .15562 L
.61796 .15504 L
.61906 .30902 L
Mistroke
.62035 .30902 L
.62156 .30902 L
.62384 .30902 L
.62893 .30902 L
.63808 .30902 L
.65882 .30902 L
.69742 .30902 L
.73847 .30902 L
.77801 .30902 L
.81604 .30902 L
.85651 .30902 L
.89548 .30902 L
.93689 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0077oool00`1Vooooooooo`07oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Koooo00<0I_ooooooool0L?ooo`00LOooo`80I_l2oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01Woool306KoL_ooo`00LOooo`0406Ko
oooo06Ko06Ko1_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0H
oooo00@0I_ooooooool0I_mboooo001aoooo00@0I_ooooooooooool306Ko1?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0Foooo0P1Vo`?oool00`1Vooooooooo`1`oooo001aoooo00<0I_oooooo
ool01?ooo`80I_lEoooo0P0001Coool306Ko1Oooo`0306Kooooooooo073oool0077oool00`1Voooo
ooooo`06oooo0`1Voa;oool00`000?ooooooo`0@oooo0`1Vo`Soool00`1Vooooooooo`1`oooo001a
oooo00<0I_ooooooool02Oooo`80I_l@oooo00<0003oooooool03_ooo`80I_l;oooo00<0I_oooooo
ool0L?ooo`00LOooo`0306Kooooooooo00_oool306Ko3Oooo`030000oooooooo00_oool306Ko3Ooo
o`0306Kooooooooo073oool0077oool00`1Vooooooooo`0>oooo0P1Vo`_oool200002_ooo`80I_l@
oooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo013oool306Ko2?ooo`030000oooooooo
00Koool306Ko4_ooo`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Coooo0P1Vo`Koool0
0`000?ooooooo`04oooo0P1VoaGoool00`1Vooooooooo`1`oooo001aoooo00<0I_ooooooool05Ooo
o`<0I_l3oooo00<0003oooooool00_ooo`80I_lGoooo00<0I_ooooooool0L?ooo`00LOooo`0306Ko
oooooooo01Soool306Ko0P0000<0I_lIoooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo
01_oool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo01_oool0
0`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo01_oool00`000?oo
ooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo01_oool200007?ooo`0306Ko
oooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Kooooooooo
073oool0077oool00`1Vooooooooo`02oooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0506Kooooooooooooo000000;oool0
0`000?ooooooo`06oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
01_oool00`1Vooooooooo`1`oooo001aoooo00D0I_ooooooooooool000000_ooo`030000oooooooo
00Ooool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Koooo00<0I_ooooooool0L?oo
o`00Koooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool06oooo`0306Kooooooooo073oool0077oool01@1Vooooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0K
oooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo00;oool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo01_oool2
00007?ooo`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06ooo
o`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Ko
oooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Kooooooooo
073oool001Soool200009Oooo`@0000Uoooo1@0000Coool00`1Vooooooooo`0Koooo0P0001coool0
0`1Vooooooooo`05oooo1@0002?oool400009_ooo`80000Goooo000Goooo00@0003oooooool0000T
oooo00<0003oooooool0:?ooo`030000oooooooo00Coool00`1Vooooooooo`0Koooo00<0003ooooo
ool06oooo`0306Kooooooooo00Ooool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`040000
oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0003ooooo
ool01?ooo`0306Kooooooooo01_oool00`000?ooooooo`0Koooo00<0I_ooooooool01oooo`030000
oooooooo02Coool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0
003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool01?oo
o`0306Kooooooooo01_oool00`000?ooooooo`0Koooo00<0I_ooooooool01oooo`030000oooooooo
02Goool00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?oo
o`040000oooooooo00009oooo`030000oooooooo00Coool00`1Vooooooooo`0Koooo0P0001coool0
0`1Vooooooooo`07oooo00<0003oooooool08oooo`040000oooooooo00009Oooo`040000oooooooo
00005_ooo`006?ooo`80000Voooo0P0002Ooool200001_ooo`0306Kooooooooo01_oool00`000?oo
ooooo`0Koooo00<0I_ooooooool01_ooo`80000Voooo0P0002Ooool200005oooo`00LOooo`0306Ko
oooooooo01_oool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00LOooo`0306Kooooooooo
01_oool200007?ooo`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003ooooo
ool06oooo`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06ooo
o`0306Kooooooooo073oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Ko
oooooooo073oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Koooo00?o
09Woooooool01oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`
oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P00
01coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
07Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo001eoooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300006oooo`03o`2Ioooooooo073oool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0K
oooo00?o09Woooooool0L?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P00
01coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?oo
o`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`
oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0000Koooo00?o09Woooooool0L?ooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007coool200002_oo
o`<00004oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool200007?ooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P00
01coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool300006oooo`03o`2Ioooooooo073oool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000L
oooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo
01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Wooooo
ool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo0027oooo1@0000?oool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00ROooo`030000oooooooo00?oool300006oooo`03o`2I
oooooooo073oool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800005
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Woool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002Oooo`@00003oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61445 .30902 L
.61984 .30902 L
.62236 .30902 L
.62502 .30902 L
.6257 .30902 L
.62642 .30902 L
s
.62642 .30902 m
.6265 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.36626 .30902 L
.36876 .30902 L
.37114 .30902 L
.37178 .30902 L
.37247 .30902 L
.37323 .15461 L
.37393 .15495 L
.37649 .15619 L
.3815 .15858 L
.42308 .17705 L
.46315 .1927 L
.48153 .19924 L
.48656 .20097 L
.49196 .20279 L
.49457 .20366 L
.49705 .20448 L
.49813 .20484 L
.49928 .20521 L
.50054 .20527 L
.5017 .20489 L
.52164 .19814 L
.5427 .19054 L
.58045 .17557 L
.60143 .16646 L
.61061 .16228 L
.61547 .16001 L
.62066 .15756 L
.62329 .1563 L
.62458 .15567 L
.62577 .1551 L
.62685 .15457 L
.628 .30902 L
.62915 .30902 L
.63042 .30902 L
.6395 .30902 L
.65934 .30902 L
.69968 .30902 L
.73851 .30902 L
.77978 .30902 L
Mistroke
.81954 .30902 L
.85779 .30902 L
.89849 .30902 L
.93767 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006ooool00`1Vooooooooo`09oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Moooo00<0I_ooooooool0K_ooo`00Koooo`<0I_l3oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01coool206KoL?ooo`00Koooo`0306Ko
oooooooo0080I_l7oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01Woool306Ko00?oool0I_ooool0Koooo`00Koooo`0306Kooooooooo00;oool206Ko1_ooo`80000:
oooo0`0000Coool00`000?ooooooo`0Goooo0P1Vo`Coool00`1Vooooooooo`1^oooo001_oooo00<0
I_ooooooool01?ooo`80I_lGoooo0P0001Koool206Ko1_ooo`0306Kooooooooo06koool006ooool0
0`1Vooooooooo`06oooo0P1VoaGoool00`000?ooooooo`0Coooo0P1Vo`Soool00`1Vooooooooo`1^
oooo001_oooo00<0I_ooooooool02?ooo`<0I_lBoooo00<0003oooooool04?ooo`<0I_l:oooo00<0
I_ooooooool0K_ooo`00Koooo`0306Kooooooooo00_oool306Ko3oooo`030000oooooooo00goool3
06Ko3Oooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0>oooo0P1Vo`goool200002ooo
o`<0I_l@oooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo013oool306Ko2_ooo`030000
oooooooo00Ooool306Ko4oooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Coooo0P1V
o`Soool00`000?ooooooo`04oooo0`1VoaKoool00`1Vooooooooo`1^oooo001_oooo00<0I_oooooo
ool05Oooo`80I_l6oooo00@0003oooooooooool306Ko6Oooo`0306Kooooooooo06koool006ooool0
0`1Vooooooooo`0Goooo1@1Vo`03oooo000000000080I_lLoooo00<0I_ooooooool0K_ooo`00Kooo
o`0306Kooooooooo01coool00`1Vo`00001Vo`0Noooo00<0I_ooooooool0K_ooo`00Koooo`0306Ko
oooooooo01goool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo
01goool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo01goool2
00007_ooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Ooo
o`0306Kooooooooo06koool006ooool00`1Vooooooooo`04oooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo
00?oool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0
003oooooool07Oooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`03oooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300007Oooo`0306Kooooooooo
06koool006ooool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo01goool00`1Vooooooooo`1^oooo001_oooo00<0I_ooooooool00oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0M
oooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo00Coool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo01goool2
00007_ooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Ooo
o`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Oooo`0306Ko
oooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Oooo`0306Kooooooooo
06koool001Soool200009Oooo`@0000Uoooo1@0000;oool00`1Vooooooooo`0Moooo0P0001koool0
0`1Vooooooooo`03oooo1@0002?oool400009_ooo`80000Goooo000Goooo00@0003oooooool0000T
oooo00<0003oooooool0:?ooo`030000oooooooo00;oool00`1Vooooooooo`0Moooo00<0003ooooo
ool07Oooo`0306Kooooooooo00Goool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`040000
oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0003ooooo
ool00_ooo`0306Kooooooooo01goool00`000?ooooooo`0Moooo00<0I_ooooooool01Oooo`030000
oooooooo02Coool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0
003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool00_oo
o`0306Kooooooooo01goool00`000?ooooooo`0Moooo00<0I_ooooooool01Oooo`030000oooooooo
02Goool00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?oo
o`040000oooooooo00009oooo`030000oooooooo00;oool00`1Vooooooooo`0Moooo0P0001koool0
0`1Vooooooooo`05oooo00<0003oooooool08oooo`040000oooooooo00009Oooo`040000oooooooo
00005_ooo`006?ooo`80000Voooo0P0002Ooool200001?ooo`0306Kooooooooo01goool00`000?oo
ooooo`0Moooo00<0I_ooooooool01?ooo`80000Voooo0P0002Ooool200005oooo`00Koooo`0306Ko
oooooooo01goool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00Koooo`0306Kooooooooo
01goool200007_ooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003ooooo
ool07Oooo`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Ooo
o`0306Kooooooooo06koool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Oooo`0306Ko
oooooooo06koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Moooo00?o
09Woooooool01Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOoo
ooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o
09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P00
01koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
07Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001eoooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300007Oooo`03o`2Ioooooooo06koool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0M
oooo00?o09Woooooool0K_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P00
01koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
08ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool0
0ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_oo
o`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOoo
ooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Moooo00?o
09Woooooool0K_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0000Moooo00?o09Woooooool0K_ooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007coool200002_oo
o`<00004oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool200007_ooo`03o`2I
oooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o
09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P00
01koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
08ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool0
0ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo01goool0
0ol0VOooooooo`1^oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool300007Oooo`03o`2Ioooooooo06koool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000Noooo00?o09Woooooool0K_ooo`00Sooo
o`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000N
oooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o
09Woooooool0K_ooo`00Soooo`80000Noooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo
01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
08ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000Noooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo0027oooo1@0000?oool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00ROooo`030000oooooooo00?oool300007Oooo`03o`2I
oooooooo06koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000koool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61984 .30902 L
.6254 .30902 L
.62812 .30902 L
.63064 .30902 L
.63292 .30902 L
.63407 .30902 L
s
.63407 .30902 m
.6342 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.35742 .30902 L
.36173 .30902 L
.36284 .30902 L
.36405 .30902 L
.3652 .15457 L
.36626 .15508 L
.37114 .15743 L
.3815 .1623 L
.42063 .17931 L
.46221 .19523 L
.48308 .20247 L
.49223 .2055 L
.49474 .20632 L
.49743 .20718 L
.49873 .2076 L
.49996 .20799 L
.50107 .20766 L
.50228 .20728 L
.52102 .20109 L
.54083 .19414 L
.58161 .17839 L
.60186 .16979 L
.61178 .16537 L
.62088 .16119 L
.62973 .15702 L
.63188 .15598 L
.63306 .15541 L
.63418 .15487 L
.6355 .30902 L
.6367 .30902 L
.63904 .30902 L
.65863 .30902 L
.69709 .30902 L
.73801 .30902 L
.77742 .30902 L
.8153 .30902 L
.85564 .30902 L
.89447 .30902 L
.93574 .30902 L
Mistroke
.9755 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006goool00`1Vooooooooo`0;oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Ooooo00<0I_ooooooool0K?ooo`00KOooo`<0I_l5oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01koool206KoK_ooo`00KOooo`0306Ko
oooooooo0080I_l9oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01_oool306Ko00?oool0I_ooool0KOooo`00KOooo`0306Kooooooooo00;oool206Ko2?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0Ioooo0P1Vo`Coool00`1Vooooooooo`1/oooo001]oooo00<0
I_ooooooool01?ooo`80I_lIoooo0P0001Ooool306Ko1_ooo`0306Kooooooooo06coool006goool0
0`1Vooooooooo`06oooo0P1VoaOoool00`000?ooooooo`0Doooo0P1Vo`Woool00`1Vooooooooo`1/
oooo001]oooo00<0I_ooooooool02?ooo`80I_lEoooo00<0003oooooool04Oooo`<0I_l;oooo00<0
I_ooooooool0K?ooo`00KOooo`0306Kooooooooo00[oool306Ko4_ooo`030000oooooooo00koool3
06Ko3_ooo`0306Kooooooooo06coool006goool00`1Vooooooooo`0=oooo0P1Voa3oool200003Ooo
o`80I_lAoooo00<0I_ooooooool0K?ooo`00KOooo`0306Kooooooooo00ooool306Ko3Oooo`030000
oooooooo00Woool306Ko4oooo`0306Kooooooooo06coool006goool00`1Vooooooooo`0Boooo0P1V
o`_oool00`000?ooooooo`06oooo0`1VoaKoool00`1Vooooooooo`1/oooo001]oooo00<0I_oooooo
ool05?ooo`@0I_l7oooo00<0003oooooool01?ooo`80I_lIoooo00<0I_ooooooool0K?ooo`00KOoo
o`0306Kooooooooo01Soool406Ko0oooo`800003oooo0P1Voa_oool00`1Vooooooooo`1/oooo001]
oooo00<0I_ooooooool07?ooo`<0I_l00`000?ooooooo`0206Ko7Oooo`0306Kooooooooo06coool0
06goool00`1Vooooooooo`0Noooo00@0I_l00000I_l0I_lOoooo00<0I_ooooooool0K?ooo`00KOoo
o`0306Kooooooooo01ooool00`000?ooooooo`0Ooooo00<0I_ooooooool0K?ooo`00KOooo`0306Ko
oooooooo01ooool200008?ooo`0306Kooooooooo06coool006goool00`1Vooooooooo`0Ooooo00<0
003oooooool07oooo`0306Kooooooooo06coool006goool00`1Vooooooooo`06oooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Ooooo00<0I_ooooooool0K?ooo`00KOoo
o`0306Kooooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool07oooo`0306Kooooooooo06coool006goool00`1Vooooooooo`05
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300007ooo
o`0306Kooooooooo06coool006goool00`1Vooooo`00000300000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo01ooool00`1Vooooooooo`1/oooo001]
oooo00<0I_ooooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`0Ooooo00<0I_ooooooool0K?ooo`00KOooo`0306Kooooooooo
00Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Ooooo00<0I_ooooooool0K?oo
o`00KOooo`0306Kooooooooo01ooool200008?ooo`0306Kooooooooo06coool006goool00`1Voooo
ooooo`0Ooooo00<0003oooooool07oooo`0306Kooooooooo06coool006goool00`1Vooooooooo`0O
oooo00<0003oooooool07oooo`0306Kooooooooo06coool006goool00`1Vooooooooo`0Ooooo00<0
003oooooool07oooo`0306Kooooooooo06coool001Soool200009Oooo`@0000Uoooo1@00000306Ko
oooooooo01ooool200008?ooo`0406Kooooooooooooo1@0002?oool400009_ooo`80000Goooo000G
oooo00@0003oooooool0000Toooo00<0003oooooool0:?ooo`040000oooooooo06Ko8Oooo`030000
oooooooo01ooool00`1Vooooooooo`03oooo00<0003oooooool08oooo`030000oooooooo02Koool0
10000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool09oooo`040000
oooooooo06Ko8Oooo`030000oooooooo01ooool00`1Vooooooooo`03oooo00<0003oooooool09?oo
o`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0L
oooo100000Coool00`000?ooooooo`0Noooo100000Coool010000?ooooooo`1Vob7oool00`000?oo
ooooo`0Ooooo00<0I_ooooooool00oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00<0
003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00009oooo`040000
oooooooo06Ko8Oooo`80000Poooo00<0I_ooooooool00oooo`030000oooooooo02?oool010000?oo
ooooo`0002Goool010000?ooooooo`0001Koool001Soool200009_ooo`80000Woooo0P0000;oool0
0`1Vooooooooo`0Ooooo00<0003oooooool07oooo`0306Kooooooooo00;oool200009_ooo`80000W
oooo0P0001Ooool006goool00`1Vooooooooo`0Ooooo00<0003oooooool07oooo`0306Kooooooooo
06coool006goool00`1Vooooooooo`0Ooooo0P00023oool00`1Vooooooooo`1/oooo001]oooo00<0
I_ooooooool07oooo`030000oooooooo01ooool00`1Vooooooooo`1/oooo001]oooo00<0I_oooooo
ool07oooo`030000oooooooo01ooool00`1Vooooooooo`1/oooo001]oooo00<0I_ooooooool07ooo
o`030000oooooooo01ooool00`1Vooooooooo`1/oooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003ooooo09T01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool07oooo`03o`2Ioooooooo00?oool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?oo
o`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?oo
ooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Sooo
o`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2I
oooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000P
oooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?
oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o
09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo
01ooool00ol0VOooooooo`1/oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Ooooo00?o09Woooooool0K?oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
01ooool00ol0VOooooooo`1/oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool07oooo`03o`2I
oooooooo06coool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Ooooo00?o
09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo
01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool0
08ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Wooooo
ool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003ooooo
ool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?oo
o`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?oo
ooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Sooo
o`030000oooooooo01ooool00ol0VOooooooo`1/oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool300007oooo`03o`2Ioooooooo06coool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo001loooo0P0000[oool300001?ooo`030000oooooooo01ooool00ol0VOooooooo`1/
oooo002?oooo0P00023oool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2I
oooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000P
oooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?
oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o
09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo
01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool0
08ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000Poooo00?o09Wooooo
ool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo01ooool00ol0VOooooooo`1/
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0001ooool00ol0VOooooooo`1/oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo01ooool0
0ol0VOooooooo`1/oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool200008?oo
o`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Sooo
o`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2I
oooooooo06coool008ooool200008?ooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0O
oooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?
oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool200008?ooo`03o`2Ioooooooo
06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo
01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool0
08ooool200008?ooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Wooooo
ool0K?ooo`00Qoooo`D00003oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008Woool0
0`000?ooooooo`03oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008Woool00`000?oo
ooooo`03oooo0`0001ooool00ol0VOooooooo`1/oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@0000;oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool01oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.63527 .30902 L
.63796 .30902 L
.64043 .30902 L
.64164 .30902 L
.64277 .30902 L
s
.64277 .30902 m
.64289 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35028 .30902 L
.35271 .30902 L
.35496 .30902 L
.35624 .30902 L
.35742 .15464 L
.35852 .15518 L
.35951 .15566 L
.36173 .15673 L
.3815 .16592 L
.42157 .18289 L
.46012 .19731 L
.47966 .20398 L
.49002 .20735 L
.49275 .20822 L
.49572 .20916 L
.49708 .20959 L
.49852 .21004 L
.49976 .21042 L
.50046 .21036 L
.50112 .21015 L
.5118 .20677 L
.52154 .20358 L
.54061 .19705 L
.57929 .18254 L
.59894 .17447 L
.62043 .16505 L
.63036 .16047 L
.63581 .1579 L
.63849 .15662 L
.63967 .15605 L
.64096 .15543 L
.64217 .15484 L
.64329 .30902 L
.64448 .30902 L
.64576 .30902 L
.65097 .30902 L
.66006 .30902 L
.70134 .30902 L
Mistroke
.7411 .30902 L
.77934 .30902 L
.82004 .30902 L
.85922 .30902 L
.90085 .30902 L
.94097 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006_oool00`1Vooooooooo`0=oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Qoooo00<0I_ooooooool0J_ooo`00Joooo`<0I_l7oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01ooool306KoK?ooo`00Joooo`0306Ko
oooooooo0080I_l;oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01koool0101Vooooooooo`1Vofcoool006_oool00`1Vooooooooo`02oooo0`1Vo`Woool200002_oo
o`<00004oooo00<0003oooooool06oooo`<0I_l3oooo00<0I_ooooooool0J_ooo`00Joooo`0306Ko
oooooooo00Goool206Ko6_ooo`80000Ioooo0`1Vo`Koool00`1Vooooooooo`1Zoooo001[oooo00<0
I_ooooooool01oooo`<0I_lGoooo00<0003oooooool05Oooo`<0I_l9oooo00<0I_ooooooool0J_oo
o`00Joooo`0306Kooooooooo00[oool206Ko5Oooo`030000oooooooo01?oool206Ko3?ooo`0306Ko
oooooooo06[oool006_oool00`1Vooooooooo`0<oooo0`1Voa;oool00`000?ooooooo`0@oooo0`1V
o`koool00`1Vooooooooo`1Zoooo001[oooo00<0I_ooooooool03oooo`80I_l@oooo0P0000ooool2
06Ko4Oooo`0306Kooooooooo06[oool006_oool00`1Vooooooooo`0Aoooo0`1Vo`goool00`000?oo
ooooo`0;oooo0`1Voa?oool00`1Vooooooooo`1Zoooo001[oooo00<0I_ooooooool05?ooo`80I_l;
oooo00<0003oooooool02Oooo`80I_lFoooo00<0I_ooooooool0J_ooo`00Joooo`0306Kooooooooo
01Koool306Ko2?ooo`030000oooooooo00Koool306Ko6?ooo`0306Kooooooooo06[oool006_oool0
0`1Vooooooooo`0Ioooo0P1Vo`Koool200001Oooo`80I_lKoooo00<0I_ooooooool0J_ooo`00Jooo
o`0306Kooooooooo01_oool206Ko1?ooo`030000oooo06Ko00@0I_lMoooo00<0I_ooooooool0J_oo
o`00Joooo`0306Kooooooooo01goool406Ko00<00000I_ooool08Oooo`0306Kooooooooo06[oool0
06_oool00`1Vooooooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006_oool0
0`1Vooooooooo`0Qoooo0P0002;oool00`1Vooooooooo`1Zoooo001[oooo00<0I_ooooooool08Ooo
o`030000oooooooo027oool00`1Vooooooooo`1Zoooo001[oooo00<0I_ooooooool02?ooo`800004
oooo0P0000?oool400000oooo`800005oooo00<0003oooooool08Oooo`0306Kooooooooo06[oool0
06_oool00`1Vooooooooo`07oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo027oool00`1Vooooooooo`1Zoooo001[oooo00<0I_oooooo
ool01oooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
027oool00`1Vooooooooo`1Zoooo001[oooo00@0I_ooooooooooool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo027oool00`1Vooooooooo`1Z
oooo001[oooo00<0I_ooooooool01oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_ooo`00Joooo`0306Ko
oooooooo00Soool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Qoooo00<0I_oooooo
ool0J_ooo`00Joooo`0306Kooooooooo027oool200008_ooo`0306Kooooooooo06[oool006_oool0
0`1Vooooooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006_oool00`1Voooo
ooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006_oool00`1Vooooooooo`0Q
oooo00<0003oooooool08Oooo`0306Kooooooooo06[oool001Soool200009Oooo`@0000Uoooo1@00
02;oool200008_ooo`0306Kooooo000000@0000Soooo100002Koool200005oooo`005oooo`040000
oooooooo00009?ooo`030000oooooooo02Soool00`00001Vooooo`0Roooo00<0003oooooool08Ooo
o`0506Kooooooooooooo000002Goool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000I
oooo00<0003oooooool09?ooo`030000oooooooo02Ooool00`00001Vooooo`0Roooo00<0003ooooo
ool08Oooo`0506Kooooooooooooo000002Koool00`000?ooooooo`0Woooo00<0003oooooool05Ooo
o`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004
oooo00<00000I_ooool08_ooo`030000oooooooo027oool01@1Vooooooooooooo`00000Woooo00<0
003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool010000?oo
ooooo`0002Ooool00`00001Vooooo`0Roooo0P0002;oool01@1Vooooooooooooo`00000Uoooo00@0
003oooooool0000Uoooo00@0003oooooool0000Foooo000Hoooo0P0002Koool200009oooo`800000
0`1Vooooooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo0080000Voooo0P0002Ooool2
00005oooo`00Joooo`0306Kooooooooo027oool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_oo
o`00Joooo`0306Kooooooooo027oool200008_ooo`0306Kooooooooo06[oool006_oool00`1Voooo
ooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006_oool00`1Vooooooooo`0Q
oooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006_oool00`1Vooooooooo`0Qoooo00<0
003oooooool08Oooo`0306Kooooooooo06[oool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool01@000?oo
ooooooooool0V@03oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo
02Goool00`000?ooooooo`0Qoooo00Go09Woooooooooool000009oooo`030000oooooooo02Koool0
0`000?ooooooo`0Eoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool2
00008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Ooo
o`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007Goool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Qoooo00?o
09Woooooool0J_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo027oool00ol0VOooooooo`1Zoooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool2
00008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Ooo
o`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo001koooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`00027oool00ol0VOooooooo`1Zoooo001koooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Sooo
o`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00M_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00MOoo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0000Qoooo00?o09Woooooool0J_ooo`00MOooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0J_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00M_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P00
02;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08Ooool500000oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0029oooo00<0003oooooool00ooo
o`<0000Qoooo00?o09Woooooool0J_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Soool300001?ooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.64043 .30902 L
.64559 .30902 L
.64812 .30902 L
.64923 .30902 L
.65045 .30902 L
s
.65045 .30902 m
.65056 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34309 .30902 L
.34566 .30902 L
.34693 .30902 L
.34811 .30902 L
.34918 .30902 L
.35031 .15505 L
.35157 .15566 L
.35271 .15621 L
.36173 .16049 L
.3815 .16945 L
.42157 .186 L
.46012 .20007 L
.47966 .20657 L
.49002 .20986 L
.49275 .21071 L
.49572 .21163 L
.49708 .21204 L
.49852 .21248 L
.49976 .21286 L
.50046 .21279 L
.50112 .21259 L
.5118 .20929 L
.52154 .20618 L
.54061 .19982 L
.57929 .18567 L
.59894 .17779 L
.62043 .1686 L
.63036 .16414 L
.63581 .16163 L
.64096 .15922 L
.64576 .15694 L
.64708 .15631 L
.64847 .15564 L
.64966 .15506 L
.65097 .30902 L
.65215 .30902 L
.65323 .30902 L
.65566 .30902 L
.66006 .30902 L
Mistroke
.69982 .30902 L
.73806 .30902 L
.77876 .30902 L
.81794 .30902 L
.85958 .30902 L
.8997 .30902 L
.9383 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006Woool00`1Vooooooooo`0?oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Soooo00<0I_ooooooool0J?ooo`00JOooo`80I_l:oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo027oool306KoJ_ooo`00JOooo`0306Ko
oooo06Ko0080I_l=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01ooool206Ko0_ooo`0306Kooooooooo06Soool006Woool00`1Vooooooooo`02oooo0P1Vo`coool2
00002_ooo`<00004oooo00<0003oooooool07_ooo`0306Kooooooooo00;oool00`1Vooooooooo`1X
oooo001Yoooo00<0I_ooooooool01?ooo`<0I_lLoooo0P0001coool306Ko1Oooo`0306Kooooooooo
06Soool006Woool00`1Vooooooooo`07oooo0P1Voa[oool00`000?ooooooo`0Hoooo0`1Vo`Soool0
0`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool02Oooo`<0I_lGoooo00<0003oooooool05Ooo
o`<0I_l;oooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo00coool206Ko5Oooo`030000
oooooooo01?oool206Ko3_ooo`0306Kooooooooo06Soool006Woool00`1Vooooooooo`0>oooo0`1V
oa;oool200004Oooo`<0I_l@oooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo017oool2
06Ko4?ooo`030000oooooooo00koool206Ko4oooo`0306Kooooooooo06Soool006Woool00`1Voooo
ooooo`0Coooo0`1Vo`goool00`000?ooooooo`0;oooo0`1VoaGoool00`1Vooooooooo`1Xoooo001Y
oooo00<0I_ooooooool05_ooo`80I_l;oooo00<0003oooooool02Oooo`80I_lHoooo00<0I_oooooo
ool0J?ooo`00JOooo`0306Kooooooooo01Soool406Ko1oooo`800006oooo101Voa[oool00`1Voooo
ooooo`1Xoooo001Yoooo00<0I_ooooooool07?ooo`<0I_l4oooo00<0003oooooool00_ooo`<0I_lN
oooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo01ooool306Ko00?oool0003oool00`1V
ob7oool00`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool08_ooo`0306Ko000006Ko02Coool0
0`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool08oooo`80000Toooo00<0I_ooooooool0J?oo
o`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00JOoo
o`0306Kooooooooo00[oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
02?oool00`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool02Oooo`040000oooooooo00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Soooo00<0I_oooooo
ool0J?ooo`00JOooo`0306Kooooooooo00Woool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0000Soooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo
00?oool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo02?oool00`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool02Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Soooo00<0
I_ooooooool0J?ooo`00JOooo`0306Kooooooooo00[oool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo02?oool200009?oo
o`0306Kooooooooo06Soool006Woool00`1Vooooooooo`0Soooo00<0003oooooool08oooo`0306Ko
oooooooo06Soool006Woool00`1Vooooooooo`0Soooo00<0003oooooool08oooo`0306Kooooooooo
06Soool006Woool00`1Vooooooooo`0Soooo00<0003oooooool08oooo`0306Kooooooooo06Soool0
01Soool200009Oooo`@0000Uoooo1@0002;oool200009?ooo`D0000Soooo100002Koool200005ooo
o`005oooo`040000oooooooo00009?ooo`030000oooooooo02Ooool00`1Vo`000?ooo`0Soooo00<0
003oooooool08oooo`0306Kooooo000002Goool00`000?ooooooo`0Voooo00@0003oooooool0000F
oooo000Ioooo00<0003oooooool09?ooo`030000oooooooo02Koool00`1Vo`000?ooo`0Soooo00<0
003oooooool08oooo`0306Kooooo000002Koool00`000?ooooooo`0Woooo00<0003oooooool05Ooo
o`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00003
oooo00<0I_l0003oool08oooo`030000oooooooo02?oool00`1Vooooo`00000Woooo00<0003ooooo
ool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool010000?ooooooo`00
02Koool00`1Vo`000?ooo`0Soooo0P0002Coool00`1Vooooo`00000Uoooo00@0003oooooool0000U
oooo00@0003oooooool0000Foooo000Hoooo0P0002Koool200009oooo`80000Toooo00<0003ooooo
ool08oooo`0306Ko0000000002Koool200009oooo`80000Goooo001Yoooo00<0I_ooooooool08ooo
o`030000oooooooo02?oool00`1Vooooooooo`1Xoooo001Yoooo00<0I_ooooooool08oooo`80000T
oooo00<0I_ooooooool0J?ooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0
I_ooooooool0J?ooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_oooooo
ool0J?ooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_ooooooool0J?oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo02?oool00ol0VOooo`00000W
oooo00<0003oooooool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Wooooo
ool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?oo
o`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?oo
ooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0002?oool00ol0VOooooooo`1Xoooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000T
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Wooooo
ool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Soooo00?o09Woooooool0J?oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool300008oooo`03o`2Ioooooooo
06Soool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo001loooo0P0000[oool300001?ooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?oo
o`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?oo
ooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000T
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0002?oool00ol0VOoo
ooooo`1Xoooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo02?oool00ol0VOooooooo`1Xoooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Wooooo
ool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool200009?oo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Qoooo`D00003oooo00<0003oooooool08oooo`03o`2Ioooooooo
06Soool008Woool00`000?ooooooo`03oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08Woool00`000?ooooooo`03oooo0`0002?oool00ol0VOooooooo`1Xoooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08
oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.64043 .30902 L
.64559 .30902 L
.65045 .30902 L
.65482 .30902 L
.65602 .30902 L
.65728 .30902 L
.65836 .30902 L
s
.65836 .30902 m
.65848 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33823 .30902 L
.33953 .30902 L
.34076 .30902 L
.34187 .1548 L
.34309 .15539 L
.38373 .17385 L
.42286 .18953 L
.44283 .19681 L
.46444 .2042 L
.48354 .21032 L
.48878 .21193 L
.49439 .21363 L
.49711 .21444 L
.49844 .21484 L
.49968 .21521 L
.5008 .21507 L
.50199 .21471 L
.50451 .21396 L
.52445 .2078 L
.54551 .20086 L
.58326 .1872 L
.60424 .17888 L
.62347 .17075 L
.64231 .1623 L
.65179 .15785 L
.65438 .15661 L
.65581 .15592 L
.65716 .15527 L
.65841 .15466 L
.65912 .30902 L
.65977 .30902 L
.66215 .30902 L
.70156 .30902 L
.73944 .30902 L
.77978 .30902 L
.81861 .30902 L
.85988 .30902 L
Mistroke
.89964 .30902 L
.93789 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006Ooool00`1Vooooooooo`0Aoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Uoooo00<0I_ooooooool0I_ooo`00Ioooo`<0I_l;oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02?oool306KoJ?ooo`00Ioooo`0306Ko
oooooooo0080I_l?oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
023oool306Ko0_ooo`0306Kooooooooo06Koool006Ooool00`1Vooooooooo`02oooo0P1Vo`koool2
00002_ooo`<00004oooo00<0003oooooool07_ooo`80I_l5oooo00<0I_ooooooool0I_ooo`00Iooo
o`0306Kooooooooo00Coool206Ko7oooo`80000Loooo0`1Vo`Ooool00`1Vooooooooo`1Voooo001W
oooo00<0I_ooooooool01_ooo`<0I_lLoooo00<0003oooooool06Oooo`80I_l:oooo00<0I_oooooo
ool0I_ooo`00Ioooo`0306Kooooooooo00Woool206Ko6_ooo`030000oooooooo01Ooool206Ko3?oo
o`0306Kooooooooo06Koool006Ooool00`1Vooooooooo`0;oooo0`1VoaOoool00`000?ooooooo`0E
oooo0P1Vo`koool00`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool03_ooo`80I_lEoooo0P00
01Coool206Ko4?ooo`0306Kooooooooo06Koool006Ooool00`1Vooooooooo`0@oooo0`1Voa;oool0
0`000?ooooooo`0Aoooo0P1Voa;oool00`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool04ooo
o`80I_l@oooo00<0003oooooool03_ooo`<0I_lDoooo00<0I_ooooooool0I_ooo`00Ioooo`0306Ko
oooooooo01Goool306Ko3Oooo`030000oooooooo00_oool306Ko5oooo`0306Kooooooooo06Koool0
06Ooool00`1Vooooooooo`0Hoooo0`1Vo`[oool200002Oooo`<0I_lJoooo00<0I_ooooooool0I_oo
o`00Ioooo`0306Kooooooooo01_oool406Ko1_ooo`030000oooooooo00Goool306Ko7Oooo`0306Ko
oooooooo06Koool006Ooool00`1Vooooooooo`0Ooooo0`1Vo`?oool010000?ooooooooooo`@0I_lP
oooo00<0I_ooooooool0I_ooo`00Ioooo`0306Kooooooooo02;oool306Ko00@00000I_l0I_l0I_lT
oooo00<0I_ooooooool0I_ooo`00Ioooo`0306Kooooooooo02Goool200009_ooo`0306Kooooooooo
06Koool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool09Oooo`0306Kooooooooo06Koool0
06Ooool00`1Vooooooooo`0<oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`0Uoooo00<0I_ooooooool0I_ooo`00Ioooo`0306Kooooooooo00_oool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool09Oooo`0306Ko
oooooooo06Koool006Ooool00`1Vooooooooo`0;oooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool300009Oooo`0306Kooooooooo06Koool006Ooool00`1Voooo
ooooo`05oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0Uoooo00<0I_ooooooool0I_ooo`00Ioooo`0306Kooooooooo00_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool09Ooo
o`0306Kooooooooo06Koool006Ooool00`1Vooooooooo`0<oooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool09Oooo`0306Kooooooooo06Koool006Ooool00`1Vooooooooo`0Uoooo0P00
02Koool00`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02Goool0
0`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02Goool00`1Voooo
ooooo`1Voooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02Goool00`1Vooooooooo`1V
oooo000Hoooo0P0002Goool400009?ooo`0306Ko0000000000<0000Roooo0P0002Coool500008ooo
o`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Uoooo00@0
I_ooooooool0000Toooo00<0003oooooool09Oooo`030000oooooooo02?oool00`000?ooooooo`0V
oooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool09?ooo`030000oooooooo02Coool0
101Vooooooooo`0002Coool00`000?ooooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo
02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool0
0`000?ooooooo`0Noooo10000005oooo06Kooooooooo000002Coool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0003ooooo
ool0000Toooo00@0003oooooool0000Toooo00@0I_ooooooool0000Toooo0P0002Koool00`000?oo
ooooo`0Soooo00@0003oooooool0000Uoooo00@0003oooooool0000Foooo000Hoooo0P0002Koool2
00009Oooo`0406Kooooo000000009?ooo`030000oooooooo02Coool200009_ooo`80000Woooo0P00
01Ooool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool09Oooo`0306Kooooooooo06Koool0
06Ooool00`1Vooooooooo`0Uoooo0P0002Koool00`1Vooooooooo`1Voooo001Woooo00<0I_oooooo
ool09Oooo`030000oooooooo02Goool00`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool09Ooo
o`030000oooooooo02Goool00`1Vooooooooo`1Voooo001Woooo00<0I_ooooooool09Oooo`030000
oooooooo02Goool00`1Vooooooooo`1Voooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOoo
ooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?oo
ooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1V
oooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2I
oooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000
oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?
oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o
09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P00
02Koool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool0
07Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo02Goool00ol0VOoo
ooooo`1Voooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo001eoooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300009Oooo`03o`2Ioooooooo06Koool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0U
oooo00?o09Woooooool0I_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P00
02Koool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool0
08ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool0
0ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?oooo00<0003ooooo
ool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_oo
o`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOoo
ooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?oo
ooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1V
oooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2I
oooooooo06Koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Uoooo00?o
09Woooooool0I_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo02Goool00ol0VOooooooo`1Voooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0000Uoooo00?o09Woooooool0I_ooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool007coool200002_oo
o`<00004oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool200009_ooo`03o`2I
oooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000
oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?
oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o
09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo0P00
02Koool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool0
08ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool0
0ol0VOooooooo`1Voooo002?oooo0P0002Koool00ol0VOooooooo`1Voooo002?oooo00<0003ooooo
ool09Oooo`03o`2Ioooooooo06Koool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo02Goool0
0ol0VOooooooo`1Voooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool300009Oooo`03o`2Ioooooooo06Koool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool09Oooo`03o`2Ioooooooo06Koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`80000Voooo00?o09Woooooool0I_ooo`00Sooo
o`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2I
oooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`80000V
oooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo002?
oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool008ooool00`000?ooooooo`0Uoooo00?o
09Woooooool0I_ooo`00Soooo`80000Voooo00?o09Woooooool0I_ooo`00Soooo`030000oooooooo
02Goool00ol0VOooooooo`1Voooo002?oooo00<0003oooooool09Oooo`03o`2Ioooooooo06Koool0
08ooool00`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00Soooo`80000Voooo00?o09Wooooo
ool0I_ooo`00Soooo`030000oooooooo02Goool00ol0VOooooooo`1Voooo0027oooo1@0000?oool0
0`000?ooooooo`0Uoooo00?o09Woooooool0I_ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Uoooo00?o09Woooooool0I_ooo`00ROooo`030000oooooooo00?oool300009Oooo`03o`2I
oooooooo06Koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0003ooooo
ool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_oo
o`00O_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004
oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`030000oooooooo00[oool00`000?ooooooo`1noooo001moooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool0OOoo
o`00O_ooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`030000oooooooo07koool0
07koool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool0O_oo
o`00Ooooo`030000oooooooo017oool200002Oooo`030000oooooooo07ooool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66177 .30902 L
.66412 .30902 L
.66534 .30902 L
.66604 .30902 L
s
.66604 .30902 m
.66611 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.32831 .30902 L
.33073 .30902 L
.33193 .30902 L
.33304 .30902 L
.33433 .15499 L
.33502 .15533 L
.33575 .15568 L
.33823 .15687 L
.34309 .15918 L
.38467 .17758 L
.42473 .19316 L
.46328 .20641 L
.48283 .21254 L
.48819 .21415 L
.49393 .21585 L
.49671 .21666 L
.49808 .21706 L
.49935 .21743 L
.50049 .21747 L
.50171 .21712 L
.50429 .21637 L
.54378 .2041 L
.58153 .19086 L
.62173 .1749 L
.64021 .16687 L
.65068 .1621 L
.65578 .15972 L
.66042 .15752 L
.66281 .15638 L
.66407 .15577 L
.6654 .15512 L
.66657 .15456 L
.66785 .30902 L
.66901 .30902 L
.67011 .30902 L
.68046 .30902 L
.70156 .30902 L
.74038 .30902 L
.78166 .30902 L
Mistroke
.82142 .30902 L
.85966 .30902 L
.90036 .30902 L
.93954 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006Goool00`1Vooooooooo`0Coooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Woooo00<0I_ooooooool0I?ooo`00IOooo`@0I_l<oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02Koool206KoI_ooo`00IOooo`0406Ko
oooooooooooo0P1Voa3oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool08oooo`<0I_l00oooo`1Vooooo`1Uoooo001Uoooo00<0I_ooooooool00oooo`80I_l?oooo0P00
00[oool300001?ooo`030000oooooooo023oool306Ko1?ooo`0306Kooooooooo06Coool006Goool0
0`1Vooooooooo`05oooo0P1Vob3oool200007oooo`80I_l7oooo00<0I_ooooooool0I?ooo`00IOoo
o`0306Kooooooooo00Ooool206Ko7_ooo`030000oooooooo01_oool306Ko2Oooo`0306Kooooooooo
06Coool006Goool00`1Vooooooooo`09oooo0`1Voa_oool00`000?ooooooo`0Ioooo0P1Vo`coool0
0`1Vooooooooo`1Toooo001Uoooo00<0I_ooooooool03?ooo`80I_lIoooo00<0003oooooool05_oo
o`<0I_l>oooo00<0I_ooooooool0I?ooo`00IOooo`0306Kooooooooo00koool306Ko5_ooo`80000E
oooo0P1Voa7oool00`1Vooooooooo`1Toooo001Uoooo00<0I_ooooooool04Oooo`80I_lDoooo00<0
003oooooool04Oooo`<0I_lCoooo00<0I_ooooooool0I?ooo`00IOooo`0306Kooooooooo01?oool3
06Ko4Oooo`030000oooooooo00ooool206Ko5_ooo`0306Kooooooooo06Coool006Goool00`1Voooo
ooooo`0Foooo0`1Vo`koool00`000?ooooooo`0<oooo0`1VoaSoool00`1Vooooooooo`1Toooo001U
oooo00<0I_ooooooool06Oooo`@0I_l:oooo0P0000_oool206Ko6oooo`0306Kooooooooo06Coool0
06Goool00`1Vooooooooo`0Moooo0`1Vo`Ooool00`000?ooooooo`07oooo0`1Voagoool00`1Voooo
ooooo`1Toooo001Uoooo00<0I_ooooooool08?ooo`80I_l5oooo00<0003oooooool01?ooo`<0I_lP
oooo00<0I_ooooooool0I?ooo`00IOooo`0306Kooooooooo02;oool306Ko0_ooo`030000oooooooo
00@0I_lSoooo00<0I_ooooooool0I?ooo`00IOooo`0306Kooooooooo02Goool206Ko0P00000306Ko
oooooooo02Goool00`1Vooooooooo`1Toooo001Uoooo00<0I_ooooooool09oooo`030000oooooooo
02Ooool00`1Vooooooooo`1Toooo001Uoooo00<0I_ooooooool03_ooo`800004oooo0P0000?oool4
00000oooo`800005oooo00<0003oooooool09oooo`0306Kooooooooo06Coool006Goool00`1Voooo
ooooo`0=oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?oo
o`030000oooooooo02Ooool00`1Vooooooooo`1Toooo001Uoooo00<0I_ooooooool03Oooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0002Soool00`1Voooo
ooooo`1Soooo001Uoooo00<0I_ooooooool01oooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0:?ooo`0306Kooooooooo06?oool006Goool0
0`1Vooooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo02Soool00`1Vooooooooo`1Soooo001Uoooo00<0I_ooooooool03_oo
o`80000:oooo0P0000Coool300001?ooo`030000oooooooo02Soool00`1Vooooooooo`1Soooo001U
oooo00<0I_ooooooool09oooo`80000Yoooo00<0I_ooooooool0Hoooo`00IOooo`0306Kooooooooo
02Ooool00`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00IOooo`0306Kooooooooo02Ooool0
0`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00IOooo`0306Kooooooooo02Ooool00`000?oo
ooooo`0Xoooo00<0I_ooooooool0Hoooo`006?ooo`80000Uoooo100002;oool00`1Vooooooooo`05
00008_ooo`80000Toooo1@00000306Kooooooooo023oool400009_ooo`80000Goooo000Goooo00@0
003oooooool0000Toooo00<0003oooooool08oooo`0306Kooooooooo00;oool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`040000oooooooo06Ko8_ooo`030000oooooooo02Koool010000?oo
ooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool08_ooo`0306Kooooooooo
00;oool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`040000oooooooo06Ko8oooo`030000
oooooooo02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo1000
00Coool00`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Ooo
o`040000oooooooo06Ko9?ooo`030000oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0
003oooooool0000Toooo00@0003oooooool0000Roooo00<0I_ooooooool00_ooo`030000oooooooo
02;oool200009_ooo`040000oooooooo06Ko8_ooo`040000oooooooo00009Oooo`040000oooooooo
00005_ooo`006?ooo`80000Voooo0P0002?oool0101Vooooooooooooo`80000Toooo00<0003ooooo
ool09?ooo`800002oooo00<0I_ooooooool08Oooo`80000Woooo0P0001Ooool006Goool00`1Voooo
ooooo`0Woooo00<0003oooooool0:?ooo`0306Kooooooooo06?oool006Goool00`1Vooooooooo`0W
oooo0P0002Woool00`1Vooooooooo`1Soooo001Uoooo00<0I_ooooooool09oooo`030000oooooooo
02Soool00`1Vooooooooo`1Soooo001Uoooo00<0I_ooooooool09oooo`030000oooooooo02Soool0
0`1Vooooooooo`1Soooo001Uoooo00<0I_ooooooool09oooo`030000oooooooo02Soool00`1Voooo
ooooo`1Soooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
ooooo`2I02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0
003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool0
0ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Sooo
o`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool300009oooo`03o`2Ioooooooo06Coool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?
oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0
003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool0
0ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Woooo00?o
09Woooooool0I?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool09oooo`03o`2Ioooooooo06Coool007coool200002_ooo`<00004oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool20000:?ooo`03o`2Ioooooooo06Coool008ooool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Sooo
o`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?
oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300009ooo
o`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Sooo
o`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000
oooooooo02Ooool00ol0VOooooooo`1Toooo0027oooo1@0000?oool00`000?ooooooo`0Woooo00?o
09Woooooool0I?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00ROooo`030000oooooooo00?oool300009oooo`03o`2Ioooooooo06Coool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66412 .30902 L
.66906 .30902 L
.67133 .30902 L
.67257 .30902 L
.67373 .30902 L
s
.67373 .30902 m
.67383 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32145 .30902 L
.32263 .30902 L
.32392 .30902 L
.32509 .30902 L
.32617 .15488 L
.32721 .15539 L
.32831 .15592 L
.33304 .15818 L
.34309 .16288 L
.38467 .18082 L
.42473 .19602 L
.46328 .20894 L
.48283 .21492 L
.48819 .21649 L
.49393 .21815 L
.49671 .21894 L
.49808 .21933 L
.49935 .21969 L
.50049 .21973 L
.50171 .21939 L
.50429 .21866 L
.54378 .20669 L
.58153 .19377 L
.62173 .17821 L
.64021 .17037 L
.65068 .16573 L
.66042 .16126 L
.6654 .15892 L
.67011 .15668 L
.67271 .15543 L
.67342 .15508 L
.67418 .15472 L
.67482 .30902 L
.67553 .30902 L
.68046 .30902 L
.70156 .30902 L
.7419 .30902 L
.78072 .30902 L
.822 .30902 L
Mistroke
.86176 .30902 L
.9 .30902 L
.9407 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006?oool00`1Vooooooooo`0Eoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000Yoooo00<0I_ooooooool0H_ooo`00Hoooo`<0I_l?oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02Ooool306KoI?ooo`00Hoooo`0306Ko
oooooooo00<0I_lBoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02Goool206Ko0_ooo`0306Kooooooooo06;oool006?oool00`1Vooooooooo`03oooo0P1Voa7oool2
00002_ooo`<00004oooo00<0003oooooool08oooo`80I_l4oooo00<0I_ooooooool0H_ooo`00Hooo
o`0306Kooooooooo00Goool206Ko8_ooo`80000Qoooo0`1Vo`Koool00`1Vooooooooo`1Roooo001S
oooo00<0I_ooooooool01oooo`80I_lPoooo00<0003oooooool07_ooo`80I_l9oooo00<0I_oooooo
ool0H_ooo`00Hoooo`0306Kooooooooo00Woool206Ko7_ooo`030000oooooooo01_oool306Ko2ooo
o`0306Kooooooooo06;oool006?oool00`1Vooooooooo`0;oooo0`1Voa_oool00`000?ooooooo`0I
oooo0P1Vo`koool00`1Vooooooooo`1Roooo001Soooo00<0I_ooooooool03_ooo`80I_lIoooo0P00
01Ooool306Ko4?ooo`0306Kooooooooo06;oool006?oool00`1Vooooooooo`0@oooo0`1VoaKoool0
0`000?ooooooo`0Doooo0P1Voa?oool00`1Vooooooooo`1Roooo001Soooo00<0I_ooooooool04ooo
o`80I_lDoooo00<0003oooooool04Oooo`<0I_lEoooo00<0I_ooooooool0H_ooo`00Hoooo`0306Ko
oooooooo01Goool306Ko4Oooo`030000oooooooo00koool306Ko6?ooo`0306Kooooooooo06;oool0
06?oool00`1Vooooooooo`0Hoooo0`1Vo`koool200002oooo`@0I_lKoooo00<0I_ooooooool0H_oo
o`00Hoooo`0306Kooooooooo01_oool406Ko2_ooo`030000oooooooo00Ooool306Ko7oooo`0306Ko
oooooooo06;oool006?oool00`1Vooooooooo`0Ooooo0`1Vo`Ooool00`000?ooooooo`05oooo0P1V
ob;oool00`1Vooooooooo`1Roooo001Soooo00<0I_ooooooool08_ooo`80I_l5oooo00<0003ooooo
ool00_ooo`<0I_lToooo00<0I_ooooooool0H_ooo`00Hoooo`0306Kooooooooo02Coool406Ko00Co
ool00000003oool206Ko9oooo`0306Kooooooooo06;oool006?oool00`1Vooooooooo`0Xoooo00@0
I_l00000I_l0I_lYoooo00<0I_ooooooool0H_ooo`00Hoooo`0306Kooooooooo013oool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo02Woool00`1Vooooooooo`1Roooo001S
oooo00<0I_ooooooool03oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`00Hoooo`0306Kooooooooo
00ooool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Y
oooo00<0I_ooooooool0H_ooo`00Hoooo`0306Kooooooooo00Woool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo02Woool00`1Vooooooooo`1R
oooo001Soooo00<0I_ooooooool03oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`00Hoooo`0306Ko
oooooooo013oool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Yoooo00<0I_oooooo
ool0H_ooo`00Hoooo`0306Kooooooooo02Woool20000:_ooo`0306Kooooooooo06;oool006?oool0
0`1Vooooooooo`0Yoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006?oool00`1Voooo
ooooo`0Yoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006?oool00`1Vooooooooo`0Y
oooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool001Soool200009Oooo`@0000Poooo00<0
I_ooooooool00_ooo`D0000Roooo0P0002Coool5000000?oool0I_ooool08?ooo`@0000Voooo0P00
01Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Qoooo00<0I_ooooooool01?oo
o`030000oooooooo02;oool00`000?ooooooo`0Uoooo00D0003oooooooooool0I_l08Oooo`030000
oooooooo02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003ooooo
ool08?ooo`0306Kooooooooo00Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`050000
oooooooooooo06Ko02;oool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005
oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003ooooo
ool08_ooo`030000oooooooo02Goool01@000?ooooooooooo`1Vo`0Soooo00<0003oooooool09ooo
o`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool010000?ooooooo`00023oool0
0`1Vooooooooo`04oooo00<0003oooooool08_ooo`80000Voooo00D0003oooooooooool0I_l08Ooo
o`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P00027oool0
0`1Vooooooooo`03oooo0P0002Coool00`000?ooooooo`0Toooo0P0000?oool00`1Vooooooooo`0P
oooo0P0002Ooool200005oooo`00Hoooo`0306Kooooooooo02Woool00`000?ooooooo`0Yoooo00<0
I_ooooooool0H_ooo`00Hoooo`0306Kooooooooo02Woool20000:_ooo`0306Kooooooooo06;oool0
06?oool00`1Vooooooooo`0Yoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006?oool0
0`1Vooooooooo`0Yoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006?oool00`1Voooo
ooooo`0Yoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00D0003ooooooooooooo09T08oooo`030000
oooooooo02Koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0
003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool0
08ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool2
0000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007Goool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<0000Yoooo00?o09Woooooool0H_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2I
oooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0
003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool0
08ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001koooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007_oool0
10000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0002Woool00ol0VOooooooo`1Roooo001k
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool2
0000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2I
oooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00M_ooo`800004
oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000Yoooo00?o09Woooooool0H_oo
o`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00M_ooo`800009
oooo100000?oool300001?ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo0P00
02[oool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo002?oooo0P0002[oool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo0P0002[oool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo0P0002[oool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06;oool008Ooool500000oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo0029
oooo00<0003oooooool00oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo0029oooo00<0
003oooooool00oooo`<0000Yoooo00?o09Woooooool0H_ooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`@00003oooo0P0000?oool500000_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.66906 .30902 L
.67373 .30902 L
.67803 .30902 L
.68044 .30902 L
.68166 .30902 L
.68235 .30902 L
s
.68235 .30902 m
.68242 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31304 .30902 L
.31454 .30902 L
.31597 .30902 L
.31725 .30902 L
.31798 .15476 L
.31865 .15509 L
.32392 .15762 L
.34309 .16649 L
.38221 .18302 L
.4238 .19849 L
.46386 .21159 L
.48224 .21707 L
.48728 .21852 L
.49267 .22004 L
.49529 .22077 L
.49777 .22146 L
.49885 .22176 L
.49999 .22207 L
.50125 .22173 L
.50241 .22141 L
.52235 .21573 L
.54342 .20933 L
.58117 .19674 L
.62137 .18159 L
.66006 .16507 L
.67044 .16029 L
.6755 .1579 L
.67771 .15684 L
.6801 .15569 L
.6814 .15506 L
.68261 .30902 L
.68375 .30902 L
.68497 .30902 L
.69018 .30902 L
.7012 .30902 L
.73909 .30902 L
.77943 .30902 L
.81825 .30902 L
.85953 .30902 L
Mistroke
.89929 .30902 L
.93753 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0067oool00`1Vooooooooo`0Goooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000[oooo00<0I_ooooooool0H?ooo`00HOooo`<0I_lAoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02Woool306KoH_ooo`00HOooo`0306Ko
oooooooo0080I_lEoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02Soool0101Vooooooooo`1Vof;oool0067oool00`1Vooooooooo`02oooo0`1Voa?oool200002_oo
o`<00004oooo00<0003oooooool09Oooo`<0I_l3oooo00<0I_ooooooool0H?ooo`00HOooo`0306Ko
oooooooo00Goool206Ko9?ooo`80000Toooo0P1Vo`Koool00`1Vooooooooo`1Poooo001Qoooo00<0
I_ooooooool01oooo`<0I_lQoooo00<0003oooooool08?ooo`<0I_l8oooo00<0I_ooooooool0H?oo
o`00HOooo`0306Kooooooooo00[oool206Ko7oooo`030000oooooooo01koool206Ko2oooo`0306Ko
oooooooo063oool0067oool00`1Vooooooooo`0<oooo0`1Voacoool00`000?ooooooo`0Koooo0`1V
o`goool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool03oooo`<0I_lIoooo0P0001[oool2
06Ko4?ooo`0306Kooooooooo063oool0067oool00`1Vooooooooo`0Boooo0P1VoaOoool00`000?oo
ooooo`0Foooo0`1Voa;oool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool05?ooo`<0I_lD
oooo00<0003oooooool05?ooo`80I_lEoooo00<0I_ooooooool0H?ooo`00HOooo`0306Kooooooooo
01Ooool306Ko4Oooo`030000oooooooo017oool306Ko5oooo`0306Kooooooooo063oool0067oool0
0`1Vooooooooo`0Joooo0P1Vo`ooool200003oooo`<0I_lJoooo00<0I_ooooooool0H?ooo`00HOoo
o`0306Kooooooooo01coool306Ko3?ooo`030000oooooooo00[oool406Ko7Oooo`0306Kooooooooo
063oool0067oool00`1Vooooooooo`0Ooooo0P1Vo`[oool00`000?ooooooo`07oooo0`1Vob7oool0
0`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool08Oooo`<0I_l7oooo00<0003oooooool01Ooo
o`80I_lToooo00<0I_ooooooool0H?ooo`00HOooo`0306Kooooooooo02Coool506Ko0_ooo`800002
oooo101VobKoool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool0:Oooo`80I_l01000001V
o`1Vo`1Vob[oool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool04_ooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0:oooo`0306Kooooooooo063oool0067oool0
0`1Vooooooooo`0Aoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool04Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0002_oool0
0`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool02oooo`@00002oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0:oooo`0306Kooooooooo063oool0
067oool00`1Vooooooooo`0Aoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001Qoooo00<0I_oooooo
ool04_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo02_oool00`1Vooooooooo`1P
oooo001Qoooo00<0I_ooooooool0:oooo`80000/oooo00<0I_ooooooool0H?ooo`00HOooo`0306Ko
oooooooo02_oool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`00HOooo`0306Kooooooooo
02_oool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`00HOooo`0306Kooooooooo02_oool0
0`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`006?ooo`80000Uoooo100001koool00`1Voooo
ooooo`04oooo1@0002;oool200009?ooo`D00003oooo00<0I_ooooooool07Oooo`@0000Voooo0P00
01Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Ooooo00<0I_ooooooool01_oo
o`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool00oooo`0306Kooooooooo
01goool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool09?oo
o`030000oooooooo01koool00`1Vooooooooo`06oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`03oooo00<0I_ooooooool07_ooo`030000oooooooo02Ooool00`000?oo
ooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?ooooooo`0M
oooo00<0I_l0000000000P0000Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000
oooooooo00?oool00`1Vooooooooo`0Ooooo00<0003oooooool09oooo`030000oooooooo01Coool0
01Ooool010000?ooooooo`0002Coool010000?ooooooo`0001koool00`1Vooooooooo`06oooo00<0
003oooooool08_ooo`80000Voooo00<0003oooooool00oooo`0306Kooooooooo01goool010000?oo
ooooo`0002Goool010000?ooooooo`0001Koool001Soool200009_ooo`80000Ooooo00<0I_oooooo
ool01Oooo`80000Toooo00<0003oooooool09?ooo`800005oooo00<0I_ooooooool07_ooo`80000W
oooo0P0001Ooool0067oool00`1Vooooooooo`0[oooo00<0003oooooool0:oooo`0306Kooooooooo
063oool0067oool00`1Vooooooooo`0[oooo0P0002coool00`1Vooooooooo`1Poooo001Qoooo00<0
I_ooooooool0:oooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001Qoooo00<0I_oooooo
ool0:oooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001Qoooo00<0I_ooooooool0:ooo
o`030000oooooooo02_oool00`1Vooooooooo`1Poooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool09Oooo`030000oooooooo00?oool00ol0VOooooooo`0Ooooo00<0003ooooo
ool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?oo
o`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOoo
ooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?oo
ooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Sooo
o`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/
oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o
09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo
02_oool00ol0VOooooooo`1Poooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0[oooo00?o09Woooooool0H?oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
02_oool00ol0VOooooooo`1Poooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0[oooo00?o
09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo
02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool0
08ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Wooooo
ool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003ooooo
ool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?oo
o`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOoo
ooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?oo
ooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Sooo
o`030000oooooooo02_oool00ol0VOooooooo`1Poooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000:oooo`03o`2Ioooooooo063oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo02_oool00ol0VOoo
ooooo`1Poooo001loooo0P0000[oool300001?ooo`030000oooooooo02_oool00ol0VOooooooo`1P
oooo002?oooo0P0002coool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/
oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o
09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo
02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool0
08ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/oooo00?o09Wooooo
ool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo02_oool00ol0VOooooooo`1P
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0002_oool00ol0VOooooooo`1Poooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo02_oool0
0ol0VOooooooo`1Poooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool20000;?oo
o`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Sooo
o`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool008ooool20000;?ooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[
oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool20000;?ooo`03o`2Ioooooooo
063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo
02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool0
08ooool20000;?ooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Wooooo
ool0H?ooo`00Qoooo`D00003oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008Woool00`000?oo
ooooo`03oooo0`0002_oool00ol0VOooooooo`1Poooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.67803 .30902 L
.68335 .30902 L
.68596 .30902 L
.68711 .30902 L
.68837 .30902 L
.6895 .30902 L
s
.6895 .30902 m
.6896 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
.30992 .1547 L
.31059 .15503 L
.31304 .15621 L
.32392 .16136 L
.34309 .17001 L
.38221 .18613 L
.4238 .20122 L
.46386 .214 L
.48224 .21934 L
.48728 .22075 L
.49267 .22224 L
.49529 .22295 L
.49777 .22362 L
.49885 .22391 L
.49999 .22422 L
.50125 .22389 L
.50241 .22357 L
.52235 .21804 L
.54342 .21179 L
.58117 .19952 L
.62137 .18473 L
.66006 .16863 L
.6801 .15948 L
.68497 .15716 L
.68765 .15588 L
.68896 .15524 L
.69018 .15465 L
.69087 .30902 L
.69161 .30902 L
.69317 .30902 L
.69589 .30902 L
.7012 .30902 L
.73909 .30902 L
.77943 .30902 L
.81825 .30902 L
.85953 .30902 L
Mistroke
.89929 .30902 L
.93753 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005ooool00`1Vooooooooo`0Ioooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000]oooo00<0I_ooooooool0G_ooo`00Goooo`80I_lDoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02_oool306KoH?ooo`00Goooo`0306Ko
oooo06Ko0080I_lGoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02Woool206Ko0_ooo`0306Kooooooooo05koool005ooool00`1Vooooooooo`02oooo0P1VoaKoool2
00002_ooo`<00004oooo00<0003oooooool09oooo`80I_l4oooo00<0I_ooooooool0G_ooo`00Gooo
o`0306Kooooooooo00Coool306Ko9_ooo`80000Voooo0P1Vo`Koool00`1Vooooooooo`1Noooo001O
oooo00<0I_ooooooool01oooo`80I_lToooo00<0003oooooool08oooo`80I_l8oooo00<0I_oooooo
ool0G_ooo`00Goooo`0306Kooooooooo00Woool306Ko8Oooo`030000oooooooo023oool306Ko2_oo
o`0306Kooooooooo05koool005ooool00`1Vooooooooo`0<oooo0P1Voaooool00`000?ooooooo`0N
oooo0P1Vo`goool00`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool03_ooo`<0I_lLoooo0P00
01coool306Ko3oooo`0306Kooooooooo05koool005ooool00`1Vooooooooo`0Aoooo0`1VoaWoool0
0`000?ooooooo`0Ioooo0P1Voa;oool00`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool05?oo
o`80I_lGoooo00<0003oooooool05_ooo`<0I_lDoooo00<0I_ooooooool0G_ooo`00Goooo`0306Ko
oooooooo01Koool306Ko5?ooo`030000oooooooo01Coool206Ko5oooo`0306Kooooooooo05koool0
05ooool00`1Vooooooooo`0Ioooo0`1Voa7oool200004_ooo`<0I_lIoooo00<0I_ooooooool0G_oo
o`00Goooo`0306Kooooooooo01coool306Ko3_ooo`030000oooooooo00koool306Ko7?ooo`0306Ko
oooooooo05koool005ooool00`1Vooooooooo`0Ooooo101Vo`[oool00`000?ooooooo`0:oooo101V
oaooool00`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool08oooo`80I_l8oooo00<0003ooooo
ool01_ooo`@0I_lSoooo00<0I_ooooooool0G_ooo`00Goooo`0306Kooooooooo02Goool206Ko1_oo
o`800003oooo101VobOoool00`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool09oooo`D0I_l0
1?ooo`000?ooooooo`80I_l[oooo00<0I_ooooooool0G_ooo`00Goooo`0306Kooooooooo01Coool2
00001?ooo`800003oooo100000?oool200001?ooo`0406Ko000006Ko06Ko;Oooo`0306Kooooooooo
05koool005ooool00`1Vooooooooo`0Coooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo02goool00`1Vooooooooo`1Noooo001Ooooo00<0
I_ooooooool04oooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02
oooo0`0002goool00`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool03Oooo`@00002oooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0;Oooo`0306Ko
oooooooo05koool005ooool00`1Vooooooooo`0Coooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02goool00`1Vooooooooo`1Noooo001O
oooo00<0I_ooooooool05?ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo02goool0
0`1Vooooooooo`1Noooo001Ooooo00<0I_ooooooool0;Oooo`80000^oooo00<0I_ooooooool0G_oo
o`00Goooo`0306Kooooooooo02goool00`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`00Gooo
o`0306Kooooooooo02goool00`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`00Goooo`0306Ko
oooooooo02goool00`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`006?ooo`80000Uoooo1000
01coool00`1Vooooooooo`06oooo1@0002;oool200009?ooo`D00005oooo00<0I_ooooooool06ooo
o`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0Moooo00<0
I_ooooooool02?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool01Ooo
o`0306Kooooooooo01_oool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Ioooo00<0
003oooooool09?ooo`030000oooooooo01coool00`1Vooooooooo`08oooo00<0003oooooool08_oo
o`030000oooooooo02Goool00`000?ooooooo`05oooo00<0I_ooooooool07?ooo`030000oooooooo
02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool0
0`000?ooooooo`0Koooo00<0I_ooooooool0100000Coool00`000?ooooooo`0Roooo00<0003ooooo
ool09Oooo`030000oooooooo00Goool00`1Vooooooooo`0Moooo00<0003oooooool09oooo`030000
oooooooo01Coool001Ooool010000?ooooooo`0002Coool010000?ooooooo`0001coool00`1Voooo
ooooo`08oooo00<0003oooooool08_ooo`80000Voooo00<0003oooooool01Oooo`0306Kooooooooo
01_oool010000?ooooooo`0002Goool010000?ooooooo`0001Koool001Soool200009_ooo`80000M
oooo00<0I_ooooooool01oooo`80000Toooo00<0003oooooool09?ooo`800007oooo00<0I_oooooo
ool07?ooo`80000Woooo0P0001Ooool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;Ooo
o`0306Kooooooooo05koool005ooool00`1Vooooooooo`0]oooo0P0002koool00`1Vooooooooo`1N
oooo001Ooooo00<0I_ooooooool0;Oooo`030000oooooooo02goool00`1Vooooooooo`1Noooo001O
oooo00<0I_ooooooool0;Oooo`030000oooooooo02goool00`1Vooooooooo`1Noooo001Ooooo00<0
I_ooooooool0;Oooo`030000oooooooo02goool00`1Vooooooooo`1Noooo000@ooooo`00017oool0
01Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo00Goool00ol0VOooooooo`0M
oooo00<0003oooooool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0002goool00ol0VOooooooo`1Noooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^
oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000;Oooo`03o`2Ioooooooo
05koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo001loooo0P0000[oool300001?ooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^
oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0002goool00ol0VOoo
ooooo`1Noooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool20000;_ooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool20000;_ooo`03o`2Ioooooooo05koool008ooool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool20000;_oo
o`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool20000;_ooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]
oooo00?o09Woooooool0G_ooo`00Qoooo`D00003oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008Woool00`000?ooooooo`03oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08Woool00`000?ooooooo`03oooo0`0002goool00ol0VOooooooo`1Noooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200000oooo`@00003oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02Oooo`030000oooooooo00Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.6883 .30902 L
.69289 .30902 L
.6954 .30902 L
.69662 .30902 L
.69774 .30902 L
s
.69774 .30902 m
.69786 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29349 .30902 L
.29809 .30902 L
.29935 .30902 L
.30004 .30902 L
.3007 .30902 L
.30198 .1547 L
.30316 .15527 L
.34135 .1727 L
.38199 .18908 L
.42112 .20299 L
.46271 .21601 L
.47285 .21893 L
.48357 .22192 L
.49273 .2244 L
.49523 .22506 L
.49661 .22543 L
.49792 .22577 L
.49914 .22609 L
.50046 .2262 L
.50166 .22588 L
.50277 .22559 L
.54132 .21482 L
.58059 .20241 L
.61834 .18895 L
.65854 .17274 L
.67702 .16458 L
.68749 .15973 L
.69259 .15732 L
.69501 .15616 L
.69723 .15508 L
.69839 .15452 L
.69962 .30902 L
.70086 .30902 L
.70221 .30902 L
.70692 .30902 L
.71727 .30902 L
.73837 .30902 L
.77871 .30902 L
.81753 .30902 L
.85881 .30902 L
Mistroke
.89857 .30902 L
.93682 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005goool00`1Vooooooooo`0Koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000_oooo00<0I_ooooooool0G?ooo`00GOooo`<0I_lEoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02koool206KoG_ooo`00GOooo`0306Ko
oooooooo0080I_lIoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02coool206Ko00?oool0I_ooool0GOooo`00GOooo`0306Kooooooooo00;oool206Ko6?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0Yoooo0`1Vo`?oool00`1Vooooooooo`1Loooo001Moooo00<0
I_ooooooool01?ooo`80I_lYoooo0P0002Soool206Ko1_ooo`0306Kooooooooo05coool005goool0
0`1Vooooooooo`06oooo0`1VobKoool00`000?ooooooo`0Toooo0`1Vo`Soool00`1Vooooooooo`1L
oooo001Moooo00<0I_ooooooool02Oooo`80I_lToooo00<0003oooooool08_ooo`80I_l;oooo00<0
I_ooooooool0G?ooo`00GOooo`0306Kooooooooo00_oool306Ko8Oooo`030000oooooooo01ooool3
06Ko3Oooo`0306Kooooooooo05coool005goool00`1Vooooooooo`0>oooo0P1Voaooool200007_oo
o`80I_l@oooo00<0I_ooooooool0G?ooo`00GOooo`0306Kooooooooo013oool306Ko7?ooo`030000
oooooooo01[oool306Ko4_ooo`0306Kooooooooo05coool005goool00`1Vooooooooo`0Coooo0P1V
oa[oool00`000?ooooooo`0Goooo0`1VoaGoool00`1Vooooooooo`1Loooo001Moooo00<0I_oooooo
ool05Oooo`<0I_lGoooo00<0003oooooool04oooo`@0I_lHoooo00<0I_ooooooool0G?ooo`00GOoo
o`0306Kooooooooo01Soool206Ko5Oooo`80000Aoooo0`1Voacoool00`1Vooooooooo`1Loooo001M
oooo00<0I_ooooooool06_ooo`<0I_lBoooo00<0003oooooool03_ooo`80I_lOoooo00<0I_oooooo
ool0G?ooo`00GOooo`0306Kooooooooo01goool406Ko3_ooo`030000oooooooo00_oool306Ko8Ooo
o`0306Kooooooooo05coool005goool00`1Vooooooooo`0Qoooo101Vo`[oool00`000?ooooooo`09
oooo0P1VobCoool00`1Vooooooooo`1Loooo001Moooo00<0I_ooooooool09Oooo`80I_l8oooo0P00
00Koool406Ko9_ooo`0306Kooooooooo05coool005goool00`1Vooooooooo`0Woooo1@1Vo`?oool0
10000?ooooooooooo`@0I_lZoooo00<0I_ooooooool0G?ooo`00GOooo`0306Kooooooooo01Koool2
00001?ooo`800003oooo100000?oool200000_ooo`<0I_l01000001Vo`1Vo`1Vobkoool00`1Voooo
ooooo`1Loooo001Moooo00<0I_ooooooool05Oooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`0_oooo00<0I_ooooooool0G?ooo`00G?oo
o`0306Kooooooooo01Koool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000`oooo00<0I_ooooooool0Foooo`00G?ooo`0306Kooooooooo013oool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo033oool0
0`1Vooooooooo`1Koooo001Loooo00<0I_ooooooool05_ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0`oooo00<0I_ooooooool0Fooo
o`00G?ooo`0306Kooooooooo01Ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0`
oooo00<0I_ooooooool0Foooo`00G?ooo`0306Kooooooooo033oool20000<Oooo`0306Kooooooooo
05_oool005coool00`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool0
05coool00`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool005coool0
0`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool001Soool200009Ooo
o`@0000Ioooo00<0I_ooooooool02Oooo`D0000Roooo0P0002Coool500002?ooo`0306Kooooooooo
01Soool400009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool06_oo
o`0306Kooooooooo00_oool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo
00Soool00`1Vooooooooo`0Hoooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Ooo
o`030000oooooooo02Coool00`000?ooooooo`0Ioooo00<0I_ooooooool02oooo`030000oooooooo
02;oool00`000?ooooooo`0Uoooo00<0003oooooool02?ooo`0306Kooooooooo01Woool00`000?oo
ooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004
oooo00<0003oooooool06?ooo`0306Kooooooooo00?oool400001?ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool02?ooo`0306Kooooooooo01[oool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00006Ooo
o`0306Kooooooooo00_oool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`08oooo00<0
I_ooooooool06?ooo`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000V
oooo0P0001[oool00`1Vooooooooo`0:oooo0P0002Coool00`000?ooooooo`0Toooo0P0000[oool0
0`1Vooooooooo`0Ioooo0P0002Ooool200005oooo`00G?ooo`0306Kooooooooo033oool00`000?oo
ooooo`0`oooo00<0I_ooooooool0Foooo`00G?ooo`0306Kooooooooo033oool20000<Oooo`0306Ko
oooooooo05_oool005coool00`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo
05_oool005coool00`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool0
05coool00`1Vooooooooo`0`oooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool01oooo`03o`2I
oooooooo01_oool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0_oooo00?o09Woooooool0G?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000_oooo00?o
09Woooooool0G?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool007coool200002_ooo`<00004oooo00<0003ooooo
ool0;oooo`03o`2Ioooooooo05coool008ooool20000<?ooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000;ooo
o`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?oo
o`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo0027oooo1@0000?oool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00ROooo`030000oooooooo00?oool30000;oooo`03o`2Ioooooooo05coool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo100000?oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`09oooo00<0003oooooool00oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_oo
o`030000oooooooo00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.6883 .30902 L
.69774 .30902 L
.7003 .30902 L
.70301 .30902 L
.70413 .30902 L
.70533 .30902 L
s
.70533 .30902 m
.70546 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29088 .30902 L
.29224 .30902 L
.29349 .30902 L
.29462 .15498 L
.2957 .1555 L
.29809 .15665 L
.30316 .15907 L
.34135 .17606 L
.38199 .19204 L
.42112 .20561 L
.46271 .2183 L
.47285 .22116 L
.48357 .22407 L
.49273 .22649 L
.49523 .22714 L
.49661 .22749 L
.49792 .22783 L
.49914 .22814 L
.50046 .22824 L
.50166 .22793 L
.50277 .22765 L
.54132 .21714 L
.58059 .20505 L
.61834 .19192 L
.65854 .17611 L
.67702 .16814 L
.68749 .16342 L
.69259 .16106 L
.69723 .15888 L
.69962 .15775 L
.70221 .15651 L
.7034 .15594 L
.70466 .15533 L
.70574 .15481 L
.70692 .30902 L
.70761 .30902 L
.70827 .30902 L
.7095 .30902 L
.71227 .30902 L
.71727 .30902 L
Mistroke
.73837 .30902 L
.77662 .30902 L
.81731 .30902 L
.85649 .30902 L
.89813 .30902 L
.93825 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005_oool00`1Vooooooooo`0Moooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000aoooo00<0I_ooooooool0F_ooo`00Foooo`<0I_lGoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02ooool306KoG?ooo`00Foooo`0306Ko
oooooooo0080I_lKoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02goool206Ko0_ooo`0306Kooooooooo05[oool005_oool00`1Vooooooooo`02oooo0P1Voa[oool2
00002_ooo`<00004oooo00<0003oooooool0:oooo`80I_l4oooo00<0I_ooooooool0F_ooo`00Fooo
o`0306Kooooooooo00Coool206Ko:oooo`80000Zoooo0P1Vo`Koool00`1Vooooooooo`1Joooo001K
oooo00<0I_ooooooool01_ooo`80I_lYoooo00<0003oooooool09oooo`80I_l8oooo00<0I_oooooo
ool0F_ooo`00Foooo`0306Kooooooooo00Soool306Ko9_ooo`030000oooooooo02Coool306Ko2_oo
o`0306Kooooooooo05[oool005_oool00`1Vooooooooo`0;oooo0P1VobCoool00`000?ooooooo`0R
oooo0P1Vo`goool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool03Oooo`<0I_lQoooo0P00
023oool306Ko3oooo`0306Kooooooooo05[oool005_oool00`1Vooooooooo`0@oooo0P1Voaooool0
0`000?ooooooo`0Moooo0P1Voa;oool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool04_oo
o`<0I_lLoooo00<0003oooooool06_ooo`<0I_lDoooo00<0I_ooooooool0F_ooo`00Foooo`0306Ko
oooooooo01Goool306Ko6Oooo`030000oooooooo01Ooool306Ko5oooo`0306Kooooooooo05[oool0
05_oool00`1Vooooooooo`0Hoooo101VoaGoool200005?ooo`@0I_lJoooo00<0I_ooooooool0F_oo
o`00Foooo`0306Kooooooooo01coool306Ko4_ooo`030000oooooooo013oool306Ko7_ooo`0306Ko
oooooooo05[oool005_oool00`1Vooooooooo`0Ooooo101Vo`koool00`000?ooooooo`0=oooo0`1V
ob7oool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool08oooo`@0I_l:oooo00<0003ooooo
ool02Oooo`@0I_lToooo00<0I_ooooooool0F_ooo`00Foooo`0306Kooooooooo02Ooool206Ko2?oo
o`800007oooo0`1VobSoool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool0:Oooo`<0I_l5
oooo00<0003oooooool00oooo`<0I_l[oooo00<0I_ooooooool0F_ooo`00Foooo`0306Kooooooooo
01Soool200001?ooo`800003oooo100000?oool20000101Vo`04oooo0000oooooooo0`1Vobkoool0
0`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool05oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000?oool0101Vo`00001Vo`1Voc7oool00`1Vooooooooo`1J
oooo001Koooo00<0I_ooooooool05oooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`00037oool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool04Ooo
o`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0<Oooo`0306Kooooooooo05[oool005_oool00`1Vooooooooo`0Goooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo037oool00`1Voooo
ooooo`1Joooo001Koooo00<0I_ooooooool06?ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo037oool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool0<Oooo`80000boooo00<0
I_ooooooool0F_ooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0I_oooooo
ool0F_ooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0I_ooooooool0F_oo
o`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0I_ooooooool0F_ooo`006?oo
o`80000Uoooo100001Soool00`1Vooooooooo`0:oooo1@0002;oool200009?ooo`D00009oooo00<0
I_ooooooool05oooo`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?oo
ooooo`0Ioooo00<0I_ooooooool03?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0
003oooooool02Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Voooo00@0003oooooool0000F
oooo000Ioooo00<0003oooooool09?ooo`030000oooooooo01Soool00`1Vooooooooo`0<oooo00<0
003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`09oooo00<0I_ooooooool06?oo
o`030000oooooooo02Ooool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0L
oooo100000Coool00`000?ooooooo`0Goooo00<0I_ooooooool01?ooo`@00004oooo00<0003ooooo
ool08_ooo`030000oooooooo02Goool00`000?ooooooo`09oooo00<0I_ooooooool06Oooo`030000
oooooooo02Ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003ooooo
ool0000Hoooo00<0I_ooooooool03?ooo`030000oooooooo02;oool200009_ooo`030000oooooooo
00Woool00`1Vooooooooo`0Goooo00@0003oooooool0000Uoooo00@0003oooooool0000Foooo000H
oooo0P0002Koool200006Oooo`0306Kooooooooo00_oool200009?ooo`030000oooooooo02Coool2
00002oooo`0306Kooooooooo01Soool200009oooo`80000Goooo001Koooo00<0I_ooooooool0<Ooo
o`030000oooooooo037oool00`1Vooooooooo`1Joooo001Koooo00<0I_ooooooool0<Oooo`80000b
oooo00<0I_ooooooool0F_ooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0
I_ooooooool0F_ooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0I_oooooo
ool0F_ooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0aoooo00<0I_ooooooool0F_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00D0
003ooooooooooooo09T00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?oo
ooooo`09oooo00?o09Woooooool06Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?
oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo
05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo
037oool00ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool0
08ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Wooooo
ool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo00<0003ooooo
ool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool0
0`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOoo
ooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_oo
o`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00M_oo
o`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0<Oooo`03o`2Ioooooooo
05[oool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool007Goool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000aoooo00?o09Woooooool0F_ooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo037oool0
0ol0VOooooooo`1Joooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo037oool00ol0VOooooooo`1Joooo001foooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_oo
o`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Sooo
o`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2I
oooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0a
oooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOooooooo`1Joooo002?
oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo
05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo
037oool00ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool0
08ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Wooooo
ool0F_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo037oool00ol0VOoo
ooooo`1Joooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool0<Oooo`03o`2Ioooooooo05[oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`00037oool00ol0VOooooooo`1Joooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`80000boooo00?o09Wooooo
ool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo00<0003ooooo
ool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool0
0`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOoo
ooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool20000<_oo
o`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Sooo
o`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2I
oooooooo05[oool008ooool20000<_ooo`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0a
oooo00?o09Woooooool0F_ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00MOooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0<Oooo`03o`2I
oooooooo05[oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<0000aoooo00?o09Woooooool0F_ooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0a
oooo00?o09Woooooool0F_ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo
037oool00ol0VOooooooo`1Joooo002?oooo0P0003;oool00ol0VOooooooo`1Joooo002?oooo00<0
003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Wooooo
ool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo0P0003;oool0
0ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008ooool0
0`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Soooo`030000oooooooo037oool00ol0VOoo
ooooo`1Joooo002?oooo0P0003;oool00ol0VOooooooo`1Joooo002?oooo00<0003oooooool0<Ooo
o`03o`2Ioooooooo05[oool008ooool00`000?ooooooo`0aoooo00?o09Woooooool0F_ooo`00Sooo
o`030000oooooooo037oool00ol0VOooooooo`1Joooo002?oooo0P0003;oool00ol0VOooooooo`1J
oooo002?oooo00<0003oooooool0<Oooo`03o`2Ioooooooo05[oool008Ooool500000oooo`030000
oooooooo037oool00ol0VOooooooo`1Joooo0029oooo00<0003oooooool00oooo`030000oooooooo
037oool00ol0VOooooooo`1Joooo0029oooo00<0003oooooool00oooo`<0000aoooo00?o09Wooooo
ool0F_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.69774 .30902 L
.7026 .30902 L
.70787 .30902 L
.71028 .30902 L
.7116 .30902 L
.71284 .30902 L
.71389 .30902 L
s
.71389 .30902 m
.714 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28025 .30902 L
.28302 .30902 L
.28425 .30902 L
.28542 .30902 L
.28606 .15468 L
.28676 .15502 L
.288 .15562 L
.29349 .15825 L
.30316 .16277 L
.3438 .18034 L
.38293 .19527 L
.42451 .20923 L
.46458 .22106 L
.48296 .22601 L
.48799 .22732 L
.49339 .22869 L
.49601 .22935 L
.49729 .22967 L
.49848 .22997 L
.49956 .23024 L
.50071 .23017 L
.50186 .22989 L
.50313 .22957 L
.52307 .22442 L
.54413 .21861 L
.58434 .20641 L
.62302 .19311 L
.66416 .17707 L
.68469 .16826 L
.6947 .16375 L
.70379 .15953 L
.70834 .15738 L
.71073 .15623 L
.71204 .1556 L
.71327 .155 L
.71433 .30902 L
.71548 .30902 L
.71792 .30902 L
.72221 .30902 L
.7419 .30902 L
.78317 .30902 L
Mistroke
.82293 .30902 L
.86118 .30902 L
.90188 .30902 L
.94106 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005Woool00`1Vooooooooo`0Ooooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000coooo00<0I_ooooooool0F?ooo`00FOooo`<0I_lIoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03;oool206KoF_ooo`00FOooo`0306Ko
oooooooo0080I_lMoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
033oool206Ko00?oool0I_ooool0FOooo`00FOooo`0306Kooooooooo00;oool206Ko7?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0^oooo0P1Vo`?oool00`1Vooooooooo`1Hoooo001Ioooo00<0
I_ooooooool01?ooo`80I_l]oooo0P0002coool306Ko1Oooo`0306Kooooooooo05Soool005Woool0
0`1Vooooooooo`06oooo0P1Vob_oool00`000?ooooooo`0Yoooo0P1Vo`Soool00`1Vooooooooo`1H
oooo001Ioooo00<0I_ooooooool02?ooo`80I_lYoooo00<0003oooooool09_ooo`<0I_l:oooo00<0
I_ooooooool0F?ooo`00FOooo`0306Kooooooooo00[oool306Ko9_ooo`030000oooooooo02?oool3
06Ko3Oooo`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0=oooo0P1VobCoool200008_oo
o`80I_l@oooo00<0I_ooooooool0F?ooo`00FOooo`0306Kooooooooo00ooool306Ko8Oooo`030000
oooooooo01koool306Ko4_ooo`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0Boooo0P1V
oaooool00`000?ooooooo`0Koooo0`1VoaGoool00`1Vooooooooo`1Hoooo001Ioooo00<0I_oooooo
ool05?ooo`<0I_lLoooo00<0003oooooool06?ooo`<0I_lHoooo00<0I_ooooooool0F?ooo`00FOoo
o`0306Kooooooooo01Ooool406Ko6?ooo`80000Eoooo101Voa_oool00`1Vooooooooo`1Hoooo001I
oooo00<0I_ooooooool06oooo`@0I_lDoooo00<0003oooooool04Oooo`<0I_lOoooo00<0I_oooooo
ool0F?ooo`00FOooo`0306Kooooooooo01ooool306Ko4Oooo`030000oooooooo00koool306Ko8_oo
o`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0Roooo0`1Vo`koool00`000?ooooooo`0:
oooo101VobGoool00`1Vooooooooo`1Hoooo001Ioooo00<0I_ooooooool09Oooo`@0I_l:oooo0P00
00Soool306Ko:Oooo`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0Yoooo101Vo`Koool0
0`000?ooooooo`05oooo0P1Vobcoool00`1Vooooooooo`1Hoooo001Ioooo00<0I_ooooooool06_oo
o`800004oooo0P0000?oool400000oooo`80000206Ko0oooo`040000oooooooooooo101Vobkoool0
0`1Vooooooooo`1Hoooo001Ioooo00<0I_ooooooool06Oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool01@000?ooooooo`000?ooo`0306Ko00@00000I_l0I_l0I_lboooo00<0I_oooooo
ool0F?ooo`00FOooo`0306Kooooooooo01Woool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0000coooo00<0I_ooooooool0F?ooo`00FOooo`0306Kooooooooo
01?oool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo03?oool00`1Vooooooooo`1Hoooo001Ioooo00<0I_ooooooool06Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0coooo00<0
I_ooooooool0F?ooo`00FOooo`0306Kooooooooo01[oool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0coooo00<0I_ooooooool0F?ooo`00FOooo`0306Kooooooooo03?oool20000=?oo
o`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`0306Ko
oooooooo05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`0306Kooooooooo
05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`0306Kooooooooo05Soool0
01Soool200009Oooo`@0000Foooo00<0I_ooooooool03?ooo`D0000Roooo0P0002Coool500002ooo
o`0306Kooooooooo01Goool400009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0
003oooooool05oooo`0306Kooooooooo00koool00`000?ooooooo`0Roooo00<0003oooooool09Ooo
o`030000oooooooo00_oool00`1Vooooooooo`0Eoooo00<0003oooooool09_ooo`040000oooooooo
00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooooooo`0Foooo00<0I_ooooooool03_oo
o`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool02oooo`0306Kooooooooo
01Koool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003ooooo
ool07?ooo`@00004oooo00<0003oooooool05Oooo`0306Kooooooooo00Koool400001?ooo`030000
oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool02oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`0Woooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000
oooooooo00005_ooo`0306Kooooooooo00koool00`000?ooooooo`0Roooo0P0002Koool00`000?oo
ooooo`0;oooo00<0I_ooooooool05Oooo`040000oooooooo00009Oooo`040000oooooooo00005_oo
o`006?ooo`80000Voooo0P0001Ooool00`1Vooooooooo`0=oooo0P0002Coool00`000?ooooooo`0T
oooo0P0000goool00`1Vooooooooo`0Foooo0P0002Ooool200005oooo`00FOooo`0306Kooooooooo
03?oool00`000?ooooooo`0coooo00<0I_ooooooool0F?ooo`00FOooo`0306Kooooooooo03?oool2
0000=?ooo`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<ooo
o`0306Kooooooooo05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`0306Ko
oooooooo05Soool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`0306Kooooooooo
05Soool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003ooooo
ool02oooo`03o`2Ioooooooo01Ooool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Sooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool0
0ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007Koool2
00001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?oo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001eoooo00@0003oooooool00009oooo00<0
003oooooool01Oooo`030000oooooooo00;oool30000<oooo`03o`2Ioooooooo05Soool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0coooo00?o
09Woooooool0F?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00M_ooo`80000:oooo0P00
00Coool300001?ooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool0
0ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOoo
ooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Sooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000coooo00?o09Woooooool0F?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007coool200002_ooo`<00004
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool0
0ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOoo
ooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007Goool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo03?oool00ol0VOoo
ooooo`1Hoooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo
00;oool30000<oooo`03o`2Ioooooooo05Soool007Goool010000?ooooooo`0000_oool010000?oo
ooooooooo`800005oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`80000doooo00?o09Woooooool0F?ooo`00Soooo`030000
oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`80000doooo00?o
09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`80000doooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool0
0ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`80000doooo00?o09Woooooool0F?oo
o`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo0027oooo1@0000?oool00`000?oo
ooooo`0coooo00?o09Woooooool0F?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00ROooo`030000oooooooo00?oool30000<oooo`03o`2Ioooooooo
05Soool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02_oo
o`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.70787 .30902 L
.71284 .30902 L
.71741 .30902 L
.71998 .30902 L
.72127 .30902 L
.72201 .30902 L
s
.72201 .30902 m
.72208 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27279 .30902 L
.27513 .30902 L
.27643 .30902 L
.27765 .30902 L
.27835 .15478 L
.2791 .15515 L
.28042 .15579 L
.28302 .15704 L
.30316 .16638 L
.3438 .18352 L
.38293 .19807 L
.42451 .21169 L
.46458 .22323 L
.48296 .22806 L
.48799 .22933 L
.49339 .23068 L
.49601 .23132 L
.49729 .23163 L
.49848 .23192 L
.49956 .23218 L
.50071 .23212 L
.50186 .23184 L
.50313 .23153 L
.52307 .22651 L
.54413 .22085 L
.58434 .20894 L
.62302 .19597 L
.66416 .18033 L
.68469 .17174 L
.70379 .16323 L
.71327 .15881 L
.71792 .15659 L
.71996 .1556 L
.72105 .15508 L
.72221 .15451 L
.72345 .30902 L
.72462 .30902 L
.72716 .30902 L
.73253 .30902 L
.7419 .30902 L
.78317 .30902 L
Mistroke
.82293 .30902 L
.86118 .30902 L
.90188 .30902 L
.94106 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005Ooool00`1Vooooooooo`0Qoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000eoooo00<0I_ooooooool0E_ooo`00Eoooo`<0I_lKoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03?oool306KoF?ooo`00Eoooo`0306Ko
oooooooo0080I_lOoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
037oool206Ko0_ooo`0306Kooooooooo05Koool005Ooool00`1Vooooooooo`02oooo0P1Voakoool2
00002_ooo`<00004oooo00<0003oooooool0;oooo`80I_l4oooo00<0I_ooooooool0E_ooo`00Eooo
o`0306Kooooooooo00Coool206Ko;oooo`80000^oooo0P1Vo`Koool00`1Vooooooooo`1Foooo001G
oooo00<0I_ooooooool01_ooo`80I_l]oooo00<0003oooooool0:oooo`80I_l8oooo00<0I_oooooo
ool0E_ooo`00Eoooo`0306Kooooooooo00Soool206Ko:oooo`030000oooooooo02Woool206Ko2_oo
o`0306Kooooooooo05Koool005Ooool00`1Vooooooooo`0:oooo0P1VobWoool00`000?ooooooo`0V
oooo0`1Vo`coool00`1Vooooooooo`1Foooo001Goooo00<0I_ooooooool03?ooo`<0I_lVoooo0P00
02Coool306Ko3oooo`0306Kooooooooo05Koool005Ooool00`1Vooooooooo`0?oooo0`1Vob?oool0
0`000?ooooooo`0Qoooo0P1Voa;oool00`1Vooooooooo`1Foooo001Goooo00<0I_ooooooool04_oo
o`@0I_lOoooo00<0003oooooool07_ooo`<0I_lDoooo00<0I_ooooooool0E_ooo`00Eoooo`0306Ko
oooooooo01Koool306Ko7?ooo`030000oooooooo01_oool306Ko5oooo`0306Kooooooooo05Koool0
05Ooool00`1Vooooooooo`0Ioooo0`1VoaWoool200006Oooo`<0I_lJoooo00<0I_ooooooool0E_oo
o`00Eoooo`0306Kooooooooo01coool206Ko5oooo`030000oooooooo01Coool406Ko7Oooo`0306Ko
oooooooo05Koool005Ooool00`1Vooooooooo`0Noooo0`1VoaCoool00`000?ooooooo`0Aoooo0`1V
ob7oool00`1Vooooooooo`1Foooo001Goooo00<0I_ooooooool08Oooo`<0I_lAoooo00<0003ooooo
ool03_ooo`<0I_lToooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo02Coool306Ko3_oo
o`80000;oooo101VobOoool00`1Vooooooooo`1Foooo001Goooo00<0I_ooooooool09oooo`@0I_l:
oooo00<0003oooooool01_ooo`@0I_l[oooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo
01coool200001?ooo`800003oooo100000<0I_l200001Oooo`030000oooooooo00;oool406Ko;ooo
o`0306Kooooooooo05Koool005Ooool00`1Vooooooooo`0Koooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooo06Ko00000P1Vo`;oool00`000?ooooooo`0206Ko<oooo`0306Ko
oooooooo05Koool005Ooool00`1Vooooooooo`0Koooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo0080I_l30000=_ooo`0306Kooooooooo05Goool005Ooool00`1Voooo
ooooo`0Eoooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0foooo00<0I_ooooooool0EOooo`00Eoooo`0306Kooooooooo01_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0=_oo
o`0306Kooooooooo05Goool005Ooool00`1Vooooooooo`0Loooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0=_ooo`0306Kooooooooo05Goool005Ooool00`1Vooooooooo`0eoooo0P00
03Ooool00`1Vooooooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Koool0
0`1Vooooooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Koool00`1Voooo
ooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Koool00`1Vooooooooo`1E
oooo000Hoooo0P0002Goool400005?ooo`0306Kooooooooo00koool500008_ooo`80000Toooo1@00
00koool00`1Vooooooooo`0Boooo100002Koool200005oooo`005oooo`040000oooooooo00009?oo
o`030000oooooooo01Goool00`1Vooooooooo`0@oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0>oooo00<0I_ooooooool04_ooo`030000oooooooo02Koool010000?oo
ooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool05?ooo`0306Kooooooooo
013oool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo00koool00`1Voooo
ooooo`0Coooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Oooo`030000
oooooooo01coool400001?ooo`030000oooooooo01?oool00`1Vooooooooo`08oooo100000Coool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo00koool00`1Vooooooooo`0D
oooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool0
10000?ooooooo`0001Coool00`1Vooooooooo`0@oooo00<0003oooooool08_ooo`80000Voooo00<0
003oooooool03_ooo`0306Kooooooooo01;oool010000?ooooooo`0002Goool010000?ooooooo`00
01Koool001Soool200009_ooo`80000Eoooo00<0I_ooooooool03oooo`80000Toooo00<0003ooooo
ool09?ooo`80000@oooo00<0I_ooooooool04oooo`80000Woooo0P0001Ooool005Ooool00`1Voooo
ooooo`0eoooo00<0003oooooool0=_ooo`0306Kooooooooo05Goool005Ooool00`1Vooooooooo`0e
oooo0P0003Ooool00`1Vooooooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo
03Koool00`1Vooooooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Koool0
0`1Vooooooooo`1Eoooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Koool00`1Voooo
ooooo`1Eoooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo00goool00ol0VOooooooo`0Eoooo00<0003oooooool09_ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Wooooo
ool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0003Goool00ol0VOooooooo`1Foooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo
03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Wooooo
ool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000=Oooo`03o`2Ioooooooo05Koool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001loooo0P0000[oool3
00001?ooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo
03Goool00ol0VOooooooo`1Foooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0003Goool00ol0VOooooooo`1Foooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
03Goool00ol0VOooooooo`1Foooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_oo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo
05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Qoooo`D00003oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo0`0003Goool00ol0VOoo
ooooo`1Foooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001Ooo
o`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00coool01@000?ooooooooooo`00001m
oooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo1@00
00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo017oool200002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72585 .30902 L
.72707 .30902 L
.72841 .30902 L
.72961 .30902 L
s
.72961 .30902 m
.72973 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.26171 .30902 L
.26425 .30902 L
.26698 .30902 L
.26778 .30902 L
.26855 .30902 L
.26923 .30902 L
.26998 .15458 L
.27068 .15492 L
.27144 .15528 L
.27279 .15594 L
.28302 .16079 L
.30316 .1699 L
.34474 .18698 L
.3848 .20145 L
.42335 .21375 L
.46436 .22529 L
.47421 .22785 L
.48478 .23051 L
.4899 .23177 L
.49475 .23294 L
.49686 .23344 L
.49802 .23372 L
.49911 .23397 L
.50028 .23412 L
.50157 .23381 L
.50385 .23327 L
.54182 .22365 L
.5805 .21258 L
.62164 .19924 L
.66127 .18465 L
.69938 .16879 L
.71899 .15985 L
.72463 .15717 L
.72741 .15584 L
.72862 .15525 L
.72927 .15494 L
.72996 .1546 L
.73117 .30902 L
.73229 .30902 L
.73475 .30902 L
.73994 .30902 L
.78121 .30902 L
Mistroke
.82098 .30902 L
.85922 .30902 L
.89992 .30902 L
.9391 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005Goool00`1Vooooooooo`0Soooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000goooo00<0I_ooooooool0E?ooo`00EOooo`80I_lNoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03Koool206KoE_ooo`00EOooo`0306Ko
oooo06Ko0080I_lQoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
03Coool206Ko00?oool0I_ooool0EOooo`00EOooo`0306Kooooooooo00;oool206Ko8?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0boooo0P1Vo`?oool00`1Vooooooooo`1Doooo001Eoooo00<0
I_ooooooool01?ooo`<0I_l`oooo0P00033oool306Ko1Oooo`0306Kooooooooo05Coool005Goool0
0`1Vooooooooo`07oooo0`1Vobgoool00`000?ooooooo`0]oooo0P1Vo`Soool00`1Vooooooooo`1D
oooo001Eoooo00<0I_ooooooool02_ooo`80I_l[oooo00<0003oooooool0:_ooo`<0I_l:oooo00<0
I_ooooooool0E?ooo`00EOooo`0306Kooooooooo00coool306Ko:?ooo`030000oooooooo02Soool2
06Ko3Oooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0?oooo0`1VobGoool200009_oo
o`<0I_l?oooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo01;oool206Ko8oooo`030000
oooooooo02?oool206Ko4_ooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0Doooo0`1V
ob3oool00`000?ooooooo`0Poooo0`1VoaCoool00`1Vooooooooo`1Doooo001Eoooo00<0I_oooooo
ool05oooo`80I_lNoooo00<0003oooooool07_ooo`80I_lGoooo00<0I_ooooooool0E?ooo`00EOoo
o`0306Kooooooooo01Woool306Ko6oooo`80000Loooo0`1VoaWoool00`1Vooooooooo`1Doooo001E
oooo00<0I_ooooooool07?ooo`<0I_lHoooo00<0003oooooool05oooo`@0I_lLoooo00<0I_oooooo
ool0E?ooo`00EOooo`0306Kooooooooo01ooool406Ko5?ooo`030000oooooooo01?oool406Ko8?oo
o`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0Soooo0`1Voa7oool00`000?ooooooo`0@
oooo0`1VobCoool00`1Vooooooooo`1Doooo001Eoooo00<0I_ooooooool09_ooo`<0I_l>oooo0P00
00koool306Ko9oooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0Yoooo101Vo`[oool0
0`000?ooooooo`0:oooo0`1Vob[oool00`1Vooooooooo`1Doooo001Eoooo00<0I_ooooooool07_oo
o`800004oooo0P0000?oool400000P1Vo`03oooo0000000000Goool00`000?ooooooo`06oooo101V
obgoool00`1Vooooooooo`1Doooo001Eoooo00<0I_ooooooool07Oooo`040000oooooooo00002?oo
o`030000oooooooo00?oool01000001Vo`1Vo`0000Coool010000?ooooooooooo`D0I_laoooo00<0
I_ooooooool0E?ooo`00E?ooo`0306Kooooooooo01koool010000?ooooooo`0000Woool00`000?oo
ooooo`05oooo00<00000I_l0I_l00P1Vo`<000000`1Vooooooooo`0eoooo00<0I_ooooooool0Dooo
o`00E?ooo`0306Kooooooooo01Soool400000_ooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo03Soool00`1Vooooooooo`1Coooo001Doooo00<0I_oooooo
ool07_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0hoooo00<0I_ooooooool0Doooo`00E?ooo`0306Kooooooooo01ooool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0hoooo00<0I_ooooooool0Doooo`00E?ooo`0306Ko
oooooooo03Soool20000>Oooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0hoooo00<0
003oooooool0>?ooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0hoooo00<0003ooooo
ool0>?ooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0hoooo00<0003oooooool0>?oo
o`0306Kooooooooo05?oool001Soool200009Oooo`@0000Aoooo00<0I_ooooooool04Oooo`D0000R
oooo0P0002Coool500004?ooo`0306Kooooooooo013oool400009_ooo`80000Goooo000Goooo00@0
003oooooool0000Toooo00<0003oooooool04_ooo`0306Kooooooooo01?oool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo013oool00`1Vooooooooo`0@oooo00<0003ooooo
ool09_ooo`040000oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooooooo`0A
oooo00<0I_ooooooool04oooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003ooooo
ool04?ooo`0306Kooooooooo017oool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`004Ooo
o`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003oooooool04?ooo`0306Kooooooooo
00_oool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool04?oo
o`0306Kooooooooo01;oool00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005oooo`040000
oooooooo00009?ooo`040000oooooooo00004Oooo`0306Kooooooooo01?oool00`000?ooooooo`0R
oooo0P0002Koool00`000?ooooooo`0@oooo00<0I_ooooooool04?ooo`040000oooooooo00009Ooo
o`040000oooooooo00005_ooo`006?ooo`80000Voooo0P0001;oool00`1Vooooooooo`0Boooo0P00
02Coool00`000?ooooooo`0Toooo0P0001;oool00`1Vooooooooo`0Aoooo0P0002Ooool200005ooo
o`00E?ooo`0306Kooooooooo03Soool00`000?ooooooo`0hoooo00<0I_ooooooool0Doooo`00E?oo
o`0306Kooooooooo03Soool20000>Oooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0h
oooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0hoooo00<0
003oooooool0>?ooo`0306Kooooooooo05?oool005Coool00`1Vooooooooo`0hoooo00<0003ooooo
ool0>?ooo`0306Kooooooooo05?oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Uoooo00<0003oooooool03oooo`03o`2Ioooooooo01?oool00`000?ooooooo`0Voooo00<0
003oooooool05Oooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P00
03Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOoo
ooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo001eoooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo001eoooo00@0
003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000=oooo`03o`2I
oooooooo05Coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000
oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o
09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P00
03Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool007coool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo001koooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0000goooo00?o09Woooooool0E?ooo`00Noooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
07coool200002_ooo`<00004oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool2
0000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOoo
ooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000
oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool007Koool200001?ooo`800005oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool007Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo03Ooool00ol0VOooooooo`1Doooo001eoooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool30000=oooo`03o`2Ioooooooo05Coool007Goool010000?oo
ooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0=oooo`03o`2Ioooooooo
05Coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool007Koool200002Oooo`@00003oooo0`00
00Coool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`80000hoooo00?o09Wooooo
ool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOoo
ooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`80000hoooo00?o09Woooooool0E?ooo`00Sooo
o`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`80000h
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0027
oooo1@0000?oool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo00?oool3
0000=oooo`03o`2Ioooooooo05Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool4
00000oooo`800005oooo0`0000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0<
oooo00@0003oooooool00002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`D00004oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000?oool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72841 .30902 L
.7332 .30902 L
.73451 .30902 L
.7359 .30902 L
.73708 .30902 L
s
.73708 .30902 m
.73721 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.25666 .30902 L
.2593 .30902 L
.26045 .30902 L
.26171 .30902 L
.26301 .15505 L
.26425 .15565 L
.26698 .15696 L
.27279 .15972 L
.28302 .16445 L
.30316 .17334 L
.3438 .18964 L
.38293 .20348 L
.42451 .21644 L
.46458 .22742 L
.48296 .23201 L
.48799 .23322 L
.49339 .2345 L
.49601 .23511 L
.49729 .23541 L
.49848 .23568 L
.49956 .23593 L
.50071 .23587 L
.50186 .2356 L
.50313 .23531 L
.52307 .23053 L
.54413 .22515 L
.58434 .21382 L
.62302 .20149 L
.66416 .18661 L
.68469 .17843 L
.70379 .17034 L
.72221 .16205 L
.72752 .15957 L
.73253 .1572 L
.73471 .15615 L
.7359 .15557 L
.73702 .15503 L
.73823 .30902 L
.73887 .30902 L
.73956 .30902 L
.7419 .30902 L
.78317 .30902 L
Mistroke
.82293 .30902 L
.86118 .30902 L
.90188 .30902 L
.94106 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005?oool00`1Vooooooooo`0Uoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000ioooo00<0I_ooooooool0D_ooo`00Doooo`80I_lPoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03Soool206KoE?ooo`00Doooo`0406Ko
oooo06Ko06Ko9?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0e
oooo0`1Vo`03oooo06Kooooo05?oool005?oool0101Vooooooooooooo`<0I_lRoooo0P0000[oool3
00001?ooo`030000oooooooo03?oool206Ko1?ooo`0306Kooooooooo05;oool005?oool00`1Voooo
ooooo`04oooo0P1Voc?oool20000<Oooo`<0I_l6oooo00<0I_ooooooool0D_ooo`00Doooo`0306Ko
oooooooo00Koool306Ko<?ooo`030000oooooooo02koool206Ko2Oooo`0306Kooooooooo05;oool0
05?oool00`1Vooooooooo`09oooo0P1Vobkoool00`000?ooooooo`0[oooo0`1Vo`_oool00`1Voooo
ooooo`1Boooo001Coooo00<0I_ooooooool02oooo`<0I_l[oooo00<0003oooooool0:Oooo`80I_l>
oooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo00koool206Ko:Oooo`80000Woooo0`1V
oa3oool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool04?ooo`<0I_lVoooo00<0003ooooo
ool08oooo`<0I_lCoooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo01?oool206Ko9?oo
o`030000oooooooo027oool206Ko5_ooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0E
oooo0`1Vob7oool00`000?ooooooo`0Noooo0`1VoaSoool00`1Vooooooooo`1Boooo001Coooo00<0
I_ooooooool06?ooo`80I_lOoooo0P0001coool306Ko6oooo`0306Kooooooooo05;oool005?oool0
0`1Vooooooooo`0Joooo0`1Voacoool00`000?ooooooo`0Hoooo0`1Voakoool00`1Vooooooooo`1B
oooo001Coooo00<0I_ooooooool07Oooo`@0I_lHoooo00<0003oooooool05?ooo`@0I_lQoooo00<0
I_ooooooool0D_ooo`00Doooo`0306Kooooooooo027oool406Ko5?ooo`030000oooooooo017oool3
06Ko9Oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0Uoooo0`1Voa7oool200003ooo
o`<0I_lXoooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo02Soool306Ko3_ooo`030000
oooooooo00[oool406Ko:oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0Poooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`07oooo0`1Vobooool00`1Voooo
ooooo`1Boooo001Coooo00<0I_ooooooool07oooo`040000oooooooo00002?ooo`040000oooooooo
oooo0P1Vo`04000006Kooooo00001?ooo`030000oooooooo00Goool206Ko<_ooo`0306Kooooooooo
05;oool005?oool00`1Vooooooooo`0Ooooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`0406Ko000006Ko06Ko0_ooo`<000000oooo`1Vo`1Vo`0206Ko=?ooo`0306Kooooooooo05;oool0
05?oool00`1Vooooooooo`0Ioooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000?oool206Ko00@00000I_l0I_l0I_lhoooo00<0I_ooooooool0D_ooo`00Doooo`0306Ko
oooooooo01ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0Poooo0P00
00[oool200001?ooo`<00004oooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool0
0`1Vooooooooo`0ioooo0P0003[oool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Ooo
o`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000
oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo
03Woool00`1Vooooooooo`1Boooo000Hoooo0P0002Goool400004?ooo`0306Kooooooooo01;oool5
00008_ooo`80000Toooo1@00017oool00`1Vooooooooo`0?oooo100002Koool200005oooo`005ooo
o`040000oooooooo00009?ooo`030000oooooooo017oool00`1Vooooooooo`0Doooo00<0003ooooo
ool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Aoooo00<0I_ooooooool03oooo`030000
oooooooo02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Toooo00<0003ooooo
ool04?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000
oooooooo017oool00`1Vooooooooo`0@oooo00<0003oooooool09oooo`030000oooooooo01Goool0
017oool400001Oooo`030000oooooooo01coool400001?ooo`030000oooooooo00ooool00`1Voooo
ooooo`0<oooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo
017oool00`1Vooooooooo`0Aoooo00<0003oooooool09oooo`030000oooooooo01Coool001Ooool0
10000?ooooooo`0002Coool010000?ooooooo`00013oool00`1Vooooooooo`0Doooo00<0003ooooo
ool08_ooo`80000Voooo00<0003oooooool04Oooo`0306Kooooooooo00ooool010000?ooooooo`00
02Goool010000?ooooooo`0001Koool001Soool200009_ooo`80000Aoooo00<0I_ooooooool04ooo
o`80000Toooo00<0003oooooool09?ooo`80000Coooo00<0I_ooooooool04?ooo`80000Woooo0P00
01Ooool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool0
05?oool00`1Vooooooooo`0ioooo0P0003[oool00`1Vooooooooo`1Boooo001Coooo00<0I_oooooo
ool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Ooo
o`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000
oooooooo03Woool00`1Vooooooooo`1Boooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool09Oooo`030000oooooooo017oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000j
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
03Woool00ol0VOooooooo`1Boooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000>Oooo`03o`2Ioooooooo05;oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo001loooo0P0000[oool300001?ooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000j
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0003Woool00ol0VOooooooo`1Boooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_oo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Qoooo`D00003oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Woool00`000?oo
ooooo`03oooo0`0003Woool00ol0VOooooooo`1Boooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Woool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool3
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.72912 .30902 L
.73838 .30902 L
.74309 .30902 L
.74423 .30902 L
.74546 .30902 L
s
.74546 .30902 m
.74553 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.24276 .30902 L
.24754 .30902 L
.25016 .30902 L
.25144 .30902 L
.25261 .30902 L
.25368 .30902 L
.2547 .15486 L
.25577 .15538 L
.25694 .15595 L
.26171 .15823 L
.30236 .17635 L
.34148 .19174 L
.38307 .20613 L
.42313 .21833 L
.46168 .2287 L
.48123 .2335 L
.49159 .23592 L
.49457 .23661 L
.49739 .23725 L
.49862 .23752 L
.49993 .23782 L
.50061 .2377 L
.50136 .23753 L
.50269 .23723 L
.52311 .23246 L
.54217 .22772 L
.58238 .21675 L
.62107 .20479 L
.66221 .19036 L
.70183 .17459 L
.7218 .16587 L
.7305 .16189 L
.73994 .15745 L
.74249 .15622 L
.74388 .15555 L
.74519 .15492 L
.7463 .30902 L
.74749 .30902 L
.75003 .30902 L
.75955 .30902 L
.7805 .30902 L
.82178 .30902 L
Mistroke
.86154 .30902 L
.89978 .30902 L
.94048 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0057oool00`1Vooooooooo`0Woooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000koooo00<0I_ooooooool0D?ooo`00DOooo`<0I_lQoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03Woool306KoD_ooo`00DOooo`0306Ko
oooooooo0080I_lUoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
03Ooool206Ko0_ooo`0306Kooooooooo053oool0057oool00`1Vooooooooo`02oooo0P1VobCoool2
00002_ooo`<00004oooo00<0003oooooool0=?ooo`<0I_l4oooo00<0I_ooooooool0D?ooo`00DOoo
o`0306Kooooooooo00Coool206Ko=Oooo`80000coooo0P1Vo`Ooool00`1Vooooooooo`1@oooo001A
oooo00<0I_ooooooool01_ooo`80I_lcoooo00<0003oooooool0;oooo`<0I_l9oooo00<0I_oooooo
ool0D?ooo`00DOooo`0306Kooooooooo00Soool306Ko<?ooo`030000oooooooo02goool206Ko3?oo
o`0306Kooooooooo053oool0057oool00`1Vooooooooo`0;oooo0P1Vobkoool00`000?ooooooo`0Z
oooo0`1Vo`koool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool03Oooo`<0I_l[oooo0P00
02Woool206Ko4Oooo`0306Kooooooooo053oool0057oool00`1Vooooooooo`0@oooo0P1VobWoool0
0`000?ooooooo`0Uoooo0`1Voa?oool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool04_oo
o`<0I_lVoooo00<0003oooooool08oooo`80I_lFoooo00<0I_ooooooool0D?ooo`00DOooo`0306Ko
oooooooo01Goool306Ko8oooo`030000oooooooo023oool306Ko6?ooo`0306Kooooooooo053oool0
057oool00`1Vooooooooo`0Hoooo101Voaooool200007oooo`80I_lKoooo00<0I_ooooooool0D?oo
o`00DOooo`0306Kooooooooo01coool306Ko7?ooo`030000oooooooo01_oool306Ko7Oooo`0306Ko
oooooooo053oool0057oool00`1Vooooooooo`0Ooooo0`1VoaWoool00`000?ooooooo`0Hoooo0`1V
ob3oool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool08_ooo`@0I_lEoooo00<0003ooooo
ool05?ooo`@0I_lSoooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo02Koool306Ko4_oo
o`80000Boooo0`1VobOoool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0:Oooo`<0I_l?
oooo00<0003oooooool03_ooo`<0I_lZoooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo
02;oool200001?ooo`800002oooo00<0I_l0000000000P0000?oool200001Oooo`030000oooooooo
00[oool406Ko;Oooo`0306Kooooooooo053oool0057oool00`1Vooooooooo`0Qoooo00@0003ooooo
ool00008oooo00<0003oooooool00`1Vo`040000oooooooo00001?ooo`030000oooooooo00Koool4
06Ko<Oooo`0306Kooooooooo053oool0057oool00`1Vooooooooo`0Qoooo00@0003oooooool00009
oooo00<0003oooooool00oooo`80I_l00`00001Vooooo`02oooo0`000003oooo06Ko06Ko00<0I_le
oooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo01_oool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200000_ooo`<0I_l01000001Vo`1Vo`1Voc[oool00`1Voooo
ooooo`1@oooo001Aoooo00<0I_ooooooool08Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOoo
o`0306Kooooooooo02;oool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0koooo00<0
I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool20000??ooo`0306Kooooooooo053oool0
057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool0
0`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool00`1Voooo
ooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool001Soool200009Oooo`@0000>
oooo00<0I_ooooooool05?ooo`D0000Roooo0P0002Coool500004oooo`0306Kooooooooo00goool4
00009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool03oooo`0306Ko
oooooooo01Koool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo01?oool0
0`1Vooooooooo`0=oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Oooo`030000
oooooooo02Coool00`000?ooooooo`0>oooo00<0I_ooooooool05_ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool04oooo`0306Kooooooooo00koool00`000?ooooooo`0W
oooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0
003oooooool03Oooo`0306Kooooooooo00koool400001?ooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool04oooo`0306Kooooooooo00ooool00`000?ooooooo`0Woooo00<0
003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00003_ooo`0306Ko
oooooooo01Koool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0Coooo00<0I_oooooo
ool03Oooo`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P00
00ooool00`1Vooooooooo`0Eoooo0P0002Coool00`000?ooooooo`0Toooo0P0001Goool00`1Voooo
ooooo`0>oooo0P0002Ooool200005oooo`00DOooo`0306Kooooooooo03_oool00`000?ooooooo`0k
oooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool20000??ooo`0306Kooooooooo
053oool0057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0
057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool0
0`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`03oooo00?o09Woool000001oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool04oooo`03o`2Ioooooooo
00ooool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo03_oool0
0ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?oo
o`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo03_oool0
0ol0VOooooooo`1@oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000>oooo`03o`2Ioooooooo053oool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P00
03coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
08ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool0
0ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?oo
o`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000koooo00?o09Wooooo
ool0D?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool007coool200002_ooo`<00004oooo00<0003oooooool0>ooo
o`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P00
03coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0>ooo
o`03o`2Ioooooooo053oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000>oooo`03o`2I
oooooooo053oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0koooo00?o09Woooooool0D?oo
o`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Sooo
o`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000l
oooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo0027oooo1@0000?oool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0koooo00?o09Woooooool0D?oo
o`00ROooo`030000oooooooo00?oool30000>oooo`03o`2Ioooooooo053oool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0
003oooooool02oooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002Ooo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75071 .30902 L
.75216 .30902 L
.75287 .30902 L
.75351 .30902 L
s
.75351 .30902 m
.75363 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24016 .30902 L
.24276 .30902 L
.24392 .30902 L
.24502 .30902 L
.24629 .15463 L
.24745 .1552 L
.25261 .15768 L
.26171 .16195 L
.2999 .17862 L
.34055 .19429 L
.37968 .2076 L
.42126 .22005 L
.46133 .2306 L
.4797 .23501 L
.49014 .2374 L
.49523 .23854 L
.49764 .23907 L
.49871 .23931 L
.49988 .23956 L
.50102 .23937 L
.50224 .2391 L
.50482 .23853 L
.5095 .23748 L
.51982 .23512 L
.54088 .23005 L
.58108 .21939 L
.61977 .20777 L
.66091 .19377 L
.70054 .17844 L
.7205 .16997 L
.73864 .16179 L
.74348 .15953 L
.74873 .15704 L
.75114 .15588 L
.75245 .15524 L
.75369 .15465 L
.75473 .30902 L
.75586 .30902 L
.75825 .30902 L
.7792 .30902 L
.82048 .30902 L
Mistroke
.86024 .30902 L
.89849 .30902 L
.93918 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004ooool00`1Vooooooooo`0Yoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000moooo00<0I_ooooooool0C_ooo`00Coooo`<0I_lSoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03coool206KoD?ooo`00Coooo`0306Ko
oooooooo00<0I_lVoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
03Woool306Ko00?oool0I_ooool0Coooo`00Coooo`0306Kooooooooo00?oool206Ko9Oooo`80000:
oooo0`0000Coool00`000?ooooooo`0goooo0P1Vo`Coool00`1Vooooooooo`1>oooo001?oooo00<0
I_ooooooool01Oooo`80I_lfoooo0P0003Goool306Ko1_ooo`0306Kooooooooo04koool004ooool0
0`1Vooooooooo`07oooo0P1VocCoool00`000?ooooooo`0boooo0P1Vo`Woool00`1Vooooooooo`1>
oooo001?oooo00<0I_ooooooool02Oooo`<0I_laoooo00<0003oooooool0;oooo`<0I_l;oooo00<0
I_ooooooool0C_ooo`00Coooo`0306Kooooooooo00coool306Ko;_ooo`030000oooooooo02goool2
06Ko3_ooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0?oooo0P1Vobcoool20000:ooo
o`<0I_l@oooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo017oool306Ko:Oooo`030000
oooooooo02Soool206Ko4oooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0Doooo0`1V
obKoool00`000?ooooooo`0Uoooo0`1VoaGoool00`1Vooooooooo`1>oooo001?oooo00<0I_oooooo
ool05oooo`80I_lToooo00<0003oooooool08_ooo`<0I_lHoooo00<0I_ooooooool0C_ooo`00Cooo
o`0306Kooooooooo01Woool206Ko8_ooo`80000Qoooo0P1Voa_oool00`1Vooooooooo`1>oooo001?
oooo00<0I_ooooooool06oooo`80I_lPoooo00<0003oooooool07Oooo`<0I_lMoooo00<0I_oooooo
ool0C_ooo`00Coooo`0306Kooooooooo01goool306Ko7Oooo`030000oooooooo01[oool306Ko8?oo
o`0306Kooooooooo04koool004ooool00`1Vooooooooo`0Poooo101VoaWoool00`000?ooooooo`0G
oooo0`1Vob?oool00`1Vooooooooo`1>oooo001?oooo00<0I_ooooooool09?ooo`@0I_lEoooo0P00
01Goool306Ko9_ooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0Xoooo0`1Voa;oool0
0`000?ooooooo`0@oooo101VobWoool00`1Vooooooooo`1>oooo001?oooo00<0I_ooooooool09?oo
o`800004oooo0P000080I_l00oooo`000000000200000oooo`800005oooo00<0003oooooool02_oo
o`H0I_l]oooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo02?oool010000?ooooooo`00
00Ooool0101Vo`00001Vo`1Vo`?oool010000?ooooooo`0000Coool00`000?ooooooo`06oooo101V
oc?oool00`1Vooooooooo`1>oooo001>oooo00<0I_ooooooool09?ooo`040000oooooooo00002Ooo
o`030000oooo06Ko00<0I_l2oooo00<0003oooooool00_ooo`<00004oooo0P1VocSoool00`1Voooo
ooooo`1=oooo001>oooo00<0I_ooooooool07_ooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`80000306Ko0_ooo`030000oooo06Ko00@0I_ljoooo00<0I_ooooooool0COoo
o`00C_ooo`0306Kooooooooo02Coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`02oooo0P1Vo`03000006Kooooo03koool00`1Vooooooooo`1=oooo001>oooo00<0
I_ooooooool09Oooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo03koool00`1Voooo
ooooo`1=oooo001>oooo00<0I_ooooooool0?_ooo`80000ooooo00<0I_ooooooool0COooo`00C_oo
o`0306Kooooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`00C_ooo`0306Ko
oooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`00C_ooo`0306Kooooooooo
03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`006?ooo`80000Uoooo100000_oool0
0`1Vooooooooo`0Goooo1@0002;oool200009?ooo`D0000Foooo00<0I_ooooooool02_ooo`@0000V
oooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`000?ooooooo`0<oooo00<0I_oooooo
ool06Oooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool05_ooo`0306Ko
oooooooo00[oool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Ioooo00<0003ooooo
ool09?ooo`030000oooooooo00_oool00`1Vooooooooo`0Ioooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Foooo00<0I_ooooooool02oooo`030000oooooooo02Ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool00`000?oo
ooooo`0:oooo00<0I_ooooooool04Oooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0Foooo00<0I_ooooooool03?ooo`030000oooooooo02Ooool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0000;oooo00<0I_oooooo
ool06Oooo`030000oooooooo02;oool200009_ooo`030000oooooooo01Koool00`1Vooooooooo`0:
oooo00@0003oooooool0000Uoooo00@0003oooooool0000Foooo000Hoooo0P0002Koool200003?oo
o`0306Kooooooooo01Soool200009?ooo`030000oooooooo02Coool200006?ooo`0306Kooooooooo
00_oool200009oooo`80000Goooo001>oooo00<0I_ooooooool0?_ooo`030000oooooooo03koool0
0`1Vooooooooo`1=oooo001>oooo00<0I_ooooooool0?_ooo`80000ooooo00<0I_ooooooool0COoo
o`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`00C_oo
o`0306Kooooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`00C_ooo`0306Ko
oooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0COooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Eoooo00?o09Woooooool03Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0m
oooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?
oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo
04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo
03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool0
08ooool20000?_ooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003ooooo
ool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000moooo00?o09Woooooool0C_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo03goool00ol0VOooooooo`1>oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
03goool00ol0VOooooooo`1>oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_oo
o`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Sooo
o`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0m
oooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?
oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo
04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo03goool00ol0VOooooooo`1>oooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0003goool00ol0VOooooooo`1>
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0m
oooo00?o09Woooooool0C_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0moooo00?o
09Woooooool0C_ooo`00Soooo`80000noooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo
03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool0
08ooool20000?_ooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003ooooo
ool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_oo
o`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0moooo00?o
09Woooooool0C_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000moooo00?o09Wooooo
ool0C_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`0moooo00?o09Woooooool0C_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?
oooo0P0003koool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo
04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo
03goool00ol0VOooooooo`1>oooo002?oooo0P0003koool00ol0VOooooooo`1>oooo002?oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo0P0003koool0
0ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo0P0003koool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Ooo
o`03o`2Ioooooooo04koool008Ooool500000oooo`030000oooooooo03goool00ol0VOooooooo`1>
oooo0029oooo00<0003oooooool00oooo`030000oooooooo03goool00ol0VOooooooo`1>oooo0029
oooo00<0003oooooool00oooo`<0000moooo00?o09Woooooool0C_ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool300001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
0`000?ooooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`040000oooooooo00001?oo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool3
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0A
oooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75315 .30902 L
.75593 .30902 L
.75853 .30902 L
.7597 .30902 L
.76081 .30902 L
s
.76081 .30902 m
.76093 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23496 .30902 L
.2364 .30902 L
.23711 .30902 L
.23775 .30902 L
.2389 .1549 L
.24014 .1555 L
.24276 .15676 L
.26171 .16558 L
.30142 .18245 L
.33961 .1968 L
.38026 .21028 L
.41939 .22173 L
.46097 .23245 L
.48184 .23732 L
.49099 .23936 L
.49584 .24041 L
.49723 .24071 L
.49856 .241 L
.49974 .24125 L
.50104 .24108 L
.5022 .24084 L
.50348 .24056 L
.50607 .24 L
.51073 .23898 L
.51978 .23695 L
.53959 .23231 L
.57979 .22196 L
.61848 .21068 L
.65962 .19707 L
.69924 .18219 L
.73735 .16601 L
.74744 .16139 L
.75239 .15907 L
.75696 .1569 L
.75952 .15567 L
.76081 .15504 L
.76154 .15469 L
.76223 .30902 L
.76296 .30902 L
.76366 .30902 L
.76498 .30902 L
.76794 .30902 L
Mistroke
.77791 .30902 L
.81615 .30902 L
.85685 .30902 L
.89603 .30902 L
.93767 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004goool00`1Vooooooooo`0[oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000ooooo00<0I_ooooooool0C?ooo`00COooo`<0I_lUoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03goool306KoC_ooo`00COooo`0306Ko
oooooooo0080I_lYoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
03_oool206Ko0_ooo`0306Kooooooooo04coool004goool00`1Vooooooooo`02oooo0`1VobOoool2
00002_ooo`<00004oooo00<0003oooooool0>?ooo`<0I_l4oooo00<0I_ooooooool0C?ooo`00COoo
o`0306Kooooooooo00Goool206Ko>?ooo`80000goooo0P1Vo`Ooool00`1Vooooooooo`1<oooo001=
oooo00<0I_ooooooool01oooo`<0I_leoooo00<0003oooooool0<oooo`<0I_l9oooo00<0I_oooooo
ool0C?ooo`00COooo`0306Kooooooooo00[oool206Ko<oooo`030000oooooooo037oool206Ko3?oo
o`0306Kooooooooo04coool004goool00`1Vooooooooo`0<oooo0`1Voc3oool00`000?ooooooo`0^
oooo0`1Vo`koool00`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool03oooo`80I_l^oooo0P00
02goool206Ko4Oooo`0306Kooooooooo04coool004goool00`1Vooooooooo`0Aoooo0P1Vobcoool0
0`000?ooooooo`0Yoooo0`1Voa?oool00`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool04ooo
o`80I_lZoooo00<0003oooooool09oooo`80I_lFoooo00<0I_ooooooool0C?ooo`00COooo`0306Ko
oooooooo01Goool306Ko9oooo`030000oooooooo02Coool306Ko6?ooo`0306Kooooooooo04coool0
04goool00`1Vooooooooo`0Hoooo101Vob?oool200008_ooo`<0I_lKoooo00<0I_ooooooool0C?oo
o`00COooo`0306Kooooooooo01coool406Ko7oooo`030000oooooooo01goool406Ko7_ooo`0306Ko
oooooooo04coool004goool00`1Vooooooooo`0Poooo0`1Voacoool00`000?ooooooo`0Joooo0`1V
ob;oool00`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool08oooo`<0I_lIoooo00<0003ooooo
ool05oooo`<0I_lUoooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo02Koool406Ko5Ooo
o`80000Doooo101VobSoool00`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool0:_ooo`<0I_lB
oooo00<0003oooooool04?ooo`<0I_l/oooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo
02Koool200001?ooo`80000206Ko00?oool0000000000P0000?oool200001Oooo`030000oooooooo
00goool306Ko;oooo`0306Kooooooooo04coool004goool00`1Vooooooooo`0Uoooo00@0003ooooo
ool00007oooo00@0I_l00000I_l0I_l3oooo00@0003oooooool00004oooo00<0003oooooool02Ooo
o`@0I_lboooo00<0I_ooooooool0C?ooo`00C?ooo`0306Kooooooooo02Koool010000?ooooooo`00
00Woool00`000?ooo`1Vo`0306Ko0_ooo`030000oooooooo00;oool300001Oooo`@0I_lfoooo00<0
I_ooooooool0C?ooo`00C?ooo`0306Kooooooooo023oool400000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200000P1Vo`?oool00`000?ooooooo`02oooo0`1Voc[oool00`1Voooo
ooooo`1<oooo001<oooo00<0I_ooooooool09_ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`040000oooooooooooo0`1Vo`03000006Ko06Ko0080I_lmoooo00<0I_ooooooool0C?oo
o`00C?ooo`0306Kooooooooo02Ooool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0o
oooo00<0I_ooooooool0C?ooo`00C?ooo`0306Kooooooooo043oool20000@?ooo`0306Kooooooooo
04coool004coool00`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo04coool0
04coool00`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo04coool004coool0
0`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo04coool001Soool200009Ooo
o`@00009oooo00<0I_ooooooool06Oooo`D0000Roooo0P0002Coool500005oooo`0306Kooooooooo
00Woool400009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool02_oo
o`0306Kooooooooo01_oool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo
01Ooool00`1Vooooooooo`09oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Ooo
o`030000oooooooo02Coool00`000?ooooooo`09oooo00<0I_ooooooool06oooo`030000oooooooo
02;oool00`000?ooooooo`0Uoooo00<0003oooooool05oooo`0306Kooooooooo00[oool00`000?oo
ooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004
oooo00<0003oooooool02?ooo`0306Kooooooooo01?oool400001?ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool05oooo`0306Kooooooooo00_oool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00002Ooo
o`0306Kooooooooo01_oool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0Goooo00<0
I_ooooooool02Oooo`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000V
oooo0P0000[oool00`1Vooooooooo`0Joooo0P0002Coool00`000?ooooooo`0Toooo0P0001Woool0
0`1Vooooooooo`0:oooo0P0002Ooool200005oooo`00C?ooo`0306Kooooooooo043oool00`000?oo
ooooo`0ooooo00<0I_ooooooool0C?ooo`00C?ooo`0306Kooooooooo043oool20000@?ooo`0306Ko
oooooooo04coool004coool00`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo
04coool004coool00`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo04coool0
04coool00`1Vooooooooo`10oooo00<0003oooooool0?oooo`0306Kooooooooo04coool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003ooooo09T01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool05oooo`03o`2I
oooooooo00_oool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000ooooo00?o
09Woooooool0C?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool007coool200002_ooo`<00004oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008ooool20000@?ooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000?ooo
o`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000
oooooooo03ooool00ol0VOooooooo`1<oooo0027oooo1@0000?oool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00ROooo`030000oooooooo00?oool30000?oooo`03o`2Ioooooooo04coool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo0`0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75853 .30902 L
.76334 .30902 L
.76596 .30902 L
.76725 .30902 L
.76842 .30902 L
.76949 .30902 L
s
.76949 .30902 m
.76959 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.22272 .30902 L
.22738 .30902 L
.22852 .30902 L
.22974 .30902 L
.23043 .15464 L
.23107 .15495 L
.23233 .15556 L
.24276 .16052 L
.26171 .16913 L
.30142 .18557 L
.33961 .19957 L
.38026 .21272 L
.41939 .22389 L
.46097 .23434 L
.48184 .23909 L
.49099 .24108 L
.49584 .24211 L
.49723 .2424 L
.49856 .24268 L
.49974 .24292 L
.50104 .24276 L
.5022 .24252 L
.50348 .24225 L
.50607 .2417 L
.51073 .24071 L
.51978 .23873 L
.53959 .23421 L
.57979 .22411 L
.61848 .2131 L
.65962 .19983 L
.69924 .18532 L
.73735 .16954 L
.75696 .16065 L
.76261 .15799 L
.76538 .15667 L
.7666 .15608 L
.76794 .15543 L
.76914 .15485 L
.77026 .30902 L
.77145 .30902 L
.77272 .30902 L
.77791 .30902 L
.81919 .30902 L
Mistroke
.85895 .30902 L
.89719 .30902 L
.93789 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004_oool00`1Vooooooooo`0]oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<00011oooo00<0I_ooooooool0B_ooo`00Boooo`80I_lXoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo043oool206KoC?ooo`00Boooo`0306Ko
oooo06Ko0080I_l[oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
03goool306Ko00?oool0I_ooool0Boooo`00Boooo`0306Kooooooooo00;oool206Ko:_ooo`80000:
oooo0`0000Coool00`000?ooooooo`0koooo0P1Vo`Coool00`1Vooooooooo`1:oooo001;oooo00<0
I_ooooooool01?ooo`<0I_ljoooo0P0003Woool306Ko1_ooo`0306Kooooooooo04[oool004_oool0
0`1Vooooooooo`07oooo0P1VocSoool00`000?ooooooo`0foooo0P1Vo`Woool00`1Vooooooooo`1:
oooo001;oooo00<0I_ooooooool02Oooo`<0I_leoooo00<0003oooooool0<oooo`<0I_l;oooo00<0
I_ooooooool0B_ooo`00Boooo`0306Kooooooooo00coool206Ko<oooo`030000oooooooo037oool2
06Ko3_ooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`0>oooo0`1Voc3oool20000;ooo
o`<0I_l@oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo017oool206Ko;_ooo`030000
oooooooo02coool206Ko4oooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`0Coooo0P1V
obcoool00`000?ooooooo`0Yoooo0`1VoaGoool00`1Vooooooooo`1:oooo001;oooo00<0I_oooooo
ool05Oooo`80I_lZoooo00<0003oooooool09oooo`80I_lHoooo00<0I_ooooooool0B_ooo`00Booo
o`0306Kooooooooo01Ooool306Ko9oooo`80000Uoooo0`1Voa[oool00`1Vooooooooo`1:oooo001;
oooo00<0I_ooooooool06_ooo`@0I_lSoooo00<0003oooooool08Oooo`<0I_lMoooo00<0I_oooooo
ool0B_ooo`00Boooo`0306Kooooooooo01koool406Ko7oooo`030000oooooooo01goool406Ko8?oo
o`0306Kooooooooo04[oool004_oool00`1Vooooooooo`0Roooo0`1Voacoool00`000?ooooooo`0J
oooo0`1VobCoool00`1Vooooooooo`1:oooo001;oooo00<0I_ooooooool09Oooo`<0I_lIoooo0P00
01Soool306Ko9oooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`0Xoooo101VoaGoool0
0`000?ooooooo`0Coooo101Vob[oool00`1Vooooooooo`1:oooo001;oooo00<0I_ooooooool0:?oo
o`800002oooo0P1Vo`800003oooo100000?oool200001Oooo`030000oooooooo00ooool406Ko;_oo
o`0306Kooooooooo04[oool004_oool00`1Vooooooooo`0Woooo00@0003oooooool00005oooo0`1V
o`03000006Kooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0:oooo1@1Voc;oool0
0`1Vooooooooo`1:oooo001:oooo00<0I_ooooooool0:?ooo`040000oooooooo00002Oooo`030000
06Ko06Ko0080I_l3oooo00<0003oooooool00_ooo`<00006oooo101VocOoool00`1Vooooooooo`1:
oooo001:oooo00<0I_ooooooool08_ooo`@00002oooo00@0003oooooool0000:oooo00D0003ooooo
ooooool0I_l00P0000Goool00`000?ooooooo`04oooo0P1Voc_oool00`1Vooooooooo`1:oooo001:
oooo00<0I_ooooooool0:?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
06Ko06Ko00@0I_l00`00001Vo`1Vo`0406Ko?Oooo`0306Kooooooooo04[oool004[oool00`1Voooo
ooooo`0Yoooo0P0000[oool200001?ooo`<00003oooo00<0I_l00000I_l0@_ooo`0306Kooooooooo
04[oool004[oool00`1Vooooooooo`12oooo0P0004;oool00`1Vooooooooo`1:oooo001:oooo00<0
I_ooooooool0@_ooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001:oooo00<0I_oooooo
ool0@_ooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001:oooo00<0I_ooooooool0@_oo
o`030000oooooooo047oool00`1Vooooooooo`1:oooo000Hoooo0P0002Goool400001oooo`0306Ko
oooooooo01_oool500008_ooo`80000Toooo1@0001Woool00`1Vooooooooo`07oooo100002Koool2
00005oooo`005oooo`040000oooooooo00009?ooo`030000oooooooo00Soool00`1Vooooooooo`0M
oooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Ioooo00<0I_oooooo
ool01oooo`030000oooooooo02Koool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0T
oooo00<0003oooooool01oooo`0306Kooooooooo01goool00`000?ooooooo`0Roooo00<0003ooooo
ool09Oooo`030000oooooooo01Woool00`1Vooooooooo`08oooo00<0003oooooool09oooo`030000
oooooooo01Goool0017oool400001Oooo`030000oooooooo01coool400001?ooo`030000oooooooo
00Koool00`1Vooooooooo`0Eoooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Ooo
o`030000oooooooo01Woool00`1Vooooooooo`09oooo00<0003oooooool09oooo`030000oooooooo
01Coool001Ooool010000?ooooooo`0002Coool010000?ooooooo`0000Ooool00`1Vooooooooo`0M
oooo00<0003oooooool08_ooo`80000Voooo00<0003oooooool06Oooo`0306Kooooooooo00Ooool0
10000?ooooooo`0002Goool010000?ooooooo`0001Koool001Soool200009_ooo`800008oooo00<0
I_ooooooool07?ooo`80000Toooo00<0003oooooool09?ooo`80000Koooo00<0I_ooooooool02?oo
o`80000Woooo0P0001Ooool004[oool00`1Vooooooooo`12oooo00<0003oooooool0@Oooo`0306Ko
oooooooo04[oool004[oool00`1Vooooooooo`12oooo0P0004;oool00`1Vooooooooo`1:oooo001:
oooo00<0I_ooooooool0@_ooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001:oooo00<0
I_ooooooool0@_ooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001:oooo00<0I_oooooo
ool0@_ooo`030000oooooooo047oool00`1Vooooooooo`1:oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`050000ooooooooooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo01Woool00ol0VOooooooo`09
oooo00<0003oooooool09_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Sooo
o`030000oooooooo047oool00ol0VOooooooo`1:oooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`00047oool00ol0VOooooooo`1:oooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Sooo
o`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012
oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?
oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000@Oooo`03o`2Ioooooooo
04[oool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo001loooo0P0000[oool300001?ooo`030000oooooooo047oool0
0ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Sooo
o`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012
oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo047oool0
0ol0VOooooooo`1:oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00047oool00ol0VOoo
ooooo`1:oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool0
0`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_oo
o`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Sooo
o`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11
oooo00?o09Woooooool0B_ooo`00Qoooo`D00003oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008Woool00`000?ooooooo`03oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08Woool00`000?ooooooo`03oooo0`00047oool00ol0VOooooooo`1:oooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003ooooo
ool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo
00[oool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77247 .30902 L
.77511 .30902 L
.77626 .30902 L
.77751 .30902 L
s
.77751 .30902 m
.77764 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21274 .30902 L
.21753 .30902 L
.21884 .30902 L
.22022 .30902 L
.22141 .30902 L
.22272 .15475 L
.22401 .15537 L
.2252 .15595 L
.22791 .15725 L
.23285 .1596 L
.24213 .1639 L
.263 .17314 L
.30213 .18889 L
.34372 .20364 L
.38378 .21613 L
.42233 .22676 L
.46334 .23672 L
.47319 .23893 L
.48376 .24123 L
.48888 .24231 L
.49373 .24332 L
.49584 .24376 L
.49809 .24422 L
.49926 .24446 L
.50055 .2445 L
.50172 .24426 L
.50282 .24403 L
.5408 .23578 L
.57948 .22628 L
.62062 .21484 L
.66025 .20232 L
.69836 .18871 L
.71961 .18038 L
.73892 .17231 L
.74855 .1681 L
.759 .16338 L
.76379 .16117 L
.76887 .15879 L
.7732 .15672 L
.77438 .15615 L
.77566 .15554 L
.77686 .15495 L
.77796 .30902 L
Mistroke
.77925 .30902 L
.78047 .30902 L
.78274 .30902 L
.78783 .30902 L
.79699 .30902 L
.81772 .30902 L
.85633 .30902 L
.89738 .30902 L
.93692 .30902 L
.97494 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Woool00`1Vooooooooo`0_oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<00013oooo00<0I_ooooooool0B?ooo`00BOooo`80I_lZoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo047oool306KoB_ooo`00BOooo`0406Ko
oooo06Ko06Ko;_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0o
oooo0P1Vo`;oool00`1Vooooooooo`18oooo0019oooo00@0I_ooooooooooool306Ko;?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0moooo0P1Vo`Coool00`1Vooooooooo`18oooo0019oooo00<0
I_ooooooool01?ooo`80I_lmoooo0P0003goool00`1Vooooooooo`04oooo00<0I_ooooooool0B?oo
o`00BOooo`0306Kooooooooo00Koool306Ko>_ooo`030000oooooooo03Woool306Ko1oooo`0306Ko
oooooooo04Soool004Woool00`1Vooooooooo`09oooo0P1VocSoool00`000?ooooooo`0goooo0P1V
o`[oool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool02oooo`<0I_leoooo00<0003ooooo
ool0=?ooo`<0I_l<oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo00koool206Ko<ooo
o`80000boooo0`1Vo`ooool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool04?ooo`<0I_l`
oooo00<0003oooooool0;_ooo`<0I_lBoooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo
01?oool206Ko;_ooo`030000oooooooo02_oool306Ko5Oooo`0306Kooooooooo04Soool004Woool0
0`1Vooooooooo`0Eoooo0`1Vob_oool00`000?ooooooo`0Xoooo0`1VoaSoool00`1Vooooooooo`18
oooo0019oooo00<0I_ooooooool06?ooo`80I_lYoooo0P0002Koool306Ko6oooo`0306Kooooooooo
04Soool004Woool00`1Vooooooooo`0Joooo0`1VobKoool00`000?ooooooo`0Soooo0P1Voakoool0
0`1Vooooooooo`18oooo0019oooo00<0I_ooooooool07Oooo`@0I_lRoooo00<0003oooooool08?oo
o`<0I_lPoooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo027oool406Ko7_ooo`030000
oooooooo01koool206Ko8oooo`0306Kooooooooo04Soool004Woool00`1Vooooooooo`0Uoooo0`1V
oa_oool200006oooo`@0I_lUoooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo02Soool3
06Ko6?ooo`030000oooooooo01Coool606Ko:Oooo`0306Kooooooooo04Soool004Woool00`1Voooo
ooooo`0Zoooo0P000080I_l2oooo0P0000?oool400000oooo`800005oooo00<0003oooooool04?oo
o`@0I_l_oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo02Woool01@000?ooooooo`00
0?ooo`0406Ko0oooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0=
oooo0`1Voc?oool00`1Vooooooooo`18oooo0018oooo00<0I_ooooooool0:_ooo`040000oooooooo
00001Oooo`@0I_l00`00001Vooooo`05oooo00<0003oooooool00_ooo`<00009oooo101VocKoool0
0`1Vooooooooo`18oooo0018oooo00<0I_ooooooool09?ooo`@00002oooo00@0003oooooool0000:
oooo00D00000I_l0I_l0I_ooool00P0000Goool00`000?ooooooo`05oooo101Voc[oool00`1Voooo
ooooo`18oooo0018oooo00<0I_ooooooool0:_ooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`0306Ko000006Ko0080I_l3oooo00@0003oooooooooool406Ko?_ooo`0306Kooooooooo
04Soool004Soool00`1Vooooooooo`0[oooo0P0000[oool200001?ooo`<000001Oooo`1Vo`1Vo`1V
o`00000306Ko@_ooo`0306Kooooooooo04Soool004Soool00`1Vooooooooo`14oooo0P0004Coool0
0`1Vooooooooo`18oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool00`1Voooo
ooooo`18oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool00`1Vooooooooo`18
oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool00`1Vooooooooo`18oooo000H
oooo0P0002Goool400001Oooo`0306Kooooooooo01goool500008_ooo`80000Toooo1@0001_oool0
0`1Vooooooooo`05oooo100002Koool200005oooo`005oooo`040000oooooooo00009?ooo`030000
oooooooo00Koool00`1Vooooooooo`0Ooooo00<0003oooooool08_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Koooo00<0I_ooooooool01Oooo`030000oooooooo02Koool010000?ooooooo`00
01Koool001Woool00`000?ooooooo`0Toooo00<0003oooooool01Oooo`0306Kooooooooo01ooool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo01_oool00`1Vooooooooo`06
oooo00<0003oooooool09oooo`030000oooooooo01Goool0017oool400001Oooo`030000oooooooo
01coool400001?ooo`030000oooooooo00Coool00`1Vooooooooo`0Goooo100000Coool00`000?oo
ooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo01_oool00`1Vooooooooo`07oooo00<0
003oooooool09oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002Coool010000?oo
ooooo`0000Goool00`1Vooooooooo`0Ooooo00<0003oooooool08_ooo`80000Voooo00<0003ooooo
ool06oooo`0306Kooooooooo00Goool010000?ooooooo`0002Goool010000?ooooooo`0001Koool0
01Soool200009_ooo`800006oooo00<0I_ooooooool07_ooo`80000Toooo00<0003oooooool09?oo
o`80000Moooo00<0I_ooooooool01_ooo`80000Woooo0P0001Ooool004Soool00`1Vooooooooo`14
oooo00<0003oooooool0@oooo`0306Kooooooooo04Soool004Soool00`1Vooooooooo`14oooo0P00
04Coool00`1Vooooooooo`18oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool0
0`1Vooooooooo`18oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool00`1Voooo
ooooo`18oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo04?oool00`1Vooooooooo`18
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo
01_oool00ol0VOooooooo`07oooo00<0003oooooool09_ooo`030000oooooooo01Goool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?oo
o`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18
oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13
oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo
04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo001foooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`13oooo00?o09Woooooool0B?oo
o`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00MOooo`040000oooooooo00002Oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0004?oool00ol0VOooooooo`18oooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0@oooo`03o`2I
oooooooo04Soool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool007Koool200002_ooo`800004
oooo0`0000Coool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Wooooo
ool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?oo
o`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18
oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0@oooo`03o`2Ioooooooo
04Soool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`13
oooo00?o09Woooooool0B?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000@oooo`03o`2Ioooooooo04Soool007_oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo04?oool00ol0VOooooooo`18oooo001loooo0P0000[oool300001?oo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo0P0004Coool00ol0VOooooooo`18
oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13
oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo
04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Wooooo
ool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo001eoooo00@0003oooooool0000:oooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`13oooo00?o09Wooooo
ool0B?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo0`0004?oool00ol0VOooooooo`18oooo001eoooo00@0003oooooool0000;oooo00@0003ooooo
ooooool200001Oooo`030000oooooooo04?oool00ol0VOooooooo`18oooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool008ooool00`000?oo
ooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18
oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2I
oooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo
04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool0
08ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Qoooo`D00003oooo00<0003ooooo
ool0@oooo`03o`2Ioooooooo04Soool008Woool00`000?ooooooo`03oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008Woool00`000?ooooooo`03oooo0`0004?oool00ol0VOooooooo`18
oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0;oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool0
10000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002Oooo`@00003oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77751 .30902 L
.78008 .30902 L
.78283 .30902 L
.78364 .30902 L
.78441 .30902 L
.7851 .30902 L
s
.7851 .30902 m
.78517 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21019 .30902 L
.2114 .30902 L
.21274 .30902 L
.21394 .30902 L
.21506 .15489 L
.21625 .15546 L
.21753 .15608 L
.22272 .15856 L
.26394 .17688 L
.30365 .19242 L
.34184 .20563 L
.38249 .21806 L
.42162 .22861 L
.4632 .23848 L
.47335 .2407 L
.48407 .24297 L
.49322 .24484 L
.49573 .24535 L
.49711 .24562 L
.49842 .24588 L
.49963 .24613 L
.50095 .24601 L
.50215 .24577 L
.50327 .24555 L
.54182 .23735 L
.58108 .22792 L
.61883 .21768 L
.65904 .20535 L
.69772 .19191 L
.73886 .17571 L
.75939 .1668 L
.7694 .16225 L
.77849 .15799 L
.78304 .15581 L
.78428 .1552 L
.7856 .15456 L
.78673 .30902 L
.78797 .30902 L
.79691 .30902 L
.8166 .30902 L
.85694 .30902 L
.89576 .30902 L
.93704 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Ooool00`1Vooooooooo`0aoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<00015oooo00<0I_ooooooool0A_ooo`00Aoooo`<0I_l[oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04?oool306KoB?ooo`00Aoooo`0306Ko
oooooooo0080I_l_oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
047oool206Ko0_ooo`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`02oooo0P1Vobkoool2
00002_ooo`<00004oooo00<0003oooooool0?oooo`80I_l4oooo00<0I_ooooooool0A_ooo`00Aooo
o`0306Kooooooooo00Coool206Ko?oooo`80000noooo0P1Vo`Koool00`1Vooooooooo`16oooo0017
oooo00<0I_ooooooool01_ooo`80I_lmoooo00<0003oooooool0>oooo`80I_l8oooo00<0I_oooooo
ool0A_ooo`00Aoooo`0306Kooooooooo00Soool306Ko>_ooo`030000oooooooo03Woool206Ko2_oo
o`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`0;oooo0P1VocSoool00`000?ooooooo`0f
oooo0`1Vo`coool00`1Vooooooooo`16oooo0017oooo00<0I_ooooooool03Oooo`<0I_leoooo0P00
03Goool206Ko3oooo`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`0@oooo0P1Voc?oool0
0`000?ooooooo`0aoooo0`1Voa7oool00`1Vooooooooo`16oooo0017oooo00<0I_ooooooool04_oo
o`<0I_l`oooo00<0003oooooool0;_ooo`<0I_lDoooo00<0I_ooooooool0A_ooo`00Aoooo`0306Ko
oooooooo01Goool306Ko;Oooo`030000oooooooo02_oool306Ko5oooo`0306Kooooooooo04Koool0
04Ooool00`1Vooooooooo`0Hoooo101VobWoool20000:?ooo`@0I_lJoooo00<0I_ooooooool0A_oo
o`00Aoooo`0306Kooooooooo01coool306Ko9_ooo`030000oooooooo02Coool306Ko7_ooo`0306Ko
oooooooo04Koool004Ooool00`1Vooooooooo`0Ooooo0`1Vob?oool00`000?ooooooo`0Qoooo0`1V
ob7oool00`1Vooooooooo`16oooo0017oooo00<0I_ooooooool08_ooo`@0I_lOoooo00<0003ooooo
ool07Oooo`@0I_lToooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo02Koool306Ko7?oo
o`80000Koooo0`1VobSoool00`1Vooooooooo`16oooo0017oooo00<0I_ooooooool0:Oooo`<0I_lI
oooo00<0003oooooool05oooo`<0I_l[oooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo
02coool200000P1Vo`;oool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Doooo0`1V
obkoool00`1Vooooooooo`16oooo0017oooo00<0I_ooooooool0:oooo`050000oooooooo0000oooo
00<0I_l4oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo013oool4
06Ko<Oooo`0306Kooooooooo04Koool004Koool00`1Vooooooooo`0/oooo00@0003oooooool00004
oooo101Vo`03oooo0000oooo00Koool00`000?ooooooo`02oooo0`0000_oool506Ko=_ooo`0306Ko
oooooooo04Goool004Koool00`1Vooooooooo`0Voooo100000;oool010000?ooooooo`0000Soool2
06Ko00<00000I_ooool00_ooo`800005oooo00<0003oooooool01_ooo`D0I_lkoooo00<0I_oooooo
ool0AOooo`00A_ooo`0306Kooooooooo02coool010000?ooooooo`0000Soool010000?ooooooo`00
00<0I_l00`00001Vooooo`04oooo00@0003oooooooooool506Ko@?ooo`0306Kooooooooo04Goool0
04Koool00`1Vooooooooo`0]oooo0P0000[oool200001?ooo`<0000406Ko00@00000I_l0I_l0I_m5
oooo00<0I_ooooooool0AOooo`00A_ooo`0306Kooooooooo04Koool20000Aoooo`0306Kooooooooo
04Goool004Koool00`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo04Goool0
04Koool00`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo04Goool004Koool0
0`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo04Goool001Soool200009Ooo
o`@00003oooo00<0I_ooooooool07oooo`D0000Roooo0P0002Coool500007_ooo`0306Kooooooooo
00;oool400009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00<0003oooooool01?oo
o`0306Kooooooooo027oool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo
01koool00`1Vooooooooo`02oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006Ooo
o`030000oooooooo02Coool00`000?ooooooo`03oooo00<0I_ooooooool08Oooo`030000oooooooo
02;oool00`000?ooooooo`0Uoooo00<0003oooooool07_ooo`0306Kooooooooo00?oool00`000?oo
ooooo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004
oooo00<0003oooooool00_ooo`0306Kooooooooo01Woool400001?ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool07_ooo`0306Kooooooooo00Coool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00009?ooo`040000oooooooo00000ooo
o`0306Kooooooooo027oool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0Noooo00<0
I_ooooooool00_ooo`040000oooooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000V
oooo0P0000Coool00`1Vooooooooo`0Poooo0P0002Coool00`000?ooooooo`0Toooo0P00023oool0
0`1Vooooooooo`03oooo0P0002Ooool200005oooo`00A_ooo`0306Kooooooooo04Koool00`000?oo
ooooo`16oooo00<0I_ooooooool0AOooo`00A_ooo`0306Kooooooooo04Koool20000Aoooo`0306Ko
oooooooo04Goool004Koool00`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo
04Goool004Koool00`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo04Goool0
04Koool00`1Vooooooooo`16oooo00<0003oooooool0A_ooo`0306Kooooooooo04Goool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool07Oooo`03o`2I
oooooooo00Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000AOooo`03o`2Ioooooooo04Koool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00015oooo00?o
09Woooooool0A_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool007coool200002_ooo`<00004oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000AOoo
o`03o`2Ioooooooo04Koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_oo
o`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo0027oooo1@0000?oool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00ROooo`030000oooooooo00?oool30000AOooo`03o`2Ioooooooo04Koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?oo
ooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.77751 .30902 L
.78293 .30902 L
.78866 .30902 L
.79102 .30902 L
.79232 .30902 L
.79355 .30902 L
s
.79355 .30902 m
.79362 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.19721 .30902 L
.20178 .30902 L
.20433 .30902 L
.20562 .30902 L
.20635 .15451 L
.20704 .15484 L
.21274 .15759 L
.22272 .16227 L
.26149 .17914 L
.30271 .19496 L
.34242 .20837 L
.38061 .21978 L
.42126 .2305 L
.46039 .23961 L
.48036 .24384 L
.49087 .24596 L
.49616 .247 L
.49761 .24729 L
.49841 .24744 L
.49917 .24759 L
.49987 .24772 L
.50063 .24763 L
.50133 .24749 L
.50197 .24737 L
.52284 .24318 L
.54204 .23907 L
.5813 .22987 L
.61906 .21987 L
.65926 .20784 L
.69795 .19472 L
.73909 .17891 L
.75961 .17022 L
.76962 .16577 L
.77871 .16161 L
.78326 .15949 L
.78819 .15714 L
.79045 .15606 L
.79169 .15546 L
.79284 .1549 L
.79383 .30902 L
.79489 .30902 L
.79713 .30902 L
.81682 .30902 L
.85809 .30902 L
Mistroke
.89786 .30902 L
.9361 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Goool00`1Vooooooooo`0coooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<00017oooo00<0I_ooooooool0A?ooo`00AOooo`<0I_l]oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04Koool206KoA_ooo`00AOooo`0306Ko
oooooooo00<0I_l`oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
04?oool306Ko00?oool0I_ooool0AOooo`00AOooo`0306Kooooooooo00?oool206Ko;oooo`80000:
oooo0`0000Coool00`000?ooooooo`11oooo0P1Vo`Coool00`1Vooooooooo`14oooo0015oooo00<0
I_ooooooool01Oooo`80I_m0oooo0P0003ooool306Ko1_ooo`0306Kooooooooo04Coool004Goool0
0`1Vooooooooo`07oooo0P1Vockoool00`000?ooooooo`0loooo0P1Vo`Woool00`1Vooooooooo`14
oooo0015oooo00<0I_ooooooool02Oooo`<0I_lkoooo00<0003oooooool0>Oooo`<0I_l;oooo00<0
I_ooooooool0A?ooo`00AOooo`0306Kooooooooo00coool306Ko>?ooo`030000oooooooo03Koool3
06Ko3_ooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`0?oooo0P1VocKoool20000=Ooo
o`80I_lAoooo00<0I_ooooooool0A?ooo`00AOooo`0306Kooooooooo017oool306Ko<oooo`030000
oooooooo037oool306Ko4oooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`0Doooo0`1V
oc3oool00`000?ooooooo`0^oooo0`1VoaKoool00`1Vooooooooo`14oooo0015oooo00<0I_oooooo
ool05oooo`80I_l^oooo00<0003oooooool0;?ooo`80I_lIoooo00<0I_ooooooool0A?ooo`00AOoo
o`0306Kooooooooo01Woool306Ko:oooo`80000Zoooo0`1Voa_oool00`1Vooooooooo`14oooo0015
oooo00<0I_ooooooool07?ooo`80I_lYoooo00<0003oooooool09oooo`80I_lNoooo00<0I_oooooo
ool0A?ooo`00AOooo`0306Kooooooooo01koool306Ko9_ooo`030000oooooooo02Coool306Ko8?oo
o`0306Kooooooooo04Coool004Goool00`1Vooooooooo`0Qoooo0`1Vob?oool00`000?ooooooo`0Q
oooo0`1Vob?oool00`1Vooooooooo`14oooo0015oooo00<0I_ooooooool09?ooo`@0I_lOoooo0P00
01koool406Ko9_ooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`0Xoooo0`1Voacoool0
0`000?ooooooo`0Ioooo101Vob[oool00`1Vooooooooo`14oooo0015oooo00<0I_ooooooool0:ooo
o`<0I_l200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01Goool406Ko;_oo
o`0306Kooooooooo04Coool004Goool00`1Vooooooooo`0]oooo00D00000I_l0I_l00000I_l01ooo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Aoooo101Voc;oool0
0`1Vooooooooo`14oooo0014oooo00<0I_ooooooool0;_ooo`050000oooooooo0000oooo00@0I_l4
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300003_ooo`<0I_lfoooo00<0I_oooooo
ool0A?ooo`00A?ooo`0306Kooooooooo02Soool400000_ooo`040000oooooooo00001Oooo`D0I_l0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0:oooo101VocWoool00`1Vooooooooo`14
oooo0014oooo00<0I_ooooooool0;_ooo`040000oooooooo00002?ooo`040000oooo06Ko00000`1V
o`030000oooooooo00Coool00`000?ooooooo`06oooo101Vocgoool00`1Vooooooooo`14oooo0014
oooo00<0I_ooooooool0;oooo`80000:oooo0P0000Coool300000`1Vo`03oooo0000oooo00;oool5
06Ko@Oooo`0306Kooooooooo04Coool004Coool00`1Vooooooooo`17oooo00<0I_l0000000000P1V
odKoool00`1Vooooooooo`14oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo04Ooool0
0`1Vooooooooo`14oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo04Ooool00`1Voooo
ooooo`14oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo04Ooool00`1Vooooooooo`14
oooo000Hoooo0P0002Goool4000000?oool0I_ooool08_ooo`D0000Roooo0P0002Coool500007ooo
o`0406Kooooooooooooo100002Koool200005oooo`005oooo`040000oooooooo00009?ooo`030000
oooooooo00;oool00`1Vooooooooo`0Soooo00<0003oooooool08_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Ooooo00D0I_ooooooooooool00000:?ooo`040000oooooooo00005_ooo`006Ooo
o`030000oooooooo02Coool01@000?ooooooooooo`1Vo`0Uoooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Ooooo00<0I_ooooooool00_ooo`030000oooooooo02Ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0Loooo100000Coool010000?oo
ooooo`1Voagoool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003ooooo
ool07oooo`0306Kooooooooo00?oool00`000?ooooooo`0Woooo00<0003oooooool05?ooo`005ooo
o`040000oooooooo00009?ooo`060000oooooooo0000oooo06Ko9Oooo`030000oooooooo02;oool2
00009_ooo`030000oooooooo01ooool01@1Vooooooooooooo`000002oooo00<0003oooooool08ooo
o`040000oooooooo00005_ooo`006?ooo`80000Voooo0P0000;oool00`1Vooooooooo`0Roooo0P00
02Coool00`000?ooooooo`0Toooo0P00027oool00`1Vooooooooo`02oooo0P0002Ooool200005ooo
o`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`17oooo00<0I_ooooooool0A?ooo`00A?oo
o`0306Kooooooooo04Soool20000B?ooo`0306Kooooooooo04Coool004Coool00`1Vooooooooo`18
oooo00<0003oooooool0Aoooo`0306Kooooooooo04Coool004Coool00`1Vooooooooo`18oooo00<0
003oooooool0Aoooo`0306Kooooooooo04Coool004Coool00`1Vooooooooo`18oooo00<0003ooooo
ool0Aoooo`0306Kooooooooo04Coool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Uoooo00<0003oooooool07oooo`03o`2Ioooooooo00?oool00`000?ooooooo`0Voooo00<0
003oooooool05Oooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P00
04Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?oo
o`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo001eoooo00@0
003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000Aoooo`03o`2I
oooooooo04Coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`17oooo00?o09Woooooool0A?oo
o`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P00
04Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool007coool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo001koooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<00017oooo00?o09Woooooool0A?ooo`00Noooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
07coool200002_ooo`<00004oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool2
0000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?oo
o`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool007Koool200001?ooo`800005oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool007Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo001eoooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool30000Aoooo`03o`2Ioooooooo04Coool007Goool010000?oo
ooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0Aoooo`03o`2Ioooooooo
04Coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool007Koool200002Oooo`@00003oooo0`00
00Coool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o09Wooooo
ool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?oo
o`00Soooo`800018oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo0027
oooo1@0000?oool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00ROooo`030000oooooooo00?oool3
0000Aoooo`03o`2Ioooooooo04Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool4
00000oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`040000oooooooo
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`000?ooooooo`08oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool2
00001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79321 .30902 L
.79616 .30902 L
.79892 .30902 L
.80016 .30902 L
.80134 .30902 L
s
.80134 .30902 m
.80141 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.18221 .30902 L
.18703 .30902 L
.19227 .30902 L
.19467 .30902 L
.19598 .30902 L
.19721 .30902 L
.19826 .30902 L
.19939 .15498 L
.20064 .15559 L
.20178 .15614 L
.22272 .1659 L
.26243 .18272 L
.30062 .19704 L
.34126 .2105 L
.38039 .22192 L
.42198 .23261 L
.46204 .24167 L
.48042 .24546 L
.49085 .24752 L
.49595 .24849 L
.49712 .24872 L
.49836 .24895 L
.49942 .24915 L
.50059 .24915 L
.50181 .24892 L
.50296 .2487 L
.50553 .24821 L
.51022 .24731 L
.52053 .24527 L
.5416 .2409 L
.58028 .23207 L
.62142 .22142 L
.66105 .20978 L
.69916 .19712 L
.73972 .18187 L
.77876 .16523 L
.789 .16051 L
.7944 .15797 L
.79735 .15656 L
.79879 .15586 L
.80011 .15523 L
.80134 .15463 L
.80251 .30902 L
.80375 .30902 L
.8051 .30902 L
Mistroke
.81059 .30902 L
.82026 .30902 L
.86096 .30902 L
.90014 .30902 L
.94177 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004?oool00`1Vooooooooo`0eoooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<00019oooo00<0I_ooooooool0@_ooo`00@oooo`80I_l`oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04Soool206KoA?ooo`00@oooo`0306Ko
oooo06Ko0080I_lcoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
04Koool206Ko00?oool0I_ooool0@oooo`00@oooo`0306Kooooooooo00;oool306Ko<Oooo`80000:
oooo0`0000Coool00`000?ooooooo`13oooo0`1Vo`?oool00`1Vooooooooo`12oooo0013oooo00<0
I_ooooooool01Oooo`80I_m2oooo0P0004;oool206Ko1_ooo`0306Kooooooooo04;oool004?oool0
0`1Vooooooooo`07oooo0`1Vocooool00`000?ooooooo`0noooo0`1Vo`Soool00`1Vooooooooo`12
oooo0013oooo00<0I_ooooooool02_ooo`80I_lmoooo00<0003oooooool0??ooo`80I_l;oooo00<0
I_ooooooool0@_ooo`00@oooo`0306Kooooooooo00coool306Ko>_ooo`030000oooooooo03Woool3
06Ko3Oooo`0306Kooooooooo04;oool004?oool00`1Vooooooooo`0?oooo0P1VocSoool20000=ooo
o`<0I_l@oooo00<0I_ooooooool0@_ooo`00@oooo`0306Kooooooooo017oool206Ko=_ooo`030000
oooooooo03Coool206Ko4oooo`0306Kooooooooo04;oool004?oool00`1Vooooooooo`0Coooo0P1V
ocCoool00`000?ooooooo`0aoooo0`1VoaGoool00`1Vooooooooo`12oooo0013oooo00<0I_oooooo
ool05Oooo`<0I_laoooo00<0003oooooool0;_ooo`<0I_lHoooo00<0I_ooooooool0@_ooo`00@ooo
o`0306Kooooooooo01Soool406Ko;Oooo`80000/oooo0`1Voa_oool00`1Vooooooooo`12oooo0013
oooo00<0I_ooooooool07?ooo`@0I_lYoooo00<0003oooooool0:?ooo`<0I_lNoooo00<0I_oooooo
ool0@_ooo`00@oooo`0306Kooooooooo023oool306Ko9_ooo`030000oooooooo02Goool306Ko8Ooo
o`0306Kooooooooo04;oool004?oool00`1Vooooooooo`0Soooo0`1Vob?oool00`000?ooooooo`0R
oooo0`1VobCoool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool09_ooo`@0I_lOoooo0P00
01ooool406Ko9oooo`0306Kooooooooo04;oool004?oool00`1Vooooooooo`0Zoooo0`1Voacoool0
0`000?ooooooo`0Koooo0`1Vob_oool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0;Ooo
o`<0I_l200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01Ooool406Ko;_oo
o`0306Kooooooooo04;oool004?oool00`1Vooooooooo`0_oooo00D00000I_l0I_l00000I_l01ooo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Coooo101Voc;oool0
0`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0<?ooo`050000oooooooo0000oooo00@0I_l4
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300003oooo`@0I_lgoooo00<0I_oooooo
ool0@Oooo`00@_ooo`0306Kooooooooo02[oool400000_ooo`040000oooooooo00001Oooo`D0I_l0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0;oooo101Voc_oool00`1Vooooooooo`11
oooo0012oooo00<0I_ooooooool0<?ooo`040000oooooooo00002?ooo`040000oooo06Ko00000`1V
o`030000oooooooo00Coool00`000?ooooooo`06oooo1@1Vocooool00`1Vooooooooo`11oooo0012
oooo00<0I_ooooooool0<Oooo`80000:oooo0P0000Coool3000000D0I_ooooooooooool000001?oo
o`@0I_m4oooo00<0I_ooooooool0@Oooo`00@_ooo`0306Kooooooooo04Ooool306Ko0P0000<0I_m8
oooo00<0I_ooooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`1:oooo00<0
I_ooooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`1:oooo00<0I_oooooo
ool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`1:oooo00<0I_ooooooool0@Ooo
o`006?ooo`80000Uoooo100002Goool500008_ooo`80000Toooo1@0002;oool00`1Vo`0000000002
00009_ooo`80000Goooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0I_lWoooo00<0
003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Roooo00<0I_l0003oool09ooo
o`040000oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooo`1Vo`0Woooo00<0
003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Roooo00<0I_ooool00000:Ooo
o`030000oooooooo01Goool0017oool400001Oooo`030000oooooooo01coool400001?ooo`030000
06Kooooo01koool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003ooooo
ool08_ooo`0406Kooooooooo0000:Oooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
02Coool010000?ooooooo`0002Ooool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0R
oooo00D0I_l0003oooooool000009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P00
000306Kooooooooo02Coool200009?ooo`030000oooooooo02Coool200009?ooo`0406Kooooo0000
00009oooo`80000Goooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo04[oool00`1Voooo
ooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`80001;oooo00<0I_ooooooool0@Oooo`00@_oo
o`0306Kooooooooo04[oool00`000?ooooooo`1:oooo00<0I_ooooooool0@Oooo`00@_ooo`0306Ko
oooooooo04[oool00`000?ooooooo`1:oooo00<0I_ooooooool0@Oooo`00@_ooo`0306Kooooooooo
04[oool00`000?ooooooo`1:oooo00<0I_ooooooool0@Oooo`004?ooool0000Aoooo000Foooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Qoooo00Go09Woooooooooool0
0000:?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_oo
o`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?oo
ooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo
04Woool00ol0VOooooooo`12oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`19oooo00?o09Woooooool0@_oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
04Woool00ol0VOooooooo`12oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo
04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool0
08ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Wooooo
ool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003ooooo
ool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_oo
o`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?oo
ooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000BOooo`03o`2Ioooooooo04;oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04Woool00ol0VOooooooo`12oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo001loooo0P0000[oool300001?ooo`030000oooooooo04Woool00ol0VOooooooo`12
oooo002?oooo0P0004[oool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo
04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool0
08ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Wooooo
ool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo04Woool00ol0VOooooooo`12
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0004Woool00ol0VOooooooo`12oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo04Woool0
0ol0VOooooooo`12oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo04Woool00ol0VOooooooo`12oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool20000B_oo
o`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool20000B_ooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool20000B_ooo`03o`2Ioooooooo
04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo
04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool0
08ooool20000B_ooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Wooooo
ool0@_ooo`00Qoooo`D00003oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008Woool00`000?oo
ooooo`03oooo0`0004Woool00ol0VOooooooo`12oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200000oooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0>oooo00<0003oooooool02Oooo`<00004oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79892 .30902 L
.80403 .30902 L
.80682 .30902 L
.80819 .30902 L
.80943 .30902 L
s
.80943 .30902 m
.80954 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.18221 .30902 L
.18475 .30902 L
.18744 .30902 L
.18855 .30902 L
.18974 .30902 L
.19104 .15478 L
.19227 .15538 L
.20178 .15991 L
.22272 .16943 L
.26394 .18643 L
.30365 .20084 L
.34184 .2131 L
.38249 .22463 L
.42162 .23442 L
.4632 .24357 L
.47335 .24563 L
.48407 .24774 L
.49322 .24948 L
.49573 .24995 L
.49711 .2502 L
.49842 .25045 L
.49963 .25067 L
.50095 .25056 L
.50215 .25034 L
.50327 .25013 L
.54182 .24253 L
.58108 .23378 L
.61883 .22428 L
.65904 .21284 L
.69772 .20037 L
.73886 .18534 L
.75939 .17708 L
.77849 .1689 L
.79691 .16053 L
.80222 .15802 L
.80482 .15678 L
.80723 .15562 L
.80835 .15508 L
.80941 .15456 L
.81051 .30902 L
.81172 .30902 L
.8166 .30902 L
.85542 .30902 L
.8967 .30902 L
Mistroke
.93646 .30902 L
.9747 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0047oool00`1Vooooooooo`0goooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001;oooo00<0I_ooooooool0@?ooo`00@Oooo`80I_lboooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04[oool206Ko@_ooo`00@Oooo`0406Ko
oooo06Ko06Ko=_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`18
oooo0P1Vo`03oooo06Kooooo047oool0047oool0101Vooooooooooooo`<0I_ldoooo0P0000[oool3
00001?ooo`030000oooooooo04Koool206Ko0oooo`0306Kooooooooo043oool0047oool00`1Voooo
ooooo`04oooo0`1VodCoool20000A?ooo`<0I_l5oooo00<0I_ooooooool0@?ooo`00@Oooo`0306Ko
oooooooo00Ooool206Ko@_ooo`030000oooooooo047oool206Ko2?ooo`0306Kooooooooo043oool0
047oool00`1Vooooooooo`09oooo0`1Vocooool00`000?ooooooo`0noooo0`1Vo`[oool00`1Voooo
ooooo`10oooo0011oooo00<0I_ooooooool03?ooo`80I_lmoooo00<0003oooooool0??ooo`80I_l=
oooo00<0I_ooooooool0@?ooo`00@Oooo`0306Kooooooooo00koool306Ko>_ooo`80000joooo0`1V
o`ooool00`1Vooooooooo`10oooo0011oooo00<0I_ooooooool04Oooo`80I_lhoooo00<0003ooooo
ool0=_ooo`<0I_lBoooo00<0I_ooooooool0@?ooo`00@Oooo`0306Kooooooooo01?oool306Ko=Ooo
o`030000oooooooo03Coool206Ko5Oooo`0306Kooooooooo043oool0047oool00`1Vooooooooo`0F
oooo0P1Voc?oool00`000?ooooooo`0aoooo0`1VoaOoool00`1Vooooooooo`10oooo0011oooo00<0
I_ooooooool06?ooo`<0I_l`oooo0P0002ooool306Ko6_ooo`0306Kooooooooo043oool0047oool0
0`1Vooooooooo`0Koooo0`1Vobgoool00`000?ooooooo`0[oooo0`1Voagoool00`1Vooooooooo`10
oooo0011oooo00<0I_ooooooool07_ooo`@0I_lYoooo00<0003oooooool09oooo`@0I_lPoooo00<0
I_ooooooool0@?ooo`00@Oooo`0306Kooooooooo02;oool306Ko9_ooo`030000oooooooo02Coool3
06Ko9?ooo`0306Kooooooooo043oool0047oool00`1Vooooooooo`0Uoooo0`1Vob?oool200008_oo
o`<0I_lWoooo00<0I_ooooooool0@?ooo`00@Oooo`0306Kooooooooo02Soool406Ko7oooo`030000
oooooooo01goool406Ko:_ooo`0306Kooooooooo043oool0047oool00`1Vooooooooo`0/oooo101V
o`;oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01Woool406Ko;_oo
o`0306Kooooooooo043oool0047oool00`1Vooooooooo`0`oooo00D0I_l00000I_l0I_l000002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Eoooo101Voc;oool0
0`1Vooooooooo`10oooo0010oooo00<0I_ooooooool0<_ooo`040000oooooooo0000101Vo`Goool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Aoooo101VocOoool00`1Vooooooooo`0o
oooo0010oooo00<0I_ooooooool0;?ooo`@00002oooo00@0003oooooool00004oooo101Vo`;oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0>oooo0`1Voc_oool00`1Vooooooooo`0o
oooo0010oooo00<0I_ooooooool0<_ooo`040000oooooooo00002?ooo`04000006Ko06Ko00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0:oooo101Vockoool00`1Vooooooooo`0ooooo0010
oooo00<0I_ooooooool0<oooo`80000:oooo0P000004oooo06Ko06Ko06Ko0`0000Coool00`000?oo
ooooo`04oooo1P1Vod;oool00`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0Aoooo`D0I_l2
00001@1VodSoool00`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0Boooo`0306Ko000006Ko
04goool00`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo04coool0
0`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo04coool00`1Voooo
ooooo`0ooooo000Hoooo0P0002Goool400009Oooo`D0000Roooo0P0002Coool500008oooo`@0000V
oooo0P0001Ooool001Ooool010000?ooooooo`0002Coool00`00001Vooooo`0Xoooo00<0003ooooo
ool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Soooo00<00000I_ooool09_ooo`040000
oooooooo00005_ooo`006Oooo`030000oooooooo02Coool00`000?ooooooo`0Woooo00<0003ooooo
ool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Toooo00<0003oooooool09oooo`030000
oooooooo01Goool0017oool400001Oooo`030000oooooooo01coool400000oooo`0306Ko0000oooo
01ooool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool09?oo
o`0306Ko0000oooo02Soool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0
0000I_ooool0000Woooo00<0003oooooool08_ooo`80000Voooo00<0003oooooool08oooo`040000
06Kooooo00009Oooo`040000oooooooo00005_ooo`006?ooo`80000Voooo0P0002Ooool200009?oo
o`030000oooooooo02Coool200009_ooo`80000Woooo0P0001Ooool0043oool00`1Vooooooooo`1<
oooo00<0003oooooool0C?ooo`0306Kooooooooo03ooool0043oool00`1Vooooooooo`1<oooo0P00
04goool00`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo04coool0
0`1Vooooooooo`0ooooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo04coool00`1Voooo
ooooo`0ooooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo04coool00`1Vooooooooo`0o
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`03
oooo00?o09Woool000002?ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo
02?oool00ol0VOooo`00000Xoooo00<0003oooooool05Oooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000Boooo`03o`2Ioooooooo043oool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P00
04coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool0
08ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001;oooo00?o09Wooooo
ool0@?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool007coool200002_ooo`<00004oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P00
04coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo04_oool00ol0VOooooooo`10oooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000Boooo`03o`2I
oooooooo043oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Sooo
o`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`80001<
oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo
04_oool00ol0VOooooooo`10oooo0027oooo1@0000?oool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00ROooo`030000oooooooo00?oool30000Boooo`03o`2Ioooooooo043oool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool400000oooo`800003oooo0`0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`0;oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo
00Woool300001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79892 .30902 L
.80403 .30902 L
.80943 .30902 L
.81404 .30902 L
.8153 .30902 L
.81599 .30902 L
.81665 .30902 L
s
.81665 .30902 m
.81678 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.17735 .30902 L
.17986 .30902 L
.18109 .30902 L
.18221 .30902 L
.18341 .15493 L
.1847 .15556 L
.18744 .15687 L
.19227 .15917 L
.20178 .16359 L
.22272 .17288 L
.26243 .18888 L
.30062 .2025 L
.34126 .2153 L
.38039 .22617 L
.42198 .23634 L
.46204 .24496 L
.48042 .24856 L
.49085 .25051 L
.49595 .25145 L
.49712 .25166 L
.49836 .25188 L
.49942 .25207 L
.50059 .25207 L
.50181 .25185 L
.50296 .25164 L
.50553 .25118 L
.51022 .25032 L
.52053 .24838 L
.5416 .24422 L
.58028 .23582 L
.62142 .22569 L
.66105 .21462 L
.69916 .20258 L
.73972 .18807 L
.77876 .17224 L
.789 .16776 L
.80011 .16273 L
.8052 .16036 L
.81059 .15782 L
.81281 .15675 L
.8152 .15561 L
.8159 .15527 L
.81656 .15494 L
.81781 .30902 L
Mistroke
.81898 .30902 L
.82026 .30902 L
.86096 .30902 L
.90014 .30902 L
.94177 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003ooool00`1Vooooooooo`0ioooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001=oooo00<0I_ooooooool0?_ooo`00?oooo`<0I_lcoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04coool206Ko@?ooo`00?oooo`0406Ko
oooooooo06Ko>?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`19
oooo0`1Vo`03oooo06Kooooo03ooool003ooool0101Vooooooooooooo`80I_lgoooo0P0000[oool3
00001?ooo`030000oooooooo04Ooool206Ko1?ooo`0306Kooooooooo03koool003ooool00`1Voooo
ooooo`03oooo0`1VodOoool20000Aoooo`0306Kooooooooo00Coool00`1Vooooooooo`0noooo000o
oooo00<0I_ooooooool01_ooo`<0I_m4oooo00<0003oooooool0@oooo`<0I_l7oooo00<0I_oooooo
ool0?_ooo`00?oooo`0306Kooooooooo00Woool206Ko@_ooo`030000oooooooo047oool206Ko2_oo
o`0306Kooooooooo03koool003ooool00`1Vooooooooo`0;oooo0`1Vocooool00`000?ooooooo`0n
oooo0`1Vo`coool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool03_ooo`80I_lmoooo0P00
03goool206Ko3oooo`0306Kooooooooo03koool003ooool00`1Vooooooooo`0@oooo0`1Voc[oool0
0`000?ooooooo`0ioooo0`1Voa7oool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool04ooo
o`<0I_lgoooo00<0003oooooool0=Oooo`@0I_lDoooo00<0I_ooooooool0?_ooo`00?oooo`0306Ko
oooooooo01Koool306Ko=?ooo`030000oooooooo037oool406Ko6?ooo`0306Kooooooooo03koool0
03ooool00`1Vooooooooo`0Ioooo0`1Voc7oool20000;oooo`<0I_lLoooo00<0I_ooooooool0?_oo
o`00?oooo`0306Kooooooooo01coool306Ko;_ooo`030000oooooooo02_oool306Ko7oooo`0306Ko
oooooooo03koool003ooool00`1Vooooooooo`0Ooooo0P1Vobcoool00`000?ooooooo`0Xoooo0`1V
ob;oool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool08Oooo`<0I_lYoooo00<0003ooooo
ool09Oooo`<0I_lUoooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo02Coool406Ko9Ooo
o`80000Soooo0`1VobSoool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0:?ooo`D0I_lP
oooo00<0003oooooool07_ooo`@0I_l[oooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo
02goool406Ko0oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool06ooo
o`<0I_l_oooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo037oool206Ko00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01Ooool4
06Ko<_ooo`0306Kooooooooo03koool003koool00`1Vooooooooo`0doooo00D00000I_l0I_l00000
I_l02?ooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001?oool406Ko=oooo`0306Ko
oooooooo03goool003koool00`1Vooooooooo`0^oooo100000;oool01@000?ooooooo`000?ooo`04
06Ko1Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo00ooool406Ko>oooo`0306Ko
oooooooo03goool003koool00`1Vooooooooo`0doooo00@0003oooooool00005oooo0`1Vo`040000
06Kooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0;oooo101Vocooool00`1Voooo
ooooo`0moooo000noooo00<0I_ooooooool0=Oooo`80000:oooo0P0000@0I_l300001?ooo`030000
oooooooo00Koool506Ko@oooo`0306Kooooooooo03goool003koool00`1Vooooooooo`17oooo101V
o`?oool200000oooo`@0I_m8oooo00<0I_ooooooool0?Oooo`00?_ooo`0306Kooooooooo04_oool3
06Ko00<00000I_l0I_l00P1Vodcoool00`1Vooooooooo`0moooo000noooo00<0I_ooooooool0C_oo
o`030000oooooooo04koool00`1Vooooooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000
oooooooo04koool00`1Vooooooooo`0moooo000Hoooo0P0002Coool00`1Vo`000000000200009Ooo
o`D0000Roooo0P0002Coool500008oooo`@0000Voooo0P0001Ooool001Ooool010000?ooooooo`00
02?oool00`1Vo`000?ooo`0Yoooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Soooo00@0003oooooool0I_lUoooo00@0003oooooool0000Foooo000Ioooo00<0003ooooo
ool08_ooo`0306Kooooo000002Woool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000
oooooooo02Coool00`000?ooo`1Vo`0Woooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0
003oooooool07?ooo`@000001Oooo`1Vooooooooo`00000Poooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Goool00`00001Vooooo`0Woooo00<0003ooooo
ool05?ooo`005oooo`040000oooooooo00008oooo`0506Ko0000oooooooo000002Ooool00`000?oo
ooooo`0Roooo0P0002Koool00`000?ooooooo`0Soooo00@0003oooooool0000Uoooo00@0003ooooo
ool0000Foooo000Hoooo0P0002Coool0101Vooooo`00000002Ooool200009?ooo`030000oooooooo
02Coool200009_ooo`8000000`1Vooooooooo`0Toooo0P0001Ooool003koool00`1Vooooooooo`1>
oooo00<0003oooooool0C_ooo`0306Kooooooooo03goool003koool00`1Vooooooooo`1>oooo0P00
04ooool00`1Vooooooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo04koool0
0`1Vooooooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo04koool00`1Voooo
ooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo04koool00`1Vooooooooo`0m
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Soooo`030000oooooooo04goool0
0ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo04goool00ol0VOooooooo`0noooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo04goool0
0ol0VOooooooo`0noooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000COooo`03o`2Ioooooooo03koool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P00
04koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
08ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool0
0ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001=oooo00?o09Wooooo
ool0?_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool007coool200002_ooo`<00004oooo00<0003oooooool0COoo
o`03o`2Ioooooooo03koool008ooool20000C_ooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P00
04koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0COoo
o`03o`2Ioooooooo03koool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo04goool00ol0VOooooooo`0noooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000COooo`03o`2I
oooooooo03koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool0COooo`03o`2Ioooooooo03koool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Sooo
o`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>
oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo0027oooo1@0000?oool00`000?ooooooo`1=oooo00?o09Wooooo
ool0?_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00ROooo`030000oooooooo00?oool30000COooo`03o`2Ioooooooo03koool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo
00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo00<0003oooooool0O_ooo`00O_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002Oooo`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Woool00`000?ooooooo`1moooo001noooo00<0003oooooool01@00
00ooool00`000?ooooooo`07oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001ooooo00<0003oooooool04Ooo
o`800009oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81373 .30902 L
.81909 .30902 L
.82156 .30902 L
.8239 .30902 L
.82518 .30902 L
s
.82518 .30902 m
.82526 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.16254 .30902 L
.16783 .30902 L
.17044 .30902 L
.17158 .30902 L
.17284 .30902 L
.17396 .30902 L
.17502 .15471 L
.17613 .15525 L
.17733 .15583 L
.18221 .15817 L
.22343 .17654 L
.26314 .19211 L
.30133 .20536 L
.34198 .21782 L
.38111 .2284 L
.42269 .23829 L
.46276 .24668 L
.48114 .25019 L
.49157 .25209 L
.49418 .25256 L
.49666 .25299 L
.49889 .25339 L
.50015 .25355 L
.50131 .25335 L
.51093 .25164 L
.52125 .24974 L
.54231 .24568 L
.58158 .23734 L
.61933 .22829 L
.65953 .21739 L
.69822 .20551 L
.73936 .19119 L
.77898 .17552 L
.79895 .16686 L
.80765 .16291 L
.81709 .1585 L
.81964 .15728 L
.82234 .15599 L
.82345 .15545 L
.82464 .15487 L
.82595 .30902 L
.82718 .30902 L
.8367 .30902 L
.85765 .30902 L
.89893 .30902 L
Mistroke
.93869 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003goool00`1Vooooooooo`0koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001?oooo00<0I_ooooooool0??ooo`00?Oooo`<0I_leoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo04goool306Ko?_ooo`00?Oooo`0306Ko
oooooooo0080I_lioooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
04_oool206Ko0_ooo`0306Kooooooooo03coool003goool00`1Vooooooooo`02oooo0P1VocSoool2
00002_ooo`<00004oooo00<0003oooooool0BOooo`80I_l4oooo00<0I_ooooooool0??ooo`00?Ooo
o`0306Kooooooooo00Coool206KoBOooo`800018oooo0P1Vo`Koool00`1Vooooooooo`0loooo000m
oooo00<0I_ooooooool01_ooo`80I_m7oooo00<0003oooooool0AOooo`80I_l8oooo00<0I_oooooo
ool0??ooo`00?Oooo`0306Kooooooooo00Soool306KoA?ooo`030000oooooooo04?oool206Ko2_oo
o`0306Kooooooooo03coool003goool00`1Vooooooooo`0;oooo0P1Vod;oool00`000?ooooooo`11
oooo0P1Vo`coool00`1Vooooooooo`0loooo000moooo00<0I_ooooooool03Oooo`<0I_looooo0P00
03ooool306Ko3_ooo`0306Kooooooooo03coool003goool00`1Vooooooooo`0@oooo0P1Vocgoool0
0`000?ooooooo`0loooo0P1Voa7oool00`1Vooooooooo`0loooo000moooo00<0I_ooooooool04_oo
o`<0I_ljoooo00<0003oooooool0>Oooo`<0I_lCoooo00<0I_ooooooool0??ooo`00?Oooo`0306Ko
oooooooo01Goool306Ko=oooo`030000oooooooo03Goool406Ko5_ooo`0306Kooooooooo03coool0
03goool00`1Vooooooooo`0Hoooo101Voc?oool20000<_ooo`@0I_lJoooo00<0I_ooooooool0??oo
o`00?Oooo`0306Kooooooooo01coool306Ko<?ooo`030000oooooooo02koool306Ko7_ooo`0306Ko
oooooooo03coool003goool00`1Vooooooooo`0Ooooo0`1Vobgoool00`000?ooooooo`0[oooo0`1V
ob7oool00`1Vooooooooo`0loooo000moooo00<0I_ooooooool08_ooo`@0I_lYoooo00<0003ooooo
ool09oooo`@0I_lToooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo02Koool306Ko9_oo
o`80000Uoooo0`1VobSoool00`1Vooooooooo`0loooo000moooo00<0I_ooooooool0:Oooo`<0I_lS
oooo00<0003oooooool08Oooo`<0I_l[oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo
02coool406Ko1_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool07Ooo
o`@0I_l^oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo033oool406Ko00Goool0003o
ooooool000002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0I
oooo101Voc;oool00`1Vooooooooo`0loooo000loooo00<0I_ooooooool0=Oooo`0506Ko000006Ko
06Ko000000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Eoooo101VocOoool0
0`1Vooooooooo`0koooo000loooo00<0I_ooooooool0<?ooo`@00002oooo00@0003oooooool00004
06Ko1_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo013oool506Ko>oooo`0306Ko
oooooooo03_oool003coool00`1Vooooooooo`0foooo00@0003oooooool00004oooo101Vo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0;oooo1@1Vod3oool00`1Voooo
ooooo`0koooo000loooo00<0I_ooooooool0=oooo`800009oooo00@0I_l000000000I_l3oooo0`00
00Coool00`000?ooooooo`06oooo1@1VodGoool00`1Vooooooooo`0koooo000loooo00<0I_oooooo
ool0A_ooo`L0I_l3oooo0P0000?oool406KoB_ooo`0306Kooooooooo03_oool003coool00`1Voooo
ooooo`1=oooo0`1Vo`03000006Ko06Ko0080I_m>oooo00<0I_ooooooool0>oooo`00??ooo`0306Ko
oooooooo053oool00`000?ooooooo`1@oooo00<0I_ooooooool0>oooo`00??ooo`0306Kooooooooo
053oool00`000?ooooooo`1@oooo00<0I_ooooooool0>oooo`006?ooo`80000Roooo00<0I_oooooo
ool0100002Goool500008_ooo`80000Toooo1@0002?oool4000000?oool0I_ooool08oooo`80000G
oooo000Goooo00@0003oooooool0000Qoooo00@0I_ooooooool0000Zoooo00<0003oooooool08_oo
o`030000oooooooo02Goool00`000?ooooooo`0Soooo00<0003oooooool00_ooo`0306Kooooooooo
027oool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Poooo00D0I_ooooooooooool0
0000:Oooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool09?ooo`050000
oooooooooooo06Ko02Goool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0L
oooo100000Coool00`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0Roooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool010000?ooooooo`1VobKoool00`000?ooooooo`0Doooo000G
oooo00@0003oooooool0000Qoooo00@0I_ooooooool00002oooo00<0003oooooool09Oooo`030000
oooooooo02;oool200009_ooo`030000oooooooo02?oool01P000?ooooooo`000?ooo`1Vob?oool0
10000?ooooooo`0001Koool001Soool200008_ooo`0406Kooooooooooooo0P0002Ooool200009?oo
o`030000oooooooo02Coool200009_ooo`800002oooo00<0I_ooooooool08_ooo`80000Goooo000l
oooo00<0I_ooooooool0D?ooo`030000oooooooo053oool00`1Vooooooooo`0koooo000loooo00<0
I_ooooooool0D?ooo`80001Aoooo00<0I_ooooooool0>oooo`00??ooo`0306Kooooooooo053oool0
0`000?ooooooo`1@oooo00<0I_ooooooool0>oooo`00??ooo`0306Kooooooooo053oool00`000?oo
ooooo`1@oooo00<0I_ooooooool0>oooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`1@
oooo00<0I_ooooooool0>oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000ooooo`2I00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Goool00`000?ooooooo`0Uoooo00<0003ooooo09T09_ooo`030000oooooooo01Goool008ooool0
0`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??oo
o`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Sooo
o`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000
oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo
03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o
09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo001foooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1?oooo00?o09Woooooool0??oo
o`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00MOooo`040000oooooooo00002Oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0004ooool00ol0VOooooooo`0loooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Coooo`03o`2I
oooooooo03coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool007Koool200002_ooo`800004
oooo0`0000Coool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o
09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0
003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Wooooo
ool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool0
0`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??oo
o`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Sooo
o`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Coooo`03o`2Ioooooooo
03coool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000Coooo`03o`2Ioooooooo03coool007_oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo04ooool00ol0VOooooooo`0loooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo04ooool00ol0VOooooooo`0loooo001loooo0P0000[oool300001?oo
o`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo0P00053oool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000
oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo
03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o
09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0
003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Wooooo
ool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo04ooool00ol0VOooooooo`0loooo001eoooo00@0003oooooool0000:oooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1?oooo00?o09Wooooo
ool0??ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo0`0004ooool00ol0VOooooooo`0loooo001eoooo00@0003oooooool0000;oooo00@0003ooooo
ooooool200001Oooo`030000oooooooo04ooool00ol0VOooooooo`0loooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo03coool008ooool00`000?oo
ooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2I
oooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000
oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo
03coool008ooool20000D?ooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o
09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0
003oooooool0Coooo`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo03coool0
08ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Qoooo`D00003oooo00<0003ooooo
ool0Coooo`03o`2Ioooooooo03coool008Woool00`000?ooooooo`03oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008Woool00`000?ooooooo`03oooo0`0004ooool00ol0VOooooooo`0l
oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool00`000?ooooooo`06
oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81909 .30902 L
.8239 .30902 L
.82904 .30902 L
.83056 .30902 L
.832 .30902 L
.83329 .30902 L
s
.83329 .30902 m
.83336 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.15825 .30902 L
.16254 .30902 L
.16494 .30902 L
.16615 .30902 L
.16683 .15459 L
.16748 .1549 L
.17284 .15748 L
.18221 .16189 L
.22098 .17881 L
.2622 .19466 L
.30191 .20811 L
.34011 .21955 L
.38075 .2303 L
.41988 .23943 L
.46146 .24797 L
.48233 .25185 L
.49148 .25348 L
.49399 .25392 L
.49668 .25438 L
.49798 .2546 L
.49922 .25481 L
.50032 .25489 L
.50153 .25469 L
.52028 .25138 L
.54008 .24767 L
.58086 .23926 L
.62013 .23008 L
.65788 .22011 L
.69808 .20811 L
.73677 .19503 L
.77791 .17926 L
.79844 .17059 L
.80844 .16616 L
.81753 .16201 L
.82208 .15989 L
.82701 .15755 L
.82927 .15647 L
.83051 .15588 L
.83167 .15532 L
.83265 .15484 L
.83371 .30902 L
.83489 .30902 L
.83596 .30902 L
.85564 .30902 L
Mistroke
.8954 .30902 L
.93365 .30902 L
.97435 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003[oool206Ko?oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000DOooo`0306Kooooooooo03[oool003[oool00`1Vooooo`1Vo`0hoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo053oool206Ko??ooo`00>_ooo`0306Ko
oooooooo00<0I_lkoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
04goool306Ko00?oool0I_ooool0>oooo`00>_ooo`0306Kooooooooo00?oool206Ko>_ooo`80000:
oooo0`0000Coool00`000?ooooooo`1;oooo0P1Vo`Coool00`1Vooooooooo`0joooo000joooo00<0
I_ooooooool01Oooo`<0I_m:oooo0P0004[oool206Ko1_ooo`0306Kooooooooo03[oool003[oool0
0`1Vooooooooo`08oooo0P1VodSoool00`000?ooooooo`17oooo0P1Vo`Soool00`1Vooooooooo`0j
oooo000joooo00<0I_ooooooool02_ooo`<0I_m5oooo00<0003oooooool0AOooo`80I_l:oooo00<0
I_ooooooool0>_ooo`00>_ooo`0306Kooooooooo00goool306Ko@_ooo`030000oooooooo04;oool3
06Ko3?ooo`0306Kooooooooo03[oool003[oool00`1Vooooooooo`0@oooo0P1Vod3oool20000@Ooo
o`80I_l?oooo00<0I_ooooooool0>_ooo`00>_ooo`0306Kooooooooo01;oool306Ko?Oooo`030000
oooooooo03goool306Ko4Oooo`0306Kooooooooo03[oool003[oool00`1Vooooooooo`0Eoooo0`1V
oc[oool00`000?ooooooo`0koooo0P1VoaCoool00`1Vooooooooo`0joooo000joooo00<0I_oooooo
ool06?ooo`80I_lhoooo00<0003oooooool0>?ooo`<0I_lFoooo00<0I_ooooooool0>_ooo`00>_oo
o`0306Kooooooooo01[oool306Ko=Oooo`80000foooo0`1VoaWoool00`1Vooooooooo`0joooo000j
oooo00<0I_ooooooool07Oooo`80I_lcoooo00<0003oooooool0<Oooo`@0I_lLoooo00<0I_oooooo
ool0>_ooo`00>_ooo`0306Kooooooooo01ooool306Ko<?ooo`030000oooooooo02koool306Ko8?oo
o`0306Kooooooooo03[oool003[oool00`1Vooooooooo`0Roooo0`1Vobgoool00`000?ooooooo`0[
oooo0`1Vob?oool00`1Vooooooooo`0joooo000joooo00<0I_ooooooool09Oooo`<0I_lZoooo0P00
02Soool406Ko9_ooo`0306Kooooooooo03[oool003[oool00`1Vooooooooo`0Xoooo101VobKoool0
0`000?ooooooo`0Soooo101Vob[oool00`1Vooooooooo`0joooo000joooo00<0I_ooooooool0;?oo
o`H0I_l7oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Noooo1@1V
obkoool00`1Vooooooooo`0joooo000joooo00<0I_ooooooool0<_ooo`@0I_l2oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01[oool4
06Ko<oooo`0306Kooooooooo03[oool003[oool00`1Vooooooooo`0foooo0P1Vo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001Ooool306Ko>?ooo`0306Ko
oooooooo03Woool003[oool00`1Vooooooooo`0boooo100000;oool01@00001Vo`1Vo`00001Vo`09
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool04oooo`@0I_lkoooo00<0I_oooooo
ool0>Oooo`00>_ooo`0306Kooooooooo03Soool01@000?ooooooo`000?ooo`0406Ko0oooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0?oooo101Vocooool00`1Voooo
ooooo`0ioooo000joooo00<0I_ooooooool0>Oooo`800006oooo101Vo`800004oooo0`0000Coool0
0`000?ooooooo`0:oooo1@1Vod?oool00`1Vooooooooo`0ioooo000joooo00<0I_ooooooool0A_oo
o`D0I_l7oooo0P0000Koool506KoB?ooo`0306Kooooooooo03Woool003[oool00`1Vooooooooo`1;
oooo1P1Vo`04oooo0000oooooooo1@1Vodgoool00`1Vooooooooo`0ioooo000joooo00<0I_oooooo
ool0DOooo`0406Ko000006Ko06KoD_ooo`0306Kooooooooo03Woool003[oool00`1Vooooooooo`1B
oooo00<0003oooooool0D_ooo`0306Kooooooooo03Woool001Soool200008?ooo`0306Kooooooooo
00;oool400009Oooo`D0000Roooo0P0002Coool500008oooo`@00003oooo00<0I_ooooooool08?oo
o`80000Goooo000Goooo00@0003oooooool0000Ooooo00<0I_ooooooool00_ooo`030000oooooooo
02Soool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02?oool00`000?oo
ooooo`04oooo00<0I_ooooooool07oooo`040000oooooooo00005_ooo`006Oooo`030000oooooooo
01koool00`1Vooooooooo`03oooo00<0003oooooool09oooo`030000oooooooo02;oool00`000?oo
ooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo00?oool00`1Vooooooooo`0Qoooo00<0
003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool07?ooo`@00004oooo00<0003ooooo
ool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0U
oooo00<0003oooooool00_ooo`0306Kooooooooo02;oool00`000?ooooooo`0Doooo000Goooo00@0
003oooooool0000Ooooo00<0I_ooooooool00_ooo`040000oooooooo00009oooo`030000oooooooo
02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0000?oool00`1Vooooooooo`0O
oooo00@0003oooooool0000Foooo000Hoooo0P00023oool00`1Vooooooooo`03oooo0P0002Ooool2
00009?ooo`030000oooooooo02Coool200009_ooo`800004oooo00<0I_ooooooool08?ooo`80000G
oooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo05;oool00`1Vooooooooo`0ioooo000j
oooo00<0I_ooooooool0D_ooo`80001Coooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo
05;oool00`000?ooooooo`1Boooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool0
0`000?ooooooo`1Boooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool00`000?oo
ooooo`1Boooo00<0I_ooooooool0>Oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00Coool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00D0003ooooooooooooo09T09?ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001B
oooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o
09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo
057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
08ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Wooooo
ool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_oo
o`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1A
oooo00?o09Woooooool0>_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00057oool00ol0VOoo
ooooo`0joooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0DOooo`03o`2Ioooooooo03[oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Aoooo00?o09Woooooool0>_oo
o`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?oo
ooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Sooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2I
oooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001B
oooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o
09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo
057oool00ol0VOooooooo`0joooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000DOooo`03o`2Ioooooooo03[oool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo057oool00ol0VOooooooo`0joooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo057oool00ol0VOooooooo`0joooo001l
oooo0P0000[oool300001?ooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo0P00
05;oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
08ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Wooooo
ool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_oo
o`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?oo
ooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Sooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo057oool00ol0VOooooooo`0joooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Aoooo00?o09Woooooool0>_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`00057oool00ol0VOooooooo`0joooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo057oool00ol0VOooooooo`0j
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo057oool00ol0VOooooooo`0joooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo
03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo
057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
08ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Wooooo
ool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool0
0`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_oo
o`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Qooo
o`D00003oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008Woool00`000?ooooooo`03oooo0`00
057oool00ol0VOooooooo`0joooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200000oooo`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003oooo`030000oooooooo00Soool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83479 .30902 L
.83749 .30902 L
.83868 .30902 L
.83996 .30902 L
.84114 .30902 L
s
.84114 .30902 m
.84125 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.1536 .30902 L
.15586 .30902 L
.15709 .30902 L
.15825 .30902 L
.15923 .15475 L
.16029 .15527 L
.16254 .15635 L
.18221 .16552 L
.22343 .183 L
.26314 .19781 L
.30133 .21042 L
.34198 .22227 L
.38111 .23233 L
.42269 .24174 L
.46276 .24972 L
.48114 .25306 L
.49157 .25486 L
.49418 .25531 L
.49666 .25573 L
.49889 .2561 L
.50015 .25626 L
.50131 .25607 L
.51093 .25444 L
.52125 .25263 L
.54231 .24877 L
.58158 .24083 L
.61933 .23222 L
.65953 .22185 L
.69822 .21056 L
.73936 .19694 L
.77898 .18203 L
.81709 .16584 L
.82718 .16122 L
.83213 .15889 L
.8367 .15672 L
.83926 .15548 L
.84055 .15486 L
.84128 .30902 L
.84197 .30902 L
.84768 .30902 L
.85765 .30902 L
.89648 .30902 L
.93775 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Woool00`1Vooooooooo`0ooooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Coooo00<0I_ooooooool0>?ooo`00>Oooo`80I_ljoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo057oool306Ko>_ooo`00>Oooo`0406Ko
oooo06Ko06Ko?_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1?
oooo0P1Vo`;oool00`1Vooooooooo`0hoooo000ioooo00@0I_ooooooooooool306Ko??ooo`80000:
oooo0`0000Coool00`000?ooooooo`1<oooo0`1Vo`Coool00`1Vooooooooo`0hoooo000ioooo00<0
I_ooooooool01?ooo`<0I_m<oooo0P0004_oool206Ko1oooo`0306Kooooooooo03Soool003Woool0
0`1Vooooooooo`07oooo0P1Vod[oool00`000?ooooooo`18oooo0P1Vo`Woool00`1Vooooooooo`0h
oooo000ioooo00<0I_ooooooool02Oooo`<0I_m7oooo00<0003oooooool0A_ooo`80I_l;oooo00<0
I_ooooooool0>?ooo`00>Oooo`0306Kooooooooo00coool306KoA?ooo`030000oooooooo04?oool3
06Ko3Oooo`0306Kooooooooo03Soool003Woool00`1Vooooooooo`0?oooo0P1Vod;oool20000@_oo
o`80I_l@oooo00<0I_ooooooool0>?ooo`00>Oooo`0306Kooooooooo017oool306Ko?oooo`030000
oooooooo03koool306Ko4_ooo`0306Kooooooooo03Soool003Woool00`1Vooooooooo`0Doooo0P1V
ocgoool00`000?ooooooo`0loooo0P1VoaGoool00`1Vooooooooo`0hoooo000ioooo00<0I_oooooo
ool05_ooo`<0I_ljoooo00<0003oooooool0>Oooo`<0I_lGoooo00<0I_ooooooool0>?ooo`00>Ooo
o`0306Kooooooooo01Woool306Ko=oooo`80000foooo101Voa[oool00`1Vooooooooo`0hoooo000i
oooo00<0I_ooooooool07?ooo`@0I_lcoooo00<0003oooooool0<Oooo`@0I_lNoooo00<0I_oooooo
ool0>?ooo`00>Oooo`0306Kooooooooo023oool306Ko<?ooo`030000oooooooo02koool306Ko8_oo
o`0306Kooooooooo03Soool003Woool00`1Vooooooooo`0Soooo0`1Vobgoool00`000?ooooooo`0[
oooo0`1VobGoool00`1Vooooooooo`0hoooo000ioooo00<0I_ooooooool09_ooo`@0I_lYoooo0P00
02Soool406Ko:?ooo`0306Kooooooooo03Soool003Woool00`1Vooooooooo`0Zoooo0`1VobKoool0
0`000?ooooooo`0Toooo0`1Vobcoool00`1Vooooooooo`0hoooo000ioooo00<0I_ooooooool0;Ooo
o`<0I_l:oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Qoooo0`1V
obooool00`1Vooooooooo`0hoooo000ioooo00<0I_ooooooool0<?ooo`@0I_l5oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01goool4
06Ko<_ooo`0306Kooooooooo03Soool003Soool00`1Vooooooooo`0eoooo101Vo`05oooo0000oooo
oooo000000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Ioooo101VocOoool0
0`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0=?ooo`@000000oooo`1Vo`00000206Ko00<0
003oooooool02?ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01Goool406Ko>ooo
o`0306Kooooooooo03Ooool003Soool00`1Vooooooooo`0joooo00@0003oooooool0000506Ko0ooo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0@oooo1@1Vocooool0
0`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0>oooo`800006oooo101Vo`800004oooo0`00
00Coool00`000?ooooooo`0;oooo1@1VodCoool00`1Vooooooooo`0goooo000hoooo00<0I_oooooo
ool0BOooo`@0I_l7oooo0P0000Ooool506KoBOooo`0306Kooooooooo03Ooool003Soool00`1Voooo
ooooo`1=oooo101Vo`?oool00`000?ooooooo`02oooo101Vodkoool00`1Vooooooooo`0goooo000h
oooo00<0I_ooooooool0DOooo`<0I_l00`00001Vo`1Vo`0206KoD_ooo`0306Kooooooooo03Ooool0
03Soool00`1Vooooooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo03Ooool001Soool2
00007_ooo`0306Kooooooooo00Coool400009Oooo`D0000Roooo0P0002Coool500008oooo`@00005
oooo00<0I_ooooooool07_ooo`80000Goooo000Goooo00@0003oooooool0000Moooo00<0I_oooooo
ool01?ooo`030000oooooooo02Soool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000
oooooooo02?oool00`000?ooooooo`06oooo00<0I_ooooooool07Oooo`040000oooooooo00005_oo
o`006Oooo`030000oooooooo01coool00`1Vooooooooo`05oooo00<0003oooooool09oooo`030000
oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo00Goool0
0`1Vooooooooo`0Ooooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool06ooo
o`0306Ko0000000000800004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_oo
o`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool01?ooo`0306Kooooooooo
023oool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Moooo00<0I_ooooooool01?oo
o`040000oooooooo00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool0
10000?ooooooo`0000Goool00`1Vooooooooo`0Moooo00@0003oooooool0000Foooo000Hoooo0P00
01koool00`1Vooooooooo`05oooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_oo
o`800006oooo00<0I_ooooooool07_ooo`80000Goooo000hoooo00<0I_ooooooool0E?ooo`030000
oooooooo05Coool00`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`80001Eoooo00<0
I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`1Doooo00<0I_oooooo
ool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=ooo
o`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00?oool01?l0VOooooooo`0000Ooool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo02Goool0
0`000?ooooooo`03oooo00?o09Woooooool08?ooo`030000oooooooo01Goool008ooool00`000?oo
ooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001D
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o
09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Wooooo
ool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo001foooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00MOoo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`1Coooo00?o09Woooooool0>?ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0`0005?oool00ol0VOooooooo`0hoooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Doooo`03o`2Ioooooooo
03Soool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool007Koool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Wooooo
ool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?oo
o`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?oo
ooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001D
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
07_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Coooo00?o
09Woooooool0>?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000Dooo
o`03o`2Ioooooooo03Soool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo001loooo0P0000[oool300001?ooo`030000
oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo0P0005Coool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o
09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Wooooo
ool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?oo
o`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo05?oool00ol0VOooooooo`0hoooo001eoooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1Coooo00?o09Woooooool0>?oo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
05?oool00ol0VOooooooo`0hoooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001Oooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo
03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Wooooo
ool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool0
0`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Qoooo`D00003oooo00<0003oooooool0Dooo
o`03o`2Ioooooooo03Soool008Woool00`000?ooooooo`03oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008Woool00`000?ooooooo`03oooo0`0005?oool00ol0VOooooooo`0hoooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00002oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003oooo`030000oooooooo00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83996 .30902 L
.84438 .30902 L
.84681 .30902 L
.84801 .30902 L
.84911 .30902 L
s
.84911 .30902 m
.84924 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14635 .30902 L
.14868 .30902 L
.1499 .30902 L
.15059 .30902 L
.15124 .15473 L
.15238 .15528 L
.1536 .15587 L
.16254 .16012 L
.18221 .16907 L
.22343 .18611 L
.26314 .20056 L
.30133 .21285 L
.34198 .22441 L
.38111 .23422 L
.42269 .2434 L
.46276 .25118 L
.48114 .25444 L
.49157 .2562 L
.49418 .25663 L
.49666 .25704 L
.49889 .25741 L
.50015 .25756 L
.50131 .25737 L
.51093 .25578 L
.52125 .25403 L
.54231 .25025 L
.58158 .24252 L
.61933 .23412 L
.65953 .22401 L
.69822 .21299 L
.73936 .1997 L
.77898 .18517 L
.81709 .16937 L
.8367 .16048 L
.84235 .15781 L
.84512 .15648 L
.84634 .1559 L
.84768 .15525 L
.84888 .15467 L
.85 .30902 L
.85119 .30902 L
.85246 .30902 L
.85765 .30902 L
.89893 .30902 L
Mistroke
.93869 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Ooool00`1Vooooooooo`11oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Eoooo00<0I_ooooooool0=_ooo`00=oooo`0306Kooooooooo03_oool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0E?ooo`80I_lhoooo000g
oooo101Vod3oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0DOoo
o`<0I_l00oooo`1Vooooo`0goooo000goooo00@0I_ooooooooooool206Ko?oooo`80000:oooo0`00
00Coool00`000?ooooooo`1?oooo0P1Vo`Coool00`1Vooooooooo`0foooo000goooo00<0I_oooooo
ool00oooo`<0I_m?oooo0P0004goool306Ko1_ooo`0306Kooooooooo03Koool003Ooool00`1Voooo
ooooo`06oooo0`1Vodcoool00`000?ooooooo`1:oooo0P1Vo`Woool00`1Vooooooooo`0foooo000g
oooo00<0I_ooooooool02Oooo`80I_m:oooo00<0003oooooool0B?ooo`80I_l;oooo00<0I_oooooo
ool0=_ooo`00=oooo`0306Kooooooooo00_oool306KoAoooo`030000oooooooo04Koool206Ko3Ooo
o`0306Kooooooooo03Koool003Ooool00`1Vooooooooo`0>oooo0`1VodCoool20000A?ooo`<0I_l?
oooo00<0I_ooooooool0=_ooo`00=oooo`0306Kooooooooo017oool206Ko@_ooo`030000oooooooo
047oool206Ko4_ooo`0306Kooooooooo03Koool003Ooool00`1Vooooooooo`0Coooo0`1Vocooool0
0`000?ooooooo`0noooo0`1VoaCoool00`1Vooooooooo`0foooo000goooo00<0I_ooooooool05_oo
o`80I_lmoooo00<0003oooooool0??ooo`80I_lGoooo00<0I_ooooooool0=_ooo`00=oooo`0306Ko
oooooooo01Soool306Ko>_ooo`80000joooo0`1VoaWoool00`1Vooooooooo`0foooo000goooo00<0
I_ooooooool06oooo`<0I_lgoooo00<0003oooooool0=Oooo`@0I_lLoooo00<0I_ooooooool0=_oo
o`00=oooo`0306Kooooooooo01koool406Ko<oooo`030000oooooooo037oool406Ko8?ooo`0306Ko
oooooooo03Koool003Ooool00`1Vooooooooo`0Roooo0`1Voc3oool00`000?ooooooo`0^oooo0`1V
obCoool00`1Vooooooooo`0foooo000goooo00<0I_ooooooool09Oooo`<0I_l]oooo0P0002coool3
06Ko9oooo`0306Kooooooooo03Koool003Ooool00`1Vooooooooo`0Xoooo101VobWoool00`000?oo
ooooo`0Woooo101Vob[oool00`1Vooooooooo`0foooo000goooo00<0I_ooooooool0;?ooo`@0I_l<
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Soooo101Vobkoool0
0`1Vooooooooo`0foooo000goooo00<0I_ooooooool0<?ooo`D0I_l6oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01koool506Ko<_oo
o`0306Kooooooooo03Koool003Koool00`1Vooooooooo`0foooo101Vo`;oool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Joooo101VocSoool00`1Voooo
ooooo`0eoooo000foooo00<0I_ooooooool0=_ooo`@0000206Ko00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool05oooo`<0I_lloooo00<0I_ooooooool0=Ooo
o`00=_ooo`0306Kooooooooo03coool01@00001Vo`1Vo`00001Vo`07oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo01Coool306Ko?oooo`0306Kooooooooo03Goool0
03Koool00`1Vooooooooo`0moooo0P0000;oool406Ko1?ooo`800004oooo0`0000Coool00`000?oo
ooooo`0@oooo101Vod;oool00`1Vooooooooo`0eoooo000foooo00<0I_ooooooool0AOooo`H0I_l;
oooo0P0000coool506KoA_ooo`0306Kooooooooo03Goool003Koool00`1Vooooooooo`1;oooo101V
o`Ooool00`000?ooooooo`02oooo2@1Vod_oool00`1Vooooooooo`0eoooo000foooo00<0I_oooooo
ool0Coooo`L0I_l00`00001Vo`1Vo`0206KoE?ooo`0306Kooooooooo03Goool003Koool00`1Voooo
ooooo`1Foooo00<0003oooooool0E_ooo`0306Kooooooooo03Goool001Soool200007?ooo`0306Ko
oooooooo00Koool400009Oooo`D0000Roooo0P0002Coool500008oooo`@00007oooo00<0I_oooooo
ool07?ooo`80000Goooo000Goooo00@0003oooooool0000Koooo00<0I_ooooooool01_ooo`030000
oooooooo02Soool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02?oool0
0`000?ooooooo`08oooo00<0I_ooooooool06oooo`040000oooooooo00005_ooo`006Oooo`030000
oooooooo01[oool00`1Vooooooooo`07oooo00<0003oooooool09oooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo00Ooool00`1Vooooooooo`0M
oooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool06Oooo`0306Kooooooooo
00@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`0306Kooooooooo01koool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool0000Koooo00<0I_ooooooool01_ooo`040000oooooooo
00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`00
00Ooool00`1Vooooooooo`0Koooo00@0003oooooool0000Foooo000Hoooo0P0001coool00`1Voooo
ooooo`07oooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_ooo`800008oooo00<0
I_ooooooool07?ooo`80000Goooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool0
0`1Vooooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`80001Goooo00<0I_ooooooool0=Ooo
o`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`00=_oo
o`0306Kooooooooo05Koool00`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Ko
oooooooo05Koool00`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0ol0V@000?ooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool01Ooo
o`03o`2Ioooooooo01koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0EOooo`03o`2I
oooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo03Koool008ooool00`000?ooooooo`1E
oooo00?o09Woooooool0=_ooo`00Soooo`030000oooooooo05Goool00ol0VOooooooo`0foooo002?
oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo
03Koool008ooool00`000?ooooooo`1Eoooo00?o09Woooooool0=_ooo`00Soooo`030000oooooooo
05Goool00ol0VOooooooo`0foooo002?oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool0
08ooool20000E_ooo`03o`2Ioooooooo03Koool008ooool00`000?ooooooo`1Eoooo00?o09Wooooo
ool0=_ooo`00Soooo`030000oooooooo05Goool00ol0VOooooooo`0foooo002?oooo00<0003ooooo
ool0EOooo`03o`2Ioooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo03Koool008ooool0
0`000?ooooooo`1Eoooo00?o09Woooooool0=_ooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0EOooo`03o`2I
oooooooo03Koool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0001Eoooo00?o09Woooooool0=_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo05Goool00ol0VOooooooo`0foooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
05Goool00ol0VOooooooo`0foooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0EOooo`03o`2Ioooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo03Koool008ooool0
0`000?ooooooo`1Eoooo00?o09Woooooool0=_ooo`00Soooo`030000oooooooo05Goool00ol0VOoo
ooooo`0foooo002?oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool008ooool20000E_oo
o`03o`2Ioooooooo03Koool008ooool00`000?ooooooo`1Eoooo00?o09Woooooool0=_ooo`00Sooo
o`030000oooooooo05Goool00ol0VOooooooo`0foooo002?oooo00<0003oooooool0EOooo`03o`2I
oooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo03Koool008ooool00`000?ooooooo`1E
oooo00?o09Woooooool0=_ooo`00Soooo`030000oooooooo05Goool00ol0VOooooooo`0foooo002?
oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool008ooool20000E_ooo`03o`2Ioooooooo
03Koool008ooool00`000?ooooooo`1Eoooo00?o09Woooooool0=_ooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo05Goool00ol0VOooooooo`0foooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0EOooo`03o`2Ioooooooo03Koool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0005Koool00ol0VOooooooo`0e
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1F
oooo00?o09Woooooool0=Oooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool20000Eooo
o`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001Foooo00?o09Wooooo
ool0=Oooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?
oooo0P0005Ooool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo
03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo0P0005Ooool00ol0VOooooooo`0eoooo002?oooo00<0
003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo0P0005Ooool0
0ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo0P0005Ooool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_oo
o`03o`2Ioooooooo03Goool008Ooool500000oooo`030000oooooooo05Koool00ol0VOooooooo`0e
oooo0029oooo00<0003oooooool00oooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo0029
oooo00<0003oooooool00oooo`<0001Foooo00?o09Woooooool0=Oooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000?oool400000oooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool00`000?ooooooo`04oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02?ooo`030000oooooooo00Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000ooool00`000?ooooooo`08oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83996 .30902 L
.84911 .30902 L
.85162 .30902 L
.85431 .30902 L
.85561 .30902 L
.85685 .30902 L
s
.85685 .30902 m
.85696 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13506 .30902 L
.13942 .30902 L
.14061 .30902 L
.14188 .30902 L
.14296 .15456 L
.14415 .15514 L
.18444 .17348 L
.22321 .18906 L
.26444 .20367 L
.30414 .21605 L
.34234 .22659 L
.38298 .2365 L
.42211 .24491 L
.46369 .25278 L
.47384 .25455 L
.48456 .25636 L
.49371 .25785 L
.49622 .25825 L
.4976 .25848 L
.49891 .25868 L
.50013 .25884 L
.50145 .25863 L
.50376 .25826 L
.54231 .2517 L
.58309 .24385 L
.62236 .23527 L
.66011 .22595 L
.70031 .21474 L
.739 .20252 L
.78014 .18779 L
.80067 .17969 L
.81977 .17167 L
.83819 .16346 L
.8435 .16101 L
.8485 .15866 L
.853 .15651 L
.85423 .15592 L
.85554 .15529 L
.85665 .15475 L
.85787 .30902 L
.85917 .30902 L
.86037 .30902 L
.86309 .30902 L
Mistroke
.86804 .30902 L
.87732 .30902 L
.89821 .30902 L
.9374 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Coool206KoAOooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Eoooo`0306Kooooooooo03Coool003Coool0101Vooooo`1Vo`1Vocgoool400000_oo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0EOooo`<0I_lfoooo000doooo00@0
I_ooooooooooool206Ko@Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`1Doooo00@0I_ooooooool0I_lfoooo000doooo00<0I_ooooooool00oooo`80I_m0oooo0P00
00[oool300001?ooo`030000oooooooo05;oool206Ko0oooo`0306Kooooooooo03Coool003Coool0
0`1Vooooooooo`05oooo0P1Voe7oool20000DOooo`80I_l5oooo00<0I_ooooooool0=?ooo`00=?oo
o`0306Kooooooooo00Ooool306KoC_ooo`030000oooooooo04goool306Ko1oooo`0306Kooooooooo
03Coool003Coool00`1Vooooooooo`0:oooo0P1Vodcoool00`000?ooooooo`1;oooo0P1Vo`[oool0
0`1Vooooooooo`0doooo000doooo00<0I_ooooooool03?ooo`<0I_m9oooo00<0003oooooool0B?oo
o`<0I_l<oooo00<0I_ooooooool0=?ooo`00=?ooo`0306Kooooooooo00ooool206KoAoooo`800017
oooo0P1Vo`ooool00`1Vooooooooo`0doooo000doooo00<0I_ooooooool04Oooo`<0I_m4oooo00<0
003oooooool0@oooo`<0I_lAoooo00<0I_ooooooool0=?ooo`00=?ooo`0306Kooooooooo01Coool2
06Ko@_ooo`030000oooooooo043oool306Ko5?ooo`0306Kooooooooo03Coool003Coool00`1Voooo
ooooo`0Foooo0`1Vocooool00`000?ooooooo`0loooo101VoaOoool00`1Vooooooooo`0doooo000d
oooo00<0I_ooooooool06Oooo`80I_lmoooo0P0003[oool306Ko6oooo`0306Kooooooooo03Coool0
03Coool00`1Vooooooooo`0Koooo0`1Voc[oool00`000?ooooooo`0goooo0P1Voakoool00`1Voooo
ooooo`0doooo000doooo00<0I_ooooooool07_ooo`<0I_lgoooo00<0003oooooool0=?ooo`<0I_lP
oooo00<0I_ooooooool0=?ooo`00=?ooo`0306Kooooooooo027oool406Ko<oooo`030000oooooooo
03;oool206Ko8oooo`0306Kooooooooo03Coool003Coool00`1Vooooooooo`0Uoooo0`1Voc3oool2
0000;oooo`@0I_lUoooo00<0I_ooooooool0=?ooo`00=?ooo`0306Kooooooooo02Soool306Ko;Ooo
o`030000oooooooo02Woool506Ko:Oooo`0306Kooooooooo03Coool003Coool00`1Vooooooooo`0[
oooo101Voa3oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo02Goool4
06Ko;_ooo`0306Kooooooooo03Coool003Coool00`1Vooooooooo`0_oooo101Vo`_oool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool08_oo
o`<0I_lboooo00<0I_ooooooool0=?ooo`00=?ooo`0306Kooooooooo03?oool506Ko1_ooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001koool406Ko=_oo
o`0306Kooooooooo03?oool003Coool00`1Vooooooooo`0hoooo1000000306Kooooo000000;oool0
0`000?ooooooo`08oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool06_ooo`@0I_lj
oooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo03goool01@1Vo`00001Vo`1Vo`000008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01Goool506Ko?_oo
o`0306Kooooooooo03?oool003Coool00`1Vooooooooo`0ooooo0P000003oooo06Ko06Ko00<0I_l4
oooo0P0000Coool300001?ooo`030000oooooooo013oool506Ko@oooo`0306Kooooooooo03?oool0
03Coool00`1Vooooooooo`17oooo1P1Vo`_oool200003?ooo`D0I_m8oooo00<0I_ooooooool0<ooo
o`00=?ooo`0306Kooooooooo04goool306Ko2?ooo`030000oooooooo00Koool506KoCOooo`0306Ko
oooooooo03?oool003Coool00`1Vooooooooo`1@oooo1`1Vo`03oooo0000oooo00;oool506KoD_oo
o`0306Kooooooooo03?oool003Coool00`1Vooooooooo`1Goooo00<0I_l00000I_l00P1VoeOoool0
0`1Vooooooooo`0coooo000Hoooo0P0001[oool00`1Vooooooooo`08oooo100002Goool500008_oo
o`80000Toooo1@0002?oool400002Oooo`0306Kooooooooo01[oool200005oooo`005oooo`040000
oooooooo00006Oooo`0306Kooooooooo00Soool00`000?ooooooo`0Xoooo00<0003oooooool08_oo
o`030000oooooooo02Goool00`000?ooooooo`0Soooo00<0003oooooool02_ooo`0306Kooooooooo
01Woool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0Hoooo00<0I_ooooooool02Ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo
02Coool00`000?ooooooo`09oooo00<0I_ooooooool06oooo`030000oooooooo01Goool0017oool4
00001Oooo`030000oooooooo01Ooool00`1Vooooooooo`02oooo100000Coool00`000?ooooooo`0N
oooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool0
0`000?ooooooo`08oooo00<0I_ooooooool07?ooo`030000oooooooo01Coool001Ooool010000?oo
ooooo`0001Woool00`1Vooooooooo`08oooo00@0003oooooool0000Woooo00<0003oooooool08_oo
o`80000Voooo00<0003oooooool08oooo`040000oooooooo00002Oooo`0306Kooooooooo01Woool0
10000?ooooooo`0001Koool001Soool200006_ooo`0306Kooooooooo00Woool200009oooo`80000T
oooo00<0003oooooool09?ooo`80000Voooo0P0000[oool00`1Vooooooooo`0Joooo0P0001Ooool0
03Coool00`1Vooooooooo`1Hoooo00<0003oooooool0F?ooo`0306Kooooooooo03?oool003Coool0
0`1Vooooooooo`1Hoooo0P0005Woool00`1Vooooooooo`0coooo000doooo00<0I_ooooooool0F?oo
o`030000oooooooo05Soool00`1Vooooooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000
oooooooo05Soool00`1Vooooooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo
05Soool00`1Vooooooooo`0coooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000o`2Ioooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`07oooo00?o09Woooooool07?ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001H
oooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo
05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
08ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Wooooo
ool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1G
oooo00?o09Woooooool0=?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0005Ooool00ol0VOoo
ooooo`0doooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0Eoooo`03o`2Ioooooooo03Coool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Sooo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001H
oooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo
05Ooool00ol0VOooooooo`0doooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000Eoooo`03o`2Ioooooooo03Coool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo001l
oooo0P0000[oool300001?ooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P00
05Soool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
08ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Wooooo
ool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Sooo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0005Ooool00ol0VOooooooo`0doooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo05Ooool00ol0VOooooooo`0d
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool20000F?ooo`03o`2Ioooooooo
03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo
05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
08ooool20000F?ooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Wooooo
ool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool20000F?ooo`03o`2Ioooooooo03Coool008ooool0
0`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool20000F?oo
o`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Qooo
o`D00003oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008Woool00`000?ooooooo`03
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008Woool00`000?ooooooo`03oooo0`00
05Ooool00ol0VOooooooo`0doooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200000oooo`@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Soool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003ooo
o`030000oooooooo00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:
oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85396 .30902 L
.85916 .30902 L
.86176 .30902 L
.86305 .30902 L
.86423 .30902 L
s
.86423 .30902 m
.86434 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.11992 .30902 L
.12507 .30902 L
.12986 .30902 L
.13117 .30902 L
.13256 .30902 L
.13375 .30902 L
.13506 .15458 L
.13624 .15515 L
.13732 .15567 L
.13975 .15684 L
.14415 .15894 L
.18386 .17658 L
.22205 .19159 L
.2627 .20571 L
.30183 .21769 L
.34341 .2289 L
.38348 .2384 L
.42203 .24647 L
.46303 .25405 L
.47289 .25573 L
.48345 .25748 L
.49258 .25894 L
.49509 .25933 L
.49774 .25975 L
.49884 .25991 L
.50001 .26009 L
.50131 .25989 L
.50252 .2597 L
.51272 .25809 L
.52238 .25652 L
.54049 .25344 L
.58163 .24575 L
.62125 .23734 L
.65936 .2282 L
.69992 .21718 L
.73897 .20516 L
.78047 .19066 L
.82045 .17477 L
.83877 .1668 L
.84918 .16206 L
.85426 .15968 L
.85891 .15748 L
.86127 .15635 L
.86251 .15575 L
.86383 .15512 L
Mistroke
.8651 .30902 L
.86625 .30902 L
.8685 .30902 L
.87879 .30902 L
.89983 .30902 L
.93995 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003;oool206KoAoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000FOooo`0306Kooooooooo03;oool003;oool406Ko?oooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Hoooo0P1VocCoool003;oool0101Voooooooooooo
o`80I_m3oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo05Goool3
06Ko00?oool0I_ooool0<oooo`00<_ooo`0306Kooooooooo00?oool206Ko@_ooo`80000:oooo0`00
00Coool00`000?ooooooo`1Boooo0`1Vo`Coool00`1Vooooooooo`0boooo000boooo00<0I_oooooo
ool01Oooo`80I_mCoooo0P00057oool206Ko1oooo`0306Kooooooooo03;oool003;oool00`1Voooo
ooooo`07oooo0P1Voe7oool00`000?ooooooo`1=oooo0`1Vo`Woool00`1Vooooooooo`0boooo000b
oooo00<0I_ooooooool02Oooo`<0I_m>oooo00<0003oooooool0Boooo`80I_l<oooo00<0I_oooooo
ool0<_ooo`00<_ooo`0306Kooooooooo00coool206KoC?ooo`030000oooooooo04Soool306Ko3_oo
o`0306Kooooooooo03;oool003;oool00`1Vooooooooo`0>oooo0P1Vod[oool20000Aoooo`80I_lA
oooo00<0I_ooooooool0<_ooo`00<_ooo`0306Kooooooooo013oool206KoB?ooo`030000oooooooo
04?oool306Ko4oooo`0306Kooooooooo03;oool003;oool00`1Vooooooooo`0Boooo0`1VodGoool0
0`000?ooooooo`11oooo0P1VoaKoool00`1Vooooooooo`0boooo000boooo00<0I_ooooooool05Ooo
o`@0I_m1oooo00<0003oooooool0?_ooo`<0I_lHoooo00<0I_ooooooool0<_ooo`00<_ooo`0306Ko
oooooooo01Woool406Ko?Oooo`80000moooo0P1Voa_oool00`1Vooooooooo`0boooo000boooo00<0
I_ooooooool07Oooo`<0I_ljoooo00<0003oooooool0>Oooo`<0I_lMoooo00<0I_ooooooool0<_oo
o`00<_ooo`0306Kooooooooo023oool306Ko=oooo`030000oooooooo03Koool306Ko8?ooo`0306Ko
oooooooo03;oool003;oool00`1Vooooooooo`0Soooo101Voc?oool00`000?ooooooo`0boooo101V
ob?oool00`1Vooooooooo`0boooo000boooo00<0I_ooooooool09oooo`<0I_l`oooo0P00033oool3
06Ko9oooo`0306Kooooooooo03;oool003;oool00`1Vooooooooo`0Zoooo0`1Vobgoool00`000?oo
ooooo`0[oooo101Vob[oool00`1Vooooooooo`0boooo000boooo00<0I_ooooooool0;Oooo`@0I_l@
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Woooo101Vobkoool0
0`1Vooooooooo`0boooo000boooo00<0I_ooooooool0<Oooo`<0I_l<oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02?oool406Ko<_oo
o`0306Kooooooooo03;oool003;oool00`1Vooooooooo`0doooo0`1Vo`Woool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Ooooo101VocOoool00`1Voooo
ooooo`0aoooo000boooo00<0I_ooooooool0=oooo`<0I_l400000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo01[oool506Ko>oooo`0306Kooooooooo
037oool003;oool00`1Vooooooooo`0koooo101Vo`05oooo0000oooooooo000000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool05Oooo`D0I_m0oooo00<0I_oooooo
ool0<Oooo`00<_ooo`0306Kooooooooo03ooool206Ko0P00000306Kooooooooo00Ooool200001?oo
o`<00004oooo00<0003oooooool04?ooo`D0I_m5oooo00<0I_ooooooool0<Oooo`00<_ooo`0306Ko
oooooooo04Coool806Ko3_ooo`80000;oooo1P1Vod[oool00`1Vooooooooo`0aoooo000boooo00<0
I_ooooooool0C?ooo`H0I_l8oooo00<0003oooooool01_ooo`@0I_m@oooo00<0I_ooooooool0<Ooo
o`00<_ooo`0306Kooooooooo05;oool506Ko0oooo`030000oooooooo00;oool406KoE?ooo`0306Ko
oooooooo037oool003;oool00`1Vooooooooo`1Goooo0`1Vo`03000006Ko06Ko0080I_mHoooo00<0
I_ooooooool0<Oooo`006?ooo`80000Hoooo00<0I_ooooooool02_ooo`@0000Uoooo1@0002;oool2
00009?ooo`D0000Soooo100000_oool00`1Vooooooooo`0Hoooo0P0001Ooool001Ooool010000?oo
ooooo`0001Ooool00`1Vooooooooo`0:oooo00<0003oooooool0:?ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo00coool00`1Vooooooooo`0G
oooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool05_ooo`0306Kooooooooo00_oool0
0`000?ooooooo`0Woooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0T
oooo00<0003oooooool02oooo`0306Kooooooooo01Woool00`000?ooooooo`0Eoooo000Aoooo1000
00Goool00`000?ooooooo`0Eoooo00<0I_ooooooool01?ooo`@00004oooo00<0003oooooool07_oo
o`@00004oooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0
003oooooool02_ooo`0306Kooooooooo01[oool00`000?ooooooo`0Doooo000Goooo00@0003ooooo
ool0000Goooo00<0I_ooooooool02_ooo`040000oooooooo00009oooo`030000oooooooo02;oool2
00009_ooo`030000oooooooo02?oool010000?ooooooo`0000_oool00`1Vooooooooo`0Goooo00@0
003oooooool0000Foooo000Hoooo0P0001Soool00`1Vooooooooo`0;oooo0P0002Ooool200009?oo
o`030000oooooooo02Coool200009_ooo`80000<oooo00<0I_ooooooool06?ooo`80000Goooo000b
oooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0aoooo000boooo00<0
I_ooooooool0F_ooo`80001Koooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool0
0`000?ooooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?oo
ooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1J
oooo00<0I_ooooooool0<Oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Koool010000?ooooooool0V@Coool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`09oooo00?o09Woooooool06_ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001J
oooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo
05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Wooooo
ool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOoo
ooooo`0boooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1I
oooo00?o09Woooooool0<_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0005Woool00ol0VOoo
ooooo`0boooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0FOooo`03o`2Ioooooooo03;oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOoo
ooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Sooo
o`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2I
oooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001J
oooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo
05Woool00ol0VOooooooo`0boooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000FOooo`03o`2Ioooooooo03;oool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo05Woool00ol0VOooooooo`0boooo001l
oooo0P0000[oool300001?ooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo0P00
05[oool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Wooooo
ool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOoo
ooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Sooo
o`030000oooooooo05Woool00ol0VOooooooo`0boooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0005Woool00ol0VOooooooo`0boooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo05Woool00ol0VOooooooo`0b
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo05Woool00ol0VOooooooo`0boooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo
03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo
05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Wooooo
ool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool0
0`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOoo
ooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_oo
o`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Qooo
o`D00003oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008Woool00`000?ooooooo`03oooo0`00
05Woool00ol0VOooooooo`0boooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000?oooo00<0003oooooool02Oooo`050000oooooooooooo000007goool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85916 .30902 L
.86384 .30902 L
.86642 .30902 L
.86886 .30902 L
.87112 .30902 L
.8724 .30902 L
s
.8724 .30902 m
.87252 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.11992 .30902 L
.1226 .30902 L
.12377 .30902 L
.12507 .30902 L
.12627 .30902 L
.12739 .15471 L
.12858 .15528 L
.12986 .1559 L
.13506 .15839 L
.14415 .16264 L
.18538 .18047 L
.22508 .19558 L
.26328 .20844 L
.30392 .22053 L
.34305 .23079 L
.38463 .24039 L
.4247 .24853 L
.46325 .25545 L
.4828 .25865 L
.48815 .25949 L
.4939 .26038 L
.49668 .2608 L
.49805 .26101 L
.49931 .2612 L
.50046 .26123 L
.50168 .26105 L
.50426 .26066 L
.54374 .25425 L
.58149 .24734 L
.6217 .23901 L
.66038 .22994 L
.70152 .219 L
.74115 .20703 L
.77926 .19402 L
.81982 .17835 L
.83855 .1704 L
.85886 .16125 L
.86426 .15871 L
.86721 .15731 L
.86997 .15598 L
.87117 .1554 L
.87232 .15485 L
.87364 .30902 L
.87484 .30902 L
.88021 .30902 L
Mistroke
.90036 .30902 L
.93861 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0033oool206KoBOooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Foooo`0306Kooooooooo033oool0033oool406Ko@Oooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Ioooo0`1Voc;oool0033oool0101Voooooooooooo
o`80I_m5oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo05Ooool2
06Ko0_ooo`0306Kooooooooo033oool0033oool00`1Vooooooooo`03oooo0P1VodCoool200002_oo
o`<00004oooo00<0003oooooool0EOooo`80I_l4oooo00<0I_ooooooool0<?ooo`00<?ooo`0306Ko
oooooooo00Goool206KoEOooo`80001Coooo0`1Vo`Koool00`1Vooooooooo`0`oooo000`oooo00<0
I_ooooooool01oooo`80I_mCoooo00<0003oooooool0D?ooo`80I_l9oooo00<0I_ooooooool0<?oo
o`00<?ooo`0306Kooooooooo00Woool206KoDOooo`030000oooooooo04goool306Ko2oooo`0306Ko
oooooooo033oool0033oool00`1Vooooooooo`0;oooo0`1Vodkoool00`000?ooooooo`1;oooo0P1V
o`koool00`1Vooooooooo`0`oooo000`oooo00<0I_ooooooool03_ooo`80I_m<oooo0P0004Woool3
06Ko4?ooo`0306Kooooooooo033oool0033oool00`1Vooooooooo`0@oooo0`1VodWoool00`000?oo
ooooo`16oooo0P1Voa?oool00`1Vooooooooo`0`oooo000`oooo00<0I_ooooooool04oooo`80I_m7
oooo00<0003oooooool0@oooo`<0I_lEoooo00<0I_ooooooool0<?ooo`00<?ooo`0306Kooooooooo
01Goool306KoA?ooo`030000oooooooo047oool206Ko6?ooo`0306Kooooooooo033oool0033oool0
0`1Vooooooooo`0Hoooo0`1Vod7oool20000?oooo`<0I_lJoooo00<0I_ooooooool0<?ooo`00<?oo
o`0306Kooooooooo01_oool406Ko?Oooo`030000oooooooo03coool206Ko7Oooo`0306Kooooooooo
033oool0033oool00`1Vooooooooo`0Ooooo0`1Voc[oool00`000?ooooooo`0ioooo0`1Voaooool0
0`1Vooooooooo`0`oooo000`oooo00<0I_ooooooool08_ooo`<0I_lgoooo00<0003oooooool0=_oo
o`<0I_lRoooo00<0I_ooooooool0<?ooo`00<?ooo`0306Kooooooooo02Goool406Ko<oooo`80000c
oooo101VobGoool00`1Vooooooooo`0`oooo000`oooo00<0I_ooooooool0:Oooo`<0I_l`oooo00<0
003oooooool0;_ooo`@0I_lYoooo00<0I_ooooooool0<?ooo`00<?ooo`0306Kooooooooo02coool3
06Ko5?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0:Oooo`D0I_l]
oooo00<0I_ooooooool0<?ooo`00<?ooo`0306Kooooooooo02ooool406Ko3oooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Uoooo101V
oc;oool00`1Vooooooooo`0`oooo000`oooo00<0I_ooooooool0<oooo`@0I_l;oooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300008_ooo`<0I_lgoooo00<0
I_ooooooool0;oooo`00<?ooo`0306Kooooooooo03Ooool506Ko100000;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Noooo101Voc[oool00`1Voooo
ooooo`0_oooo000`oooo00<0I_ooooooool0?Oooo`D0I_l010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool06_ooo`@0I_lnoooo00<0I_oooooo
ool0;oooo`00<?ooo`0306Kooooooooo04;oool00`1Vo`000000000206Ko2?ooo`800004oooo0`00
00Coool00`000?ooooooo`0Eoooo1@1Vod;oool00`1Vooooooooo`0_oooo000`oooo00<0I_oooooo
ool0Aoooo`D0I_l@oooo0P00017oool506KoAoooo`0306Kooooooooo02ooool0033oool00`1Voooo
ooooo`1<oooo1@1Vo`_oool00`000?ooooooo`0;oooo1@1Vodcoool00`1Vooooooooo`0_oooo000`
oooo00<0I_ooooooool0DOooo`D0I_l6oooo00<0003oooooool01?ooo`L0I_mAoooo00<0I_oooooo
ool0;oooo`00<?ooo`0306Kooooooooo05Koool606Ko00<00000I_l0I_l0101VoeSoool00`1Voooo
ooooo`0_oooo000Hoooo0P0001Koool00`1Vooooooooo`0<oooo100002Goool500008_ooo`80000T
oooo1@0002?oool400003Oooo`0306Kooooooooo01Koool200005oooo`005oooo`040000oooooooo
00005Oooo`0306Kooooooooo00coool00`000?ooooooo`0Xoooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Soooo00<0003oooooool03_ooo`0306Kooooooooo01Goool0
10000?ooooooo`0001Koool001Woool00`000?ooooooo`0Doooo00<0I_ooooooool03Oooo`030000
oooooooo02Ooool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Coool0
0`000?ooooooo`0=oooo00<0I_ooooooool05oooo`030000oooooooo01Goool0017oool400001Ooo
o`030000oooooooo01?oool00`1Vooooooooo`06oooo100000Coool00`000?ooooooo`0Noooo1000
00Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?oo
ooooo`0<oooo00<0I_ooooooool06?ooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
01Goool00`1Vooooooooo`0<oooo00@0003oooooool0000Woooo00<0003oooooool08_ooo`80000V
oooo00<0003oooooool08oooo`040000oooooooo00003Oooo`0306Kooooooooo01Goool010000?oo
ooooo`0001Koool001Soool200005_ooo`0306Kooooooooo00goool200009oooo`80000Toooo00<0
003oooooool09?ooo`80000Voooo0P0000koool00`1Vooooooooo`0Foooo0P0001Ooool0033oool0
0`1Vooooooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0033oool00`1Voooo
ooooo`1Loooo0P0005goool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000
oooooooo05coool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo
05coool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool0
0`1Vooooooooo`0_oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00;oool01?l0VOooooooo`00
00Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`0U
oooo00<0003oooooool09Oooo`030000oooooooo00_oool00ol0VOooooooo`0Hoooo00<0003ooooo
ool05Oooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool0
0ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool0
0`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOoo
ooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Sooo
o`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`
oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo05_oool0
0ol0VOooooooo`0`oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo001eoooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000Foooo`03o`2Ioooooooo
033oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`1Koooo00?o09Woooooool0<?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00M_oo
o`80000:oooo0P0000Coool300001?ooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0
003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Wooooo
ool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool0
0ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool0
0`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOoo
ooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo05_oool00ol0VOooooooo`0`oooo001koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Koooo00?o09Woooooool0<?ooo`00Noooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool007coool2
00002_ooo`<00004oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool20000G?oo
o`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Sooo
o`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`
oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0
003oooooool0Foooo`03o`2Ioooooooo033oool007Koool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool30000Foooo`03o`2Ioooooooo033oool007Goool010000?ooooooo`00
00_oool010000?ooooooooooo`800005oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0Foooo`03o`2Ioooooooo033oool007Koool200002Oooo`@00003oooo0`0000Coool0
0`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`80001Loooo00?o09Woooooool0<?oo
o`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Sooo
o`80001Loooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`
oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Soooo`80001Loooo00?o09Woooooool0<?ooo`00Soooo`030000
oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`80001Loooo00?o
09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo0027oooo1@00
00?oool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00ROooo`030000oooooooo00?oool30000Fooo
o`03o`2Ioooooooo033oool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?oo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool01?oo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool0
0`000?ooooooo`09oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool2
00001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.86886 .30902 L
.87359 .30902 L
.87791 .30902 L
.87903 .30902 L
.88025 .30902 L
s
.88025 .30902 m
.88036 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.1128 .30902 L
.11531 .30902 L
.11758 .30902 L
.11872 .30902 L
.11999 .15496 L
.12125 .15558 L
.12261 .15623 L
.12507 .15741 L
.14415 .16626 L
.18538 .18364 L
.22508 .19838 L
.26328 .21092 L
.30392 .22271 L
.34305 .23272 L
.38463 .24209 L
.4247 .25002 L
.46325 .25677 L
.4828 .25989 L
.48815 .26071 L
.4939 .26158 L
.49668 .26199 L
.49805 .26219 L
.49931 .26238 L
.50046 .26241 L
.50168 .26223 L
.50426 .26185 L
.54374 .2556 L
.58149 .24886 L
.6217 .24074 L
.66038 .23189 L
.70152 .22122 L
.74115 .20955 L
.77926 .19686 L
.81982 .18157 L
.85886 .16489 L
.86911 .16017 L
.8745 .15762 L
.87745 .1562 L
.87889 .15551 L
.88021 .15487 L
.88144 .30902 L
.88262 .30902 L
.8852 .30902 L
.89069 .30902 L
Mistroke
.90036 .30902 L
.93861 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002ooool00`1Vooooooooo`19oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Moooo00<0I_ooooooool0;_ooo`00;oooo`<0I_m3oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo05coool206Ko<?ooo`00;oooo`0306Ko
oooooooo0080I_m7oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
05[oool206Ko00?oool0I_ooool0;oooo`00;oooo`0306Kooooooooo00;oool206KoA_ooo`80000:
oooo0`0000Coool00`000?ooooooo`1Goooo0`1Vo`?oool00`1Vooooooooo`0^oooo000_oooo00<0
I_ooooooool01?ooo`80I_mGoooo0P0005Koool206Ko1_ooo`0306Kooooooooo02koool002ooool0
0`1Vooooooooo`06oooo0P1VoeGoool00`000?ooooooo`1Boooo0`1Vo`Soool00`1Vooooooooo`0^
oooo000_oooo00<0I_ooooooool02?ooo`80I_mCoooo00<0003oooooool0D?ooo`80I_l;oooo00<0
I_ooooooool0;_ooo`00;oooo`0306Kooooooooo00[oool206KoDOooo`030000oooooooo04goool3
06Ko3Oooo`0306Kooooooooo02koool002ooool00`1Vooooooooo`0<oooo0`1Vodkoool20000C?oo
o`80I_l@oooo00<0I_ooooooool0;_ooo`00;oooo`0306Kooooooooo00ooool306KoBoooo`030000
oooooooo04Soool306Ko4_ooo`0306Kooooooooo02koool002ooool00`1Vooooooooo`0Boooo101V
odOoool00`000?ooooooo`16oooo0P1VoaGoool00`1Vooooooooo`0^oooo000_oooo00<0I_oooooo
ool05_ooo`<0I_m4oooo00<0003oooooool0@oooo`<0I_lGoooo00<0I_ooooooool0;_ooo`00;ooo
o`0306Kooooooooo01Woool206Ko@_ooo`800011oooo0`1Voa[oool00`1Vooooooooo`0^oooo000_
oooo00<0I_ooooooool06oooo`<0I_looooo00<0003oooooool0??ooo`@0I_lMoooo00<0I_oooooo
ool0;_ooo`00;oooo`0306Kooooooooo01koool206Ko?Oooo`030000oooooooo03Woool306Ko8Ooo
o`0306Kooooooooo02koool002ooool00`1Vooooooooo`0Poooo0`1Voc[oool00`000?ooooooo`0f
oooo0`1VobCoool00`1Vooooooooo`0^oooo000_oooo00<0I_ooooooool08oooo`<0I_lgoooo0P00
03?oool406Ko9oooo`0306Kooooooooo02koool002ooool00`1Vooooooooo`0Voooo101Voc?oool0
0`000?ooooooo`0_oooo0`1Vob_oool00`1Vooooooooo`0^oooo000_oooo00<0I_ooooooool0:_oo
o`@0I_lFoooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0/oooo0`1V
obkoool00`1Vooooooooo`0^oooo000_oooo00<0I_ooooooool0;_ooo`D0I_l@oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02Soool4
06Ko<Oooo`0306Kooooooooo02koool002koool00`1Vooooooooo`0doooo1@1Vo`_oool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Toooo101VocKoool0
0`1Vooooooooo`0]oooo000^oooo00<0I_ooooooool0>Oooo`D0I_l400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01ooool506Ko>_ooo`0306Ko
oooooooo02goool002koool00`1Vooooooooo`0ooooo1@1Vo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Joooo1@1Vocooool00`1Voooo
ooooo`0]oooo000^oooo00<0I_ooooooool0A?ooo`0306Ko000000000080I_l8oooo0P0000Coool3
00001?ooo`030000oooooooo01Goool506KoA?ooo`0306Kooooooooo02goool002koool00`1Voooo
ooooo`19oooo1@1Voa3oool200004Oooo`D0I_m9oooo00<0I_ooooooool0;Oooo`00;_ooo`0306Ko
oooooooo04koool506Ko2oooo`030000oooooooo00_oool506KoC_ooo`0306Kooooooooo02goool0
02koool00`1Vooooooooo`1Coooo1@1Vo`Koool00`000?ooooooo`04oooo1`1Voe?oool00`1Voooo
ooooo`0]oooo000^oooo00<0I_ooooooool0F?ooo`H0I_l00`00001Vo`1Vo`0406KoF_ooo`0306Ko
oooooooo02goool001Soool200005?ooo`0306Kooooooooo00koool400009Oooo`D0000Qoooo00<0
I_l0000000009?ooo`D0000Soooo100000ooool00`1Vooooooooo`0Doooo0P0001Ooool001Ooool0
10000?ooooooo`0001?oool00`1Vooooooooo`0>oooo00<0003oooooool0:?ooo`030000oooooooo
02;oool00`000?ooooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo013oool00`1Voooo
ooooo`0Coooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool04_ooo`0306Kooooooooo
00ooool00`000?ooooooo`0Woooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Toooo00<0003oooooool03oooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo000A
oooo100000Goool00`000?ooooooo`0Aoooo00<0I_ooooooool02?ooo`@00004oooo00<0003ooooo
ool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0U
oooo00<0003oooooool03_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Doooo000Goooo00@0
003oooooool0000Coooo00<0I_ooooooool03_ooo`040000oooooooo00009oooo`030000oooooooo
02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0000ooool00`1Vooooooooo`0C
oooo00@0003oooooool0000Foooo000Hoooo0P0001Coool00`1Vooooooooo`0?oooo0P0002Ooool2
00009?ooo`030000oooooooo02Coool200009_ooo`80000@oooo00<0I_ooooooool05?ooo`80000G
oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]oooo000^
oooo00<0I_ooooooool0G_ooo`80001Ooooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo
05koool00`000?ooooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool0
0`000?ooooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?oo
ooooo`1Noooo00<0I_ooooooool0;Oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`04oooo00?o
09T0003oool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool03Oooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`0Eoooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool2
0000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOoo
o`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?oo
ooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2I
oooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o
09Woooooool0;_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0GOooo`03o`2Ioooooooo02koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool007Goool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001Moooo00?o
09Woooooool0;_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo05goool00ol0VOooooooo`0^oooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo02koool0
08ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool2
0000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOoo
o`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?oo
ooooo`1Moooo00?o09Woooooool0;_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo001koooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool007_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0005goool00ol0VOooooooo`0^oooo001koooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Sooo
o`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2I
oooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo02koool0
08ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00M_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00MOoo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0001Moooo00?o09Woooooool0;_ooo`00MOooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1Moooo00?o09Wooooo
ool0;_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00M_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo0P0005koool00ol0VOoo
ooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?oo
ooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo0P0005koool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2I
oooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo002?oooo0P0005koool00ol0VOooooooo`0^oooo002?
oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo0P00
05koool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool0
08Ooool500000oooo`030000oooooooo05goool00ol0VOooooooo`0^oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo05goool00ol0VOooooooo`0^oooo0029oooo00<0003oooooool00ooo
o`<0001Moooo00?o09Woooooool0;_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Goool300000_ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000_oool0
1@000?ooooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`000?ooooooo`07oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00ooool00`000?ooooooo`06oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002oooo`800002oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.87791 .30902 L
.88246 .30902 L
.88497 .30902 L
.88735 .30902 L
.888 .30902 L
.88869 .30902 L
s
.88869 .30902 m
.88877 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.09905 .30902 L
.10458 .30902 L
.10708 .30902 L
.10972 .30902 L
.11039 .30902 L
.1111 .30902 L
.11189 .15489 L
.11263 .15524 L
.11531 .15654 L
.12507 .16115 L
.14415 .16978 L
.18538 .18674 L
.22508 .20111 L
.26328 .21335 L
.30392 .22484 L
.34305 .2346 L
.38463 .24374 L
.4247 .25148 L
.46325 .25806 L
.4828 .2611 L
.48815 .2619 L
.4939 .26275 L
.49668 .26315 L
.49805 .26335 L
.49931 .26353 L
.50046 .26356 L
.50168 .26339 L
.50426 .26302 L
.54374 .25692 L
.58149 .25035 L
.6217 .24242 L
.66038 .23379 L
.70152 .22339 L
.74115 .212 L
.77926 .19963 L
.81982 .18472 L
.85886 .16845 L
.86911 .16384 L
.8745 .16136 L
.88021 .15868 L
.8852 .15629 L
.88657 .15563 L
.88732 .15527 L
.88804 .15492 L
.8887 .1546 L
.88943 .30902 L
Mistroke
.89069 .30902 L
.90036 .30902 L
.94106 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002goool00`1Vooooooooo`1;oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Ooooo0P1Vobgoool002goool206KoA_ooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Moooo101Vobgoool002goool00`1Vooooo`1Vo`02
06KoBOooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Loooo00D0
I_ooooooooooool0I_l0;Oooo`00;Oooo`0306Kooooooooo00;oool206KoB?ooo`80000:oooo0`00
00Coool00`000?ooooooo`1Joooo0P1Vo`Coool00`1Vooooooooo`0[oooo000]oooo00<0I_oooooo
ool01?ooo`<0I_mHoooo0P0005Soool306Ko1_ooo`0306Kooooooooo02_oool002goool00`1Voooo
ooooo`07oooo0P1VoeKoool00`000?ooooooo`1Eoooo0P1Vo`Woool00`1Vooooooooo`0[oooo000]
oooo00<0I_ooooooool02Oooo`<0I_mCoooo00<0003oooooool0D_ooo`<0I_l;oooo00<0I_oooooo
ool0:oooo`00;Oooo`0306Kooooooooo00coool206KoDOooo`030000oooooooo053oool206Ko3_oo
o`0306Kooooooooo02_oool002goool00`1Vooooooooo`0>oooo0`1Vodkoool20000C_ooo`<0I_l@
oooo00<0I_ooooooool0:oooo`00;Oooo`0306Kooooooooo017oool206KoC?ooo`030000oooooooo
04_oool206Ko4oooo`0306Kooooooooo02_oool002goool00`1Vooooooooo`0Coooo0`1VodWoool0
0`000?ooooooo`18oooo0`1VoaGoool00`1Vooooooooo`0[oooo000]oooo00<0I_ooooooool05_oo
o`80I_m7oooo00<0003oooooool0A_ooo`80I_lHoooo00<0I_ooooooool0:oooo`00;Oooo`0306Ko
oooooooo01Soool306KoA?ooo`800014oooo0`1Voa[oool00`1Vooooooooo`0[oooo000]oooo00<0
I_ooooooool06oooo`<0I_m1oooo00<0003oooooool0@?ooo`<0I_lMoooo00<0I_ooooooool0:ooo
o`00;Oooo`0306Kooooooooo01koool406Ko?Oooo`030000oooooooo03coool406Ko8?ooo`0306Ko
oooooooo02_oool002goool00`1Vooooooooo`0Roooo0`1Voc[oool00`000?ooooooo`0ioooo0`1V
obCoool00`1Vooooooooo`0[oooo000]oooo00<0I_ooooooool09Oooo`<0I_lgoooo0P0003Ooool3
06Ko9oooo`0306Kooooooooo02_oool002goool00`1Vooooooooo`0Xoooo101Voc?oool00`000?oo
ooooo`0boooo101Vob[oool00`1Vooooooooo`0[oooo000]oooo00<0I_ooooooool0;?ooo`<0I_lG
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0^oooo101Vobkoool0
0`1Vooooooooo`0[oooo000]oooo00<0I_ooooooool0;oooo`<0I_lCoooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02Woool506Ko<_oo
o`0306Kooooooooo02_oool002coool00`1Vooooooooo`0coooo101Vo`ooool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Uoooo101VocOoool00`1Voooo
ooooo`0[oooo000/oooo00<0I_ooooooool0=oooo`@0I_l5oooo100000;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Roooo0`1Voc_oool00`1Voooo
ooooo`0[oooo000/oooo00<0I_ooooooool0>oooo`H0I_l5oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01koool406Ko?_ooo`0306Ko
oooooooo02_oool002coool00`1Vooooooooo`11oooo1@1Vo`03oooo0000000000[oool200001?oo
o`<00004oooo00<0003oooooool06_ooo`@0I_m2oooo00<0I_ooooooool0:oooo`00;?ooo`0306Ko
oooooooo04Koool506Ko5Oooo`80000Foooo1@1VodKoool00`1Vooooooooo`0[oooo000/oooo00<0
I_ooooooool0Boooo`L0I_l>oooo00<0003oooooool03_ooo`L0I_m;oooo00<0I_ooooooool0:ooo
o`00;?ooo`0306Kooooooooo05;oool806Ko1_ooo`030000oooooooo00Koool806KoD_ooo`0306Ko
oooooooo02_oool002coool00`1Vooooooooo`1Joooo101Vo`;oool010000?ooooooooooo`D0I_mJ
oooo00<0I_ooooooool0:oooo`006?ooo`80000Boooo00<0I_ooooooool04?ooo`@0000Uoooo1@00
023oool206Ko0P000080I_lRoooo1@0002?oool400004Oooo`0306Kooooooooo01;oool200005ooo
o`005oooo`040000oooooooo00004Oooo`0306Kooooooooo013oool00`000?ooooooo`0Xoooo00<0
003oooooool08_ooo`030000oooooooo02Goool00`000?ooooooo`0Soooo00<0003oooooool04_oo
o`0306Kooooooooo017oool010000?ooooooo`0001Koool001Woool00`000?ooooooo`0@oooo00<0
I_ooooooool04Oooo`030000oooooooo02Ooool00`000?ooooooo`0Roooo00<0003oooooool09Ooo
o`030000oooooooo02Coool00`000?ooooooo`0Aoooo00<0I_ooooooool04oooo`030000oooooooo
01Goool0017oool400001Oooo`030000oooooooo00ooool00`1Vooooooooo`0:oooo100000Coool0
0`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000
oooooooo02Goool00`000?ooooooo`0@oooo00<0I_ooooooool05?ooo`030000oooooooo01Coool0
01Ooool010000?ooooooo`00017oool00`1Vooooooooo`0@oooo00@0003oooooool0000Woooo00<0
003oooooool08_ooo`80000Voooo00<0003oooooool08oooo`040000oooooooo00004Oooo`0306Ko
oooooooo017oool010000?ooooooo`0001Koool001Soool200004_ooo`0306Kooooooooo017oool2
00009oooo`80000Toooo00<0003oooooool09?ooo`80000Voooo0P0001;oool00`1Vooooooooo`0B
oooo0P0001Ooool002coool00`1Vooooooooo`1Poooo00<0003oooooool0H?ooo`0306Kooooooooo
02_oool002coool00`1Vooooooooo`1Poooo0P00067oool00`1Vooooooooo`0[oooo000/oooo00<0
I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/oooo00<0I_oooooo
ool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/oooo00<0I_ooooooool0H?oo
o`030000oooooooo063oool00`1Vooooooooo`0[oooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooool0V@05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0@oooo00?o09Wooooo
ool04oooo`030000oooooooo01Goool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOoo
ooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?oo
ooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Sooo
o`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2I
oooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Q
oooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?
oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o
09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
063oool00ol0VOooooooo`0[oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0H?ooo`03o`2I
oooooooo02_oool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Poooo00?o
09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool0
08ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Wooooo
ool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003ooooo
ool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOoo
ooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?oo
ooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Sooo
o`030000oooooooo063oool00ol0VOooooooo`0[oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000H?ooo`03o`2Ioooooooo02_oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo063oool00ol0VOooooooo`0[oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo063oool00ol0VOoo
ooooo`0[oooo001loooo0P0000[oool300001?ooo`030000oooooooo063oool00ol0VOooooooo`0[
oooo002?oooo0P00067oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2I
oooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Q
oooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?
oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o
09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool0
08ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Wooooo
ool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo063oool00ol0VOooooooo`0[
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`00063oool00ol0VOooooooo`0[oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo063oool0
0ol0VOooooooo`0[oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo063oool00ol0VOooooooo`0[oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool20000HOoo
o`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Sooo
o`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2I
oooooooo02_oool008ooool20000HOooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1P
oooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?
oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool20000HOooo`03o`2Ioooooooo
02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool0
08ooool20000HOooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Wooooo
ool0:oooo`00Qoooo`D00003oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008Woool00`000?oo
ooooo`03oooo0`00063oool00ol0VOooooooo`0[oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001Oooo`<00002oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool0000;oooo00@0003oooooool00002oooo00D0003oooooooooool00000N_ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`D00004oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003oooo`030000
oooooooo00Koool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P00
00?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.87791 .30902 L
.88735 .30902 L
.88993 .30902 L
.89271 .30902 L
.89405 .30902 L
.89533 .30902 L
.89647 .30902 L
s
.89647 .30902 m
.89659 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09396 .30902 L
.09682 .30902 L
.09952 .30902 L
.1007 .30902 L
.10195 .30902 L
.1026 .30902 L
.10332 .15458 L
.10458 .15519 L
.14487 .17352 L
.18364 .1891 L
.22486 .2037 L
.26457 .21609 L
.30277 .22662 L
.34341 .23652 L
.38254 .24493 L
.42412 .2528 L
.46419 .25946 L
.48257 .26225 L
.4876 .26299 L
.493 .26376 L
.49562 .26413 L
.49809 .26448 L
.49917 .26463 L
.50032 .26471 L
.50158 .26453 L
.50274 .26437 L
.52268 .26147 L
.54374 .25821 L
.58149 .25179 L
.6217 .24407 L
.66038 .23565 L
.70152 .2255 L
.74115 .2144 L
.77926 .20233 L
.81982 .18779 L
.85886 .17192 L
.86911 .16743 L
.88021 .16239 L
.8853 .16002 L
.89069 .15746 L
.89291 .1564 L
.8953 .15525 L
.896 .15491 L
.89666 .15459 L
.89791 .30902 L
Mistroke
.89908 .30902 L
.90036 .30902 L
.94106 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002[oool206KoCoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000HOooo`80I_l[oooo000Zoooo00@0I_ooool0I_l0I_m7oooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo063oool306Ko:oooo`00:_ooo`0406Kooooooooo
oooo0P1Vod_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0GOoo
o`<0I_l2oooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo00?oool206KoB_ooo`80000:
oooo0`0000Coool00`000?ooooooo`1Loooo00<0I_ooooooool00oooo`0306Kooooooooo02Woool0
02[oool00`1Vooooooooo`05oooo0P1Voe_oool20000Foooo`80I_l6oooo00<0I_ooooooool0:Ooo
o`00:_ooo`0306Kooooooooo00Ooool306KoF?ooo`030000oooooooo05Ooool306Ko2?ooo`0306Ko
oooooooo02Woool002[oool00`1Vooooooooo`0:oooo0P1VoeKoool00`000?ooooooo`1Eoooo0P1V
o`_oool00`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool03?ooo`<0I_mCoooo00<0003ooooo
ool0D_ooo`<0I_l=oooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo00ooool206KoDOoo
o`80001Aoooo0P1Voa3oool00`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool04Oooo`<0I_m>
oooo00<0003oooooool0COooo`<0I_lBoooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo
01Coool206KoC?ooo`030000oooooooo04[oool306Ko5Oooo`0306Kooooooooo02Woool002[oool0
0`1Vooooooooo`0Foooo0`1VodWoool00`000?ooooooo`16oooo101VoaSoool00`1Vooooooooo`0Y
oooo000Zoooo00<0I_ooooooool06Oooo`80I_m7oooo0P0004Coool306Ko7?ooo`0306Kooooooooo
02Woool002[oool00`1Vooooooooo`0Koooo0`1VodCoool00`000?ooooooo`10oooo0`1Voaooool0
0`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool07_ooo`<0I_m1oooo00<0003oooooool0??oo
o`@0I_lRoooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo027oool406Ko?Oooo`030000
oooooooo03Woool306Ko9_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`0Uoooo0`1V
oc[oool20000=oooo`<0I_lYoooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo02Soool3
06Ko=oooo`030000oooooooo03;oool406Ko;?ooo`0306Kooooooooo02Woool002[oool00`1Voooo
ooooo`0[oooo101Voa[oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
02ooool306Ko<?ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`0_oooo101VoaGoool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool0;?ooo`<0I_lcoooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo03?oool506Ko4?oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0002Soool4
06Ko=_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`0hoooo1@1Vo`Goool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo02Coool4
06Ko>_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`0moooo1@1Vo`Koool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool07ooo
o`D0I_lnoooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo04;oool506Ko0_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo01[oool506Ko@oooo`0306Kooooooooo02Woool0
02[oool00`1Vooooooooo`17oooo1P1VoaGoool200005_ooo`D0I_m8oooo00<0I_ooooooool0:Ooo
o`00:_ooo`0306Kooooooooo04goool506Ko4?ooo`030000oooooooo013oool506KoCOooo`0306Ko
oooooooo02Woool002[oool00`1Vooooooooo`1Boooo1@1Vo`_oool00`000?ooooooo`0;oooo1@1V
oe;oool00`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool0Eoooo`D0I_l6oooo00@0003ooooo
ooooool:06KoEoooo`0306Kooooooooo02Woool001Soool200004?ooo`0306Kooooooooo01;oool4
00009Oooo`D0000Loooo1P1Vo`80000206Ko8_ooo`D0000Soooo100001?oool00`1Vooooooooo`0@
oooo0P0001Ooool001Ooool010000?ooooooo`0000ooool00`1Vooooooooo`0Boooo00<0003ooooo
ool0:?ooo`030000oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool08oooo`030000
oooooooo01Coool00`1Vooooooooo`0?oooo00@0003oooooool0000Foooo000Ioooo00<0003ooooo
ool03_ooo`0306Kooooooooo01?oool00`000?ooooooo`0Woooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Toooo00<0003oooooool04oooo`0306Kooooooooo017oool0
0`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`0=oooo00<0I_ooooooool03?oo
o`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0Uoooo00<0003oooooool04_ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool0000?oooo00<0I_ooooooool04_ooo`040000oooooooo
00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`00
01?oool00`1Vooooooooo`0?oooo00@0003oooooool0000Foooo000Hoooo0P00013oool00`1Voooo
ooooo`0Coooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_ooo`80000Doooo00<0
I_ooooooool04?ooo`80000Goooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool0
0`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`80001Soooo00<0I_ooooooool0:Ooo
o`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`00:_oo
o`0306Kooooooooo06;oool00`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Ko
oooooooo06;oool00`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00@0003ooooooooo09T4oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0A
oooo00?o09Woooooool04_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`1Qoooo00?o
09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo
067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool0
08ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Wooooo
ool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003ooooo
ool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_oo
o`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOoo
ooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?oo
ooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Sooo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`1Qoooo00?o
09Woooooool0:_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`00067oool00ol0VOooooooo`0Zoooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0HOooo`03o`2Ioooooooo02[oool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Sooo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2I
oooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001R
oooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o
09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo
067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool0
08ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Wooooo
ool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Qoooo00?o09Woooooool0:_oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000H_ooo`03o`2Ioooooooo
02Woool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
06;oool00ol0VOooooooo`0Yoooo001loooo0P0000[oool300001?ooo`030000oooooooo06;oool0
0ol0VOooooooo`0Yoooo002?oooo0P0006?oool00ol0VOooooooo`0Yoooo002?oooo00<0003ooooo
ool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Ooo
o`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?oo
ooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001S
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo06;oool0
0ol0VOooooooo`0Yoooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0006;oool00ol0VOoo
ooooo`0Yoooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo06;oool00ol0VOooooooo`0Yoooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Wooooo
ool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003ooooo
ool0H_ooo`03o`2Ioooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool0
0`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool20000Hooo
o`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1R
oooo00?o09Woooooool0:Oooo`00Qoooo`D00003oooo00<0003oooooool0H_ooo`03o`2Ioooooooo
02Woool008Woool00`000?ooooooo`03oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08Woool00`000?ooooooo`03oooo0`0006;oool00ol0VOooooooo`0Yoooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00[oool00`000?ooooooo`02
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01ooo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89307 .30902 L
.89771 .30902 L
.90008 .30902 L
.90133 .30902 L
.90265 .30902 L
.90381 .30902 L
s
.90381 .30902 m
.90394 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09109 .30902 L
.09258 .30902 L
.09324 .30902 L
.09396 .30902 L
.09525 .15452 L
.09596 .15486 L
.09662 .15518 L
.09952 .15658 L
.10458 .15899 L
.14335 .17624 L
.18458 .19241 L
.22428 .20612 L
.26248 .21778 L
.30312 .22875 L
.34225 .23805 L
.38383 .24677 L
.4239 .25415 L
.46245 .26042 L
.482 .26332 L
.48735 .26409 L
.4931 .26489 L
.49588 .26528 L
.49725 .26547 L
.49851 .26564 L
.49966 .2658 L
.50088 .26572 L
.5021 .26556 L
.50346 .26537 L
.54294 .25959 L
.58315 .25292 L
.62183 .24564 L
.66297 .23688 L
.7026 .22729 L
.74071 .21686 L
.78127 .2043 L
.82031 .1906 L
.86181 .17406 L
.88261 .16492 L
.89175 .16072 L
.89659 .15844 L
.89926 .15716 L
.90179 .15595 L
.90296 .15538 L
.90421 .15478 L
.90492 .30902 L
Mistroke
.90557 .30902 L
.90684 .30902 L
.91144 .30902 L
.92048 .30902 L
.94026 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Soool206KoDOooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Hoooo`0306Kooooooooo02Soool002Soool406KoBOooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Roooo0P1Vob[oool002Soool0101Voooooooooooo
o`80I_m=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo063oool2
06Ko00?oool0I_ooool0:Oooo`00:?ooo`0306Kooooooooo00?oool206KoC?ooo`80000:oooo0`00
00Coool00`000?ooooooo`1Moooo0`1Vo`?oool00`1Vooooooooo`0Xoooo000Xoooo00<0I_oooooo
ool01Oooo`80I_mMoooo0P0005coool206Ko1_ooo`0306Kooooooooo02Soool002Soool00`1Voooo
ooooo`07oooo0P1Voe_oool00`000?ooooooo`1Hoooo0`1Vo`Soool00`1Vooooooooo`0Xoooo000X
oooo00<0I_ooooooool02Oooo`<0I_mHoooo00<0003oooooool0EOooo`<0I_l;oooo00<0I_oooooo
ool0:?ooo`00:?ooo`0306Kooooooooo00coool206KoE_ooo`030000oooooooo05?oool206Ko3_oo
o`0306Kooooooooo02Soool002Soool00`1Vooooooooo`0>oooo0`1Voe?oool20000DOooo`<0I_l@
oooo00<0I_ooooooool0:?ooo`00:?ooo`0306Kooooooooo017oool206KoDOooo`030000oooooooo
04goool306Ko4oooo`0306Kooooooooo02Soool002Soool00`1Vooooooooo`0Coooo0`1Vodkoool0
0`000?ooooooo`1;oooo0P1VoaKoool00`1Vooooooooo`0Xoooo000Xoooo00<0I_ooooooool05_oo
o`<0I_m;oooo00<0003oooooool0B?ooo`<0I_lHoooo00<0I_ooooooool0:?ooo`00:?ooo`0306Ko
oooooooo01Woool406KoAoooo`800017oooo0P1Voa_oool00`1Vooooooooo`0Xoooo000Xoooo00<0
I_ooooooool07Oooo`<0I_m4oooo00<0003oooooool0@oooo`<0I_lMoooo00<0I_ooooooool0:?oo
o`00:?ooo`0306Kooooooooo023oool306Ko@Oooo`030000oooooooo043oool306Ko8?ooo`0306Ko
oooooooo02Soool002Soool00`1Vooooooooo`0Soooo101Vocgoool00`000?ooooooo`0loooo101V
ob?oool00`1Vooooooooo`0Xoooo000Xoooo00<0I_ooooooool09oooo`<0I_ljoooo0P0003[oool3
06Ko9oooo`0306Kooooooooo02Soool002Soool00`1Vooooooooo`0Zoooo0`1VocOoool00`000?oo
ooooo`0foooo0`1Vob[oool00`1Vooooooooo`0Xoooo000Xoooo00<0I_ooooooool0;Oooo`@0I_lJ
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0boooo101Vobgoool0
0`1Vooooooooo`0Xoooo000Xoooo00<0I_ooooooool0<Oooo`@0I_lEoooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02koool406Ko<Ooo
o`0306Kooooooooo02Soool002Soool00`1Vooooooooo`0eoooo1@1Voa3oool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Yoooo1@1VocKoool00`1Voooo
ooooo`0Woooo000Xoooo00<0I_ooooooool0>_ooo`@0I_l6oooo100000;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Toooo1@1Voc_oool00`1Voooo
ooooo`0Woooo000Xoooo00<0I_ooooooool0?_ooo`@0I_l8oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01ooool506Ko@?ooo`0306Ko
oooooooo02Ooool002Soool00`1Vooooooooo`12oooo101Vo`Goool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0Joooo1@1VodGoool00`1Vooooooooo`0Woooo000Xoooo00<0I_oooooo
ool0A_ooo`@0I_lJoooo0P0001Koool506KoB_ooo`0306Kooooooooo02Ooool002Soool00`1Voooo
ooooo`1:oooo1@1VoaGoool00`000?ooooooo`0@oooo1@1Vodooool00`1Vooooooooo`0Woooo000X
oooo00<0I_ooooooool0Coooo`L0I_l>oooo00<0003oooooool02oooo`D0I_mDoooo00<0I_oooooo
ool09oooo`00:?ooo`0306Kooooooooo05Koool706Ko1oooo`030000oooooooo00Coool706KoFOoo
o`0306Kooooooooo02Ooool001Soool200003_ooo`0306Kooooooooo01Coool400009Oooo`D0000K
oooo1`1Vo`80000506Ko7oooo`D0000Soooo100001Goool00`1Vooooooooo`0>oooo0P0001Ooool0
01Ooool010000?ooooooo`0000goool00`1Vooooooooo`0Doooo00<0003oooooool0:?ooo`030000
oooooooo02;oool00`000?ooooooo`0Uoooo00<0003oooooool08oooo`030000oooooooo01Koool0
0`1Vooooooooo`0=oooo00@0003oooooool0000Foooo000Ioooo00<0003oooooool03?ooo`0306Ko
oooooooo01Goool00`000?ooooooo`0Woooo00<0003oooooool08_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Toooo00<0003oooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0E
oooo000Aoooo100000Goool00`000?ooooooo`0;oooo00<0I_ooooooool03_ooo`@00004oooo00<0
003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Uoooo00<0003oooooool05?ooo`0306Kooooooooo013oool00`000?ooooooo`0Doooo000G
oooo00@0003oooooool0000=oooo00<0I_ooooooool05?ooo`040000oooooooo00009oooo`030000
oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`0001Goool00`1Voooo
ooooo`0=oooo00@0003oooooool0000Foooo000Hoooo0P0000koool00`1Vooooooooo`0Eoooo0P00
02Ooool200009?ooo`030000oooooooo02Coool200009_ooo`80000Foooo00<0I_ooooooool03_oo
o`80000Goooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool00`1Vooooooooo`0W
oooo000Xoooo00<0I_ooooooool0I?ooo`80001Uoooo00<0I_ooooooool09oooo`00:?ooo`0306Ko
oooooooo06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo
06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool0
0`000?ooooooo`1Toooo00<0I_ooooooool09oooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`04o`2Ioooooooo00001oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Coooo00?o09Wooooo
ool04?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?oo
o`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?oo
ooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001T
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o
09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`1Soooo00?o09Woooooool0:?oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
06?oool00ol0VOooooooo`0Xoooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Soooo00?o
09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003ooooo
ool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?oo
o`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?oo
ooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000Hoooo`03o`2Ioooooooo02Soool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo001loooo0P0000[oool300001?ooo`030000oooooooo06?oool00ol0VOooooooo`0X
oooo002?oooo0P0006Coool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001T
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o
09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo06?oool00ol0VOooooooo`0X
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0006?oool00ol0VOooooooo`0Xoooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo06?oool0
0ol0VOooooooo`0Xoooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?oo
o`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1S
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo
02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00Qoooo`D00003oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008Woool00`000?oo
ooooo`03oooo0`0006?oool00ol0VOooooooo`0Xoooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02_oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000?oooo00<0003oooooool01oooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89771 .30902 L
.90265 .30902 L
.90733 .30902 L
.90992 .30902 L
.91063 .30902 L
.91138 .30902 L
.91202 .30902 L
s
.91202 .30902 m
.91209 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.07216 .30902 L
.0775 .30902 L
.08255 .30902 L
.08542 .30902 L
.0862 .30902 L
.08703 .30902 L
.08774 .15472 L
.08852 .1551 L
.09396 .15771 L
.10458 .16269 L
.14487 .18013 L
.18364 .19495 L
.22486 .20884 L
.26457 .22062 L
.30277 .23064 L
.34341 .24006 L
.38254 .24806 L
.42412 .25554 L
.46419 .26188 L
.48257 .26453 L
.4876 .26523 L
.493 .26597 L
.49562 .26632 L
.49809 .26666 L
.49917 .2668 L
.50032 .26687 L
.50158 .2667 L
.50274 .26654 L
.52268 .26379 L
.54374 .26069 L
.58149 .25458 L
.6217 .24724 L
.66038 .23923 L
.70152 .22957 L
.74115 .21901 L
.77926 .20753 L
.81982 .1937 L
.85886 .17861 L
.87877 .17017 L
.88926 .16551 L
.90036 .1604 L
.90514 .15815 L
.90777 .15689 L
.91027 .15569 L
.91167 .15501 L
.91247 .15462 L
.91321 .30902 L
Mistroke
.91451 .30902 L
.9159 .30902 L
.92116 .30902 L
.94034 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Koool206KoDoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000IOooo`80I_lWoooo000Voooo00@0I_ooool0I_l0I_m;oooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo06Coool306Ko9oooo`009_ooo`0406Kooooooooo
oooo0P1Vodooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0H_oo
o`80I_l2oooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo00?oool206KoC_ooo`80000:
oooo0`0000Coool00`000?ooooooo`1Ooooo0`1Vo`Coool00`1Vooooooooo`0Uoooo000Voooo00<0
I_ooooooool01Oooo`80I_mOoooo0P0005goool306Ko1oooo`0306Kooooooooo02Goool002Koool0
0`1Vooooooooo`07oooo0P1Voegoool00`000?ooooooo`1Joooo0P1Vo`[oool00`1Vooooooooo`0U
oooo000Voooo00<0I_ooooooool02Oooo`80I_mKoooo00<0003oooooool0Eoooo`<0I_l<oooo00<0
I_ooooooool09Oooo`009_ooo`0306Kooooooooo00_oool306KoF?ooo`030000oooooooo05Goool2
06Ko3oooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`0>oooo0`1VoeGoool20000Dooo
o`<0I_lAoooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo017oool406KoDOooo`030000
oooooooo053oool206Ko5?ooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`0Eoooo0`1V
odkoool00`000?ooooooo`1=oooo0`1VoaKoool00`1Vooooooooo`0Uoooo000Voooo00<0I_oooooo
ool06?ooo`80I_m<oooo00<0003oooooool0Boooo`80I_lIoooo00<0I_ooooooool09Oooo`009_oo
o`0306Kooooooooo01[oool306KoBOooo`800019oooo0`1Voa_oool00`1Vooooooooo`0Uoooo000V
oooo00<0I_ooooooool07Oooo`80I_m7oooo00<0003oooooool0A_ooo`80I_lNoooo00<0I_oooooo
ool09Oooo`009_ooo`0306Kooooooooo01ooool306KoA?ooo`030000oooooooo04?oool306Ko8?oo
o`0306Kooooooooo02Goool002Koool00`1Vooooooooo`0Roooo0`1Vod7oool00`000?ooooooo`10
oooo0`1Vob?oool00`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool09Oooo`@0I_lmoooo0P00
03goool406Ko9_ooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`0Yoooo0`1Voc[oool0
0`000?ooooooo`0hoooo101Vob[oool00`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool0;?oo
o`<0I_lNoooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0coooo1@1V
obkoool00`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool0;oooo`@0I_lIoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02ooool4
06Ko<oooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`0coooo101VoaGoool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000/oooo0`1VocOoool0
0`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool0=oooo`D0I_l:oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Xoooo101Voc[oool0
0`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool0??ooo`D0I_l;oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo02Coool406Ko?_oo
o`0306Kooooooooo02Goool002Koool00`1Vooooooooo`11oooo1@1Vo`Ooool200002_ooo`800004
oooo0`0000Coool00`000?ooooooo`0Ooooo1@1Vod;oool00`1Vooooooooo`0Uoooo000Voooo00<0
I_ooooooool0A_ooo`D0I_lKoooo0P0001_oool506KoAoooo`0306Kooooooooo02Goool002Koool0
0`1Vooooooooo`1;oooo1P1VoaGoool00`000?ooooooo`0Eoooo1@1Vodcoool00`1Vooooooooo`0U
oooo000Voooo00<0I_ooooooool0DOooo`L0I_l>oooo00<0003oooooool03_ooo`L0I_mAoooo00<0
I_ooooooool09Oooo`009_ooo`0306Kooooooooo05Soool806Ko1_ooo`030000oooooooo00Koool8
06KoF?ooo`0306Kooooooooo02Goool001Soool200003?ooo`0306Kooooooooo01Koool400009Ooo
o`D0000Loooo1@1Vo`03oooo0000000000;oool506Ko7Oooo`D0000Soooo100001Ooool00`1Voooo
ooooo`0<oooo0P0001Ooool001Ooool010000?ooooooo`0000_oool00`1Vooooooooo`0Foooo00<0
003oooooool0:?ooo`030000oooooooo027oool00`1Vo`00001Vo`0206Ko9?ooo`030000oooooooo
02?oool00`000?ooooooo`0Hoooo00<0I_ooooooool02oooo`040000oooooooo00005_ooo`006Ooo
o`030000oooooooo00[oool00`1Vooooooooo`0Goooo00<0003oooooool09oooo`030000oooooooo
02;oool00`000?ooooooo`0Uoooo00<0003oooooool09?ooo`030000oooooooo01Ooool00`1Voooo
ooooo`0=oooo00<0003oooooool05Oooo`004Oooo`@00005oooo00<0003oooooool02Oooo`0306Ko
oooooooo013oool400001?ooo`030000oooooooo01koool400001?ooo`030000oooooooo02;oool0
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo01Koool00`1Vooooooooo`0>
oooo00<0003oooooool05?ooo`005oooo`040000oooooooo00002oooo`0306Kooooooooo01Koool0
10000?ooooooo`0002Ooool00`000?ooooooo`0Roooo0P0002Koool00`000?ooooooo`0Soooo00@0
003oooooool0000Goooo00<0I_ooooooool02oooo`040000oooooooo00005_ooo`006?ooo`80000<
oooo00<0I_ooooooool05oooo`80000Woooo0P0002Coool00`000?ooooooo`0Toooo0P0002Koool2
00006?ooo`0306Kooooooooo00coool200005oooo`009_ooo`0306Kooooooooo06Koool00`000?oo
ooooo`1Voooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo06Koool20000Ioooo`0306Ko
oooooooo02Goool002Koool00`1Vooooooooo`1Voooo00<0003oooooool0I_ooo`0306Kooooooooo
02Goool002Koool00`1Vooooooooo`1Voooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool0
02Koool00`1Vooooooooo`1Voooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Coool00ol0V@000?ooo`06oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo01Goool00ol0VOooooooo`0>oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool0
0ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0V
oooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000IOooo`03o`2Ioooooooo02Koool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Uoooo00?o09Woooooool09_oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0V
oooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1U
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo
02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool0
0ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Uoooo00?o
09Woooooool09_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool007coool200002_ooo`<00004oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0V
oooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1U
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo
02Koool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000IOoo
o`03o`2Ioooooooo02Koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0IOooo`03o`2Ioooooooo
02Koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool0
0ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_oo
o`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Sooo
o`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0V
oooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1U
oooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000
oooooooo06Goool00ol0VOooooooo`0Voooo0027oooo1@0000?oool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00ROooo`030000oooooooo00?oool30000IOooo`03o`2Ioooooooo02Koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003oooo`030000
oooooooo00Koool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.90802 .30902 L
.91306 .30902 L
.91765 .30902 L
.91884 .30902 L
.92014 .30902 L
s
.92014 .30902 m
.92026 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.06747 .30902 L
.07286 .30902 L
.07547 .30902 L
.07675 .30902 L
.07793 .30902 L
.07901 .30902 L
.08015 .15489 L
.08129 .15544 L
.08255 .15605 L
.10458 .16631 L
.14487 .18331 L
.18364 .19777 L
.22486 .21131 L
.26457 .2228 L
.30277 .23257 L
.34341 .24176 L
.38254 .24956 L
.42412 .25686 L
.46419 .26304 L
.48257 .26563 L
.4876 .26631 L
.493 .26703 L
.49562 .26738 L
.49809 .2677 L
.49917 .26784 L
.50032 .26791 L
.50158 .26774 L
.50274 .26759 L
.52268 .26491 L
.54374 .26188 L
.58149 .25593 L
.6217 .24876 L
.66038 .24095 L
.70152 .23153 L
.74115 .22123 L
.77926 .21004 L
.81982 .19655 L
.85886 .18183 L
.87877 .1736 L
.88926 .16905 L
.90036 .16407 L
.91027 .15947 L
.91298 .15819 L
.9159 .1568 L
.91731 .15612 L
.91865 .15547 L
.91985 .15489 L
Mistroke
.92116 .30902 L
.92247 .30902 L
.92369 .30902 L
.92598 .30902 L
.93111 .30902 L
.94034 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Goool00`1Vooooooooo`1Coooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Woooo00<0I_ooooooool09?ooo`009Oooo`80I_m>oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo06Goool306Ko9_ooo`009Oooo`0306Ko
oooo06Ko0080I_mAoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
06?oool206Ko0_ooo`0306Kooooooooo02Coool002Goool00`1Vooooooooo`02oooo0P1Voe3oool2
00002_ooo`<00004oooo00<0003oooooool0H_ooo`0306Kooooooooo00;oool00`1Vooooooooo`0T
oooo000Uoooo00<0I_ooooooool01?ooo`80I_mQoooo0P00063oool306Ko1Oooo`0306Kooooooooo
02Coool002Goool00`1Vooooooooo`06oooo0P1Voeooool00`000?ooooooo`1Loooo0`1Vo`Soool0
0`1Vooooooooo`0Toooo000Uoooo00<0I_ooooooool02?ooo`80I_mMoooo00<0003oooooool0F_oo
o`80I_l;oooo00<0I_ooooooool09?ooo`009Oooo`0306Kooooooooo00[oool206KoFoooo`030000
oooooooo05Ooool306Ko3Oooo`0306Kooooooooo02Coool002Goool00`1Vooooooooo`0<oooo0`1V
oeSoool20000E_ooo`80I_l@oooo00<0I_ooooooool09?ooo`009Oooo`0306Kooooooooo00ooool3
06KoEOooo`030000oooooooo05;oool306Ko4_ooo`0306Kooooooooo02Coool002Goool00`1Voooo
ooooo`0Boooo101Voe7oool00`000?ooooooo`1@oooo0P1VoaGoool00`1Vooooooooo`0Toooo000U
oooo00<0I_ooooooool05_ooo`<0I_m>oooo00<0003oooooool0COooo`<0I_lGoooo00<0I_oooooo
ool09?ooo`009Oooo`0306Kooooooooo01Woool206KoC?ooo`80001;oooo0`1Voa[oool00`1Voooo
ooooo`0Toooo000Uoooo00<0I_ooooooool06oooo`<0I_m9oooo00<0003oooooool0A_ooo`@0I_lM
oooo00<0I_ooooooool09?ooo`009Oooo`0306Kooooooooo01koool206KoAoooo`030000oooooooo
04?oool306Ko8Oooo`0306Kooooooooo02Coool002Goool00`1Vooooooooo`0Poooo0`1VodCoool0
0`000?ooooooo`10oooo0`1VobCoool00`1Vooooooooo`0Toooo000Uoooo00<0I_ooooooool08ooo
o`<0I_m1oooo0P0003goool406Ko9oooo`0306Kooooooooo02Coool002Goool00`1Vooooooooo`0V
oooo101Vocgoool00`000?ooooooo`0ioooo0`1Vob_oool00`1Vooooooooo`0Toooo000Uoooo00<0
I_ooooooool0:_ooo`@0I_lPoooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`0foooo0`1Vobkoool00`1Vooooooooo`0Toooo000Uoooo00<0I_ooooooool0;_ooo`D0I_lJ
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000
oooooooo03;oool406Ko<Oooo`0306Kooooooooo02Coool002Coool00`1Vooooooooo`0doooo1@1V
oaGoool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000^
oooo101VocKoool00`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0>Oooo`D0I_l:oooo1000
00;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Y
oooo1@1Voc[oool00`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0?_ooo`D0I_l;oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
02Coool506Ko?oooo`0306Kooooooooo02?oool002Coool00`1Vooooooooo`13oooo1@1Vo`Ooool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Ooooo1@1VodCoool00`1Vooooooooo`0S
oooo000Toooo00<0I_ooooooool0B?ooo`D0I_lKoooo0P0001_oool506KoBOooo`0306Kooooooooo
02?oool002Coool00`1Vooooooooo`1=oooo1P1VoaGoool00`000?ooooooo`0Eoooo1@1Vodkoool0
0`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0Doooo`D0I_l@oooo00<0003oooooool03_oo
o`L0I_mCoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo05Soool506Ko2oooo`030000
oooooooo00Koool806KoF_ooo`0306Kooooooooo02?oool001Soool200002_ooo`0306Kooooooooo
01Soool400009Oooo`D0000Goooo201Vo`?oool200000_ooo`D0I_lMoooo1@0002?oool400006Ooo
o`0306Kooooooooo00[oool200005oooo`005oooo`040000oooooooo00002Oooo`0306Kooooooooo
01Soool00`000?ooooooo`0Xoooo00<0003oooooool07oooo`<0I_l01000001Vo`1Vo`1VobCoool0
0`000?ooooooo`0Soooo00<0003oooooool06_ooo`0306Kooooooooo00Woool010000?ooooooo`00
01Koool001Woool00`000?ooooooo`08oooo00<0I_ooooooool06Oooo`030000oooooooo02Ooool0
0`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Coool00`000?ooooooo`0I
oooo00<0I_ooooooool02oooo`030000oooooooo01Goool0017oool400001Oooo`030000oooooooo
00Ooool00`1Vooooooooo`0Boooo100000Coool00`000?ooooooo`0Noooo100000Coool00`000?oo
ooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Hoooo00<0
I_ooooooool03?ooo`030000oooooooo01Coool001Ooool010000?ooooooo`0000Woool00`1Voooo
ooooo`0Hoooo00@0003oooooool0000Woooo00<0003oooooool08_ooo`80000Voooo00<0003ooooo
ool08oooo`040000oooooooo00006Oooo`0306Kooooooooo00Woool010000?ooooooo`0001Koool0
01Soool200002_ooo`0306Kooooooooo01Woool200009oooo`80000Toooo00<0003oooooool09?oo
o`80000Voooo0P0001[oool00`1Vooooooooo`0:oooo0P0001Ooool002Coool00`1Vooooooooo`1X
oooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Coool00`1Vooooooooo`1Xoooo0P00
06Woool00`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool0
0`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Voooo
ooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0S
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003o09Wo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo
02Goool00`000?ooooooo`0Goooo00?o09Woooooool03?ooo`030000oooooooo01Goool008ooool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?oo
o`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Iooo
o`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0T
oooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000
oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o
09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo001foooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1Woooo00?o09Woooooool09?oo
o`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00MOooo`040000oooooooo00002Oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0006Ooool00ol0VOooooooo`0Toooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Ioooo`03o`2I
oooooooo02Coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool007Koool200002_ooo`800004
oooo0`0000Coool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o
09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool0
0ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?oo
o`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Iooo
o`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0T
oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000J?ooo`03o`2Ioooooooo02?oool007_oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo001loooo0P0000[oool300001?oo
o`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0S
oooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1X
oooo00?o09Woooooool08oooo`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo
02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`80001Yoooo00?o
09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Wooooo
ool08oooo`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo06Soool00ol0VOooooooo`0Soooo001eoooo00@0003oooooool0000:oooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1Xoooo00?o09Wooooo
ool08oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo0`0006Soool00ol0VOooooooo`0Soooo001eoooo00@0003oooooool0000;oooo00@0003ooooo
ooooool200001Oooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0J?oo
o`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2Ioooooooo02?oool008ooool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2I
oooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo
02?oool008ooool20000JOooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Qoooo`D00003oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008Woool00`000?ooooooo`03oooo00<0003oooooool0J?oo
o`03o`2Ioooooooo02?oool008Woool00`000?ooooooo`03oooo0`0006Soool00ol0VOooooooo`0S
oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool00`000?ooooooo`06
oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91765 .30902 L
.9225 .30902 L
.92516 .30902 L
.92648 .30902 L
.92769 .30902 L
.92838 .30902 L
s
.92838 .30902 m
.92846 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.06244 .30902 L
.06525 .30902 L
.0679 .30902 L
.06905 .30902 L
.07027 .30902 L
.07091 .30902 L
.07162 .1546 L
.07286 .1552 L
.08255 .15983 L
.10458 .16983 L
.14487 .18642 L
.18364 .20051 L
.22486 .21373 L
.26457 .22493 L
.30277 .23446 L
.34341 .24342 L
.38254 .25103 L
.42412 .25815 L
.46419 .26418 L
.48257 .2667 L
.4876 .26737 L
.493 .26807 L
.49562 .26841 L
.49809 .26872 L
.49917 .26886 L
.50032 .26892 L
.50158 .26876 L
.50274 .26862 L
.52268 .266 L
.54374 .26304 L
.58149 .25724 L
.6217 .25025 L
.66038 .24263 L
.70152 .23345 L
.74115 .2234 L
.77926 .21248 L
.81982 .19933 L
.85886 .18497 L
.87877 .17694 L
.90036 .16765 L
.91046 .16307 L
.91599 .16051 L
.92116 .15807 L
.92557 .15596 L
.92683 .15535 L
.92804 .15477 L
.92912 .30902 L
Mistroke
.9303 .30902 L
.94034 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002;oool206KoEoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000JOooo`80I_lSoooo000Roooo00<0I_ooool0I_l0D?ooo`@00002oooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1Xoooo0`1Vob?oool002;oool00`1Vooooooooo`02
06KoE?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Uoooo0`1V
o`;oool00`1Vooooooooo`0Qoooo000Roooo00<0I_ooooooool00_ooo`<0I_mBoooo0P0000[oool3
00001?ooo`030000oooooooo06?oool206Ko1Oooo`0306Kooooooooo027oool002;oool00`1Voooo
ooooo`05oooo0`1Vof;oool20000H_ooo`80I_l7oooo00<0I_ooooooool08Oooo`008_ooo`0306Ko
oooooooo00Soool206KoH?ooo`030000oooooooo05ooool206Ko2Oooo`0306Kooooooooo027oool0
02;oool00`1Vooooooooo`0:oooo0`1Voegoool00`000?ooooooo`1Loooo0`1Vo`_oool00`1Voooo
ooooo`0Qoooo000Roooo00<0I_ooooooool03Oooo`80I_mKoooo00<0003oooooool0F_ooo`80I_l>
oooo00<0I_ooooooool08Oooo`008_ooo`0306Kooooooooo00ooool306KoF?ooo`80001Hoooo0`1V
oa3oool00`1Vooooooooo`0Qoooo000Roooo00<0I_ooooooool04_ooo`80I_mFoooo00<0003ooooo
ool0EOooo`80I_lCoooo00<0I_ooooooool08Oooo`008_ooo`0306Kooooooooo01Coool306KoDooo
o`030000oooooooo05;oool306Ko5Oooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`0G
oooo0P1Voe7oool00`000?ooooooo`1@oooo0P1VoaSoool00`1Vooooooooo`0Qoooo000Roooo00<0
I_ooooooool06Oooo`<0I_m>oooo0P0004koool306Ko6_ooo`0306Kooooooooo027oool002;oool0
0`1Vooooooooo`0Loooo0`1Vod_oool00`000?ooooooo`1:oooo0`1Voagoool00`1Vooooooooo`0Q
oooo000Roooo00<0I_ooooooool07oooo`@0I_m7oooo00<0003oooooool0A_ooo`@0I_lPoooo00<0
I_ooooooool08Oooo`008_ooo`0306Kooooooooo02?oool306KoA?ooo`030000oooooooo04?oool3
06Ko9?ooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`0Voooo0`1Vod7oool20000@Ooo
o`<0I_lWoooo00<0I_ooooooool08Oooo`008_ooo`0306Kooooooooo02Woool406Ko?Oooo`030000
oooooooo03coool406Ko:_ooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`0]oooo0`1V
ob7oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo03Soool406Ko;_oo
o`0306Kooooooooo027oool002;oool00`1Vooooooooo`0`oooo0`1Voagoool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0<oooo`D0I_lb
oooo00<0I_ooooooool08Oooo`008_ooo`0306Kooooooooo03?oool406Ko6Oooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0002ooool406Ko=oooo`0306Ko
oooooooo027oool002;oool00`1Vooooooooo`0goooo101Vo`ooool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo02coool306Ko>oooo`0306Ko
oooooooo027oool002;oool00`1Vooooooooo`0koooo1@1Voa3oool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0:?ooo`@0I_lnoooo00<0
I_ooooooool08Oooo`008_ooo`0306Kooooooooo043oool506Ko3?ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo02Coool406Ko@_ooo`0306Kooooooooo027oool002;oool00`1Voooo
ooooo`15oooo1@1Vob3oool200008?ooo`D0I_m6oooo00<0I_ooooooool08Oooo`008_ooo`0306Ko
oooooooo04[oool506Ko6oooo`030000oooooooo01Soool706KoBoooo`0306Kooooooooo027oool0
02;oool00`1Vooooooooo`1?oooo1P1VoaGoool00`000?ooooooo`0@oooo201Voe;oool00`1Voooo
ooooo`0Qoooo000Roooo00<0I_ooooooool0EOooo`L0I_l>oooo00<0003oooooool02oooo`D0I_mJ
oooo00<0I_ooooooool08Oooo`006?ooo`800008oooo00<0I_ooooooool06_ooo`@0000Uoooo1@00
01Coool806Ko1_ooo`800007oooo1@1VoaSoool500008oooo`@0000Koooo00<0I_ooooooool02?oo
o`80000Goooo000Goooo00@0003oooooool00007oooo00<0I_ooooooool06_ooo`030000oooooooo
02Soool00`000?ooooooo`0Loooo1P1Vo`03000006Ko06Ko00H0I_lOoooo00<0003oooooool08ooo
o`030000oooooooo01coool00`1Vooooooooo`07oooo00@0003oooooool0000Foooo000Ioooo00<0
003oooooool01_ooo`0306Kooooooooo01_oool00`000?ooooooo`0Woooo00<0003oooooool08_oo
o`030000oooooooo02Goool00`000?ooooooo`0Toooo00<0003oooooool06oooo`0306Kooooooooo
00Woool00`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`05oooo00<0I_oooooo
ool05?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool06_ooo`0306Kooooooooo00[oool0
0`000?ooooooo`0Doooo000Goooo00@0003oooooool00007oooo00<0I_ooooooool06_ooo`040000
oooooooo00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?oo
ooooo`0001_oool00`1Vooooooooo`07oooo00@0003oooooool0000Foooo000Hoooo0P0000Soool0
0`1Vooooooooo`0Koooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_ooo`80000L
oooo00<0I_ooooooool02?ooo`80000Goooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo
06[oool00`1Vooooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`80001[oooo00<0I_oooooo
ool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Ooo
o`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Oooo`008_oo
o`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Oooo`004?ooool0000A
oooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00?oool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0
003oooooool06_ooo`03o`2Ioooooooo00Woool00`000?ooooooo`0Eoooo002?oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo027oool008ooool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Jooo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2I
oooooooo027oool008ooool20000Joooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00M_ooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool007Goool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0001Zoooo00?o09Woooooool08Oooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001foooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
08ooool20000Joooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo027oool008ooool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Jooo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00O?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001k
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0J_ooo`03o`2I
oooooooo027oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0006[oool0
0ol0VOooooooo`0Qoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`80001[oooo00?o09Woooooool08Oooo`00Sooo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2I
oooooooo027oool008ooool20000Joooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
08ooool20000Joooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`1Zoooo00?o09Woooooool08Oooo`00MOooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001Z
oooo00?o09Woooooool08Oooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool008Ooool500000oooo`030000oooooooo06[oool0
0ol0VOooooooo`0Qoooo0029oooo00<0003oooooool00oooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo0029oooo00<0003oooooool00oooo`<0001Zoooo00?o09Woooooool08Oooo`00ROoo
o`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09
oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003ooo
o`030000oooooooo00Woool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91765 .30902 L
.92769 .30902 L
.93044 .30902 L
.93339 .30902 L
.93482 .30902 L
.93553 .30902 L
.93618 .30902 L
s
.93618 .30902 m
.9363 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.05746 .30902 L
.06005 .30902 L
.06119 .30902 L
.06244 .30902 L
.06371 .15462 L
.06441 .15495 L
.06506 .15527 L
.0679 .15664 L
.07286 .159 L
.08255 .16351 L
.10458 .17327 L
.14335 .18887 L
.18458 .2035 L
.22428 .21591 L
.26248 .22646 L
.30312 .23638 L
.34225 .24481 L
.38383 .25269 L
.4239 .25937 L
.46245 .26505 L
.482 .26767 L
.48735 .26836 L
.4931 .26909 L
.49588 .26944 L
.49725 .26961 L
.49851 .26977 L
.49966 .26991 L
.50088 .26984 L
.5021 .26969 L
.50346 .26952 L
.54294 .26429 L
.58315 .25825 L
.62183 .25168 L
.66297 .24374 L
.7026 .23506 L
.74071 .22563 L
.78127 .21427 L
.82031 .20187 L
.86181 .1869 L
.88261 .17863 L
.90179 .17051 L
.92048 .16212 L
.9299 .15769 L
.93248 .15646 L
.9339 .15577 L
.93525 .15512 L
.9365 .15451 L
Mistroke
.93721 .30902 L
.93787 .30902 L
.94026 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0023oool206KoFOooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Joooo`80I_lQoooo000Poooo101Voe7oool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0J_ooo`<0I_lQoooo000Poooo00D0I_ooooooooooool0I_l0E_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Woooo0`1Vo`;oool0
0`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool00_ooo`80I_mEoooo0P0000[oool300001?oo
o`030000oooooooo06Goool206Ko1Oooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`04
oooo0`1VofGoool20000Hoooo`<0I_l7oooo00<0I_ooooooool07oooo`008?ooo`0306Kooooooooo
00Ooool306KoH_ooo`030000oooooooo063oool206Ko2_ooo`0306Kooooooooo01ooool0023oool0
0`1Vooooooooo`0:oooo0P1Vof3oool00`000?ooooooo`1Moooo0`1Vo`coool00`1Vooooooooo`0O
oooo000Poooo00<0I_ooooooool03?ooo`<0I_mMoooo00<0003oooooool0Foooo`80I_l?oooo00<0
I_ooooooool07oooo`008?ooo`0306Kooooooooo00ooool206KoFoooo`80001Ioooo0`1Voa7oool0
0`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool04Oooo`<0I_mHoooo00<0003oooooool0EOoo
o`<0I_lDoooo00<0I_ooooooool07oooo`008?ooo`0306Kooooooooo01Coool206KoE_ooo`030000
oooooooo05?oool206Ko5oooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`0Foooo0`1V
oe?oool00`000?ooooooo`1@oooo0`1VoaWoool00`1Vooooooooo`0Ooooo000Poooo00<0I_oooooo
ool06Oooo`80I_mAoooo0P0004koool306Ko7?ooo`0306Kooooooooo01ooool0023oool00`1Voooo
ooooo`0Koooo0`1Vodkoool00`000?ooooooo`1:oooo0`1Voaooool00`1Vooooooooo`0Ooooo000P
oooo00<0I_ooooooool07_ooo`<0I_m;oooo00<0003oooooool0A_ooo`@0I_lRoooo00<0I_oooooo
ool07oooo`008?ooo`0306Kooooooooo027oool406KoAoooo`030000oooooooo04?oool306Ko9_oo
o`0306Kooooooooo01ooool0023oool00`1Vooooooooo`0Uoooo101Vod?oool20000@Oooo`<0I_lY
oooo00<0I_ooooooool07oooo`008?ooo`0306Kooooooooo02Woool506Ko?_ooo`030000oooooooo
03coool406Ko;?ooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`0^oooo101Vob7oool2
00001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo03Woool306Ko<?ooo`0306Ko
oooooooo01ooool0023oool00`1Vooooooooo`0boooo0`1Voagoool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0=_ooo`<0I_lcoooo00<0
I_ooooooool07oooo`008?ooo`0306Kooooooooo03Goool406Ko6Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0003;oool406Ko=_ooo`0306Kooooooooo
01ooool0023oool00`1Vooooooooo`0ioooo101Vo`ooool400000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo02koool406Ko>_ooo`0306Kooooooooo
01ooool0023oool00`1Vooooooooo`0moooo1@1Voa3oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0:Oooo`D0I_lnoooo00<0I_oooooo
ool07oooo`008?ooo`0306Kooooooooo04;oool506Ko3?ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo02Coool506Ko@oooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`17
oooo1P1Voaooool200008?ooo`D0I_m8oooo00<0I_ooooooool07oooo`008?ooo`0306Kooooooooo
04goool506Ko6_ooo`030000oooooooo01[oool506KoCOooo`0306Kooooooooo01ooool0023oool0
0`1Vooooooooo`1Boooo1@1VoaGoool00`000?ooooooo`0Eoooo1@1Voe;oool00`1Vooooooooo`0O
oooo000Poooo00<0I_ooooooool0Eoooo`L0I_l>oooo00<0003oooooool03_ooo`L0I_mGoooo00<0
I_ooooooool07oooo`006?ooo`800006oooo00<0I_ooooooool07?ooo`@0000Uoooo1@0001Coool7
06Ko1oooo`800005oooo2P1VoaGoool500008oooo`@0000Moooo00<0I_ooooooool01_ooo`80000G
oooo000Goooo00@0003oooooool00005oooo00<0I_ooooooool07?ooo`030000oooooooo02Soool0
0`000?ooooooo`0Koooo1`1Vo`03000006Ko06Ko00@0I_lQoooo00<0003oooooool08oooo`030000
oooooooo01koool00`1Vooooooooo`05oooo00@0003oooooool0000Foooo000Ioooo00<0003ooooo
ool01?ooo`0306Kooooooooo01goool00`000?ooooooo`0Woooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Toooo00<0003oooooool07Oooo`0306Kooooooooo00Ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Goool00`000?ooooooo`03oooo00<0I_ooooooool05_oo
o`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0Uoooo00<0003oooooool07?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool00005oooo00<0I_ooooooool07?ooo`040000oooooooo
00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`00
01goool00`1Vooooooooo`05oooo00@0003oooooool0000Foooo000Hoooo0P0000Koool00`1Voooo
ooooo`0Moooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_ooo`80000Noooo00<0
I_ooooooool01_ooo`80000Goooo000Poooo00<0I_ooooooool0K?ooo`030000oooooooo06coool0
0`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool0K?ooo`80001]oooo00<0I_ooooooool07ooo
o`008?ooo`0306Kooooooooo06coool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`008?oo
o`0306Kooooooooo06coool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`008?ooo`0306Ko
oooooooo06coool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000007
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool07?oo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0K?ooo`03o`2I
oooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/
oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?
oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo
01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo
06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool0
08ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Wooooo
ool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003ooooo
ool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool0
0`000?ooooooo`1/oooo00?o09Woooooool07oooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0K?ooo`03o`2I
oooooooo01ooool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0001/oooo00?o09Woooooool07oooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
06coool00ol0VOooooooo`0Ooooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool0
0`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOoo
ooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOoo
o`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Sooo
o`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2I
oooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/
oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?
oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo
01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0006coool00ol0VOooooooo`0O
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1/oooo00?o09Wooooo
ool07oooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1/
oooo00?o09Woooooool07oooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1/oooo00?o
09Woooooool07oooo`00Soooo`80001]oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo
06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool0
08ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Wooooo
ool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003ooooo
ool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool0
0`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOoo
ooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool20000KOoo
o`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1/oooo00?o
09Woooooool07oooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001/oooo00?o09Wooooo
ool07oooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`1/oooo00?o09Woooooool07oooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?
oooo0P0006goool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo
01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo
06coool00ol0VOooooooo`0Ooooo002?oooo0P0006goool00ol0VOooooooo`0Ooooo002?oooo00<0
003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Wooooo
ool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo0P0006goool0
0ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool0
0`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOoo
ooooo`0Ooooo002?oooo0P0006goool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?oo
o`03o`2Ioooooooo01ooool008Ooool500000oooo`030000oooooooo06coool00ol0VOooooooo`0O
oooo0029oooo00<0003oooooool00oooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo0029
oooo00<0003oooooool00oooo`<0001/oooo00?o09Woooooool07oooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003oooo`030000oooooooo00Woool010000?ooooooooooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002Oooo`@00003oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93331 .30902 L
.93871 .30902 L
.94107 .30902 L
.94236 .30902 L
.94357 .30902 L
s
.94357 .30902 m
.9437 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.0503 .30902 L
.05288 .30902 L
.05405 .30902 L
.05528 .30902 L
.05593 .15469 L
.05664 .15503 L
.05789 .15564 L
.06244 .15783 L
.10458 .17662 L
.14487 .1924 L
.18364 .2058 L
.22486 .21837 L
.26457 .22903 L
.30277 .2381 L
.34341 .24662 L
.38254 .25386 L
.42412 .26063 L
.46419 .26637 L
.48257 .26876 L
.4876 .2694 L
.493 .27007 L
.49562 .27039 L
.49809 .27069 L
.49917 .27082 L
.50032 .27088 L
.50158 .27073 L
.50274 .27059 L
.52268 .26809 L
.54374 .26529 L
.58149 .25976 L
.6217 .25312 L
.66038 .24587 L
.70152 .23713 L
.74115 .22758 L
.77926 .21719 L
.81982 .20467 L
.85886 .19102 L
.90036 .17454 L
.92116 .16543 L
.9303 .16124 L
.93514 .15897 L
.93781 .1577 L
.94034 .15649 L
.94259 .15541 L
.94386 .15479 L
.94504 .30902 L
Mistroke
.94614 .30902 L
.94712 .30902 L
.94934 .30902 L
.95776 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001koool206KoFoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000KOooo`80I_lOoooo000Noooo101Voe?oool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0Joooo`@0I_lOoooo000Noooo00@0I_ooooooooooool206KoEooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Zoooo00D0I_oooooo
ooooool0I_l07oooo`007_ooo`0306Kooooooooo00?oool206KoE_ooo`80000:oooo0`0000Coool0
0`000?ooooooo`1Woooo0`1Vo`Coool00`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool01Ooo
o`80I_mWoooo0P0006Goool306Ko1oooo`0306Kooooooooo01goool001koool00`1Vooooooooo`07
oooo0P1VofGoool00`000?ooooooo`1Qoooo0`1Vo`[oool00`1Vooooooooo`0Moooo000Noooo00<0
I_ooooooool02Oooo`<0I_mRoooo00<0003oooooool0Goooo`80I_l=oooo00<0I_ooooooool07Ooo
o`007_ooo`0306Kooooooooo00coool206KoH?ooo`030000oooooooo05coool306Ko3oooo`0306Ko
oooooooo01goool001koool00`1Vooooooooo`0>oooo0`1Voegoool20000Foooo`80I_lBoooo00<0
I_ooooooool07Oooo`007_ooo`0306Kooooooooo017oool206KoFoooo`030000oooooooo05Ooool3
06Ko5?ooo`0306Kooooooooo01goool001koool00`1Vooooooooo`0Coooo0`1VoeSoool00`000?oo
ooooo`1Eoooo0P1VoaOoool00`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool05_ooo`<0I_mE
oooo00<0003oooooool0D_ooo`<0I_lIoooo00<0I_ooooooool07Oooo`007_ooo`0306Kooooooooo
01Woool406KoDOooo`80001Aoooo0P1Voacoool00`1Vooooooooo`0Moooo000Noooo00<0I_oooooo
ool07Oooo`<0I_m>oooo00<0003oooooool0COooo`<0I_lNoooo00<0I_ooooooool07Oooo`007_oo
o`0306Kooooooooo023oool306KoBoooo`030000oooooooo04[oool306Ko8Oooo`0306Kooooooooo
01goool001koool00`1Vooooooooo`0Soooo101VodOoool00`000?ooooooo`16oooo101VobCoool0
0`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool09oooo`<0I_m4oooo0P0004Coool306Ko:?oo
o`0306Kooooooooo01goool001koool00`1Vooooooooo`0Zoooo0`1Vod7oool00`000?ooooooo`10
oooo0`1Vob_oool00`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool0;Oooo`@0I_lToooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0loooo101Vobkoool00`1Voooo
ooooo`0Moooo000Noooo00<0I_ooooooool0<Oooo`@0I_lOoooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo03Soool406Ko<_ooo`0306Ko
oooooooo01goool001koool00`1Vooooooooo`0eoooo1@1Voa[oool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000coooo1@1VocKoool00`1Vooooooooo`0M
oooo000Noooo00<0I_ooooooool0>_ooo`@0I_l@oooo100000;oool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0^oooo1@1Voc_oool00`1Vooooooooo`0M
oooo000Noooo00<0I_ooooooool0?_ooo`<0I_lCoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02Woool506Ko@?ooo`0306Kooooooooo
01goool001koool00`1Vooooooooo`11oooo101Voa3oool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0Toooo1@1VodGoool00`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool0AOoo
o`H0I_lSoooo0P00023oool506KoB_ooo`0306Kooooooooo01goool001koool00`1Vooooooooo`1;
oooo201Voa_oool00`000?ooooooo`0Joooo1@1Vodooool00`1Vooooooooo`0Moooo000Noooo00<0
I_ooooooool0Doooo`H0I_lEoooo00<0003oooooool05Oooo`D0I_mDoooo00<0I_ooooooool07Ooo
o`007_ooo`0306Kooooooooo05Woool506Ko4?ooo`030000oooooooo00koool706KoFOooo`0306Ko
oooooooo01goool001Soool200001?ooo`0306Kooooooooo01koool400009Oooo`D0000Boooo1@1V
o`_oool200001oooo`P0I_lEoooo1@0002?oool400007oooo`0306Kooooooooo00Coool200005ooo
o`005oooo`040000oooooooo00000oooo`0306Kooooooooo01koool00`000?ooooooo`0Xoooo00<0
003oooooool05oooo`T0I_l2oooo00@0003oooooooooool506Ko7oooo`030000oooooooo02?oool0
0`000?ooooooo`0Poooo00<0I_ooooooool00oooo`040000oooooooo00005_ooo`006Oooo`030000
oooooooo00;oool00`1Vooooooooo`0Ooooo00<0003oooooool09oooo`030000oooooooo023oool2
06Ko00@00000I_l0I_l0I_lToooo00<0003oooooool09?ooo`030000oooooooo01ooool00`1Voooo
ooooo`05oooo00<0003oooooool05Oooo`004Oooo`@00005oooo00D0003oooooooooool0I_l06_oo
o`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo
02Goool00`000?ooooooo`0Uoooo00<0003oooooool07_ooo`0306Kooooooooo00Koool00`000?oo
ooooo`0Doooo000Goooo00@0003oooooool00003oooo00<0I_ooooooool07_ooo`040000oooooooo
00009oooo`030000oooooooo02;oool200009_ooo`030000oooooooo02?oool010000?ooooooo`00
01ooool00`1Vooooooooo`03oooo00@0003oooooool0000Foooo000Hoooo0P0000Coool00`1Voooo
ooooo`0Ooooo0P0002Ooool200009?ooo`030000oooooooo02Coool200009_ooo`80000Poooo00<0
I_ooooooool01?ooo`80000Goooo000Noooo00<0I_ooooooool0K_ooo`030000oooooooo06koool0
0`1Vooooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`80001_oooo00<0I_ooooooool07Ooo
o`007_ooo`0306Kooooooooo06koool00`000?ooooooo`1^oooo00<0I_ooooooool07Oooo`007_oo
o`0306Kooooooooo06koool00`000?ooooooo`1^oooo00<0I_ooooooool07Oooo`007_ooo`0306Ko
oooooooo06koool00`000?ooooooo`1^oooo00<0I_ooooooool07Oooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Coool00ol0V@000?ooo`06
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool07Ooo
o`03o`2Ioooooooo00Koool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0KOooo`03o`2I
oooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0KOooo`03o`2I
oooooooo01koool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0001]oooo00?o09Woooooool07_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo06goool00ol0VOooooooo`0Noooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOoo
ooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_oo
o`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Sooo
o`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2I
oooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo06goool00ol0VOooooooo`0Noooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0006goool00ol0VOooooooo`0N
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1]oooo00?o
09Woooooool07_ooo`00Soooo`80001^oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOoo
ooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_oo
o`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1]oooo00?o
09Woooooool07_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001]oooo00?o09Wooooo
ool07_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`1]oooo00?o09Woooooool07_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0
003oooooool0KOooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo0P0006koool0
0ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOoo
ooooo`0Noooo002?oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOoo
o`03o`2Ioooooooo01koool008Ooool500000oooo`030000oooooooo06goool00ol0VOooooooo`0N
oooo0029oooo00<0003oooooool00oooo`030000oooooooo06goool00ol0VOooooooo`0Noooo0029
oooo00<0003oooooool00oooo`<0001]oooo00?o09Woooooool07_ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01ooo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93871 .30902 L
.94392 .30902 L
.94648 .30902 L
.94885 .30902 L
.951 .30902 L
.95208 .30902 L
s
.95208 .30902 m
.9522 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04517 .30902 L
.04642 .30902 L
.04758 .30902 L
.04822 .1548 L
.04891 .15513 L
.05035 .15583 L
.05288 .15705 L
.06244 .16156 L
.10458 .17989 L
.14241 .19439 L
.1827 .20806 L
.22147 .21966 L
.2627 .23054 L
.30241 .23977 L
.3406 .24762 L
.38125 .255 L
.42038 .26126 L
.46196 .26713 L
.48283 .26979 L
.49198 .27091 L
.49449 .27121 L
.49717 .27152 L
.49848 .27168 L
.49971 .27182 L
.50082 .27176 L
.50202 .27162 L
.52077 .26934 L
.54057 .26679 L
.58136 .261 L
.62062 .25468 L
.65837 .24782 L
.69858 .23956 L
.73726 .23055 L
.7784 .2197 L
.81803 .20782 L
.85614 .19492 L
.8967 .17937 L
.91543 .17148 L
.93574 .1624 L
.941 .15995 L
.94657 .15731 L
.94886 .15621 L
.95012 .1556 L
.95132 .15502 L
.952 .1547 L
.95273 .30902 L
.95402 .30902 L
Mistroke
.95655 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001coool206KoGOooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Koooo`80I_lMoooo000Loooo0`1VoeKoool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0K_ooo`<0I_lMoooo000Loooo00<0I_ooooooool00`1VoeWoool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0Joooo`<0I_l2oooo00<0
I_ooooooool06oooo`007?ooo`0306Kooooooooo00?oool206KoF?ooo`80000:oooo0`0000Coool0
0`000?ooooooo`1Yoooo0P1Vo`Goool00`1Vooooooooo`0Koooo000Loooo00<0I_ooooooool01Ooo
o`80I_mYoooo0P0006Soool206Ko1oooo`0306Kooooooooo01_oool001coool00`1Vooooooooo`07
oooo0P1VofOoool00`000?ooooooo`1Voooo00<0I_ooooooool01oooo`0306Kooooooooo01_oool0
01coool00`1Vooooooooo`09oooo0P1VofGoool00`000?ooooooo`1Toooo0P1Vo`[oool00`1Voooo
ooooo`0Koooo000Loooo00<0I_ooooooool02oooo`<0I_mRoooo00<0003oooooool0HOooo`<0I_l<
oooo00<0I_ooooooool06oooo`007?ooo`0306Kooooooooo00koool306KoGoooo`80001Noooo101V
o`ooool00`1Vooooooooo`0Koooo000Loooo00<0I_ooooooool04Oooo`<0I_mLoooo00<0003ooooo
ool0FOooo`@0I_lCoooo00<0I_ooooooool06oooo`007?ooo`0306Kooooooooo01Coool306KoFOoo
o`030000oooooooo05Koool306Ko5oooo`0306Kooooooooo01_oool001coool00`1Vooooooooo`0G
oooo0`1VoeKoool00`000?ooooooo`1Doooo0P1Voa[oool00`1Vooooooooo`0Koooo000Loooo00<0
I_ooooooool06_ooo`80I_mDoooo0P0005?oool206Ko7?ooo`0306Kooooooooo01_oool001coool0
0`1Vooooooooo`0Loooo0`1Voe7oool00`000?ooooooo`1@oooo0P1Voakoool00`1Vooooooooo`0K
oooo000Loooo00<0I_ooooooool07oooo`<0I_m>oooo00<0003oooooool0COooo`<0I_lPoooo00<0
I_ooooooool06oooo`007?ooo`0306Kooooooooo02;oool306KoBoooo`030000oooooooo04[oool3
06Ko8oooo`0306Kooooooooo01_oool001coool00`1Vooooooooo`0Uoooo0`1VodSoool20000Aooo
o`@0I_lVoooo00<0I_ooooooool06oooo`007?ooo`0306Kooooooooo02Soool306KoAOooo`030000
oooooooo04?oool306Ko:_ooo`0306Kooooooooo01_oool001coool00`1Vooooooooo`0[oooo101V
obSoool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo03ooool406Ko;Ooo
o`0306Kooooooooo01_oool001coool00`1Vooooooooo`0_oooo101Vob?oool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0>oooo`@0I_la
oooo00<0I_ooooooool06oooo`007?ooo`0306Kooooooooo03?oool406Ko7oooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0003Ooool406Ko=Oooo`0306Ko
oooooooo01_oool001coool00`1Vooooooooo`0goooo1@1VoaCoool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo03;oool506Ko>Oooo`0306Ko
oooooooo01_oool001coool00`1Vooooooooo`0loooo1@1VoaGoool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0;Oooo`D0I_lnoooo00<0
I_ooooooool06oooo`007?ooo`0306Kooooooooo047oool506Ko4Oooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo02Soool506Ko@oooo`0306Kooooooooo01_oool001coool00`1Voooo
ooooo`16oooo1@1VobGoool200009?ooo`D0I_m8oooo00<0I_ooooooool06oooo`007?ooo`0306Ko
oooooooo04_oool506Ko8?ooo`030000oooooooo01ooool406KoCOooo`0306Kooooooooo01_oool0
01coool00`1Vooooooooo`1@oooo1`1VoaWoool00`000?ooooooo`0Hoooo1`1Voe7oool00`1Voooo
ooooo`0Koooo000Loooo00<0I_ooooooool0Eoooo`P0I_lAoooo00<0003oooooool04?ooo`P0I_mH
oooo00<0I_ooooooool06oooo`006?ooo`800002oooo00<0I_ooooooool08?ooo`@0000Uoooo1@00
017oool506Ko3?ooo`80000;oooo1P1Voa?oool500008oooo`@0000Qoooo00<0I_ooooooool00_oo
o`80000Goooo000Goooo00H0003oooooool0003oool0I_lRoooo00<0003oooooool0:?ooo`030000
oooooooo01Koool906Ko0oooo`030000oooooooo00X0I_lKoooo00<0003oooooool08oooo`030000
oooooooo02;oool01@1Vooooooooooooo`000002oooo00<0003oooooool05?ooo`006Oooo`040000
oooooooo06Ko8oooo`030000oooooooo02Ooool00`000?ooooooo`0Ooooo0`1Vo`03000006Ko06Ko
02Goool00`000?ooooooo`0Toooo00<0003oooooool08Oooo`0306Kooooooooo00?oool00`000?oo
ooooo`0Eoooo000Aoooo100000Goool00`000?ooo`1Vo`0Loooo100000Coool00`000?ooooooo`0N
oooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool09Oooo`030000oooooooo02Goool0
0`000?ooooooo`0Poooo00<0I_ooooooool01?ooo`030000oooooooo01Coool001Ooool01P000?oo
ooooo`000?ooo`1Vob;oool010000?ooooooo`0002Ooool00`000?ooooooo`0Roooo0P0002Koool0
0`000?ooooooo`0Soooo00@0003oooooool0000Qoooo00D0I_ooooooooooool000000_ooo`030000
oooooooo01Coool001Soool200000_ooo`0306Kooooooooo027oool200009oooo`80000Toooo00<0
003oooooool09?ooo`80000Voooo0P0002;oool00`1Vooooooooo`02oooo0P0001Ooool001coool0
0`1Vooooooooo`1`oooo00<0003oooooool0L?ooo`0306Kooooooooo01_oool001coool00`1Voooo
ooooo`1`oooo0P00077oool00`1Vooooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000
oooooooo073oool00`1Vooooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo
073oool00`1Vooooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo073oool0
0`1Vooooooooo`0Koooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool09Ooo
o`030000oooooooo02Goool00`000?ooooooo`0Poooo00?o09Woooooool00oooo`030000oooooooo
01Goool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o
09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool0
0ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06ooo
o`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?oo
o`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Sooo
o`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0K
oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1`oooo00?o
09Woooooool06oooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00MOooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00073oool00ol0VOooooooo`0K
oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool007Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool007Koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Sooo
o`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0K
oooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`
oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000
oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo
01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o
09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool0
0ol0VOooooooo`0Koooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0L?oo
o`03o`2Ioooooooo01_oool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000L?ooo`03o`2Ioooooooo01_oool007_oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001koooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001loooo0P00
00[oool300001?ooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo0P00077oool0
0ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06ooo
o`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?oo
o`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Sooo
o`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0K
oooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`
oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000
oooooooo073oool00ol0VOooooooo`0Koooo001foooo0P0000Coool200001Oooo`030000oooooooo
00;oool200001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001eoooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1`
oooo00?o09Woooooool06oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool0
0`000?ooooooo`02oooo0`00073oool00ol0VOooooooo`0Koooo001eoooo00@0003oooooool0000;
oooo00@0003oooooooooool200001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001e
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo073oool00ol0VOooooooo`0Koooo001foooo0P0000Woool400000oooo`<00004oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2Ioooooooo01_oool0
08ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool0
0ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool2
0000LOooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06ooo
o`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?oo
o`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2Ioooooooo01_oool008ooool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0K
oooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2I
oooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Qoooo`D00003
oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008Woool00`000?ooooooo`03oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008Woool00`000?ooooooo`03oooo0`00073oool0
0ol0VOooooooo`0Koooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool0
0`000?ooooooo`07oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?oo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.93871 .30902 L
.94807 .30902 L
.95322 .30902 L
.95575 .30902 L
.9581 .30902 L
.95923 .30902 L
.96029 .30902 L
s
.96029 .30902 m
.96041 .61803 L
s
0 .4 1 r
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03523 .30902 L
.03754 .30902 L
.03881 .30902 L
.03953 .30902 L
.0402 .15476 L
.04137 .15533 L
.04262 .15593 L
.06244 .1652 L
.10458 .18307 L
.14241 .19722 L
.1827 .21055 L
.22147 .22187 L
.2627 .23248 L
.30241 .24148 L
.3406 .24914 L
.38125 .25633 L
.42038 .26244 L
.46196 .26816 L
.48283 .27076 L
.49198 .27185 L
.49449 .27214 L
.49717 .27245 L
.49848 .2726 L
.49971 .27274 L
.50082 .27268 L
.50202 .27254 L
.52077 .27032 L
.54057 .26783 L
.58136 .26219 L
.62062 .25602 L
.65837 .24933 L
.69858 .24127 L
.73726 .23249 L
.7784 .2219 L
.81803 .21032 L
.85614 .19773 L
.8967 .18257 L
.93574 .16602 L
.94573 .16145 L
.95098 .15899 L
.95386 .15762 L
.95655 .15633 L
.95889 .1552 L
.96021 .15456 L
.96142 .30902 L
.96273 .30902 L
.96416 .30902 L
Mistroke
.96677 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001[oool206KoGoooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000LOooo`80I_lKoooo000Joooo0`1VoeSoool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0Koooo`@0I_lKoooo000Joooo00<0I_ooooooool00P1Voecoool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0KOooo`80I_l3oooo00<0
I_ooooooool06Oooo`006_ooo`0306Kooooooooo00;oool306KoF_ooo`80000:oooo0`0000Coool0
0`000?ooooooo`1Zoooo0`1Vo`Goool00`1Vooooooooo`0Ioooo000Joooo00<0I_ooooooool01Ooo
o`<0I_mZoooo0P0006Woool206Ko2?ooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`08
oooo0P1VofSoool00`000?ooooooo`1Voooo0P1Vo`[oool00`1Vooooooooo`0Ioooo000Joooo00<0
I_ooooooool02_ooo`<0I_mUoooo00<0003oooooool0I?ooo`80I_l<oooo00<0I_ooooooool06Ooo
o`006_ooo`0306Kooooooooo00goool306KoH_ooo`030000oooooooo067oool306Ko3_ooo`0306Ko
oooooooo01Woool001[oool00`1Vooooooooo`0@oooo0P1Vof3oool20000Goooo`<0I_lAoooo00<0
I_ooooooool06Oooo`006_ooo`0306Kooooooooo01;oool206KoG_ooo`030000oooooooo05coool2
06Ko5?ooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`0Doooo0P1Voecoool00`000?oo
ooooo`1Ioooo0`1VoaKoool00`1Vooooooooo`0Ioooo000Joooo00<0I_ooooooool05_ooo`<0I_mI
oooo00<0003oooooool0E_ooo`<0I_lIoooo00<0I_ooooooool06Oooo`006_ooo`0306Kooooooooo
01Woool406KoEOooo`80001Doooo0`1Voacoool00`1Vooooooooo`0Ioooo000Joooo00<0I_oooooo
ool07Oooo`@0I_mAoooo00<0003oooooool0D?ooo`<0I_lOoooo00<0I_ooooooool06Oooo`006_oo
o`0306Kooooooooo027oool306KoC_ooo`030000oooooooo04goool306Ko8_ooo`0306Kooooooooo
01Woool001[oool00`1Vooooooooo`0Toooo0`1Vod_oool00`000?ooooooo`1:oooo0`1VobGoool0
0`1Vooooooooo`0Ioooo000Joooo00<0I_ooooooool09oooo`<0I_m8oooo0P0004Ooool406Ko:?oo
o`0306Kooooooooo01Woool001[oool00`1Vooooooooo`0Zoooo0`1VodGoool00`000?ooooooo`13
oooo0`1Vobcoool00`1Vooooooooo`0Ioooo000Joooo00<0I_ooooooool0;Oooo`@0I_lXoooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0ooooo101Vobooool00`1Voooo
ooooo`0Ioooo000Joooo00<0I_ooooooool0<Oooo`@0I_lSoooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo03_oool406Ko<oooo`0306Ko
oooooooo01Woool001[oool00`1Vooooooooo`0eoooo101Voaooool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000goooo101VocOoool00`1Vooooooooo`0I
oooo000Joooo00<0I_ooooooool0>Oooo`D0I_lDoooo100000;oool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0boooo1@1Voc_oool00`1Vooooooooo`0I
oooo000Joooo00<0I_ooooooool0?_ooo`D0I_lEoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02goool506Ko@?ooo`0306Kooooooooo
01Woool001[oool00`1Vooooooooo`13oooo1@1Voa7oool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0Xoooo1@1VodGoool00`1Vooooooooo`0Ioooo000Joooo00<0I_ooooooool0B?oo
o`D0I_lUoooo0P0002Coool506KoB_ooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`1=
oooo1@1Vob3oool00`000?ooooooo`0Ooooo101Vodooool00`1Vooooooooo`0Ioooo000Joooo00<0
I_ooooooool0D_ooo`D0I_lKoooo00<0003oooooool06_ooo`D0I_mCoooo00<0I_ooooooool06Ooo
o`006_ooo`0306Kooooooooo05Ooool506Ko5_ooo`030000oooooooo01Goool506KoF?ooo`0306Ko
oooooooo01Woool001Soool2000000<0I_ooooooool08_ooo`@0000Uoooo1@0000coool706Ko3ooo
o`80000>oooo201Vo`koool500008oooo`@0000Soooo00<0I_ooooooool00P0001Ooool001Ooool0
10000?ooooooo`0002Coool00`000?ooooooo`0Xoooo00<0003oooooool04oooo`P0I_l7oooo00<0
003oooooool01Oooo`P0I_lHoooo00<0003oooooool08oooo`030000oooooooo02Coool00`1Voooo
o`000002oooo00<0003oooooool05?ooo`006Oooo`03000006Kooooo02Coool00`000?ooooooo`0W
oooo00<0003oooooool06oooo`L0I_l00`00001Vo`1Vo`0506Ko8?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Soooo00D0I_ooooooooooool000005oooo`004Oooo`@00005oooo00<0003ooooo
ool07?ooo`@00004oooo00<0003oooooool07_ooo`@00004oooo00<0003oooooool08_ooo`030000
oooooooo02Goool00`000?ooooooo`0Uoooo00<0003oooooool08_ooo`0306Kooooooooo00;oool0
0`000?ooooooo`0Doooo000Goooo00@0003oooooool0000Toooo00@0003oooooool0000Woooo00<0
003oooooool08_ooo`80000Voooo00<0003oooooool08oooo`040000oooooooo00008oooo`0306Ko
oooo000000;oool00`000?ooooooo`0Doooo000Hoooo0P00000306Kooooooooo02?oool200009ooo
o`80000Toooo00<0003oooooool09?ooo`80000Voooo0P0002Coool00`1Vooooooooo`0200005ooo
o`006_ooo`0306Kooooooooo07;oool00`000?ooooooo`1boooo00<0I_ooooooool06Oooo`006_oo
o`0306Kooooooooo07;oool20000Loooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`1b
oooo00<0003oooooool0L_ooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`1boooo00<0
003oooooool0L_ooo`0306Kooooooooo01Woool001[oool00`1Vooooooooo`1boooo00<0003ooooo
ool0L_ooo`0306Kooooooooo01Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000oooooooo02;oool01Ol0VOoooooooooo
o`00000Goooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Looo
o`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Sooo
o`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2I
oooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1b
oooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?
oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo
01Woool008ooool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo
07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool0
08ooool20000Loooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Wooooo
ool06Oooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0L_oo
o`03o`2Ioooooooo01Woool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool007Goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001boooo00?o09Wooooo
ool06Oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo07;oool00ol0VOooooooo`0Ioooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo001f
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool0
08ooool20000Loooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Wooooo
ool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003ooooo
ool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo01Woool008ooool0
0`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOoo
ooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Looo
o`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Sooo
o`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2I
oooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1b
oooo00?o09Woooooool06Oooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
07;oool00ol0VOooooooo`0Ioooo001koooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool007_oool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0007;oool00ol0VOooooooo`0Ioooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Soooo`80001c
oooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?
oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo
01Woool008ooool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo
07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool0
08ooool20000Loooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Wooooo
ool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo00<0003ooooo
ool0L_ooo`03o`2Ioooooooo01Woool008ooool20000Loooo`03o`2Ioooooooo01Woool008ooool0
0`000?ooooooo`1boooo00?o09Woooooool06Oooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0L_ooo`03o`2Ioooooooo01Woool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`<0001boooo00?o09Woooooool06Oooo`00MOooo`040000oooooooo
00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1boooo00?o09Woooooool06Ooo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1boooo00?o09Woooooool06Oooo`00M_ooo`800009oooo100000?oool300001?oo
o`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo0P0007?oool00ol0VOooooooo`0I
oooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1b
oooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?
oooo0P0007?oool00ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo
01Woool008ooool00`000?ooooooo`1boooo00?o09Woooooool06Oooo`00Soooo`030000oooooooo
07;oool00ol0VOooooooo`0Ioooo002?oooo0P0007?oool00ol0VOooooooo`0Ioooo002?oooo00<0
003oooooool0L_ooo`03o`2Ioooooooo01Woool008ooool00`000?ooooooo`1boooo00?o09Wooooo
ool06Oooo`00Soooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo002?oooo0P0007?oool0
0ol0VOooooooo`0Ioooo002?oooo00<0003oooooool0L_ooo`03o`2Ioooooooo01Woool008Ooool5
00000oooo`030000oooooooo07;oool00ol0VOooooooo`0Ioooo0029oooo00<0003oooooool00ooo
o`030000oooooooo07;oool00ol0VOooooooo`0Ioooo0029oooo00<0003oooooool00oooo`<0001b
oooo00?o09Woooooool06Oooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2D
oooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0003oooooool02?ooo`<00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000?oooo00<0003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.56474, \
-1.05744, 0.0248468, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.56474, -1.05744, 0.0248468, 0.0127628}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{123, Automatic}, {Automatic, 16}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 217, 6, 96, "Title"],
Cell[1947, 60, 1021, 26, 258, "Text"],
Cell[2971, 88, 120, 4, 49, "Text"],
Cell[3094, 94, 344, 6, 19, "Input",
  CellOpen->False],
Cell[3441, 102, 185, 5, 68, "Text"],
Cell[3629, 109, 91, 1, 30, "Input"],
Cell[3723, 112, 108, 1, 49, "Text"],
Cell[3834, 115, 404, 10, 19, "Input",
  CellOpen->False],
Cell[4241, 127, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4318, 131, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4396, 135, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[4794, 151, 653, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[5472, 166, 24009, 999, 186, 13090, 860, "GraphicsData", "PostScript", \
"Graphics"],
Cell[29484, 1167, 24085, 999, 186, 13077, 859, "GraphicsData", "PostScript", \
"Graphics"],
Cell[53572, 2168, 24017, 1000, 186, 13106, 861, "GraphicsData", "PostScript", \
"Graphics"],
Cell[77592, 3170, 24108, 1000, 186, 13092, 860, "GraphicsData", "PostScript", \
"Graphics"],
Cell[101703, 4172, 24040, 1001, 186, 13121, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[125746, 5175, 24133, 1002, 186, 13125, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[149882, 6179, 24027, 1001, 186, 13120, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[173912, 7182, 24129, 1002, 186, 13125, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[198044, 8186, 24063, 1003, 186, 13152, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[222110, 9191, 24130, 1003, 186, 13138, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[246243, 10196, 24028, 1002, 186, 13137, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[270274, 11200, 24156, 1003, 186, 13140, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[294433, 12205, 24066, 1003, 186, 13155, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[318502, 13210, 24172, 1004, 186, 13156, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[342677, 14216, 24053, 1002, 186, 13138, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[366733, 15220, 24160, 1004, 186, 13156, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[390896, 16226, 24045, 1002, 186, 13138, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[414944, 17230, 24157, 1004, 186, 13157, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[439104, 18236, 23918, 1000, 186, 13137, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[463025, 19238, 24145, 1004, 186, 13157, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[487173, 20244, 24082, 1004, 186, 13171, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[511258, 21250, 24165, 1003, 186, 13141, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[535426, 22255, 24073, 1003, 186, 13154, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[559502, 23260, 24197, 1005, 186, 13173, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[583702, 24267, 24082, 1003, 186, 13155, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[607787, 25272, 24192, 1005, 186, 13172, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[631982, 26279, 24106, 1005, 186, 13187, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[656091, 27286, 24221, 1007, 186, 13205, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[680315, 28295, 24093, 1004, 186, 13170, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[704411, 29301, 24209, 1007, 186, 13205, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[728623, 30310, 24090, 1005, 186, 13187, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[752716, 31317, 24213, 1006, 186, 13189, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[776932, 32325, 24108, 1005, 186, 13185, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[801043, 33332, 24247, 1009, 186, 13218, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[825293, 34343, 24129, 1006, 186, 13202, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[849425, 35351, 24237, 1008, 186, 13221, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[873665, 36361, 24138, 1007, 186, 13219, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[897806, 37370, 24233, 1008, 186, 13221, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[922042, 38380, 27194, 1102, 186, 15443, 953, "GraphicsData", \
"PostScript", "Graphics"],
Cell[949239, 39484, 23859, 995, 186, 12859, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[973101, 40481, 23764, 994, 186, 12857, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[996868, 41477, 23847, 994, 186, 12843, 854, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1020718, 42473, 23772, 994, 186, 12857, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1044493, 43469, 23931, 997, 186, 12874, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1068427, 44468, 23742, 995, 186, 12871, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1092172, 45465, 23656, 993, 186, 12858, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1115831, 46460, 23492, 990, 186, 12840, 854, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1139326, 47452, 23671, 993, 186, 12857, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1163000, 48447, 23653, 993, 186, 12872, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1186656, 49442, 23688, 995, 186, 12890, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1210347, 50439, 23572, 993, 186, 12888, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1233922, 51434, 23639, 994, 186, 12890, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1257564, 52430, 23548, 994, 186, 12904, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1281115, 53426, 23651, 995, 186, 12906, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1304769, 54423, 23435, 992, 186, 12888, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1328207, 55417, 23453, 993, 186, 12906, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1351663, 56412, 22890, 986, 186, 12902, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1374556, 57400, 22429, 980, 186, 12903, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1396988, 58382, 21993, 974, 186, 12884, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1418984, 59358, 23294, 1012, 186, 13318, 884, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1442281, 60372, 24600, 1030, 186, 13357, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1466884, 61404, 25810, 1044, 186, 13344, 886, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1492697, 62450, 25789, 1044, 186, 13347, 886, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1518489, 63496, 25995, 1049, 186, 13399, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1544487, 64547, 25906, 1048, 186, 13395, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1570396, 65597, 26003, 1048, 186, 13379, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1596402, 66647, 25944, 1050, 186, 13429, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1622349, 67699, 26093, 1053, 186, 13440, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1648445, 68754, 26001, 1047, 186, 13361, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1674449, 69803, 26162, 1054, 186, 13461, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1700614, 70859, 25990, 1049, 186, 13394, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1726607, 71910, 26170, 1053, 186, 13445, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1752780, 72965, 26159, 1053, 186, 13425, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1778942, 74020, 26477, 1065, 186, 13606, 902, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1805422, 75087, 26220, 1055, 186, 13454, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1831645, 76144, 26223, 1053, 186, 13408, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1857871, 77199, 26112, 1055, 186, 13492, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1883986, 78256, 26164, 1057, 186, 13507, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1910153, 79315, 25953, 1052, 186, 13454, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1936109, 80369, 26318, 1056, 186, 13463, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1962430, 81427, 26262, 1055, 186, 13456, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1988695, 82484, 26418, 1057, 186, 13445, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2015116, 83543, 26339, 1056, 186, 13439, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2041458, 84601, 26436, 1056, 186, 13427, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2067897, 85659, 26425, 1060, 186, 13505, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2094325, 86721, 26512, 1060, 186, 13487, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2120840, 87783, 26385, 1058, 186, 13477, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2147228, 88843, 26502, 1059, 186, 13477, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2173733, 89904, 26440, 1059, 186, 13488, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2200176, 90965, 26533, 1059, 186, 13459, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2226712, 92026, 26439, 1058, 186, 13471, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2253154, 93086, 26600, 1063, 186, 13518, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2279757, 94151, 26485, 1061, 186, 13508, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2306245, 95214, 26690, 1067, 186, 13584, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2332938, 96283, 26440, 1058, 186, 13455, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2359381, 97343, 26522, 1059, 186, 13477, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2385906, 98404, 26313, 1059, 186, 13519, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2412222, 99465, 26298, 1057, 186, 13475, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2438523, 100524, 26259, 1060, 186, 13546, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2464785, 101586, 26512, 1059, 186, 13479, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2491300, 102647, 26549, 1062, 186, 13520, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2517852, 103711, 26649, 1061, 186, 13478, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2544504, 104774, 26549, 1061, 186, 13487, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2571056, 105837, 26763, 1066, 186, 13552, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2597822, 106905, 26671, 1066, 186, 13569, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2624496, 107973, 26724, 1064, 186, 13517, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2651223, 109039, 26597, 1062, 186, 13503, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2677823, 110103, 26733, 1065, 186, 13530, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2704559, 111170, 26680, 1066, 186, 13545, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2731242, 112238, 26806, 1069, 186, 13586, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2758051, 113309, 26728, 1068, 186, 13581, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2784782, 114379, 26830, 1068, 186, 13570, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2811615, 115449, 26670, 1064, 186, 13515, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2838288, 116515, 26791, 1067, 186, 13547, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2865082, 117584, 26704, 1067, 186, 13565, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2891789, 118653, 26725, 1065, 186, 13526, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2918517, 119720, 26555, 1063, 186, 13534, 898, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

