(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2383473,      94317]*)
(*NotebookOutlinePosition[   2384217,      94342]*)
(*  CellTagsIndexPosition[   2384173,      94338]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING BEHIND A POSITIVE DELTA-FUNCTION \
NONHOMOGENEITY", "Text",
  CellFrame->True,
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  v[x]  ",
    FontSize->12],
  StyleBox["is a delta-function of strength  c0, positive or negative, \
located at  x=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  The potential has one bound state if  c0<0  and no bound states \
if  c0>0.\n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" >0, is behind the nonhomogeneity and needs to be specified. ",
    FontSize->12],
  StyleBox["\n\nThe transmission coefficient, left reflection coefficient, \
and right reflection coefficient, respectively, are denoted by  T[k],  L[k],  \
R[k].\n\nThe tail of the wave is denoted by  g[x,t].\n\nThe focusing moment \
is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, c0, x0, g];\)\), "\[IndentingNewLine]", 
    \(\(v[x_] = \ c0\ \ DiracDelta[x]\ ;\)\), "\n", 
    \(\(T[k_] = k/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(L[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(R[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the strength of the potential, c0, a positive number;
also specify the focusing location  x0, a positive number, next:\
\>", "Text",\

  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(c0 = 1\)\(;\)\(\ \ \)\(x0 = 1\)\(;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\n\)\(g[x_, 
          t_] = \ \(-\ \((c0/2)\)\)\ UnitStep[
              x]\ \ UnitStep[\(-x\) - x0 + 
                t]\ E^\((c0 \((x + x0 - t)\)/2)\) + \((c0/2)\) 
            UnitStep[\(-x\)]\ \((UnitStep[\(-x\) + x0 + t]\  - \ 
                UnitStep[\(-x\) - x0 + t]\  - \ UnitStep[x + x0 + t] + \ 
                UnitStep[x - x0 + t] - \ 
                UnitStep[
                    x - x0 + 
                      t]\ E^\((c0 \((\(-x\) + x0 - t)\)/
                          2)\))\);\)\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-4\), \ 
              4}, \ PlotRange -> {\(-1\), 1}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-4\), \ 4}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-4\), \ 4}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 1}]}, \[IndentingNewLine]\ {t, \ \(-2\), \ 
          2.9, 0.05}, PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.37114 .30902 L
.37372 .30902 L
.37649 .30902 L
.37783 .30902 L
.3791 .30902 L
.38025 .30902 L
s
.38025 .30902 m
.38037 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13506 .30902 L
.13942 .30902 L
.14061 .30902 L
.14188 .30902 L
.14296 .46353 L
.14415 .46353 L
.18444 .46353 L
.22321 .46353 L
.26444 .46353 L
.30414 .46353 L
.34234 .46353 L
.36201 .46353 L
.36767 .46353 L
.37301 .46353 L
.3778 .46353 L
.37911 .46353 L
.37983 .46353 L
.3805 .46353 L
.38168 .30902 L
.38298 .30902 L
.42189 .30902 L
.46325 .30902 L
.5031 .30902 L
.54143 .30902 L
.58221 .30902 L
.62148 .30902 L
.65923 .30902 L
.69943 .30902 L
.73812 .30902 L
.77926 .30902 L
.81888 .30902 L
.85699 .30902 L
.89755 .30902 L
.9366 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Koooo00<0I_ooooooool07?ooo`030000oooooooo01_oool00`1Vooooooooo`0K
oooo00<0003oooooool0>Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000doooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000doooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01_oool20000Soooo`00=?ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Koooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0K
oooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0
003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo0P0008ooool0
03Coool00`1Vooooooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool0
0`1Vooooooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Voooo
ooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0j
oooo00<0I_ooooooool06oooo`80002?oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo
01_oool00`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool0
0`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?oo
ooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool20000Soooo`00=?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0003oooooool0S_ooo`00=?ooo`0306Ko
oooooooo03[oool00`1Vooooooooo`02oooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0506Kooooooooooooo000000;oool0
0`000?ooooooo`06oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
08koool003Coool00`1Vooooooooo`0joooo00D0I_ooooooooooool000000_ooo`030000oooooooo
00Ooool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo000doooo00<0I_oooooo
ool0>_ooo`0506Kooooooooooooo000000;oool00`000?ooooooo`08oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool01@1Voooooooooooo
o`000002oooo00<0003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo00;oool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo01_oool20000Soooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0
003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0003ooooo
ool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0003oooooool0S_oo
o`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo0P0008ooool003Coool00`1Voooo
ooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0j
oooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0joooo00<0
I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0joooo00<0I_oooooo
ool06oooo`80002?oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?oo
ooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>
oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000d
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool20000Soooo`00=?ooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Koooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool0
0`1Vooooooooo`08oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00=?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`07oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00=?oooch0I_l9oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0002>oooo001aoooo00?o09Woooooool01oooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo00Ooool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo00Soool2
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Sooo
o`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06ooo
o`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOoo
ooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0K
oooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo00;oool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool0S_ooo`00LOooo`05o`2Ioooooooooooo000000;oool0
0`000?ooooooo`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo001aoooo00Go09Woooooooooool000000_ooo`030000oooooooo00Soool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001aoooo00Go09Woooooooooool000000_oo
o`030000oooooooo00Woool010000?ooooooooooo`800005oooo00<0003oooooool0S_ooo`00LOoo
o`05o`2Ioooooooooooo000000;oool00`000?ooooooo`06oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo08koool0077oool00ol0VOooooooo`02oooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Sooo
o`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06ooo
o`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0K
oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo
01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool04oooo`D00003oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`03oooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`03oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?oo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0
003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003ooooo
ool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool400000ooo
o`030000oooooooo07koool007koool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`030000oooooooo00Coool00`000?ooooooo`1noooo001m
oooo00<0003oooooool00_ooo`030000oooooooo01Coool00`000?ooooooo`04oooo00<0003ooooo
ool0OOooo`00O_ooo`030000oooooooo00D0000Doooo00<0003oooooool00_ooo`030000oooooooo
07koool007koool01@000?ooooooooooo`00000Eoooo00@0003oooooool00003oooo00<0003ooooo
ool0O_ooo`00Ooooo`030000oooooooo01Ooool200000oooo`030000oooooooo07ooool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-8.05779, 1.32095, 0.0331906, 0.0127866}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-8.05779, 1.32095, 0.0331906, 0.0127866}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.38508 .30902 L
.3864 .30902 L
s
.3864 .30902 m
.38653 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14635 .30902 L
.14756 .30902 L
.14868 .30902 L
.1499 .46353 L
.15055 .46353 L
.15124 .46353 L
.1536 .46353 L
.16254 .46353 L
.18221 .46353 L
.22343 .46353 L
.26314 .46353 L
.30133 .46353 L
.34198 .46353 L
.36078 .46353 L
.37066 .46353 L
.38111 .46353 L
.38367 .46353 L
.38509 .46353 L
.38578 .46353 L
.38643 .46353 L
.38718 .30902 L
.388 .30902 L
.38944 .30902 L
.39226 .30902 L
.40252 .30902 L
.42269 .30902 L
.46196 .30902 L
.49971 .30902 L
.53991 .30902 L
.5786 .30902 L
.61974 .30902 L
.65936 .30902 L
.69747 .30902 L
.73803 .30902 L
.77708 .30902 L
.81858 .30902 L
.85856 .30902 L
.89702 .30902 L
.93794 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
o`1Vo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
0000I_ooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Moooo00<0I_ooooooool06_ooo`030000oooooooo01coool00`1Vooooooooo`0J
oooo00<0003oooooool0>Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000foooo00<0
I_ooooooool0>Oooo`0306Kooooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01[oool20000Soooo`00=_ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0J
oooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0
003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo0P0008ooool0
03Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool0
0`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool00`1Voooo
ooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool00`1Vooooooooo`0i
oooo00<0I_ooooooool06_ooo`80002?oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01[oool00`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool0
0`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool00`000?oo
ooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool20000Soooo`00=_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Ko
oooooooo03Woool0101Vooooooooooooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool0101Vooooooooo`0000;oool00`000?oo
ooooo`06oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo08koool0
03Koool00`1Vooooooooo`0ioooo00@0I_ooooooool00002oooo00<0003oooooool01oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0008koool003Koool00`1Vooooooooo`0ioooo00@0
I_ooooooool00002oooo00<0003oooooool02?ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool003Koool00`1Vooooooooo`0ioooo00@0I_ooooooool00002oooo00<0003ooooo
ool01_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000f
oooo00<0I_ooooooool0>Oooo`0406Kooooooooooooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo0P0008ooool0
03Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool0
0`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool00`1Voooo
ooooo`0ioooo00<0I_ooooooool06_ooo`030000oooooooo08koool003Koool00`1Vooooooooo`0i
oooo00<0I_ooooooool06_ooo`80002?oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01[oool00`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool0
0`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool00`000?oo
ooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool20000Soooo`00=_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Joooo0P0008ooool003Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_oo
o`030000oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0I_ooooooool01oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0
I_ooooooool01_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
08koool003Kooolm06Ko2?ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000S_oo
o`00L_ooo`03o`2Ioooooooo00Koool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
08koool007;oool00ol0VOooooooo`06oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`07oooo0P0000[oool300001?ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o
09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
1?l0VOooooooooooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`2>oooo001boooo00Co09Woooooool00002oooo00<0003oooooool02?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_ooo`00L_ooo`04o`2Ioooooooo
00000_ooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>
oooo001boooo00Co09Woooooool00002oooo00<0003oooooool02Oooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`2>oooo001boooo00Co09Woooooool00002oooo00<0003oooooool01_oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001boooo00Co
09Woooooooooool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Boooo1@0000?oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool05?ooo`030000oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`D00002oooo0P0000?oool300001?ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`08
oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo
00D0000Doooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0G
oooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.3864 .30902 L
.38881 .30902 L
.39106 .30902 L
.3923 .30902 L
s
.3923 .30902 m
.39237 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.15107 .30902 L
.15238 .30902 L
.1536 .30902 L
.15467 .30902 L
.15581 .46353 L
.15709 .46353 L
.15825 .46353 L
.16254 .46353 L
.18221 .46353 L
.22192 .46353 L
.26011 .46353 L
.30075 .46353 L
.33988 .46353 L
.35986 .46353 L
.37037 .46353 L
.38147 .46353 L
.38627 .46353 L
.38891 .46353 L
.39141 .46353 L
.3921 .46353 L
.39283 .46353 L
.39363 .30902 L
.39437 .30902 L
.39706 .30902 L
.40233 .30902 L
.42153 .30902 L
.45928 .30902 L
.49949 .30902 L
.53817 .30902 L
.57931 .30902 L
.61894 .30902 L
.65705 .30902 L
.69761 .30902 L
.73665 .30902 L
.77815 .30902 L
.81813 .30902 L
.8566 .30902 L
.89752 .30902 L
.93692 .30902 L
.97481 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool010000?oo
ooooo`1Vo`coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
10000?ooooooo`1Vo`_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool07_ooo`0306Kooooooooo01Woool00`000?ooooooo`0Noooo00<0I_oooooo
ool06?ooo`030000oooooooo03Woool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00=ooo
o`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0Hoooo0P0008ooool003Ooool00`1Vooooooooo`0joooo00<0
I_ooooooool06?ooo`030000oooooooo08koool003Ooool00`1Vooooooooo`0joooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool003Ooool00`1Vooooooooo`0joooo00<0I_ooooooool06?oo
o`030000oooooooo08koool003Ooool00`1Vooooooooo`0joooo00<0I_ooooooool06?ooo`80002?
oooo000goooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000g
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000goooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000goooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01Soool20000Soooo`00=oooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0H
oooo00<0003oooooool0S_ooo`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0
003oooooool0S_ooo`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo0P0008ooool0
03Ooool00`1Vooooooooo`0joooo00<0I_ooooooool06?ooo`030000oooooooo08koool003Ooool0
0`1Vooooooooo`0joooo00@0I_ooool000000004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0S_ooo`00=oooo`0306Kooooooooo03[oool01@1Vo`000?ooooooo`000008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo08koool003Ooool00`1Voooo
ooooo`0joooo00D0I_l0003oooooool000002Oooo`030000oooooooo00Goool00`000?ooooooo`02
oooo0`0008koool003Soool00`1Vooooooooo`0ioooo00D0I_l0003oooooool000002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00D0
I_l0003oooooool000002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo000hoooo00<0I_ooooooool0>Oooo`0406Kooooo000000002_ooo`800004oooo0`00
00Coool00`000?ooooooo`2>oooo000hoooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Soool2
0000Soooo`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Hoooo00<0003oooooool0S_oo
o`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00>?oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00>?ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Hoooo0P0008ooool003Soool00`1Vooooooooo`0ioooo00<0
I_ooooooool06?ooo`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_ooooooool06?oo
o`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_ooooooool06?ooo`80002?
oooo000hoooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000h
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0
I_ooooooool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01Soool20000Soooo`00>?ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Hoooo00<0003oooooool0S_ooo`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`05
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00>?ooo`0306Kooooooooo
03Woool00`1Vooooooooo`04oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00>?ooocd0I_l6oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0002>oooo001doooo00?o09Woooooool01?ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo00Goool200002_ooo`<00004
oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_oo
o`00M?ooo`04o`2Ioooo000000001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00M?ooo`05o`2I0000oooooooo000000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo08koool007Coool01Ol0V@000?ooooooo`00000:
oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000S_ooo`00M?ooo`05o`2I0000oooo
oooo000000_oool010000?ooooooooooo`800005oooo00<0003oooooool0S_ooo`00M?ooo`05o`2I
0000oooooooo000000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00M?ooo`04o`2Ioooo000000002Oooo`@00003oooo0`0000Coool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Wooooo
ool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0@oooo1@0000?oool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool04_ooo`030000oooooooo00?oool30000S_ooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400001Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02?ooo`<00004
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000G
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.39106 .30902 L
.39381 .30902 L
.39642 .30902 L
.39756 .30902 L
.39877 .30902 L
s
.39877 .30902 m
.39884 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.1536 .30902 L
.15586 .30902 L
.15825 .30902 L
.15923 .30902 L
.16029 .30902 L
.16145 .46353 L
.16254 .46353 L
.18221 .46353 L
.22343 .46353 L
.26314 .46353 L
.30133 .46353 L
.34198 .46353 L
.36078 .46353 L
.38111 .46353 L
.38653 .46353 L
.39226 .46353 L
.39462 .46353 L
.39715 .46353 L
.3979 .46353 L
.3986 .46353 L
.39924 .30902 L
.39993 .30902 L
.40252 .30902 L
.42269 .30902 L
.46347 .30902 L
.50274 .30902 L
.54049 .30902 L
.58069 .30902 L
.61938 .30902 L
.66052 .30902 L
.70014 .30902 L
.73825 .30902 L
.77881 .30902 L
.81786 .30902 L
.85936 .30902 L
.89934 .30902 L
.93781 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`02oooo00<0I_ooooooool02?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`050000oooooooooooo06Ko00[oool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool08?ooo`0306Kooooooooo01Ooool00`000?oo
ooooo`0Ooooo00<0I_ooooooool05oooo`030000oooooooo03Woool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003ooooo
ool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo0P0008ooool003Woool0
0`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool003Woool00`1Voooo
ooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool003Woool00`1Vooooooooo`0i
oooo00<0I_ooooooool05oooo`030000oooooooo08koool003Woool00`1Vooooooooo`0ioooo00<0
I_ooooooool05oooo`80002?oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool00`000?oo
ooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool00`000?ooooooo`2>
oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool20000Soooo`00>Oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Goooo0P0008ooool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000
oooooooo08koool003Woool00`1Vooooooooo`0ioooo00<0I_l0000000001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo08koool003Woool00`1Vooooooooo`0ioooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo08koool0
03Woool00`1Vooooooooo`0ioooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000S_ooo`00>Oooo`0306Kooooooooo03Woool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Ko0000000000[oool200001?ooo`<00004
oooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo0P00
08ooool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool0
03Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool003Woool0
0`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool003Woool00`1Voooo
ooooo`0ioooo00<0I_ooooooool05oooo`80002?oooo000ioooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool20000Sooo
o`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Ooo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Goooo0P0008ooool003Woool00`1Vooooooooo`0ioooo00<0I_oooooo
ool05oooo`030000oooooooo08koool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool01?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo08koool003Woool00`1Vooooooooo`0i
oooo00<0I_ooooooool00oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo08koool003Wooolm06Ko1Oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000S_ooo`00MOooo`03o`2Ioooooooo00?oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo08koool007Goool00ol0VOooooooo`03oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool007Goool00ol0VOooooooo`04oooo0P0000[oool300001?oo
o`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`80002?oooo001eoooo00?o09Woooooool05oooo`030000
oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`80002?oooo001e
oooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0
003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool05oooo`80002?oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool0
07Goool00ol0V@0000000004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`2>oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`2>oooo001eoooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007Goool00ol0V@00
00000009oooo100000?oool300001?ooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0
003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P0008ooool0
07Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool0
0ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo00ooool500000oooo`030000oooooooo08koool007Goool00ol0VOoo
ooooo`0Aoooo00<0003oooooool00oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0A
oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000
oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003ooooo
ool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Ooo
o`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<
oooo1@0000;oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool0
0`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01ooo
o`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0
003oooooool01@0001Coool00`000?ooooooo`08oooo0P0000Coool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05ooo
o`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.39675 .30902 L
.40134 .30902 L
.40252 .30902 L
.40381 .30902 L
s
.40381 .30902 m
.40393 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.15825 .30902 L
.16254 .30902 L
.16494 .30902 L
.16615 .30902 L
.16683 .46353 L
.16748 .46353 L
.17284 .46353 L
.18221 .46353 L
.22098 .46353 L
.2622 .46353 L
.30191 .46353 L
.34011 .46353 L
.36142 .46353 L
.38075 .46353 L
.39043 .46353 L
.39552 .46353 L
.3983 .46353 L
.4009 .46353 L
.40317 .46353 L
.40445 .46353 L
.40561 .30902 L
.40688 .30902 L
.40827 .30902 L
.41079 .30902 L
.41988 .30902 L
.46066 .30902 L
.49993 .30902 L
.53768 .30902 L
.57788 .30902 L
.61657 .30902 L
.65771 .30902 L
.69733 .30902 L
.73544 .30902 L
.776 .30902 L
.81505 .30902 L
.85655 .30902 L
.89653 .30902 L
.935 .30902 L
.97591 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`03oooo00<0I_ooooooool01oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo027oool00`1Vooooooooo`0F
oooo00<0003oooooool08Oooo`0306Kooooooooo01Goool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Ooo
o`030000oooooooo08koool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`80002?
oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?ooooooo`2>oooo000j
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?ooooooo`2>oooo000joooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?ooooooo`2>oooo000joooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01Goool20000Soooo`00>_ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0E
oooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Eoooo00<0
003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Eoooo0P0008ooool0
03[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool0
0`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Voooo
ooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0j
oooo00<0I_ooooooool05Oooo`80002?oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo
01Goool00`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>Oooo`800004oooo0P0000?oool4
00000oooo`800005oooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03Soool010000?oo
o`1Vo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_oo
o`00>_ooo`0306Kooooooooo03Soool010000?ooo`1Vo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<0002>oooo000joooo00<0I_ooooooool0>?ooo`040000oooo06Ko00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0h
oooo00@0003oool0I_l00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo08koool003[oool00`1Vooooooooo`0ioooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Eoooo0P0008ooool0
03[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool0
0`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Voooo
ooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0j
oooo00<0I_ooooooool05Oooo`80002?oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo
01Goool00`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?oo
ooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool20000Soooo`00>_oo
o`0306Kooooooooo03[oool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool0
0`1Vooooooooo`0Eoooo0P0008ooool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Ooo
o`030000oooooooo08koool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool00_ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0joooo00D0
I_ooooooooooool000000_ooo`030000oooooooo00Koool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo000joooo?P1Vo`?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Ooool01Ol0VOooooooooooo`000002oooo00<0003oooooool01oooo`800005oooo00<0
003oooooool0S_ooo`00Moooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`07oooo00<0
003oooooool01?ooo`030000oooooooo08koool007Ooool00ol0VOooooooo`02oooo0P0000[oool3
00001?ooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo0P0008ooool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?
oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0E
oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001g
oooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Oooo`030000oooooooo
08koool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0S_ooo`00MOooo`040000ooooo`2I00002_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool0S_ooo`00MOooo`040000ooooo`2I00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0008koool007Goool010000?ooool0V@0000_oool010000?oo
ooooooooo`800005oooo00<0003oooooool0S_ooo`00MOooo`040000ooooo`2I00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Sooo
o`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>
oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0E
oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2I
oooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo
08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo
01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool03Oooo`D00003oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`03oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?oo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_oo
o`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Soool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.40134 .30902 L
.40616 .30902 L
.40755 .30902 L
.40887 .30902 L
.41005 .30902 L
s
.41005 .30902 m
.41018 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.16254 .30902 L
.16748 .30902 L
.16883 .30902 L
.17026 .30902 L
.17149 .30902 L
.17219 .30902 L
.17284 .46353 L
.17405 .46353 L
.1752 .46353 L
.17735 .46353 L
.18221 .46353 L
.2204 .46353 L
.26105 .46353 L
.30018 .46353 L
.34176 .46353 L
.36263 .46353 L
.38182 .46353 L
.40057 .46353 L
.40513 .46353 L
.40764 .46353 L
.40887 .46353 L
.41001 .46353 L
.41066 .46353 L
.41135 .30902 L
.41205 .30902 L
.41282 .30902 L
.41537 .30902 L
.42038 .30902 L
.46058 .30902 L
.49927 .30902 L
.54041 .30902 L
.58003 .30902 L
.61814 .30902 L
.6587 .30902 L
.69774 .30902 L
.73924 .30902 L
.77922 .30902 L
.81769 .30902 L
.85861 .30902 L
.89801 .30902 L
.9359 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`05oooo00<0I_ooooooool01Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Coool00`1Vooooooooo`05oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02?oool00`1Vooooooooo`0D
oooo00<0003oooooool08_ooo`0306Kooooooooo01Coool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool003coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?oo
o`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`80002?
oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo000l
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo000loooo00<0
I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo000loooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01Coool20000Soooo`00??ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0D
oooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Doooo00<0
003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Doooo0P0008ooool0
03coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool0
0`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Voooo
ooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0i
oooo00<0I_ooooooool05?ooo`80002?oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01Coool00`000?ooooooo`2>oooo000loooo00<0I_ooooooool0=oooo`800000101Voooooooooooo
o`800003oooo100000?oool200001Oooo`030000oooooooo08koool003coool00`1Vooooooooo`0f
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000
oooooooo08koool003coool00`1Vooooooooo`0foooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool30000S_ooo`00??ooo`0306Kooooooooo03Koool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo000loooo00<0
I_ooooooool0=_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000loooo00<0I_ooooooool0=oooo`8000000`1Vooooooooo`07
oooo0P0000Coool300001?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0
I_ooooooool05?ooo`80002?oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool0
0`000?ooooooo`2>oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>
oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool20000Soooo`00??ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Doooo0P0008ooool003coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000
oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo
08koool003coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool0
03coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`80002?oooo000loooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo000loooo00<0I_ooooooool0>Ooo
o`0406Kooooooooooooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00??oo
o`0306Kooooooooo03Woool0101Vooooooooo`0000;oool00`000?ooooooo`06oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00??ooocd0I_l2oooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0002>oooo001hoooo00Co09Woooooool00002oooo00<0003oooooool01ooo
o`800005oooo00<0003oooooool0S_ooo`00N?ooo`04o`2Ioooooooo00000_ooo`030000oooooooo
00Ooool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00N?ooo`04o`2Ioooooooooooo0P00
00[oool300001?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool0
07Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool0
0`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Koool2000000Co09Woooooooooool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00M_ooo`8000000ol0VOooooooo`06oooo100000?oool300001?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool0
0ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?oo
o`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0D
oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo00coool500000oooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0>oooo00<0003oooooool00oooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0>oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo1@0000;oool200001Oooo`030000oooooooo00;oool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool01@000?ooooooooooo`000002
oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003ooooo
ool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`040000oooooooo
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005oooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Ooool200002Oooo`@00003oooo0`0000;oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.40616 .30902 L
.41134 .30902 L
.41287 .30902 L
.41432 .30902 L
.41562 .30902 L
.41635 .30902 L
s
.41635 .30902 m
.41642 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.16254 .30902 L
.16783 .30902 L
.17284 .30902 L
.17502 .30902 L
.17733 .30902 L
.17854 .30902 L
.17922 .46353 L
.17987 .46353 L
.18221 .46353 L
.22098 .46353 L
.2622 .46353 L
.30191 .46353 L
.34011 .46353 L
.36142 .46353 L
.38075 .46353 L
.39043 .46353 L
.4009 .46353 L
.40571 .46353 L
.41079 .46353 L
.41288 .46353 L
.41512 .46353 L
.41641 .46353 L
.41758 .30902 L
.41876 .30902 L
.41988 .30902 L
.45821 .30902 L
.49899 .30902 L
.53826 .30902 L
.57601 .30902 L
.61621 .30902 L
.6549 .30902 L
.69604 .30902 L
.73566 .30902 L
.77377 .30902 L
.81433 .30902 L
.85338 .30902 L
.89488 .30902 L
.93486 .30902 L
.97332 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`06oooo00<0I_ooooooool01?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Koool00`1Vooooooooo`03oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Coool00`1Vooooooooo`0C
oooo00<0003oooooool09?ooo`0306Kooooooooo01;oool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool003goool00`1Vooooooooo`0joooo00<0I_ooooooool04_oo
o`030000oooooooo08koool003goool00`1Vooooooooo`0joooo00<0I_ooooooool04_ooo`80002?
oooo000moooo00<0I_ooooooool0>_ooo`0306Kooooooooo01;oool00`000?ooooooo`2>oooo000m
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01;oool00`000?ooooooo`2>oooo000moooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01;oool00`000?ooooooo`2>oooo000moooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01;oool20000Soooo`00?Oooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Boooo00<0
003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Boooo0P0008ooool0
03goool00`1Vooooooooo`0joooo00<0I_ooooooool04_ooo`030000oooooooo08koool003goool0
0`1Vooooooooo`0joooo00<0I_ooooooool04_ooo`030000oooooooo08koool003goool00`1Voooo
ooooo`0joooo00<0I_ooooooool04_ooo`030000oooooooo08koool003goool00`1Vooooooooo`0j
oooo00<0I_ooooooool04_ooo`80002?oooo000moooo00<0I_ooooooool0>_ooo`0306Kooooooooo
01;oool00`000?ooooooo`2>oooo000moooo00<0I_ooooooool0=_ooo`800002oooo00@0I_ooool0
00000003oooo100000?oool200001Oooo`030000oooooooo08koool003goool00`1Vooooooooo`0e
oooo00H0003oooooool0003oool0I_l6oooo00<0003oooooool00oooo`040000oooooooo00001?oo
o`030000oooooooo08koool003goool00`1Vooooooooo`0eoooo00H0003oooooool0003oool0I_l7
oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00?_ooo`0306Kooooooooo
03Coool01P000?ooooooo`000?ooo`1Vo`Soool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`2>oooo000noooo00<0I_ooooooool0=?ooo`060000oooooooo0000oooo06Ko1_ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000noooo00<0I_oooooo
ool0=Oooo`800002oooo00<0I_ooooooool01Oooo`800004oooo0`0000Coool00`000?ooooooo`2>
oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo01;oool20000Soooo`00?_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?_ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Boooo0P0008ooool003koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000
oooooooo08koool003koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000oooooooo
08koool003koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
03koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`80002?oooo000noooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01;oool00`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo01;oool00`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01;oool00`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01;oool20000Soooo`00?_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Boooo00<0003ooooo
ool0S_ooo`00?_ooo`0306Kooooooooo03Woool0101Vooooo`00000000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00?_ooo`0306Kooooooooo03Woool01@1Vo`000?ooooooo`000008
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00?_ooocd0I_l010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0008koool007[oool01Ol0V@000?ooooooo`000009oooo0P00
00Goool00`000?ooooooo`2>oooo001joooo00Go09T0003oooooool000002Oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001joooo00Co09Woool00000000:oooo0`0000Coool00`000?oo
ooooo`2>oooo001joooo00?o09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001foooo0P00
00;oool01?l0VOooo`00000000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>
oooo001eoooo00H0003oooooool0003ooooo09T8oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`2>oooo001eoooo00H0003oooooool0003ooooo09T8oooo00<0
003oooooool01?ooo`030000oooooooo00;oool30000S_ooo`00MOooo`060000oooooooo0000oooo
o`2I2Oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00H0003ooooo
ool0003ooooo09T6oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool007Koool200000_ooo`03o`2Ioooooooo00Coool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Sooo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool02_ooo`D00003oooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo00coool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo00coool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800005oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
01Coool00`000?ooooooo`0:oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooo
oooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Ooool200002Oooo`@00002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.41976 .30902 L
.42113 .30902 L
.42237 .30902 L
s
.42237 .30902 m
.42249 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.17735 .30902 L
.17986 .30902 L
.18221 .30902 L
.18341 .30902 L
.1847 .46353 L
.18543 .46353 L
.18613 .46353 L
.18744 .46353 L
.19227 .46353 L
.20178 .46353 L
.22272 .46353 L
.26091 .46353 L
.30156 .46353 L
.34068 .46353 L
.38227 .46353 L
.40313 .46353 L
.41229 .46353 L
.41714 .46353 L
.4198 .46353 L
.42112 .46353 L
.42233 .46353 L
.42351 .30902 L
.42476 .30902 L
.4274 .30902 L
.43203 .30902 L
.44108 .30902 L
.46088 .30902 L
.49863 .30902 L
.53884 .30902 L
.57753 .30902 L
.61867 .30902 L
.65829 .30902 L
.6964 .30902 L
.73696 .30902 L
.776 .30902 L
.8175 .30902 L
.85748 .30902 L
.89595 .30902 L
.93687 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`08oooo00<0I_ooooooool00_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Ooool00ol0V@1Vooooo`02oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Koool00`1Vooooooooo`0A
oooo00<0003oooooool09Oooo`03o`2I06Kooooo017oool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool003ooool00`1Vooooooooo`0ioooo00?o09T0I_ooool04Ooo
o`030000oooooooo08koool003ooool00`1Vooooooooo`0ioooo00?o09T0I_ooool04Oooo`80002?
oooo000ooooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo017oool00`000?ooooooo`2>oooo000o
oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo017oool00`000?ooooooo`2>oooo000ooooo00<0
I_ooooooool0>Oooo`03o`2I06Kooooo017oool00`000?ooooooo`2>oooo000ooooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo017oool20000Soooo`00?oooo`0306Kooooooooo03Woool00ol0V@1V
ooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0A
oooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0Aoooo00<0
003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0Aoooo0P0008ooool0
03ooool00`1Vooooooooo`0ioooo00?o09T0I_ooool04Oooo`030000oooooooo08koool003ooool0
0`1Vooooooooo`0ioooo00?o09T0I_ooool04Oooo`030000oooooooo08koool003ooool00`1Voooo
ooooo`0ioooo00?o09T0I_ooool04Oooo`030000oooooooo08koool003ooool00`1Vooooooooo`0i
oooo00?o09T0I_ooool04Oooo`80002?oooo000ooooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
017oool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0=?ooo`800003oooo00?o09T00000
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0<ooo
o`040000oooooooo00000_ooo`03o`2I06Kooooo00?oool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03?oool010000?ooooooo`00
00;oool00`1Vooooooooo`04oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000S_oo
o`00?oooo`0306Kooooooooo03?oool010000?ooooooo`0000;oool00`1Vooooooooo`05oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03?oool0
10000?ooooooo`0000;oool00`1Vooooooooo`03oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool003ooool00`1Vooooooooo`0doooo0P0000?oool00`1Voooo
ooooo`04oooo0P0000Coool300001?ooo`030000oooooooo08koool003ooool00`1Vooooooooo`0i
oooo00<0I_ooooooool04Oooo`80002?oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo
017oool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo017oool0
0`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo017oool00`000?oo
ooooo`2>oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo017oool20000Soooo`00?ooo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Aoooo0P0008ooool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Ooo
o`030000oooooooo08koool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000
oooooooo08koool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000oooooooo
08koool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`80002?oooo000ooooo00<0
I_ooooooool0>Oooo`0306Kooooooooo017oool00`000?ooooooo`2>oooo000ooooo00<0I_oooooo
ool0>Oooo`0306Ko0000000000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00?ooo
o`0306Kooooooooo03Woool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo000ooooo?01Vo`040000oooooooo00002oooo`030000oooooooo00;oool30000S_oo
o`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001koooo00?o09T00000
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Sooo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Ooo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0A
oooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo
08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0
003oooooool0S_ooo`00M_ooo`800003oooo00?o09T0000000001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000;oool00ol0VOooooooo`05
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo001e
oooo00@0003oooooool00002oooo00?o09Woooooool01Oooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool007Goool010000?ooooooo`0000;oool00ol0VOooooooo`06oooo00@0
003oooooooooool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000;oool0
0ol0VOooooooo`03oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
08koool007Koool200000oooo`03o`2Ioooooooo00?oool400000oooo`<00004oooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool0
0`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool0
0ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Sooo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Ooo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Nooo
o`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0A
oooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool02Oooo`D00003oooo00<0
003oooooool0S_ooo`00Noooo`03o`2Ioooooooo00_oool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo00_oool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000
oooooooo01Goool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0003oooooool00_oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool3
00001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Ooool0
0`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1e
oooo001foooo00<0003oooooool05oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo
07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.42237 .30902 L
.42482 .30902 L
.42617 .30902 L
.42744 .30902 L
.42816 .30902 L
s
.42816 .30902 m
.42824 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.18221 .30902 L
.18475 .30902 L
.18744 .30902 L
.18855 .30902 L
.18974 .30902 L
.19104 .46353 L
.19227 .46353 L
.20178 .46353 L
.22272 .46353 L
.26394 .46353 L
.30365 .46353 L
.34184 .46353 L
.38249 .46353 L
.40128 .46353 L
.41117 .46353 L
.42162 .46353 L
.42418 .46353 L
.42693 .46353 L
.42774 .46353 L
.42851 .46353 L
.4292 .30902 L
.42995 .30902 L
.43277 .30902 L
.44303 .30902 L
.4632 .30902 L
.50398 .30902 L
.54325 .30902 L
.581 .30902 L
.6212 .30902 L
.65989 .30902 L
.70103 .30902 L
.74065 .30902 L
.77876 .30902 L
.81932 .30902 L
.85837 .30902 L
.89987 .30902 L
.93985 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`09oooo00D0I_ooooooooooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool02Oooo`0406Kooooooooo00003_ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Ooool00`1Vooooooooo`0@oooo00<0003oooooool09oooo`0306Ko
oooooooo00ooool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo01Goool0
043oool00`1Vooooooooo`0joooo00<0I_ooooooool03oooo`030000oooooooo08koool0043oool0
0`1Vooooooooo`0joooo00<0I_ooooooool03oooo`80002?oooo0010oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0010oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00ooool00`000?ooooooo`2>oooo0010oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00ooool00`000?ooooooo`2>oooo0010oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00ooool2
0000Soooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@?ooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0?oooo0P0008ooool0043oool00`1Vooooooooo`0joooo00<0
I_ooooooool03oooo`030000oooooooo08koool0043oool00`1Vooooooooo`0joooo00<0I_oooooo
ool03oooo`030000oooooooo08koool0043oool00`1Vooooooooo`0joooo00<0I_ooooooool03ooo
o`030000oooooooo08koool0043oool00`1Vooooooooo`0joooo00<0I_ooooooool03oooo`80002?
oooo0010oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0010
oooo00<0I_ooooooool0<oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00@?ooo`0306Kooooooooo03;oool010000?ooooooo`0000Coool01@1Voooooooooooo
o`000005oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00@?ooo`0306Kooooooooo
03;oool010000?ooooooo`0000Coool00`1Vooooooooo`02oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000S_ooo`00@Oooo`0306Kooooooooo037oool010000?ooooooo`0000Coool0
0`1Vooooooooo`03oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00@Ooo
o`0306Kooooooooo037oool010000?ooooooo`0000Coool01@1Vooooooooooooo`000002oooo00D0
003oooooooooool000001_ooo`030000oooooooo08koool0047oool00`1Vooooooooo`0boooo0P00
00Goool00`1Vooooooooo`02oooo0P0000Coool300001?ooo`030000oooooooo08koool0047oool0
0`1Vooooooooo`0ioooo00<0I_ooooooool03oooo`80002?oooo0011oooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00ooool00`000?ooooooo`2>oooo0011oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00ooool00`000?ooooooo`2>oooo0011oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00ooool2
0000Soooo`00@Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00@Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@Ooo
o`0306Kooooooooo03Woool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@Oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0?oooo0P0008ooool0047oool00`1Vooooooooo`0ioooo00<0
I_ooooooool03oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0I_oooooo
ool03oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0I_ooooooool03ooo
o`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0I_ooooooool03oooo`80002?
oooo0011oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011
oooo00<0I_ooooooool0>?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo08koool0
047oool00`1Vooooooooo`0goooo00@0003oool0I_l00008oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00@OooocX0I_l01000001Vo`1Vo`0000_oool00`000?ooooooo`02oooo0`00
08koool007_oool010000?ooool0V@0000Woool200001Oooo`030000oooooooo08koool007_oool0
10000?ooool0V@0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`80002?oooo001m
oooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo
00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool2
0000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_oo
o`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2>oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool007Goool010000?ooooooo`0000Coool00ol0VOooooooo`03oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>oooo001eoooo00@0003ooooo
ool00004oooo00?o09Woooooool00oooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
08koool007Goool010000?ooooooo`0000Coool00ol0VOooooooo`04oooo00@0003oooooooooool2
00001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Coool01Ol0VOoooooooooo
o`000002oooo00D0003oooooooooool000001_ooo`030000oooooooo08koool007Koool200001Ooo
o`04o`2Ioooooooooooo100000?oool300001?ooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOoo
o`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000
oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?
oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001m
oooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P00
08ooool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo
00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool0
07goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0003ooooo
ool0S_ooo`00OOooo`03o`2Ioooooooo00Ooool500000oooo`030000oooooooo08koool007goool0
0ol0VOooooooo`09oooo00<0003oooooool00oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`09oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0<oooo1@0000;oool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`07oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo
00Soool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool2
00002_ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43049 .30902 L
.43179 .30902 L
.43298 .30902 L
.43413 .30902 L
s
.43413 .30902 m
.43424 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.18221 .30902 L
.18703 .30902 L
.18957 .30902 L
.19227 .30902 L
.19462 .30902 L
.19527 .30902 L
.19596 .30902 L
.19721 .46353 L
.19844 .46353 L
.1996 .46353 L
.20178 .46353 L
.22272 .46353 L
.26091 .46353 L
.30156 .46353 L
.34068 .46353 L
.38227 .46353 L
.40313 .46353 L
.41229 .46353 L
.42233 .46353 L
.42701 .46353 L
.42959 .46353 L
.43203 .46353 L
.43313 .46353 L
.4343 .46353 L
.43558 .30902 L
.43676 .30902 L
.44108 .30902 L
.46088 .30902 L
.49863 .30902 L
.53884 .30902 L
.57753 .30902 L
.61867 .30902 L
.65829 .30902 L
.6964 .30902 L
.73696 .30902 L
.776 .30902 L
.8175 .30902 L
.85748 .30902 L
.89595 .30902 L
.93687 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0;oooo00<0I_ooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool02_ooo`03o`2I06Ko000000koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Yoooo00<0I_ooooooool03_ooo`030000oooooooo02Soool00ol0V@1Vooooo`0>
oooo00<0003oooooool0>Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo0012oooo00<0
I_ooooooool0>Oooo`03o`2I06Kooooo00koool00`000?ooooooo`2>oooo0012oooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo00koool20000Soooo`00@_ooo`0306Kooooooooo03Woool00ol0V@1V
ooooo`0>oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0>
oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0>oooo00<0
003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0>oooo0P0008ooool0
04;oool00`1Vooooooooo`0ioooo00?o09T0I_ooool03_ooo`030000oooooooo08koool004;oool0
0`1Vooooooooo`0ioooo00?o09T0I_ooool03_ooo`030000oooooooo08koool004;oool00`1Voooo
ooooo`0ioooo00?o09T0I_ooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0i
oooo00?o09T0I_ooool03_ooo`80002?oooo0012oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
00koool00`000?ooooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00koool0
0`000?ooooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00koool00`000?oo
ooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00koool20000Soooo`00@_oo
o`0306Kooooooooo03Woool00ol0V@1Vooooo`0>oooo00<0003oooooool0S_ooo`00@_ooo`0306Ko
oooooooo037oool200001?ooo`8000000ol0V@1Vooooo`0400000oooo`800005oooo00<0003ooooo
ool0S_ooo`00@_ooo`0306Kooooooooo033oool010000?ooooooo`0000Goool01?l0V@1Vooooo`00
00Goool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0012oooo00<0I_ooooooool0<?oo
o`040000oooooooo00001Oooo`0506Kooooooooooooo000000Ooool00`000?ooooooo`02oooo0`00
08koool004;oool00`1Vooooooooo`0`oooo00@0003oooooool00005oooo00<0I_ooooooool00_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool004;oool00`1Vooooooooo`0`
oooo00@0003oooooool00005oooo00@0I_ooooooool00002oooo00D0003oooooooooool000001_oo
o`030000oooooooo08koool004;oool00`1Vooooooooo`0aoooo0P0000Koool0101Voooooooooooo
o`800004oooo0`0000Coool00`000?ooooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00koool20000Soooo`00@_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0>oooo00<0
003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0>oooo00<0003ooooo
ool0S_ooo`00@_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0>oooo00<0003oooooool0S_oo
o`00@_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0>oooo0P0008ooool004;oool00`1Voooo
ooooo`0ioooo00<0I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0i
oooo00<0I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0ioooo00<0
I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0ioooo00<0I_oooooo
ool03_ooo`80002?oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?oo
ooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?ooooooo`2>
oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?ooooooo`2>oooo0012
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool20000Soooo`00@_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0>oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Ooool2
000000@0I_ooooooooooool200001?ooo`800005oooo00<0003oooooool0S_ooo`00@_ooo`0306Ko
oooooooo03Koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo0012oooo>@1Vo`04000006Ko06Ko00002oooo`030000oooooooo00;oool30000S_ooo`00Nooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001loooo0P000003o`2Ioooooooo
00Ooool300001?ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo0P0008ooool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`80002?oooo001noooo00?o09Wooooo
ool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`80002?oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOoo
ooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`80002?oooo001noooo00?o09Woooooool03_ooo`030000
oooooooo08koool007Koool200001?ooo`8000000ol0VOooooooo`02oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00001Oooo`03o`2Ioooooooo
00;oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000Goool00ol0VOooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00001Oooo`03o`2Ioooooooo00?oool0
10000?ooooooooooo`800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00001Ooo
o`04o`2Ioooooooo00000_ooo`050000oooooooooooo000000Koool00`000?ooooooo`2>oooo001f
oooo0P0000Koool00ol0VOooooooo`0400000oooo`<00004oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2I
oooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo
08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo
00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o
09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003ooooo
ool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool01_ooo`D00003oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool0
0`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`0:oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1d
oooo001eoooo00<0003oooooool01@0001Coool00`000?ooooooo`08oooo0P0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool02?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43298 .30902 L
.43762 .30902 L
.43889 .30902 L
.43959 .30902 L
.44024 .30902 L
s
.44024 .30902 m
.44037 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.19721 .30902 L
.19939 .30902 L
.20054 .30902 L
.20178 .30902 L
.2031 .46353 L
.20433 .46353 L
.20704 .46353 L
.21274 .46353 L
.22272 .46353 L
.26394 .46353 L
.30365 .46353 L
.34184 .46353 L
.38249 .46353 L
.40128 .46353 L
.42162 .46353 L
.42704 .46353 L
.43277 .46353 L
.43766 .46353 L
.439 .46353 L
.43974 .46353 L
.44044 .46353 L
.44109 .30902 L
.44179 .30902 L
.44303 .30902 L
.4632 .30902 L
.50398 .30902 L
.54325 .30902 L
.581 .30902 L
.6212 .30902 L
.65989 .30902 L
.70103 .30902 L
.74065 .30902 L
.77876 .30902 L
.81932 .30902 L
.85837 .30902 L
.89987 .30902 L
.93985 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0I_l0003oool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Zoooo00<0I_ooooooool03Oooo`030000oooooooo02[oool00`1Vooooooooo`0<
oooo00<0003oooooool0>Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo0013oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00coool20000Soooo`00@oooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0<oooo00<0003oooooool0S_ooo`00@oooo`0306Kooooooooo03[oool00`1Vooooooooo`0<
oooo00<0003oooooool0S_ooo`00@oooo`0306Kooooooooo03[oool00`1Vooooooooo`0<oooo00<0
003oooooool0S_ooo`00@oooo`0306Kooooooooo03[oool00`1Vooooooooo`0<oooo0P0008ooool0
04?oool00`1Vooooooooo`0joooo00<0I_ooooooool03?ooo`030000oooooooo08koool004?oool0
0`1Vooooooooo`0joooo00<0I_ooooooool03?ooo`030000oooooooo08koool004?oool00`1Voooo
ooooo`0joooo00<0I_ooooooool03?ooo`030000oooooooo08koool004?oool00`1Vooooooooo`0j
oooo00<0I_ooooooool03?ooo`80002?oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00coool0
0`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00coool00`000?oo
ooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00coool20000Soooo`00@ooo
o`0306Kooooooooo03[oool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00@oooo`0306Ko
oooooooo033oool200001?ooo`800002oooo00<0I_l0000000000P0000?oool200001Oooo`030000
oooooooo08koool004?oool00`1Vooooooooo`0_oooo00@0003oooooool00007oooo00<0I_l0003o
ool01?ooo`040000oooooooo00001?ooo`030000oooooooo08koool004?oool00`1Vooooooooo`0_
oooo00@0003oooooool00007oooo00<0I_ooool000001oooo`030000oooooooo00;oool30000S_oo
o`00A?ooo`0306Kooooooooo02koool010000?ooooooo`0000Ooool0101Vooooooooo`0000Coool2
00001Oooo`030000oooooooo08koool004Coool00`1Vooooooooo`0^oooo00@0003oooooool00007
oooo00D0I_l0003oooooool000000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0014
oooo00<0I_ooooooool0;oooo`800008oooo00@0I_ooool000000004oooo0`0000Coool00`000?oo
ooooo`2>oooo0014oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00coool20000Soooo`00A?oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00A?ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00A?ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00A?ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0<oooo0P0008ooool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?oo
o`030000oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?ooo`030000
oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?ooo`030000oooooooo
08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?ooo`80002?oooo0014oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0014oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0014oooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo0014oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00coool20000Soooo`00A?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo00<0
003oooooool0S_ooo`00A?ooo`0306Kooooooooo03Goool200000_ooo`0406Kooooo000000001?oo
o`800005oooo00<0003oooooool0S_ooo`00A?ooo`0306Kooooooooo03Coool01P000?ooooooo`00
0?ooo`1Vo`Koool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0014oooo=`1Vo`040000
06Ko06Ko00000P1Vo`Woool00`000?ooooooo`02oooo0`0008koool007_oool01P000?ooooooo`00
0?ooool0V@Ooool200001Oooo`030000oooooooo08koool007_oool01P000?ooooooo`000?ooool0
V@Ooool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`800002oooo00?o09Wooooo
ool01Oooo`<00004oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Sooo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0
003oooooool0S_ooo`00M_ooo`800004oooo0P0000;oool01?l0VOooooooo`0000Coool200001Ooo
o`030000oooooooo08koool007Goool010000?ooooooo`0000Ooool01?l0VOooooooo`0000?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00007oooo00Co
09Woooooool00006oooo00<0003oooooool00_ooo`<0002>oooo001eoooo00@0003oooooool00007
oooo00Go09Woooooooooool000000oooo`800005oooo00<0003oooooool0S_ooo`00MOooo`040000
oooooooo00001oooo`05o`2I0000oooooooo000000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00M_ooo`800008oooo00?o09T0000000000P0000?oool300001?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0
003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool0
0ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00Coool500000oooo`030000
oooooooo08koool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`030000oooooooo
08koool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0
003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0
003oooooool02?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Ooool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44268 .30902 L
.44498 .30902 L
.44627 .30902 L
s
.44627 .30902 m
.44639 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.20178 .30902 L
.20433 .30902 L
.20573 .30902 L
.20704 .30902 L
.20772 .30902 L
.20845 .46353 L
.20926 .46353 L
.21 .46353 L
.21274 .46353 L
.22272 .46353 L
.26243 .46353 L
.30062 .46353 L
.34126 .46353 L
.38039 .46353 L
.40037 .46353 L
.42198 .46353 L
.43212 .46353 L
.43767 .46353 L
.44037 .46353 L
.44284 .46353 L
.44393 .46353 L
.44511 .46353 L
.44623 .46353 L
.44726 .30902 L
.44835 .30902 L
.44956 .30902 L
.452 .30902 L
.46204 .30902 L
.50225 .30902 L
.54093 .30902 L
.58207 .30902 L
.6217 .30902 L
.65981 .30902 L
.70037 .30902 L
.73941 .30902 L
.78091 .30902 L
.82089 .30902 L
.85936 .30902 L
.90028 .30902 L
.93968 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<00000I_ooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000o`2I06Ko00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0/oooo00<0I_ooooooool02oooo`030000oooooooo02_oool00ol0V@1Vooooo`0;
oooo00<0003oooooool0>Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo0015oooo00<0
I_ooooooool0>Oooo`03o`2I06Kooooo00_oool00`000?ooooooo`2>oooo0015oooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo00_oool20000Soooo`00AOooo`0306Kooooooooo03Woool00ol0V@1V
ooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0;
oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0;oooo00<0
003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00ol0V@1Vooooo`0;oooo0P0008ooool0
04Goool00`1Vooooooooo`0ioooo00?o09T0I_ooool02oooo`030000oooooooo08koool004Goool0
0`1Vooooooooo`0ioooo00?o09T0I_ooool02oooo`030000oooooooo08koool004Goool00`1Voooo
ooooo`0ioooo00?o09T0I_ooool02oooo`030000oooooooo08koool004Goool00`1Vooooooooo`0i
oooo00?o09T0I_ooool02oooo`80002?oooo0015oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
00_oool00`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00_oool0
0`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00_oool00`000?oo
ooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00_oool20000Soooo`00AOoo
o`0306Kooooooooo03Woool00ol0V@1Vooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Ko
oooooooo02koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo08koool0
04Goool00`1Vooooooooo`0]oooo00@0003oooooool00008oooo00<00000I_ooool00oooo`040000
oooooooo00001?ooo`030000oooooooo08koool004Goool00`1Vooooooooo`0]oooo00@0003ooooo
ool00008oooo00<0I_l0003oool01_ooo`030000oooooooo00;oool30000S_ooo`00AOooo`0306Ko
oooooooo02goool010000?ooooooo`0000Soool00`1Vooooo`000004oooo0P0000Goool00`000?oo
ooooo`2>oooo0015oooo00<0I_ooooooool0;Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0;_oo
o`800009oooo00<0I_l0000000001?ooo`<00004oooo00<0003oooooool0S_ooo`00AOooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0;oooo0P0008ooool004Goool00`1Vooooooooo`0ioooo00<0
I_ooooooool02oooo`030000oooooooo08koool004Goool00`1Vooooooooo`0ioooo00<0I_oooooo
ool02oooo`030000oooooooo08koool004Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02ooo
o`030000oooooooo08koool004Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02oooo`80002?
oooo0015oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00_oool00`000?ooooooo`2>oooo0015
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00_oool00`000?ooooooo`2>oooo0015oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00_oool00`000?ooooooo`2>oooo0015oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00_oool20000Soooo`00AOooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00`1Vooooooooo`0;
oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00`1Vooooooooo`0;oooo00<0
003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00`1Vooooooooo`0;oooo0P0008ooool0
04Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02oooo`030000oooooooo08koool004Goool0
0`1Vooooooooo`0doooo0P0000?oool00`1Vo`0000000004oooo0P0000Goool00`000?ooooooo`2>
oooo0015oooo00<0I_ooooooool0<oooo`040000oooooooo00000_ooo`0306Kooooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0015oooo=P1Vo`04000006Ko06Ko00000`1V
o`Soool00`000?ooooooo`02oooo0`0008koool007_oool010000?ooooooo`0000;oool00ol0VOoo
ooooo`04oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00002oooo00?o
09Woooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001loooo0P0000?oool0
0ol0VOooooooo`04oooo0`0000Coool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02ooo
o`80002?oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POoo
o`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021
oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0
003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo
00_oool00`000?ooooooo`2>oooo001foooo0P0000Coool200000oooo`03o`2Ioooo000000Coool2
00001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool00ol0VOooo`000003
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?oo
o`03o`2Ioooo000000Koool00`000?ooooooo`02oooo0`0008koool007Goool010000?ooooooo`00
00Soool01?l0VOooooooo`0000?oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POoo
o`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;
oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021
oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P00
08ooool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo
00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0
087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00?oool500000oooo`030000oooooooo08koool0087oool0
0ol0VOooooooo`05oooo00<0003oooooool00oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`05oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0
003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0<oooo1@0000;oool200001Oooo`<00002oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00Goool00`000?ooooooo`0:oooo00@0003oooooool00002oooo00D0003oooooooooool00000Mooo
o`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`D00004
oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooo000000?oool0
0`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002ooo
o`800003oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44268 .30902 L
.44744 .30902 L
.44874 .30902 L
.45013 .30902 L
.45143 .30902 L
s
.45143 .30902 m
.45155 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21019 .30902 L
.2114 .30902 L
.21274 .30902 L
.21394 .30902 L
.21506 .46353 L
.21625 .46353 L
.21753 .46353 L
.22272 .46353 L
.26394 .46353 L
.30365 .46353 L
.34184 .46353 L
.38249 .46353 L
.42162 .46353 L
.4319 .46353 L
.43731 .46353 L
.44303 .46353 L
.44804 .46353 L
.44941 .46353 L
.45088 .46353 L
.45159 .46353 L
.45227 .46353 L
.45353 .30902 L
.4547 .30902 L
.45594 .30902 L
.45816 .30902 L
.4632 .30902 L
.50095 .30902 L
.54115 .30902 L
.57984 .30902 L
.62098 .30902 L
.66061 .30902 L
.69871 .30902 L
.73927 .30902 L
.77832 .30902 L
.81982 .30902 L
.8598 .30902 L
.89827 .30902 L
.93918 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oool0I_l03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`040000oooooooo06Ko2oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02goool00`1Vooooooooo`0:oooo00<0003oooooool0;Oooo`0306Kooooooooo
00Woool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo01Goool004Koool0
0`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Koool00`1Voooo
ooooo`0joooo00<0I_ooooooool02Oooo`80002?oooo0016oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo0016oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00Woool00`000?ooooooo`2>oooo0016oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Woool0
0`000?ooooooo`2>oooo0016oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Woool20000Sooo
o`00A_ooo`0306Kooooooooo03[oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00A_oo
o`0306Kooooooooo03[oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00A_ooo`0306Ko
oooooooo03[oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00A_ooo`0306Kooooooooo
03[oool00`1Vooooooooo`09oooo0P0008ooool004Koool00`1Vooooooooo`0joooo00<0I_oooooo
ool02Oooo`030000oooooooo08koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Ooo
o`030000oooooooo08koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000
oooooooo08koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`80002?oooo0016
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo0016oooo00<0
I_ooooooool0;Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0S_oo
o`00A_ooo`0306Kooooooooo02coool010000?ooooooo`0000Soool00`000?ooo`1Vo`03oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00A_ooo`0306Kooooooooo02coool010000?oo
ooooo`0000Woool00`00001Vooooo`05oooo00<0003oooooool00_ooo`<0002>oooo0017oooo00<0
I_ooooooool0:oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool004Ooool00`1Vooooooooo`0[oooo00@0003oooooool00008oooo00@0003oool0
I_l00003oooo00<0003oooooool01?ooo`030000oooooooo08koool004Ooool00`1Vooooooooo`0/
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Aoooo`0306Kooooooooo
03Woool00`1Vooooooooo`09oooo0P0008ooool004Ooool00`1Vooooooooo`0ioooo00<0I_oooooo
ool02Oooo`030000oooooooo08koool004Ooool00`1Vooooooooo`0ioooo00<0I_ooooooool02Ooo
o`030000oooooooo08koool004Ooool00`1Vooooooooo`0ioooo00<0I_ooooooool02Oooo`030000
oooooooo08koool004Ooool00`1Vooooooooo`0ioooo00<0I_ooooooool02Oooo`80002?oooo0017
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo0017oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo0017oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo0017oooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00Woool20000Soooo`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`09
oooo00<0003oooooool0S_ooo`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`09oooo00<0
003oooooool0S_ooo`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`09oooo00<0003ooooo
ool0S_ooo`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`09oooo0P0008ooool004Ooool0
0`1Vooooooooo`0ioooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Ooool00`1Voooo
ooooo`0boooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00Aoooo`0306Ko
oooooooo037oool010000?ooooooo`0000Coool01@1Vooooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo08koool004Oooold06Ko00@00000I_l0I_l0000506Ko1_ooo`030000
oooooooo00;oool30000S_ooo`00Noooo`040000oooooooo00001?ooo`03o`2Ioooooooo00;oool2
00001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000Coool00ol0VOooooooo`02
oooo00<0003oooooool01?ooo`030000oooooooo08koool007coool200001Oooo`03o`2Ioooooooo
00;oool300001?ooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo0P0008ooool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000
oooooooo08koool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0S_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0008koool007Goool010000?ooooooo`0000[oool0
0ol0V@000?ooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008
oooo00@0003ooooo09T00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007Koool2
00002Oooo`@00003oooo0`0000Coool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000
oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023
oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0
003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool0
08?oool01?l0VOooooooooooo`D00003oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool5
00000_ooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`0:
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool01oooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000Doooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooo000000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.44268 .30902 L
.44778 .30902 L
.45262 .30902 L
.45473 .30902 L
.45697 .30902 L
.45826 .30902 L
s
.45826 .30902 m
.45838 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21274 .30902 L
.21753 .30902 L
.21884 .30902 L
.21955 .30902 L
.22022 .30902 L
.22141 .46353 L
.22272 .46353 L
.26149 .46353 L
.30271 .46353 L
.34242 .46353 L
.38061 .46353 L
.40193 .46353 L
.42126 .46353 L
.43094 .46353 L
.44141 .46353 L
.44622 .46353 L
.45129 .46353 L
.45563 .46353 L
.45682 .46353 L
.45809 .46353 L
.45929 .30902 L
.46039 .30902 L
.50023 .30902 L
.53856 .30902 L
.57935 .30902 L
.61861 .30902 L
.65636 .30902 L
.69657 .30902 L
.73525 .30902 L
.77639 .30902 L
.81602 .30902 L
.85413 .30902 L
.89469 .30902 L
.93373 .30902 L
.97523 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00D0003oooooooooool0I_l02_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`060000ooooooooooooo`2I06Ko2Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo02ooool00`1Vooooooooo`08oooo00<0003oooooool0;_oo
o`03o`2I06Kooooo00Soool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool004Soool00`1Vooooooooo`0ioooo00?o09T0I_ooool02?ooo`030000oooooooo08koool0
04Soool00`1Vooooooooo`0ioooo00?o09T0I_ooool02?ooo`80002?oooo0018oooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>Ooo
o`03o`2I06Kooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>Oooo`03o`2I
06Kooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
00Soool20000Soooo`00B?ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`08oooo00<0003ooooo
ool0S_ooo`00B?ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`08oooo00<0003oooooool0S_oo
o`00B?ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`08oooo00<0003oooooool0S_ooo`00B?oo
o`0306Kooooooooo03Woool00ol0V@1Vooooo`08oooo0P0008ooool004Soool00`1Vooooooooo`0i
oooo00?o09T0I_ooool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00?o
09T0I_ooool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00?o09T0I_oo
ool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00?o09T0I_ooool02?oo
o`80002?oooo0018oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00Soool00`000?ooooooo`2>
oooo0018oooo00<0I_ooooooool0:oooo`800004oooo0P0000?oool4000000<0I_ooooooool00P00
00Goool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0:_ooo`040000oooooooo00002?oo
o`070000ooooooooo`2I06Kooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_oo
o`00B?ooo`0306Kooooooooo02[oool010000?ooooooo`0000Woool00`000?ooo`1Vo`05oooo00<0
003oooooool00_ooo`<0002>oooo0018oooo00<0I_ooooooool0:_ooo`040000oooooooo00002_oo
o`03000006Kooooo00;oool200001Oooo`030000oooooooo08koool004Soool00`1Vooooooooo`0Z
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo08koool004Soool00`1Vooooooooo`0[oooo0P0000[oool2000000@0I_ooooooooooool3
00001?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00<0I_ooooooool02?oo
o`80002?oooo0018oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>
oooo0018oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo0018
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Soool20000Soooo`00B?ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`08oooo00<0003oooooool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`08oooo00<0003oooooool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08
oooo00<0003oooooool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08oooo0P00
08ooool004Soool00`1Vooooooooo`0ioooo00<0I_ooooooool02?ooo`030000oooooooo08koool0
04Soool00`1Vooooooooo`0ioooo00<0I_ooooooool02?ooo`030000oooooooo08koool004Soool0
0`1Vooooooooo`0ioooo00<0I_ooooooool02?ooo`030000oooooooo08koool004Soool00`1Voooo
ooooo`0ioooo00<0I_ooooooool02?ooo`80002?oooo0018oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0<Oooo`800004oooo0P00
000406Kooooooooooooo0P0000Goool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0<?oo
o`040000oooooooo00001Oooo`0406Kooooooooo00000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo0018oooo<`1Vo`04000006Ko06Ko00001P1Vo`Goool00`000?ooooooo`02oooo0`00
08koool007_oool010000?ooooooo`0000Goool01?l0VOooooooooooo`800005oooo00<0003ooooo
ool0S_ooo`00Noooo`040000oooooooo00001Oooo`05o`2Ioooooooooooo000000Koool00`000?oo
ooooo`2>oooo001loooo0P0000Koool01?l0VOooooooooooo`<00004oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo0P0008ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000
oooooooo08koool008Coool00ol0VOooooooo`08oooo0P0008ooool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00M_ooo`800004oooo0P00
00Goool00`000?l0VOooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003ooooo
ool0000:oooo00D0003o09Woooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo001eoooo00@0003oooooool0000:oooo00<0003o09Woool01?ooo`030000oooooooo00;oool3
0000S_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`2>oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o
09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`0500000oooo`030000
oooooooo08koool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`030000oooooooo
08koool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0
003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?oo
ooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0
003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`040000
oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005ooo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool00`000?oo
ooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.45734 .30902 L
.46172 .30902 L
.46283 .30902 L
.46388 .30902 L
s
.46388 .30902 m
.464 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.21786 .30902 L
.22037 .30902 L
.22272 .30902 L
.22387 .30902 L
.22496 .30902 L
.22623 .46353 L
.22738 .46353 L
.23233 .46353 L
.24276 .46353 L
.26171 .46353 L
.2999 .46353 L
.34055 .46353 L
.37968 .46353 L
.42126 .46353 L
.44213 .46353 L
.45128 .46353 L
.45613 .46353 L
.4588 .46353 L
.46133 .46353 L
.4625 .46353 L
.46376 .46353 L
.46441 .30902 L
.46513 .30902 L
.4664 .30902 L
.47102 .30902 L
.48007 .30902 L
.49988 .30902 L
.54008 .30902 L
.57877 .30902 L
.61991 .30902 L
.65953 .30902 L
.69764 .30902 L
.7382 .30902 L
.77725 .30902 L
.81874 .30902 L
.85873 .30902 L
.89719 .30902 L
.93811 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool00_ooo`0306Kooooooooo00Ooool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`03oooo00<0I_ooooooool01_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo033oool00`1Vooooooooo`07
oooo00<0003oooooool0<?ooo`0306Kooooooooo00Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool004Woool00`1Vooooooooo`0joooo00<0I_ooooooool01_oo
o`030000oooooooo08koool004Woool00`1Vooooooooo`0joooo00<0I_ooooooool01_ooo`80002?
oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00Koool20000Soooo`00BOooo`0306Kooooooooo03[oool00`1Voooo
ooooo`06oooo00<0003oooooool0S_ooo`00BOooo`0306Kooooooooo03[oool00`1Vooooooooo`06
oooo00<0003oooooool0S_ooo`00BOooo`0306Kooooooooo03[oool00`1Vooooooooo`06oooo00<0
003oooooool0S_ooo`00BOooo`0306Kooooooooo03[oool00`1Vooooooooo`06oooo0P0008ooool0
04Woool00`1Vooooooooo`0joooo00<0I_ooooooool01_ooo`030000oooooooo08koool004Woool0
0`1Vooooooooo`0joooo00<0I_ooooooool01_ooo`030000oooooooo08koool004Woool00`1Voooo
ooooo`0joooo00<0I_ooooooool01_ooo`030000oooooooo08koool004Woool00`1Vooooooooo`0j
oooo00<0I_ooooooool01_ooo`80002?oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0:_ooo`800004oooo0P0000?oool4
000000?oool0I_ooool00P0000Goool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0:Ooo
o`040000oooooooo00002?ooo`030000oooooooo00;oool01@1Vo`000?ooooooo`000004oooo00<0
003oooooool0S_ooo`00BOooo`0306Kooooooooo02Woool010000?ooooooo`0000Woool01@000?oo
ooooooooo`1Vo`03oooo00<0003oooooool00_ooo`<0002>oooo001:oooo00<0I_ooooooool0:?oo
o`040000oooooooo00002_ooo`050000oooooooo06Kooooo00800005oooo00<0003oooooool0S_oo
o`00B_ooo`0306Kooooooooo02Soool010000?ooooooo`0000Soool020000?ooooooo`000?ooo`1V
ooooo`0000Koool00`000?ooooooo`2>oooo001:oooo00<0I_ooooooool0:Oooo`80000:oooo0P00
00;oool00`1Vooooo`00000200001?ooo`030000oooooooo08koool004[oool00`1Vooooooooo`0i
oooo00<0I_ooooooool01_ooo`80002?oooo001:oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo001:oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Koool0
0`000?ooooooo`2>oooo001:oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Koool00`000?oo
ooooo`2>oooo001:oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Koool20000Soooo`00B_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00B_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00B_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00B_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`06oooo0P0008ooool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_oo
o`030000oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`030000
oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`030000oooooooo
08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`80002?oooo001:oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001:oooo00<0I_oooooo
ool0;oooo`800004oooo0P0000;oool0101Vooooo`00000000Goool00`000?ooooooo`2>oooo001:
oooo00<0I_ooooooool0;_ooo`040000oooooooo00001oooo`0506Ko0000oooooooo000000Coool0
0`000?ooooooo`2>oooo001:oooo<@1Vo`04000006Ko06Ko0000201Vo`?oool00`000?ooooooo`02
oooo0`0008koool007_oool010000?ooooooo`0000Ooool01?l0VOooo`00000000Goool00`000?oo
ooooo`2>oooo001koooo00@0003oooooool00007oooo00?o09Woool000001_ooo`030000oooooooo
08koool007coool200002?ooo`03o`2Ioooo000000800004oooo00<0003oooooool0S_ooo`00Q_oo
o`03o`2Ioooooooo00Koool20000Soooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>
oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06
oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2I
oooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo
08koool008Koool00ol0VOooooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0
003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o
09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo0P0008ooool0
08Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00M_ooo`800004oooo0P0000Goool0
1@000?ooooooool0VOooo`0200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`00
00[oool01@000?ooooooool0V@000002oooo00<0003oooooool00_ooo`030000oooooooo08koool0
07Goool010000?ooooooo`0000[oool010000?ooooooool0V@?oool00`000?ooooooo`02oooo0`00
08koool007Goool010000?ooooooo`0000_oool010000?ooool0VOooo`800005oooo00<0003ooooo
ool0S_ooo`00MOooo`040000oooooooo00002?ooo`080000oooooooo0000ooooo`2Ioooo00001_oo
o`030000oooooooo08koool007Koool200002Oooo`@000000oooool0VOooo`0300001?ooo`030000
oooooooo08koool008Koool00ol0VOooooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06
oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026
oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo0P00
08ooool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool0
08Koool00ol0VOooooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0003ooooo
ool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Wooooo
ool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo0P0008ooool008Koool0
0ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2I0000000000<00003oooo00<0
003oooooool0S_ooo`00Q_ooo`04o`2Ioooooooo00001Oooo`030000oooooooo08koool008Koool0
1?l0VOooooooo`0000Goool30000S_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`D00002oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00[oool01@000?oooooooooo
o`00001joooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P00
00?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.46741 .30902 L
.46871 .30902 L
.46994 .30902 L
s
.46994 .30902 m
.47006 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.22272 .30902 L
.22738 .30902 L
.22974 .30902 L
.23038 .30902 L
.23107 .30902 L
.23233 .46353 L
.23302 .46353 L
.23366 .46353 L
.23512 .46353 L
.23778 .46353 L
.24276 .46353 L
.26171 .46353 L
.30084 .46353 L
.34242 .46353 L
.38249 .46353 L
.42104 .46353 L
.44059 .46353 L
.45094 .46353 L
.45664 .46353 L
.46204 .46353 L
.46716 .46353 L
.46856 .46353 L
.46933 .46353 L
.47005 .46353 L
.47132 .30902 L
.472 .30902 L
.47272 .30902 L
.48246 .30902 L
.50153 .30902 L
.54267 .30902 L
.58229 .30902 L
.6204 .30902 L
.66096 .30902 L
.70001 .30902 L
.74151 .30902 L
.78149 .30902 L
.81995 .30902 L
.86087 .30902 L
.90028 .30902 L
.93816 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01?ooo`0306Kooooooooo00Goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`04oooo00?o09T0I_ooool01Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03;oool00`1Vooooooooo`05
oooo00<0003oooooool0<Oooo`03o`2I06Kooooo00Goool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool004_oool00`1Vooooooooo`0ioooo00?o09T0I_ooool01Ooo
o`030000oooooooo08koool004_oool00`1Vooooooooo`0ioooo00?o09T0I_ooool01Oooo`80002?
oooo001;oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00Goool00`000?ooooooo`2>oooo001;
oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00Goool00`000?ooooooo`2>oooo001;oooo00<0
I_ooooooool0>Oooo`03o`2I06Kooooo00Goool00`000?ooooooo`2>oooo001;oooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo00Goool20000Soooo`00Boooo`0306Kooooooooo03Woool00ol0V@1V
ooooo`05oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00ol0V@1Vooooo`05
oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00ol0V@1Vooooo`05oooo00<0
003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00ol0V@1Vooooo`05oooo0P0008ooool0
04_oool00`1Vooooooooo`0ioooo00?o09T0I_ooool01Oooo`030000oooooooo08koool004_oool0
0`1Vooooooooo`0ioooo00?o09T0I_ooool01Oooo`030000oooooooo08koool004_oool00`1Voooo
ooooo`0ioooo00?o09T0I_ooool01Oooo`030000oooooooo08koool004_oool00`1Vooooooooo`0i
oooo00?o09T0I_ooool01Oooo`80002?oooo001;oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
00Goool00`000?ooooooo`2>oooo001;oooo00<0I_ooooooool0:?ooo`800004oooo0P0000?oool4
00000_ooo`03o`2I0000000000Goool00`000?ooooooo`2>oooo001;oooo00<0I_ooooooool09ooo
o`040000oooooooo00002?ooo`030000oooooooo00?oool01000001Vooooo`0000Coool00`000?oo
ooooo`2>oooo001;oooo00<0I_ooooooool09oooo`040000oooooooo00002Oooo`030000oooooooo
00;oool0101Vooooooooo`0000Coool30000S_ooo`00Boooo`0306Kooooooooo02Ooool010000?oo
ooooo`0000[oool01@000?ooooooooooo`1Vo`0200001Oooo`030000oooooooo08koool004_oool0
0`1Vooooooooo`0Woooo00@0003oooooool00008oooo00@0003oooooool00002oooo00<0I_l0003o
ool01Oooo`030000oooooooo08koool004_oool00`1Vooooooooo`0Xoooo0P0000[oool200000ooo
o`0406Ko0000000000001?ooo`030000oooooooo08koool004_oool00`1Vooooooooo`0ioooo00<0
I_ooooooool01Oooo`80002?oooo001;oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool0
0`000?ooooooo`2>oooo001;oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool00`000?oo
ooooo`2>oooo001;oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool00`000?ooooooo`2>
oooo001;oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool20000Soooo`00Boooo`0306Ko
oooooooo03Woool00`1Vooooooooo`05oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo
03Woool00`1Vooooooooo`05oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool0
0`1Vooooooooo`05oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00`1Voooo
ooooo`05oooo0P0008ooool004_oool00`1Vooooooooo`0ioooo00<0I_ooooooool01Oooo`030000
oooooooo08koool004_oool00`1Vooooooooo`0ioooo00<0I_ooooooool01Oooo`030000oooooooo
08koool004_oool00`1Vooooooooo`0ioooo00<0I_ooooooool01Oooo`030000oooooooo08koool0
04_oool00`1Vooooooooo`0ioooo00<0I_ooooooool01Oooo`80002?oooo001;oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001;oooo00<0I_ooooooool0;_oo
o`800004oooo0P0000?oool00`1Vo`0000000005oooo00<0003oooooool0S_ooo`00Boooo`0306Ko
oooooooo02goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001;oooo<01Vo`04000006Ko06Ko00002@1Vo`;oool00`000?ooooooo`02oooo0`0008koool0
07_oool010000?ooooooo`0000Soool00ol0V@0000000005oooo00<0003oooooool0S_ooo`00Nooo
o`040000oooooooo00002?ooo`03o`2I0000oooo00Goool00`000?ooooooo`2>oooo001loooo0P00
00Woool01?l0V@000000000000Coool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo001foooo0P0000Coool200001Oooo`050000ooooooooooooo`2I
00800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo
00002_ooo`050000ooooooooooooo`2I00;oool00`000?ooooooo`02oooo0`0008koool007Goool0
10000?ooooooo`0000_oool010000?ooooooool0V@800005oooo00<0003oooooool0S_ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`03o`2I0000oooo00Goool00`000?oo
ooooo`2>oooo001foooo0P0000Woool400000_ooo`04o`2I0000000000001?ooo`030000oooooooo
08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`D00003oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooo000000Goool00`000?ooooooo`2>oooo0027oooo00?o09Woool000001Oooo`<0002>
oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`@00003
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00<0003ooooo
ool00oooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.47106 .30902 L
.47329 .30902 L
.47451 .30902 L
.47567 .30902 L
s
.47567 .30902 m
.47578 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23496 .30902 L
.2364 .30902 L
.23711 .30902 L
.23775 .30902 L
.2389 .46353 L
.24014 .46353 L
.24276 .46353 L
.26171 .46353 L
.30142 .46353 L
.33961 .46353 L
.38026 .46353 L
.41939 .46353 L
.43936 .46353 L
.44987 .46353 L
.46097 .46353 L
.46577 .46353 L
.47092 .46353 L
.47243 .46353 L
.47387 .46353 L
.47516 .46353 L
.47589 .46353 L
.47656 .30902 L
.47778 .30902 L
.47912 .30902 L
.48184 .30902 L
.50104 .30902 L
.54124 .30902 L
.57993 .30902 L
.62107 .30902 L
.66069 .30902 L
.6988 .30902 L
.73936 .30902 L
.7784 .30902 L
.8199 .30902 L
.85988 .30902 L
.89835 .30902 L
.93927 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01Oooo`0306Kooooooooo00Coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00<0I_ooooooool00ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03?oool00`1Vooooooooo`04
oooo00<0003oooooool0<oooo`0306Kooooooooo00?oool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool004coool00`1Vooooooooo`0joooo00<0I_ooooooool00ooo
o`030000oooooooo08koool004coool00`1Vooooooooo`0joooo00<0I_ooooooool00oooo`80002?
oooo001<oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001<
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001<oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001<oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00?oool20000Soooo`00C?ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`03oooo00<0003oooooool0S_ooo`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03
oooo00<0003oooooool0S_ooo`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03oooo00<0
003oooooool0S_ooo`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03oooo0P0008ooool0
04coool00`1Vooooooooo`0joooo00<0I_ooooooool00oooo`030000oooooooo08koool004coool0
0`1Vooooooooo`0joooo00<0I_ooooooool00oooo`030000oooooooo08koool004coool00`1Voooo
ooooo`0joooo00<0I_ooooooool00oooo`030000oooooooo08koool004coool00`1Vooooooooo`0j
oooo00<0I_ooooooool00oooo`80002?oooo001<oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00?oool00`000?ooooooo`2>oooo001<oooo00<0I_ooooooool09oooo`800004oooo0P0000?oool4
00000oooo`800005oooo00<0003oooooool0S_ooo`00C?ooo`0306Kooooooooo02Koool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oool0I_l00004oooo00<0003oooooool0S_oo
o`00C?ooo`0306Kooooooooo02Koool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
I_l0003oool00oooo`<0002>oooo001=oooo00<0I_ooooooool09Oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo08koool004goool00`1Vooooooooo`0U
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<00000I_ooool01?ooo`030000
oooooooo08koool004goool00`1Vooooooooo`0Voooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0S_ooo`00COooo`0306Kooooooooo03Woool00`1Vooooooooo`03oooo0P0008ooool0
04goool00`1Vooooooooo`0ioooo00<0I_ooooooool00oooo`030000oooooooo08koool004goool0
0`1Vooooooooo`0ioooo00<0I_ooooooool00oooo`030000oooooooo08koool004goool00`1Voooo
ooooo`0ioooo00<0I_ooooooool00oooo`030000oooooooo08koool004goool00`1Vooooooooo`0i
oooo00<0I_ooooooool00oooo`80002?oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00?oool00`000?ooooooo`2>oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool0
0`000?ooooooo`2>oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool00`000?oo
ooooo`2>oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool20000Soooo`00COoo
o`0306Kooooooooo03Woool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00COooo`0306Ko
oooooooo03Woool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00COooo`0306Kooooooooo
03Woool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00COooo`0306Kooooooooo03Woool0
0`1Vooooooooo`03oooo0P0008ooool004goool00`1Vooooooooo`0ioooo00<0I_ooooooool00ooo
o`030000oooooooo08koool004goool00`1Vooooooooo`0/oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00COooo`0306Kooooooooo02_oool010000?ooooooo`0000Soool0
10000?ooo`1Vo`0000Coool00`000?ooooooo`2>oooo001=oooo;P1Vo`04000006Ko06Ko00002`1V
o`030000oooooooo00;oool30000S_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00002Oooo`030000o`2Ioooo00Coool00`000?oo
ooooo`2>oooo001loooo0P0000[oool300001?ooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o
09Woooooool00oooo`030000oooooooo08koool007Koool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002_ooo`080000
oooooooooooo0000ooooo`2I00001?ooo`030000oooooooo08koool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`03oooo00?o09T0003oool00oooo`<0002>oooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?l0VOooo`04oooo00<0003oooooool0S_oo
o`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo0P00
08ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003ooooo
ool0S_ooo`00Qoooo`D00003oooo00<0003oooooool0S_ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`@00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47791 .30902 L
.47994 .30902 L
.48116 .30902 L
s
.48116 .30902 m
.48128 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24016 .30902 L
.24152 .30902 L
.24276 .30902 L
.24392 .30902 L
.24502 .46353 L
.24618 .46353 L
.24745 .46353 L
.25261 .46353 L
.26171 .46353 L
.30236 .46353 L
.34148 .46353 L
.38307 .46353 L
.42313 .46353 L
.46168 .46353 L
.472 .46353 L
.47703 .46353 L
.47923 .46353 L
.48039 .46353 L
.48162 .46353 L
.48292 .30902 L
.48411 .30902 L
.48647 .30902 L
.49166 .30902 L
.50269 .30902 L
.54044 .30902 L
.58064 .30902 L
.61933 .30902 L
.66047 .30902 L
.70009 .30902 L
.7382 .30902 L
.77876 .30902 L
.81781 .30902 L
.85931 .30902 L
.89929 .30902 L
.93775 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01oooo`0306Kooooooooo00;oool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`07oooo00?o09T0I_ooool00_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03Goool00`1Vooooooooo`02
oooo00<0003oooooool0=?ooo`03o`2I06Kooooo00;oool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool004koool00`1Vooooooooo`0ioooo00?o09T0I_ooool00_oo
o`030000oooooooo08koool004koool00`1Vooooooooo`0ioooo00?o09T0I_ooool00_ooo`80002?
oooo001>oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00;oool00`000?ooooooo`2>oooo001>
oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo00;oool00`000?ooooooo`2>oooo001>oooo00<0
I_ooooooool0>Oooo`03o`2I06Kooooo00;oool00`000?ooooooo`2>oooo001>oooo00<0I_oooooo
ool0>Oooo`03o`2I06Kooooo00;oool20000Soooo`00C_ooo`0306Kooooooooo03Woool00ol0V@1V
ooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`02
oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`02oooo00<0
003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool00ol0V@1Vooooo`02oooo0P0008ooool0
04koool00`1Vooooooooo`0ioooo00?o09T0I_ooool00_ooo`030000oooooooo08koool004koool0
0`1Vooooooooo`0ioooo00?o09T0I_ooool00_ooo`030000oooooooo08koool004koool00`1Voooo
ooooo`0ioooo00?o09T0I_ooool00_ooo`030000oooooooo08koool004koool00`1Vooooooooo`0i
oooo00?o09T0I_ooool00_ooo`80002?oooo001>oooo00<0I_ooooooool0>Oooo`03o`2I06Kooooo
00;oool00`000?ooooooo`2>oooo001>oooo00<0I_ooooooool09Oooo`800004oooo0P0000?oool4
00000oooo`8000000ol0V@1Vooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo
02Coool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00D0003oooooool00000I_l00ooo
o`030000oooooooo08koool004koool00`1Vooooooooo`0Toooo00@0003oooooool00009oooo00<0
003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00C_ooo`0306Kooooooooo02Coool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00000306Kooooooooo00;oool00`000?oo
ooooo`2>oooo001>oooo00<0I_ooooooool09?ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooo06Ko00Coool00`000?ooooooo`2>oooo001>oooo00<0I_ooooooool09Ooo
o`80000:oooo0P0000Coool300001?ooo`030000oooooooo08koool004koool00`1Vooooooooo`0i
oooo00<0I_ooooooool00_ooo`80002?oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00;oool00`000?ooooooo`2>oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool0
0`000?ooooooo`2>oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?oo
ooooo`2>oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool20000Soooo`00C_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`02oooo0P0008ooool004koool00`1Vooooooooo`0ioooo00<0I_ooooooool00_oo
o`030000oooooooo08koool004koool00`1Vooooooooo`0ioooo00<0I_ooooooool00_ooo`030000
oooooooo08koool004koool00`1Vooooooooo`0ioooo00<0I_ooooooool00_ooo`030000oooooooo
08koool004koool00`1Vooooooooo`0ioooo00<0I_ooooooool00_ooo`80002?oooo001>oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001>oooo00<0I_oooooo
ool0:oooo`800004oooo0P0000Coool2000000<0I_ooooooool00_ooo`030000oooooooo08koool0
04koool00`1Vooooooooo`0Zoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00C_ooobd0I_l01000001Vo`1Vo`0000/0I_l00`000?ooooooo`02oooo0`00
08koool007_oool010000?ooooooo`0000Woool2000000?o09Woooooool00_ooo`030000oooooooo
08koool007_oool010000?ooooooo`0000Woool00`000?ooool0V@04oooo00<0003oooooool0S_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_oo
o`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2I
oooooooo00;oool20000Soooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:
oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0
003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`2>oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
000000?o09Woooooool00_ooo`030000oooooooo08koool007Goool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0002>oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool2000000?o09Woooooool00_ooo`030000
oooooooo08koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ool0V@04oooo00<0003oooooool0S_ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:
oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo0P00
08ooool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool0
08[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003ooooo
ool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Wooooo
ool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo0P0008ooool008[oool0
0ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00Qoooo`D00003oooo00<0003oooooool0S_oo
o`00ROooo`030000o`2Ioooo00?oool00`000?ooooooo`2>oooo0029oooo00<0003o09Woool00ooo
o`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`D00002oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00D0
003oooooooooool000000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool00ooo
o`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002
oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47994 .30902 L
.48484 .30902 L
.48618 .30902 L
.48692 .30902 L
.48761 .30902 L
s
.48761 .30902 m
.48768 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24276 .30902 L
.24502 .30902 L
.24745 .30902 L
.24816 .30902 L
.24884 .30902 L
.25012 .46353 L
.25131 .46353 L
.25261 .46353 L
.26171 .46353 L
.30236 .46353 L
.34148 .46353 L
.38307 .46353 L
.42313 .46353 L
.46168 .46353 L
.472 .46353 L
.48162 .46353 L
.48411 .46353 L
.48647 .46353 L
.48777 .46353 L
.48851 .30902 L
.48919 .30902 L
.49166 .30902 L
.50269 .30902 L
.54195 .30902 L
.5797 .30902 L
.61991 .30902 L
.65859 .30902 L
.69973 .30902 L
.73936 .30902 L
.77747 .30902 L
.81803 .30902 L
.85707 .30902 L
.89857 .30902 L
.93855 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool02?ooo`0506Kooooooooooooo000000koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Woool0101Vooooooooo`0000koool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03Koool01@1Vooooooooooooo`00000hoooo00@0I_ooooooool0000k
oooo00<0003oooooool0>_ooo`030000oooooooo01Goool004ooool00`1Vooooooooo`0joooo00@0
I_ooooooool0002@oooo001?oooo00<0I_ooooooool0>_ooo`0306Kooooooooo0080002?oooo001?
oooo00<0I_ooooooool0>_ooo`0406Kooooooooo0000T?ooo`00Coooo`0306Kooooooooo03[oool0
101Vooooooooo`00093oool004ooool00`1Vooooooooo`0joooo00@0I_ooooooool0002@oooo001?
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo0080002?oooo001?oooo00<0I_ooooooool0>_oo
o`0406Kooooooooo0000T?ooo`00Coooo`0306Kooooooooo03[oool0101Vooooooooo`00093oool0
04ooool00`1Vooooooooo`0joooo00@0I_ooooooool0002@oooo001?oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo0080002?oooo001?oooo00<0I_ooooooool0>_ooo`0406Kooooooooo0000T?oo
o`00Coooo`0306Kooooooooo03[oool0101Vooooooooo`00093oool004ooool00`1Vooooooooo`0j
oooo00@0I_ooooooool0002@oooo001?oooo00<0I_ooooooool0>_ooo`0306Kooooooooo0080002?
oooo001?oooo00<0I_ooooooool0>_ooo`0406Kooooooooo0000T?ooo`00Coooo`0306Kooooooooo
02Coool200001?ooo`800003oooo100000?oool200000_ooo`0406Kooooooooo0000T?ooo`00Cooo
o`0306Kooooooooo02?oool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00H0003ooooo
ool0003oool0I_l2oooo00<0003oooooool0S_ooo`00Coooo`0306Kooooooooo02?oool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oool0I_l00_ooo`<0002>oooo001@oooo00<0
I_ooooooool08_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200000_ooo`0406Ko
oooooooo0000T?ooo`00D?ooo`0306Kooooooooo02;oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool01@000?ooooooooooo`1Vo`02oooo00<0003oooooool0S_ooo`00D?ooo`0306Ko
oooooooo02?oool200002_ooo`800004oooo0`000005oooo06Kooooooooo0000093oool0053oool0
0`1Vooooooooo`0ioooo00<0I_ooooooool00P0008ooool0053oool00`1Vooooooooo`0ioooo00@0
I_ooooooool0002@oooo001@oooo00<0I_ooooooool0>Oooo`0406Kooooooooo0000T?ooo`00D?oo
o`0306Kooooooooo03Woool0101Vooooooooo`00093oool0053oool00`1Vooooooooo`0ioooo00<0
I_ooooooool00P0008ooool0053oool00`1Vooooooooo`0ioooo00@0I_ooooooool0002@oooo001@
oooo00<0I_ooooooool0>Oooo`0406Kooooooooo0000T?ooo`00D?ooo`0306Kooooooooo03Woool0
101Vooooooooo`00093oool0053oool00`1Vooooooooo`0ioooo00<0I_ooooooool00P0008ooool0
053oool00`1Vooooooooo`0ioooo00@0I_ooooooool0002@oooo001@oooo00<0I_ooooooool0>Ooo
o`0406Kooooooooo0000T?ooo`00D?ooo`0306Kooooooooo03Woool0101Vooooooooo`00093oool0
053oool00`1Vooooooooo`0ioooo00<0I_ooooooool00P0008ooool0053oool00`1Vooooooooo`0i
oooo00@0I_ooooooool0002@oooo001@oooo00<0I_ooooooool0:Oooo`800004oooo0P0000Coool2
00000_ooo`0406Kooooooooo0000T?ooo`00D?ooo`0306Kooooooooo02Soool010000?ooooooo`00
00Soool01P000?ooooooo`000?ooo`1Vo`;oool00`000?ooooooo`2>oooo001@oooo:`1Vo`040000
06Ko06Ko00002`1Vo`03000006Ko06Ko00;oool30000S_ooo`00Noooo`040000oooooooo00002Ooo
o`800002oooo00Co09Woooooool0002@oooo001koooo00@0003oooooool00009oooo00D0003ooooo
oooooooo09T00_ooo`030000oooooooo08koool007coool200002_ooo`<000001Oooool0VOoooooo
o`00002@oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool00ol0VOooooooo`020000Soooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`03o`2Ioooooooo0080002?oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co
09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00?o09Woooooool00P00
08ooool008coool01?l0VOooooooo`00093oool007Koool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800002oooo00Co09Woooooool0002@oooo001eoooo00@0003oooooool0000:oooo00D0
003oooooooooool000000_ooo`030000ooooo`2I00;oool00`000?ooooooo`2>oooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000ooooo`2I00;oool30000S_ooo`00MOoo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000;oool01?l0VOooooooo`00093oool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool01@000?ooooooooooool0V@02
oooo00<0003oooooool0S_ooo`00M_ooo`800009oooo100000?oool3000000Gooooo09Woooooool0
0000T?ooo`00S?ooo`03o`2Ioooooooo0080002?oooo002<oooo00Co09Woooooool0002@oooo002<
oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00?o09Wooooo
ool00P0008ooool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool00ol0VOooooooo`020000Soooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`03o`2Ioooooooo0080002?oooo002<oooo00Co09Woooooool0002@oooo0027oooo1@00
0004o`2Ioooooooo0000T?ooo`00ROooo`040000ooooooooo`2I0_ooo`030000oooooooo08koool0
08Woool010000?ooooooool0V@;oool30000S_ooo`00ROooo`030000oooooooo09Coool008Woool0
0`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool03?ooo`D00002oooo0P0000?oool500000_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000
oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`09oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003ooooo
ool02Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.48778 .30902 L
.49018 .30902 L
.49235 .30902 L
.49356 .30902 L
s
.49356 .30902 m
.49367 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.24276 .30902 L
.24754 .30902 L
.25016 .30902 L
.25261 .30902 L
.2547 .30902 L
.25587 .30902 L
.25694 .46353 L
.25811 .46353 L
.25939 .46353 L
.26171 .46353 L
.30236 .46353 L
.34148 .46353 L
.38307 .46353 L
.42313 .46353 L
.46168 .46353 L
.48162 .46353 L
.48647 .46353 L
.48914 .46353 L
.49166 .46353 L
.49309 .46353 L
.4939 .46353 L
.49465 .30902 L
.49596 .30902 L
.49737 .30902 L
.50269 .30902 L
.54044 .30902 L
.58064 .30902 L
.61933 .30902 L
.66047 .30902 L
.70009 .30902 L
.7382 .30902 L
.77876 .30902 L
.81781 .30902 L
.85931 .30902 L
.89929 .30902 L
.93775 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool02_ooo`0306Kooooo000000koool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00[oool00ol0V@1Vo`00000>oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0hoooo00<0I_ooool00000>Oooo`03o`2I06Ko000003_oool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`00DOooo`0306Kooooooooo03Woool00ol0V@1Vo`00002@oooo001A
oooo00<0I_ooooooool0>Oooo`04o`2I06Ko00000000Soooo`00DOooo`0306Kooooooooo03Woool0
0ol0V@1Vo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`03o`2I06Ko0000093oool0057oool0
0`1Vooooooooo`0ioooo00?o09T0I_l00000T?ooo`00DOooo`0306Kooooooooo03Woool01?l0V@1V
o`00000008ooool0057oool00`1Vooooooooo`0ioooo00?o09T0I_l00000T?ooo`00DOooo`0306Ko
oooooooo03Woool00ol0V@1Vo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`03o`2I06Ko0000
093oool0057oool00`1Vooooooooo`0ioooo00Co09T0I_l00000002?oooo001Aoooo00<0I_oooooo
ool0>Oooo`03o`2I06Ko0000093oool0057oool00`1Vooooooooo`0ioooo00?o09T0I_l00000T?oo
o`00DOooo`0306Kooooooooo03Woool00ol0V@1Vo`00002@oooo001Aoooo00<0I_ooooooool0>Ooo
o`04o`2I06Ko00000000Soooo`00DOooo`0306Kooooooooo03Woool00ol0V@1Vo`00002@oooo001A
oooo00<0I_ooooooool08_ooo`800004oooo0P0000?oool400000oooo`800003oooo00?o09T0I_l0
0000T?ooo`00DOooo`0306Kooooooooo027oool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00002oooo00?o09T0I_l00000T?ooo`00DOooo`0306Kooooooooo027oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00D0003oooooool0I_ooool00`0008koool0
057oool00`1Vooooooooo`0Qoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800003
oooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo027oool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`02oooo00<0I_ooool00000T?ooo`00DOooo`0306Ko
oooooooo02;oool200002_ooo`800004oooo0`0000;oool00`1Vooooo`00002@oooo001Aoooo00<0
I_ooooooool0>Oooo`0406Kooooo00000000Soooo`00DOooo`0306Kooooooooo03Woool00`1Voooo
o`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0306Kooooo0000093oool0057oool00`1Voooo
ooooo`0ioooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo03Woool0101Vooooo`000000
08ooool0057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo
03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0306Kooooo0000093oool0
057oool00`1Vooooooooo`0ioooo00@0I_ooool00000002?oooo001Aoooo00<0I_ooooooool0>Ooo
o`0306Kooooo0000093oool0057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?ooo`00DOoo
o`0306Kooooooooo03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0406Ko
oooo00000000Soooo`00DOooo`0306Kooooooooo03Woool00`1Vooooo`00002@oooo001Aoooo00<0
I_ooooooool0:?ooo`800004oooo0P0000Coool200000oooo`0306Kooooo0000093oool0057oool0
0`1Vooooooooo`0Woooo00@0003oooooool00008oooo00@0003oooooool00002oooo00<0I_ooool0
0000T?ooo`00DOooobX0I_l01000001Vo`1Vo`0000/0I_l01@00001Vo`1Vo`1Vooooo`030000S_oo
o`00Noooo`040000oooooooo00002Oooo`800003oooo00?o09Woool00000T?ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00;oool00ol0VOooo`00002@oooo001loooo0P0000[oool3
00000_ooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOoo
o`03o`2Ioooo0000093oool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800003
oooo00?o09Woool00000T?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool01P000?ooooooool0VOooo`00093oool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00D0003ooooooooo09Woool00`0008koool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800003oooo00?o09Woool00000T?ooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00;oool00ol0VOooo`00002@oooo001foooo0P00
00Woool400000oooo`<00002oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Sooo
o`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool0
0ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Sooo
o`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008Ooool5
000000Cooooo09Woool0002@oooo0029oooo00L0003ooooooooooooo09Woool00000T?ooo`00ROoo
o`060000ooooooooooooo`2Ioooo0`0008koool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?oo
ooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool500000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`07
oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool0
0`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0
003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
s
.49955 .30902 m
.49968 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.25666 .30902 L
.2593 .30902 L
.26045 .30902 L
.26171 .30902 L
.26301 .46353 L
.26425 .46353 L
.26698 .46353 L
.27279 .46353 L
.28302 .46353 L
.30316 .46353 L
.3438 .46353 L
.38293 .46353 L
.42451 .46353 L
.44538 .46353 L
.46458 .46353 L
.48333 .46353 L
.49277 .46353 L
.49535 .46353 L
.49678 .46353 L
.49813 .46353 L
.49938 .46353 L
.50009 .30902 L
.50074 .30902 L
.50313 .30902 L
.5424 .30902 L
.58015 .30902 L
.62035 .30902 L
.65904 .30902 L
.70018 .30902 L
.7398 .30902 L
.77791 .30902 L
.81847 .30902 L
.85752 .30902 L
.89901 .30902 L
.939 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo03Woool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo
08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo
03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0
I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_oooooo
ool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool0
0`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?oo
ooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Ooo
o`030000oooooooo08koool005?oool00`1Vooooooooo`0Poooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool07oooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool07oooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0008koool005?oool00`1Vooooooooo`0Ooooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo01ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00Doooo`0306Kooooooooo023oool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Ooo
o`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo
08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo
03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0
I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0Voooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo02Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Coooo:01Vo`040000
06Ko06Ko00002`1Vo`03000006Ko06Ko0080I_l30000S_ooo`00Noooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001loooo0P0000[oool300001?ooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`2>oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`2>oooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool30000S_ooo`00MOooo`040000oooooooo00002ooo
o`040000oooooooooooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool007Koool2
00002Oooo`@00003oooo0`0000Coool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo0027oooo1@0000?oool00`000?ooooooo`2>oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo08koool008Woool00`000?ooooooo`03oooo0`0008koool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool02?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0001Coool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo01Ooool200002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49955 .30902 L
.50205 .30902 L
.50342 .30902 L
.50471 .30902 L
.50592 .30902 L
s
.50592 .30902 m
.50605 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.26171 .30902 L
.26425 .30902 L
.26565 .30902 L
.26698 .30902 L
.26773 .30902 L
.26855 .46353 L
.26929 .46353 L
.26998 .46353 L
.27279 .46353 L
.28302 .46353 L
.30316 .46353 L
.34228 .46353 L
.38387 .46353 L
.42393 .46353 L
.46248 .46353 L
.48242 .46353 L
.48727 .46353 L
.48994 .46353 L
.49246 .46353 L
.49316 .46353 L
.49389 .46353 L
.4947 .30902 L
.49545 .30902 L
.49817 .30902 L
.50349 .30902 L
.54124 .30902 L
.58144 .30902 L
.62013 .30902 L
.66127 .30902 L
.70089 .30902 L
.739 .30902 L
.77956 .30902 L
.81861 .30902 L
.86011 .30902 L
.90009 .30902 L
.93855 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`03000006Kooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00_oool00`1Vo`000?l0V@0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<00000I_ooool0>?ooo`0306Ko0000o`2I03[oool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?l0V@2?oooo001D
oooo00<0I_ooooooool0=oooo`0306Ko0000000008ooool005Coool00`1Vooooooooo`0goooo00<0
I_l0003o09T0Soooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?l0V@2?oooo001Doooo00<0
I_ooooooool0=oooo`0306Ko0000o`2I08ooool005Coool00`1Vooooooooo`0goooo00<0I_l00000
0000Soooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?l0V@2?oooo001Doooo00<0I_oooooo
ool0=oooo`0306Ko0000o`2I08ooool005Coool00`1Vooooooooo`0goooo00<0I_l0003o09T0Sooo
o`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000000002?oooo001Doooo00<0I_ooooooool0=ooo
o`0306Ko0000o`2I08ooool005Coool00`1Vooooooooo`0goooo00<0I_l0003o09T0Soooo`00E?oo
o`0306Kooooooooo03Ooool00`1Vo`000?l0V@2?oooo001Doooo00<0I_ooooooool0=oooo`0306Ko
0000000008ooool005Coool00`1Vooooooooo`0goooo00<0I_l0003o09T0Soooo`00E?ooo`0306Ko
oooooooo01ooool200001?ooo`800003oooo100000?oool200001?ooo`0306Ko0000o`2I08ooool0
05Coool00`1Vooooooooo`0Noooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00000oooo`0306Ko0000o`2I08ooool005Coool00`1Vooooooooo`0Noooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`050000oooooooo06Kooooo00<0002>oooo001Doooo00<0
I_ooooooool07_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200000oooo`0406Ko
oooo0000o`2ISoooo`00E?ooo`0306Kooooooooo01koool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`02oooo00@0I_ooool0003o09V?oooo001Doooo00<0I_oooooo
ool07oooo`80000:oooo0P0000Coool300000_ooo`0406Kooooo0000o`2ISoooo`00E?ooo`0306Ko
oooooooo03Koool0101Vooooo`00000008ooool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
003o09V?oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo0000o`2ISoooo`00E?ooo`0306Ko
oooooooo03Koool0101Vooooo`000?l0VHooool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
0000002?oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo0000o`2ISoooo`00E?ooo`0306Ko
oooooooo03Koool0101Vooooo`000?l0VHooool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
003o09V?oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo00000000Soooo`00E?ooo`0306Ko
oooooooo03Koool0101Vooooo`000?l0VHooool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
003o09V?oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo0000o`2ISoooo`00E?ooo`0306Ko
oooooooo03Koool0101Vooooo`00000008ooool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
003o09V?oooo001Doooo00<0I_ooooooool09Oooo`800004oooo0P0000Coool200000oooo`0406Ko
oooo0000o`2ISoooo`00E?ooo`0306Kooooooooo02Coool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool0101Vooooo`000?l0VHooool005CooolW06Ko00@00000I_l0I_l0000;06Ko00D0
0000I_l0I_l0I_ooool00`0008koool007_oool010000?ooooooo`0000Woool200001Oooo`030000
ooooo`2I08koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
09T0S_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooool0V@2>oooo002?oooo0P000003o`2I
oooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Sooo
o`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I
08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool0
08ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool007Koool200001?oo
o`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo09T0S_ooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
09T0S_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo0`0008koool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003ooooo09T0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooool0V@2>oooo001foooo0P0000Woool400000oooo`<00004oooo00<0
003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2I
oooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Sooo
o`030000ooooo`2I08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I
08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`800000
0ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Qoooo`D00003oooo00<0003ooooo
09T0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000
oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo
07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool2
00000oooo`<00004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00009oooo0`0000Goool00`000?oo
ooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0`00
00?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.50682 .30902 L
.5082 .30902 L
.5095 .30902 L
.51074 .30902 L
.51143 .30902 L
s
.51143 .30902 m
.5115 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27003 .30902 L
.27147 .30902 L
.27279 .30902 L
.27399 .46353 L
.27513 .46353 L
.27765 .46353 L
.28302 .46353 L
.30316 .46353 L
.34135 .46353 L
.38199 .46353 L
.42112 .46353 L
.4411 .46353 L
.46271 .46353 L
.47285 .46353 L
.4784 .46353 L
.48357 .46353 L
.48584 .46353 L
.48696 .46353 L
.48799 .46353 L
.48918 .30902 L
.49047 .30902 L
.49273 .30902 L
.50277 .30902 L
.54204 .30902 L
.57979 .30902 L
.61999 .30902 L
.65868 .30902 L
.69982 .30902 L
.73944 .30902 L
.77755 .30902 L
.81811 .30902 L
.85716 .30902 L
.89866 .30902 L
.93864 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooo06Ko00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Woool0101Vooooooooo`0000;oool00ol0VOooooooo`09
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oool0I_l0=_ooo`0406Kooooooooo
00000_ooo`03o`2Ioooooooo03Koool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00EOoo
o`0306Kooooooooo03Coool0101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001Eoooo00<0
I_ooooooool0=?ooo`0306Kooooooooo008000000oooool0VOooo`2<oooo001Eoooo00<0I_oooooo
ool0=?ooo`0406Kooooooooo00000_ooo`03o`2Ioooooooo08_oool005Goool00`1Vooooooooo`0d
oooo00@0I_ooooooool00002oooo00?o09Woooooool0Roooo`00EOooo`0306Kooooooooo03Coool0
101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001Eoooo00<0I_ooooooool0=?ooo`0306Ko
oooooooo008000000oooool0VOooo`2<oooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo
00000_ooo`03o`2Ioooooooo08_oool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool00002
oooo00?o09Woooooool0Roooo`00EOooo`0306Kooooooooo03Coool0101Vooooooooo`0000;oool0
0ol0VOooooooo`2;oooo001Eoooo00<0I_ooooooool0=?ooo`0306Kooooooooo008000000oooool0
VOooo`2<oooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo00000_ooo`03o`2Ioooooooo
08_oool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool00002oooo00?o09Woooooool0Rooo
o`00EOooo`0306Kooooooooo03Coool0101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001E
oooo00<0I_ooooooool0=?ooo`0306Kooooooooo008000000oooool0VOooo`2<oooo001Eoooo00<0
I_ooooooool0=?ooo`0406Kooooooooo00000_ooo`03o`2Ioooooooo08_oool005Goool00`1Voooo
ooooo`0Noooo0P0000Coool200000oooo`@00003oooo0P0000;oool0101Vooooooooo`0000;oool0
0ol0VOooooooo`2;oooo001Eoooo00<0I_ooooooool07Oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool01P000?ooooooo`000?ooo`1Vo`;oool010000?ooooooool0VHgoool005Goool0
0`1Vooooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooo06Ko
00;oool3000000?o09Woooooool0Roooo`00E_ooo`0306Kooooooooo01coool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000;oool0101Vooooooooo`0000;oool00ol0VOooooooo`2;
oooo001Foooo00<0I_ooooooool07?ooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`050000oooooooooooo06Ko00;oool010000?ooooooool0VHgoool005Koool00`1Vooooooooo`0M
oooo0P0000[oool200001?ooo`<000001Oooo`1Vooooooooo`000002oooo00?o09Woooooool0Rooo
o`00E_ooo`0306Kooooooooo03?oool00`1Vooooooooo`02000000?ooooo09Woool0S?ooo`00E_oo
o`0306Kooooooooo03?oool0101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001Foooo00<0
I_ooooooool0<oooo`0406Kooooooooo00000_ooo`03o`2Ioooooooo08_oool005Koool00`1Voooo
ooooo`0coooo00@0I_ooooooool00002oooo00?o09Woooooool0Roooo`00E_ooo`0306Kooooooooo
03?oool00`1Vooooooooo`02000000?ooooo09Woool0S?ooo`00E_ooo`0306Kooooooooo03?oool0
101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001Foooo00<0I_ooooooool0<oooo`0406Ko
oooooooo00000_ooo`03o`2Ioooooooo08_oool005Koool00`1Vooooooooo`0coooo00@0I_oooooo
ool00002oooo00?o09Woooooool0Roooo`00E_ooo`0306Kooooooooo03?oool00`1Vooooooooo`02
000000?ooooo09Woool0S?ooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`0000;oool0
0ol0VOooooooo`2;oooo001Foooo00<0I_ooooooool0<oooo`0406Kooooooooo00000_ooo`03o`2I
oooooooo08_oool005Koool00`1Vooooooooo`0coooo00@0I_ooooooool00002oooo00?o09Wooooo
ool0Roooo`00E_ooo`0306Kooooooooo03?oool00`1Vooooooooo`02000000?ooooo09Woool0S?oo
o`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`0000;oool00ol0VOooooooo`2;oooo001F
oooo00<0I_ooooooool08oooo`800004oooo0P0000Coool200000_ooo`0406Kooooooooo00000_oo
o`03o`2Ioooooooo08_oool005Koool00`1Vooooooooo`0Roooo00@0003oooooool00008oooo00H0
003oooooool0003oool0I_l2oooo00@0003ooooooooo09V=oooo001Foooo9@1Vo`04000006Ko06Ko
00002`1Vo`03000006Ko06Ko00;oool3000000?o09Woooooool0Roooo`00Noooo`040000oooooooo
00002Oooo`800005oooo00@0003ooooooooo09V=oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`040000ooooooooo`2ISOooo`00O?ooo`80000:oooo0`0000Coool010000?oo
ooooool0VHgoool008ooool2000000?ooooo09Woool0S?ooo`00Soooo`040000ooooooooo`2ISOoo
o`00Soooo`040000ooooooooo`2ISOooo`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0
003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=
oooo002?oooo0P000003ooooo`2Ioooo08coool008ooool010000?ooooooool0VHgoool008ooool0
10000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool2000000?ooooo09Wo
ool0S?ooo`00Soooo`040000ooooooooo`2ISOooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool010000?ooooooool0VHgoool007Goool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`040000ooooooooo`2ISOooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`000003o`2I
oooooooo08_oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00@0
003ooooooooo09V=oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`040000ooooooooo`2ISOooo`00M_ooo`800009oooo100000?oool300001?oo
o`040000ooooooooo`2ISOooo`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0003ooooo
oooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?
oooo0P000003ooooo`2Ioooo08coool008ooool010000?ooooooool0VHgoool008ooool010000?oo
ooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool2000000?ooooo09Woool0S?oo
o`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000
ooooooooo`2ISOooo`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0003ooooooooo09V=
oooo0027oooo1@0000?oool010000?ooooooool0VHgoool008Woool00`000?ooooooo`03oooo00@0
003ooooooooo09V=oooo0029oooo00<0003oooooool00oooo`<000000ol0VOooooooo`2;oooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`<00004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo
00002Oooo`<00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.5095 .30902 L
.51188 .30902 L
.51441 .30902 L
.51564 .30902 L
.5168 .30902 L
.51784 .30902 L
s
.51784 .30902 m
.51795 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27279 .30902 L
.27513 .30902 L
.27765 .30902 L
.2784 .30902 L
.2791 .30902 L
.28042 .46353 L
.28166 .46353 L
.28302 .46353 L
.30316 .46353 L
.3438 .46353 L
.38293 .46353 L
.42451 .46353 L
.44538 .46353 L
.45453 .46353 L
.46458 .46353 L
.46926 .46353 L
.47427 .46353 L
.47671 .46353 L
.47901 .46353 L
.48001 .46353 L
.48108 .46353 L
.48224 .30902 L
.48333 .30902 L
.50313 .30902 L
.54088 .30902 L
.58108 .30902 L
.61977 .30902 L
.66091 .30902 L
.70054 .30902 L
.73864 .30902 L
.7792 .30902 L
.81825 .30902 L
.85975 .30902 L
.89973 .30902 L
.9382 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`050000oooooooooooo06Ko00[oool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Ooool00`1Vooooooooo`02oooo00D0003ooooo
oooooooo09T02_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`050000oooooooooooo06Ko
03;oool00`1Vooooooooo`02oooo00D0003ooooooooooooo09T0=oooo`030000oooooooo03[oool0
0`000?ooooooo`0Eoooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool01@000?oo
ooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool200000_oo
o`03o`2Ioooooooo08[oool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`050000
ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`050000
ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`050000
ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`800002
oooo00?o09Woooooool0R_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00D0
003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00D0
003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00D0
003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P00
00;oool00ol0VOooooooo`2:oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
1@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
1@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
1@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool2
00000_ooo`03o`2Ioooooooo08[oool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`050000ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0Loooo0P0000Coool200000ooo
o`@00003oooo0P00000306Kooooooooo00;oool01@000?ooooooooooool0V@2<oooo001Goooo00<0
I_ooooooool06oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool01@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool06oooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`000003ooooo`2Ioooo08_oool0
05Ooool00`1Vooooooooo`0Koooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800000
0`1Vooooooooo`02oooo00D0003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo01_oool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooo`1Vo`04oooo00D0003ooooo
oooooooo09T0S?ooo`00Eoooo`0306Kooooooooo01coool200002_ooo`800004oooo0`0000Coool0
1@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool2
00000_ooo`03o`2Ioooooooo08[oool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`050000ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`050000ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`050000ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`800002oooo00?o09Woooooool0R_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00D0003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00D0003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00D0003ooooooooooooo09T0S?ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo0P0000;oool00ol0VOooooooo`2:oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo
00;oool01@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo
00;oool01@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo
00;oool01@000?ooooooooooool0V@2<oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo
00;oool200000_ooo`03o`2Ioooooooo08[oool005Ooool00`1Vooooooooo`0`oooo00<0I_oooooo
ool00_ooo`050000ooooooooooooo`2I08coool005Ooool00`1Vooooooooo`0Roooo0P0000Coool2
00001?ooo`8000000`1Vooooooooo`02oooo00D0003ooooooooooooo09T0S?ooo`00Eoooo`0306Ko
oooooooo027oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool01@000?oooooooooo
ool0V@2<oooo001Goooo901Vo`04000006Ko06Ko00002`1Vo`030000oooooooo00;oool300000_oo
o`03o`2Ioooooooo08Woool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo00;oool00ol0VOooooooo`29oooo001loooo0P0000[oool300001?ooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOooooooo`29oooo002?
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o
09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool0
08ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Wooooo
ool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOoo
ooooo`29oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo001eoooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
00;oool00ol0VOooooooo`29oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001Oooo`030000oooooooo00;oool00ol0VOooooooo`29oooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo00;oool00ol0VOoo
ooooo`29oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool00_ooo`03o`2I
oooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool200000oooo`03o`2Ioooooooo
08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool0
08ooool200000oooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Wooooo
ool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool008ooool0
0`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Qoooo`D00003oooo00<0003oooooool00_oo
o`03o`2Ioooooooo08Woool008Woool00`000?ooooooo`03oooo00<0003oooooool00_ooo`03o`2I
oooooooo08Woool008Woool00`000?ooooooo`03oooo0`0000;oool00ol0VOooooooo`29oooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo0P00
00Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?oo
ooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003ooooo
ool00009oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00ooo
o`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002
oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51441 .30902 L
.51896 .30902 L
.52148 .30902 L
.52221 .30902 L
.52289 .30902 L
s
.52289 .30902 m
.52302 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28025 .30902 L
.28302 .30902 L
.28425 .30902 L
.28542 .30902 L
.28606 .46353 L
.28676 .46353 L
.288 .46353 L
.29349 .46353 L
.30316 .46353 L
.3438 .46353 L
.38293 .46353 L
.42451 .46353 L
.44538 .46353 L
.45453 .46353 L
.46458 .46353 L
.46926 .46353 L
.47183 .46353 L
.4731 .46353 L
.47427 .46353 L
.47537 .46353 L
.47654 .30902 L
.47771 .30902 L
.47901 .30902 L
.48333 .30902 L
.50313 .30902 L
.54333 .30902 L
.58202 .30902 L
.62316 .30902 L
.66278 .30902 L
.70089 .30902 L
.74145 .30902 L
.7805 .30902 L
.822 .30902 L
.86198 .30902 L
.90044 .30902 L
.94136 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00<0I_ooooooool00ooo
o`030000oooooooo00?oool00ol0VOooooooo`06oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool00oooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo03?oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00FOoo
o`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`800004oooo00?o09Wooooo
ool0R?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000
oooooooo00?oool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo
00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo02goool0
0`1Vooooooooo`03oooo0P0000Coool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Ooo
o`0306Kooooooooo00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Ko
oooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
05Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool200001?ooo`03o`2I
oooooooo08Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool0
0`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo02goool00`1Voooo
ooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`800004oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo
02goool00`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool005Woool0
0`1Vooooooooo`0Joooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo01Woool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oool0I_l00004oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool005Woool00`1Vooooooooo`0Ioooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`0306Ko0000oooo00?oool300000oooo`03o`2Ioooooooo08Soool005Woool00`1Vooooooooo`0I
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool005Woool00`1Vooooooooo`0Ioooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<00000I_ooool01?ooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo001Ioooo00<0I_ooooooool06_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool2
00001?ooo`03o`2Ioooooooo08Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00ooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Ko
oooooooo00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo
02goool00`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool005Woool0
0`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`800004oooo00?o09Woooooool0R?ooo`00FOoo
o`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03
oooo0P0000Coool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo
00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00FOooo`0306Kooooooooo02goool0
0`1Vooooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool005Woool00`1Voooo
ooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001I
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool200001?ooo`03o`2Ioooooooo08Soool0
05Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo001Ioooo00<0I_ooooooool08?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo00?oool00ol0VOooooooo`28oooo001Ioooo00<0I_ooooooool07oooo`040000oooooooo
00002?ooo`040000oooo06Ko00001?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001I
oooo8P1Vo`04000006Ko06Ko00002`1Vo`030000oooooooo00;oool300000oooo`03o`2Ioooooooo
08Soool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo001loooo0P0000[oool300001?ooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0000?oool00ol0VOoo
ooooo`28oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo00?oool00ol0VOooooooo`28oooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool0
0`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?oo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Qoooo`D00003oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool008Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08Woool00`000?ooooooo`03oooo0`0000?oool00ol0VOooooooo`28oooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0
003oooooool00009oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51896 .30902 L
.52417 .30902 L
.5256 .30902 L
.52712 .30902 L
.52786 .30902 L
.52856 .30902 L
s
.52856 .30902 m
.52869 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28302 .30902 L
.288 .30902 L
.28936 .30902 L
.29012 .30902 L
.29083 .30902 L
.2915 .30902 L
.29222 .46353 L
.29349 .46353 L
.30316 .46353 L
.3438 .46353 L
.38293 .46353 L
.42451 .46353 L
.44538 .46353 L
.45453 .46353 L
.45938 .46353 L
.46458 .46353 L
.46718 .46353 L
.46846 .46353 L
.46965 .46353 L
.47072 .30902 L
.47186 .30902 L
.47427 .30902 L
.48333 .30902 L
.50313 .30902 L
.54088 .30902 L
.58108 .30902 L
.61977 .30902 L
.66091 .30902 L
.70054 .30902 L
.73864 .30902 L
.7792 .30902 L
.81825 .30902 L
.85975 .30902 L
.89973 .30902 L
.9382 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Coool00`1Vooooooooo`05oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`05oooo00<0I_ooooooool01?oo
o`030000oooooooo00Coool00ol0VOooooooo`05oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool01?ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo03;oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00F_oo
o`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`800005oooo00?o09Wooooo
ool0Qoooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool01?oo
o`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo
00Coool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo02_oool0
0`1Vooooooooo`04oooo0P0000Goool00ol0VOooooooo`27oooo001Joooo00<0I_ooooooool0:ooo
o`0306Kooooooooo00Coool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00F_ooo`0306Ko
oooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
05[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00ol0VOoo
ooooo`27oooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool200001Oooo`03o`2I
oooooooo08Ooool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo02_oool00`1Voooo
ooooo`04oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0[
oooo00<0I_ooooooool01?ooo`800005oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo
02_oool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool005[oool0
0`1Vooooooooo`0Ioooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo01Soool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@00000I_ooool00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool005[oool00`1Vooooooooo`0Hoooo00@0003oooooool00009oooo00<0003oooooool00_oo
o`0406Kooooooooo00001?ooo`<00004oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo
01Soool010000?ooooooo`0000[oool01@000?ooooooooooo`1Vo`0200001Oooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo001Joooo00<0I_ooooooool06?ooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`0306Ko0000oooo00Goool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00F_ooo`0306Kooooooooo01Woool200002_ooo`800003oooo00@0I_l0000000000004
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0Zoooo00<0
I_ooooooool01Oooo`800005oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo02[oool0
0`1Vooooooooo`05oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool005[oool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool01Oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo001J
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo0P0000Goool00ol0VOoo
ooooo`27oooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool01Oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo001Joooo00<0I_ooooooool0:_oo
o`0306Kooooooooo00Goool200001Oooo`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0Z
oooo00<0I_ooooooool01Oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo001Joooo00<0
I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`04oooo00?o09Woooooool0Qooo
o`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool005[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Oooo`800005oooo00?o
09Woooooool0Qoooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool005[oool00`1Vooooooooo`0Ooooo0P0000Coool200000ooo
o`0306Ko0000000000Goool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00F_ooo`0306Ko
oooooooo01koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00F_ooob40I_l01000001Vo`1Vo`0000T0I_l2oooo00<0003ooooo
ool00_ooo`<00004oooo00?o09Woooooool0Qoooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool007coool200002_oo
o`<00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOooooooo`27oooo002?
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P00
00Goool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
08ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool0
0ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOooooooo`27oooo002?oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool0
0ol0VOooooooo`27oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool300001?ooo`03o`2Ioooooooo08Ooool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005
oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
08ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Wooooo
ool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo0027oooo1@0000?oool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00ROooo`030000oooooooo00?oool300001?ooo`03o`2I
oooooooo08Ooool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOoo
o`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007Ooool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000B
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P00
00Woool400000oooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.51896 .30902 L
.52455 .30902 L
.52986 .30902 L
.53217 .30902 L
.53344 .30902 L
.53463 .30902 L
.53531 .30902 L
s
.53531 .30902 m
.53539 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29088 .30902 L
.29349 .30902 L
.2957 .30902 L
.29695 .30902 L
.29809 .46353 L
.29933 .46353 L
.30069 .46353 L
.30316 .46353 L
.3438 .46353 L
.38293 .46353 L
.40291 .46353 L
.42451 .46353 L
.43466 .46353 L
.44538 .46353 L
.45453 .46353 L
.45704 .46353 L
.45973 .46353 L
.46103 .46353 L
.46227 .46353 L
.46337 .46353 L
.46458 .30902 L
.4658 .30902 L
.46691 .30902 L
.46943 .30902 L
.47398 .30902 L
.48435 .30902 L
.50536 .30902 L
.54499 .30902 L
.58309 .30902 L
.62365 .30902 L
.6627 .30902 L
.7042 .30902 L
.74418 .30902 L
.78265 .30902 L
.82356 .30902 L
.86297 .30902 L
.90085 .30902 L
.94119 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Goool00`1Vooooooooo`04oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`03oooo00<0I_ooooooool01_oo
o`030000oooooooo00Koool00ol0VOooooooo`03oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool01Oooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo033oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Fooo
o`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`800007oooo00?o09Wooooo
ool0QOooo`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo
00Koool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Foooo`0306Kooooooooo02Soool0
0`1Vooooooooo`06oooo0P0000Ooool00ol0VOooooooo`25oooo001Koooo00<0I_ooooooool0:?oo
o`0306Kooooooooo00Koool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Foooo`0306Ko
oooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
05_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool200001oooo`03o`2I
oooooooo08Goool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool0
0`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Foooo`0306Kooooooooo02Soool00`1Voooo
ooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool005_oool00`1Vooooooooo`0X
oooo00<0I_ooooooool01_ooo`800007oooo00?o09Woooooool0QOooo`00Foooo`0306Kooooooooo
02Soool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool005_oool0
0`1Vooooooooo`0Hoooo0P0000Coool200000oooo`@000000oooo`1Vooooo`0200001Oooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo001Koooo00<0I_ooooooool05oooo`040000oooooooo
00002?ooo`030000oooooooo00;oool01@1Vo`000?ooooooo`000004oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool005_oool00`1Vooooooooo`0Goooo00@0003oooooool00009oooo00D0
003oooooooooool0I_l00oooo`030000oooooooo00;oool300001_ooo`03o`2Ioooooooo08Goool0
05coool00`1Vooooooooo`0Foooo00@0003oooooool0000:oooo00D0003oooooool0I_ooool00P00
00Goool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00G?ooo`0306Kooooooooo01Koool0
10000?ooooooo`0000Soool020000?ooooooo`000?ooo`1Vooooo`0000Koool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00G?ooo`0306Kooooooooo01Ooool200002_ooo`800002oooo00<0
I_ooool000000P0000Coool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00G?ooo`0306Ko
oooooooo02Ooool00`1Vooooooooo`06oooo0P0000Ooool00ol0VOooooooo`25oooo001Loooo00<0
I_ooooooool09oooo`0306Kooooooooo00Koool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2I
oooooooo08Goool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool2
00001oooo`03o`2Ioooooooo08Goool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_oo
o`030000oooooooo00Koool00ol0VOooooooo`25oooo001Loooo00<0I_ooooooool09oooo`0306Ko
oooooooo00Koool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00G?ooo`0306Kooooooooo
02Ooool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool005coool0
0`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`800007oooo00?o09Woooooool0QOooo`00G?oo
o`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000oooooooo00Koool0
0ol0VOooooooo`25oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06
oooo0P0000Ooool00ol0VOooooooo`25oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo
00Koool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00G?ooo`0306Kooooooooo01goool2
00001?ooo`800002oooo00@0I_ooool000000005oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool005coool00`1Vooooooooo`0Loooo00@0003oooooool00007oooo00D0I_l0003oooooool0
00001?ooo`030000oooooooo00Koool00ol0VOooooooo`25oooo001Loooo7`1Vo`04000006Ko06Ko
0000201Vo`?oool00`000?ooooooo`02oooo0`0000Koool00ol0VOooooooo`25oooo001koooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Nooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`800007oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool200001ooo
o`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Sooo
o`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2I
oooooooo08Goool008ooool200001oooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?
oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool200001oooo`03o`2Ioooooooo
08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00M_ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<00006oooo00?o09Woooooool0QOooo`00MOoo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`06oooo00?o
09Woooooool0QOooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00M_ooo`800009oooo1000
00?oool300001?ooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool0
0ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool0
0`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo002?oooo0P0000Ooool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Sooo
o`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?
oooo0P0000Ooool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008Ooool500000oooo`030000oooooooo00Koool00ol0VOooooooo`25oooo0029oooo00<0
003oooooool00oooo`030000oooooooo00Koool00ol0VOooooooo`25oooo0029oooo00<0003ooooo
ool00oooo`<00006oooo00?o09Woooooool0QOooo`00ROooo`030000oooooooo09Coool008Woool0
0`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool03Oooo`800004oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo
00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`00
00_oool01@000?ooooooooooo`00001joooo001hoooo00D0003oooooooooool000005Oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Goooo0P0000Woool400000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53057 .30902 L
.53543 .30902 L
.53755 .30902 L
.53984 .30902 L
.54107 .30902 L
s
.54107 .30902 m
.54119 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30059 .30902 L
.30182 .30902 L
.30246 .30902 L
.30316 .30902 L
.30442 .46353 L
.3056 .46353 L
.30791 .46353 L
.31304 .46353 L
.32392 .46353 L
.34309 .46353 L
.38467 .46353 L
.40553 .46353 L
.42473 .46353 L
.44348 .46353 L
.45292 .46353 L
.45551 .46353 L
.45693 .46353 L
.45763 .46353 L
.45828 .46353 L
.45953 .30902 L
.4602 .30902 L
.4609 .30902 L
.46328 .30902 L
.50104 .30902 L
.54124 .30902 L
.57993 .30902 L
.62107 .30902 L
.66069 .30902 L
.6988 .30902 L
.73936 .30902 L
.7784 .30902 L
.8199 .30902 L
.85988 .30902 L
.89835 .30902 L
.93927 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Ooool00`1Vooooooooo`02oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`02oooo00<0I_ooooooool01ooo
o`030000oooooooo00Ooool00ol0VOooooooo`02oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool01oooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo02ooool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00GOoo
o`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`800008oooo00?o09Wooooo
ool0Q?ooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo
00Ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo02Goool0
0`1Vooooooooo`07oooo0P0000Soool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09Ooo
o`0306Kooooooooo00Ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Ko
oooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
05goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool200002?ooo`03o`2I
oooooooo08Coool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo02Goool00`1Voooo
ooooo`07oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool005goool00`1Vooooooooo`0U
oooo00<0I_ooooooool01oooo`800008oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo
02Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool005goool0
0`1Vooooooooo`0Foooo0P0000Coool200000oooo`@000000`1Vooooooooo`0200001Oooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool05Oooo`040000oooooooo
00002?ooo`070000oooooooooooo06Kooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool005goool00`1Vooooooooo`0Eoooo00@0003oooooool00009
oooo00<0003oool0I_l01Oooo`030000oooooooo00;oool300001oooo`03o`2Ioooooooo08Coool0
05goool00`1Vooooooooo`0Eoooo00@0003oooooool0000:oooo00<00000I_ooool00_ooo`800005
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool005goool00`1Vooooooooo`0Eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool05_ooo`80000:oooo0P00000406Ko
oooooooooooo0`0000Coool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Ko
oooooooo02Coool00`1Vooooooooo`08oooo0P0000Soool00ol0VOooooooo`24oooo001Moooo00<0
I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool2
00002?ooo`03o`2Ioooooooo08Coool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?oo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09?ooo`0306Ko
oooooooo00Soool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo
02Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool005goool0
0`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`800008oooo00?o09Woooooool0Q?ooo`00GOoo
o`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08
oooo0P0000Soool00ol0VOooooooo`24oooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo
00Soool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00GOooo`0306Kooooooooo01coool2
00001?ooo`800000101Vooooooooooooo`800005oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool005goool00`1Vooooooooo`0Koooo00@0003oooooool00005oooo00@0I_ooooooool00002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo001Moooo7P1V
o`04000006Ko06Ko00001P1Vo`Goool00`000?ooooooo`02oooo0`0000Ooool00ol0VOooooooo`24
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool200002?oo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<00007oooo00?o09Wooooo
ool0Q?ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008Ooool500000oooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo0029oooo00<0003oooooool00oooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo0029
oooo00<0003oooooool00oooo`<00007oooo00?o09Woooooool0Q?ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?ooo`800004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000
oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`<00004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000
oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53057 .30902 L
.53984 .30902 L
.54444 .30902 L
.54576 .30902 L
.54701 .30902 L
s
.54701 .30902 m
.54712 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
.30992 .46353 L
.31059 .46353 L
.31304 .46353 L
.32392 .46353 L
.34309 .46353 L
.38221 .46353 L
.40219 .46353 L
.4238 .46353 L
.43394 .46353 L
.43949 .46353 L
.44466 .46353 L
.44908 .46353 L
.45035 .46353 L
.45156 .46353 L
.45264 .30902 L
.45382 .30902 L
.46386 .30902 L
.50465 .30902 L
.54391 .30902 L
.58166 .30902 L
.62187 .30902 L
.66055 .30902 L
.70169 .30902 L
.74132 .30902 L
.77943 .30902 L
.81999 .30902 L
.85903 .30902 L
.90053 .30902 L
.94051 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Woool0101Vooooooooo`0000koool0
0`000?ooooooo`0<oooo00@0003oooooool0I_l;oooo00<0003oooooool02Oooo`04o`2Ioooooooo
00003_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool02Oooo`0306Kooooooooo027oool00`1Voooo
ooooo`09oooo00<0003oooooool02Oooo`03o`2Ioooooooo02goool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Ooo
o`80000:oooo00?o09Woooooool0P_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0
I_ooooooool02Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_oooooo
ool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo0P0000[oool00ol0VOooooooo`22oooo001O
oooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo
00Woool200002_ooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_oooooo
ool02Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool08Ooo
o`0306Kooooooooo00Woool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Goooo`0306Ko
oooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
05ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`80000:oooo00?o09Woooooool0P_oo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool005ooool00`1Vooooooooo`0Doooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Goooo`0306Kooooooooo01?oool0
10000?ooooooo`0000Soool00`000?ooo`1Vo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Coooo00@0003oooooool00009
oooo00<00000I_ooool01Oooo`030000oooooooo00;oool300002Oooo`03o`2Ioooooooo08;oool0
05ooool00`1Vooooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Coooo00@0
003oooooool00008oooo00@0003oool0I_l00003oooo00<0003oooooool01?ooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool05?ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool08Ooo
o`0306Kooooooooo00Woool200002_ooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Q
oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0
I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00?o09Woooooool0P_oo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`80000:oooo00?o
09Woooooool0P_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Ooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Goooo`0306Kooooooooo
027oool00`1Vooooooooo`09oooo0P0000[oool00ol0VOooooooo`22oooo001Ooooo00<0I_oooooo
ool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool200002_oo
o`03o`2Ioooooooo08;oool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_ooooooool06_ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001Ooooo00<0I_oooooo
ool06Oooo`040000oooooooo00001?ooo`0506Kooooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool005oooolL06Ko00@00000I_l0I_l00005
06Ko1_ooo`030000oooooooo00;oool300002Oooo`03o`2Ioooooooo08;oool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo00Woool00ol0VOooooooo`22
oooo001loooo0P0000[oool300001?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001foooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001e
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0000Woool00ol0VOooooooo`22oooo001eoooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001foooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool2
00002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_oo
o`00Qoooo`D00003oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Woool00`000?ooooooo`03
oooo0`0000Woool00ol0VOooooooo`22oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000
oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54444 .30902 L
.54934 .30902 L
.5508 .30902 L
.55216 .30902 L
.55339 .30902 L
s
.55339 .30902 m
.55346 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31054 .30902 L
.31304 .30902 L
.31444 .30902 L
.31523 .30902 L
.31597 .46353 L
.31727 .46353 L
.31865 .46353 L
.32392 .46353 L
.34309 .46353 L
.38467 .46353 L
.40553 .46353 L
.42473 .46353 L
.43443 .46353 L
.43916 .46353 L
.44348 .46353 L
.4446 .46353 L
.44582 .46353 L
.44697 .30902 L
.44804 .30902 L
.45292 .30902 L
.46328 .30902 L
.50255 .30902 L
.5403 .30902 L
.5805 .30902 L
.61919 .30902 L
.66033 .30902 L
.69996 .30902 L
.73806 .30902 L
.77863 .30902 L
.81767 .30902 L
.85917 .30902 L
.89915 .30902 L
.93762 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00[oool00`1Vooooo`00000>oooo00<0
003oooooool03?ooo`030000oooo06Ko00coool00`000?ooooooo`0;oooo00?o09T0003oool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool02_ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:
oooo00<0003oooooool02oooo`03o`2Ioooooooo02_oool00`000?ooooooo`0joooo00<0003ooooo
ool05Oooo`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`80000<
oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Ooooo00<0I_oooooo
ool02_ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001Poooo00<0I_ooooooool07ooo
o`0306Kooooooooo00[oool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00H?ooo`0306Ko
oooooooo01ooool00`1Vooooooooo`0:oooo0P0000coool00ol0VOooooooo`20oooo001Poooo00<0
I_ooooooool07oooo`0306Kooooooooo00[oool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool2
00003?ooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_oo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo001Poooo00<0I_ooooooool07oooo`0306Ko
oooooooo00[oool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo
01ooool00`1Vooooooooo`0:oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0063oool0
0`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`80000<oooo00?o09Woooooool0P?ooo`00H?oo
o`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool0063oool00`1Vooooooooo`0Coooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo01;oool010000?oo
ooooo`0000Soool00`00001Vooooo`03oooo00@0003oooooool00004oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Boooo00@0003oooooool00008oooo00<0
I_l0003oool01_ooo`030000oooooooo00;oool300002oooo`03o`2Ioooooooo083oool0063oool0
0`1Vooooooooo`0Boooo00@0003oooooool00008oooo00<0I_ooool000001?ooo`800005oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Boooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo001Poooo00<0I_ooooooool04oooo`800009oooo00<0I_l0000000001?oo
o`<00004oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0N
oooo00<0I_ooooooool02oooo`80000<oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo
01koool00`1Vooooooooo`0;oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0063oool0
0`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo0P0000coool0
0ol0VOooooooo`20oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Noooo00<0
I_ooooooool02oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001Poooo00<0I_oooooo
ool07_ooo`0306Kooooooooo00_oool200003?ooo`03o`2Ioooooooo083oool0063oool00`1Voooo
ooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001P
oooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`80000<
oooo00?o09Woooooool0P?ooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool0063oool00`1Vooooooooo`0Ioooo0P0000?oool0
0`1Vo`0000000004oooo0P0000Goool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00H?oo
o`0306Kooooooooo01Soool010000?ooooooo`0000;oool00`1Vooooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0063ooolK06Ko00@00000I_l0
I_l0000306Ko2?ooo`030000oooooooo00;oool300002oooo`03o`2Ioooooooo083oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo001loooo0P0000[oool300001?ooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0000_oool00ol0VOooooooo`20oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?oo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Qoooo`D00003oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Woool00`000?oo
ooooo`03oooo0`0000_oool00ol0VOooooooo`20oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001foooo00<0
003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0=oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?oo
ooooo`0000_oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Coool0
07Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`800004oooo0P0000Coool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002Ooo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000
oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55195 .30902 L
.55472 .30902 L
.55607 .30902 L
.55734 .30902 L
.55848 .30902 L
s
.55848 .30902 m
.55861 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.31304 .30902 L
.31574 .30902 L
.31865 .30902 L
.32006 .30902 L
.32076 .30902 L
.3214 .30902 L
.3226 .46353 L
.32392 .46353 L
.34309 .46353 L
.38221 .46353 L
.40219 .46353 L
.4127 .46353 L
.4238 .46353 L
.43374 .46353 L
.43647 .46353 L
.43797 .46353 L
.43871 .46353 L
.43939 .46353 L
.44071 .30902 L
.44141 .30902 L
.44215 .30902 L
.44466 .30902 L
.46386 .30902 L
.50161 .30902 L
.54182 .30902 L
.5805 .30902 L
.62164 .30902 L
.66127 .30902 L
.69938 .30902 L
.73994 .30902 L
.77898 .30902 L
.82048 .30902 L
.86046 .30902 L
.89893 .30902 L
.93985 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool03?ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<
oooo00<0003oooooool03?ooo`03o`2Ioooooooo02[oool00`000?ooooooo`0joooo00<0003ooooo
ool05Oooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80000=
oooo00?o09Woooooool0Ooooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool03?ooo`030000oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Ko
oooooooo01_oool00`1Vooooooooo`0<oooo0P0000goool00ol0VOooooooo`1ooooo001Roooo00<0
I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0<oooo00?o09Woooooool0Oooo
o`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo
00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool2
00003Oooo`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Kooooooooo
01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool006;oool0
0`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80000=oooo00?o09Woooooool0Ooooo`00H_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`03o`2Ioooooooo
07ooool006;oool00`1Vooooooooo`0Aoooo0P0000Coool200000_ooo`0306Ko0000000000800003
oooo0P0000Goool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Kooooooooo
013oool010000?ooooooo`0000Ooool00`1Vo`000?ooo`04oooo00@0003oooooool00004oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0@oooo00@0003ooooo
ool00007oooo00<0I_ooool000001oooo`030000oooooooo00;oool300003?ooo`03o`2Ioooooooo
07ooool006;oool00`1Vooooooooo`0@oooo00@0003oooooool00007oooo00@0I_ooooooool00004
oooo0P0000Goool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Kooooooooo
013oool010000?ooooooo`0000Ooool01@1Vo`000?ooooooo`000003oooo00<0003oooooool01?oo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool04Oooo`800008
oooo00@0I_ooool000000004oooo0`0000Coool00`000?ooooooo`0<oooo00?o09Woooooool0Oooo
o`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo0P0000goool00ol0VOooooooo`1o
oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0<oooo00?o
09Woooooool0Ooooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool200003Oooo`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0
I_ooooooool03?ooo`030000oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_oooooo
ool06oooo`0306Kooooooooo00coool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`03o`2Ioooooooo
07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80000=oooo00?o09Wooooo
ool0Ooooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000
oooooooo00coool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Kooooooooo01_oool0
0`1Vooooooooo`0<oooo0P0000goool00ol0VOooooooo`1ooooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00H_ooo`0306Ko
oooooooo01Ooool200000_ooo`0406Kooooo000000001?ooo`800005oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool006;oool00`1Vooooooooo`0Foooo00H0003oooooool0003oool0I_l6
oooo00@0003oooooool00004oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool006;ooolI
06Ko00@00000I_l0I_l0000206Ko2Oooo`030000oooooooo00;oool300003?ooo`03o`2Ioooooooo
07ooool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
00coool00ol0VOooooooo`1ooooo001loooo0P0000[oool300001?ooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo002?oooo0P0000goool00ol0VOooooooo`1ooooo002?oooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Oooo
o`00Soooo`80000=oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?oo
ooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=
oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0000coool00ol0VOoo
ooooo`1ooooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo00coool00ol0VOooooooo`1ooooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo00coool00ol0VOooooooo`1ooooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool0
08ooool200003Oooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Wooooo
ool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool200003Ooo
o`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<
oooo00?o09Woooooool0Ooooo`00Qoooo`D00003oooo00<0003oooooool03?ooo`03o`2Ioooooooo
07ooool008Woool00`000?ooooooo`03oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool0
08Woool00`000?ooooooo`03oooo0`0000coool00ol0VOooooooo`1ooooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000
oooooooo00002Oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55436 .30902 L
.55972 .30902 L
.56236 .30902 L
.56366 .30902 L
.56486 .30902 L
s
.56486 .30902 m
.56496 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32145 .30902 L
.32392 .30902 L
.32499 .30902 L
.32617 .30902 L
.32728 .30902 L
.32831 .46353 L
.32951 .46353 L
.3306 .46353 L
.33304 .46353 L
.34309 .46353 L
.38315 .46353 L
.40153 .46353 L
.41196 .46353 L
.4217 .46353 L
.42664 .46353 L
.43133 .46353 L
.43258 .46353 L
.43326 .46353 L
.43391 .46353 L
.4346 .30902 L
.43537 .30902 L
.43672 .30902 L
.44164 .30902 L
.46271 .30902 L
.50139 .30902 L
.54253 .30902 L
.58216 .30902 L
.62027 .30902 L
.66083 .30902 L
.69987 .30902 L
.74137 .30902 L
.78135 .30902 L
.81982 .30902 L
.86074 .30902 L
.90014 .30902 L
.93803 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`00001Vooooo`0<oooo00<0
003oooooool02_ooo`0306Kooooo000000koool00`000?ooooooo`0<oooo00<0003o09Woool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool03Oooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo00<0003oooooool03Oooo`03o`2Ioooooooo02Woool00`000?ooooooo`0joooo00<0003ooooo
ool05Oooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`80000>
oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0Hoooo00<0I_oooooo
ool03_ooo`030000oooooooo00goool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool06?oo
o`0306Kooooooooo00koool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Hoooo`0306Ko
oooooooo01Soool00`1Vooooooooo`0>oooo0P0000koool00ol0VOooooooo`1noooo001Soooo00<0
I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo
00goool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool2
00003_ooo`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_oo
o`030000oooooooo00goool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool06?ooo`0306Ko
oooooooo00koool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo
01Soool00`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool006?oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`80000>oooo00?o09Woooooool0O_ooo`00Hooo
o`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2Ioooooooo
07koool006?oool00`1Vooooooooo`0@oooo0P0000Coool2000000<0I_ooooooool0100000?oool2
00001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool03ooo
o`040000oooooooo00001Oooo`0406Kooooooooo00001Oooo`040000oooooooo00001?ooo`030000
oooooooo00goool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool03oooo`040000oooooooo
00001Oooo`0506Kooooooooooooo000000Ooool00`000?ooooooo`02oooo0`0000goool00ol0VOoo
ooooo`1noooo001Soooo00<0I_ooooooool03oooo`040000oooooooo00001Oooo`0306Kooooooooo
00;oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Hoooo`0306Kooooooooo00ooool010000?ooooooo`0000Goool0101Vooooooooo`0000;oool0
1@000?ooooooooooo`000006oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool006?oool0
0`1Vooooooooo`0@oooo0P0000Koool0101Vooooooooooooo`800004oooo0`0000Coool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo0P0000koool00ol0VOooooooo`1noooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo
00koool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Soool0
0`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool006?oool00`1Voooo
ooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0VOooooooo`1noooo001S
oooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool200003_ooo`03o`2Ioooooooo07koool0
06?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0Hoooo00<0I_oooooo
ool03_ooo`80000>oooo00?o09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Soool00`1Voooo
ooooo`0>oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0H
oooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0VOooooooo`1noooo001Soooo00<0
I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo0P0000koool00ol0VOooooooo`1n
oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Hoooo`0306Kooooooooo01Koool2000000@0I_ooooooooooool200001?oo
o`800005oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool006?oool00`1Vooooooooo`0E
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool006?ooolH06Ko00@00000I_l0I_l0000;oooo00<0003oooooool00_ooo`<0000=
oooo00?o09Woooooool0O_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool007coool200002_ooo`<00004oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo0P0000koool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1n
oooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool007Goool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00goool00ol0VOooooooo`1n
oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool3
00003Oooo`03o`2Ioooooooo07koool007Goool010000?ooooooo`0000_oool010000?oooooooooo
o`800005oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Wooooo
ool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo0027oooo1@0000?oool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00ROooo`030000oooooooo00?oool300003Oooo`03o`2Ioooooooo07koool0
08Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOoo
o`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`0000;oool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002oooo`040000oooooooo
00000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000_oool200000oooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55972 .30902 L
.56446 .30902 L
.56706 .30902 L
.56834 .30902 L
.56951 .30902 L
.57063 .30902 L
s
.57063 .30902 m
.57075 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.32831 .30902 L
.33073 .30902 L
.33193 .30902 L
.33304 .30902 L
.33433 .46353 L
.33502 .46353 L
.33575 .46353 L
.33823 .46353 L
.34309 .46353 L
.38467 .46353 L
.40553 .46353 L
.41469 .46353 L
.41954 .46353 L
.42221 .46353 L
.42473 .46353 L
.42716 .46353 L
.42783 .46353 L
.42854 .46353 L
.4298 .30902 L
.43094 .30902 L
.432 .30902 L
.43443 .30902 L
.44348 .30902 L
.46328 .30902 L
.50197 .30902 L
.54311 .30902 L
.58274 .30902 L
.62084 .30902 L
.66141 .30902 L
.70045 .30902 L
.74195 .30902 L
.78193 .30902 L
.8204 .30902 L
.86132 .30902 L
.90072 .30902 L
.93861 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool010000?ooooooo`1Vo`_oool0
0`000?ooooooo`09oooo00@0I_ooooooool0000>oooo00<0003oooooool03?ooo`040000oooooooo
o`2I2oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool03oooo`0306Kooooooooo01Goool00`1Voooo
ooooo`0?oooo00<0003oooooool03oooo`03o`2Ioooooooo02Ooool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03ooo
o`80000@oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?
oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool03oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo001Uoooo00<0I_oooooo
ool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo0P00013oool00ol0VOooooooo`1loooo001U
oooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo
00ooool200004?ooo`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool03oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool05Ooo
o`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Ko
oooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
06Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`80000@oooo00?o09Woooooool0O?oo
o`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool006Goool00`1Vooooooooo`0>oooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo00goool0
10000?ooooooo`0000Coool01@1Vooooooooooooo`000005oooo00@0003oooooool00004oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0=oooo00@0003ooooo
ool00004oooo00<0I_ooooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
00ooool00ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool03Oooo`040000oooooooo00001?oo
o`0306Kooooooooo00?oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00IOooo`0306Kooooooooo00goool010000?ooooooo`0000Coool01@1Voooo
ooooooooo`000002oooo00D0003oooooooooool000001_ooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo001Uoooo00<0I_ooooooool03_ooo`800005oooo00<0I_ooooooool00_ooo`800004
oooo0`0000Coool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo
01Goool00`1Vooooooooo`0?oooo0P00013oool00ol0VOooooooo`1loooo001Uoooo00<0I_oooooo
ool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool200004?oo
o`03o`2Ioooooooo07coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo
00ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo01Goool0
0`1Vooooooooo`0?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool006Goool00`1Voooo
ooooo`0Eoooo00<0I_ooooooool03oooo`80000@oooo00?o09Woooooool0O?ooo`00IOooo`0306Ko
oooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
06Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo0P00
013oool00ol0VOooooooo`1loooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Kooooooooo01Coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00IOooo`0306Ko
oooooooo01?oool010000?ooo`1Vo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00IOoooaH0I_l01000001Vo`1Vo`0000_oool00`000?ooooooo`02
oooo0`0000ooool00ol0VOooooooo`1loooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`80000@oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?oo
o`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Sooo
o`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00MOooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<0000?oooo00?o09Woooooool0O?ooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool0
0ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Sooo
o`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008Ooool500000oooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo0029oooo00<0003oooooool00oooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo0029oooo00<0003oooooool00oooo`<0000?oooo00?o09Wooooo
ool0O?ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Goool3
00000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002oooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo
00002?ooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55972 .30902 L
.56446 .30902 L
.56951 .30902 L
.57197 .30902 L
.57429 .30902 L
.5753 .30902 L
.57636 .30902 L
s
.57636 .30902 m
.57648 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33692 .30902 L
.33823 .30902 L
.33944 .46353 L
.34013 .46353 L
.34076 .46353 L
.34309 .46353 L
.38221 .46353 L
.3925 .46353 L
.40363 .46353 L
.40873 .46353 L
.41413 .46353 L
.41874 .46353 L
.42 .46353 L
.4207 .46353 L
.42135 .46353 L
.42263 .30902 L
.4238 .30902 L
.46213 .30902 L
.50291 .30902 L
.54217 .30902 L
.57993 .30902 L
.62013 .30902 L
.65882 .30902 L
.69996 .30902 L
.73958 .30902 L
.77769 .30902 L
.81825 .30902 L
.85729 .30902 L
.89879 .30902 L
.93877 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool01@000?ooooooooooo`1Vo`0:
oooo00<0003oooooool01oooo`0306Kooooooooo00;oool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`050000ooooooooooooo`2I00[oool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo013oool0
0`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo013oool00ol0VOooooooo`0V
oooo00<0003oooooool0>_ooo`030000oooooooo01Goool006Koool00`1Vooooooooo`0Boooo00<0
I_ooooooool04Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0I_oooooo
ool04_ooo`0306Kooooooooo017oool200004Oooo`03o`2Ioooooooo07_oool006Koool00`1Voooo
ooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo001V
oooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o09Wooooo
ool0Noooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`80000A
oooo00?o09Woooooool0Noooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_oooooo
ool04Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0I_ooooooool04_oo
o`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00I_ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0Aoooo0P00017oool00ol0VOooooooo`1koooo001Voooo00<0
I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo
013oool00ol0VOooooooo`1koooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool2
00004Oooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Ooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0I_ooooooool03Oooo`800003
oooo00<0I_l0000000000oooo`@00003oooo0P0000Goool00`000?ooooooo`0@oooo00?o09Wooooo
ool0Noooo`00I_ooo`0306Kooooooooo00coool010000?ooooooo`0000;oool00`1Vooooooooo`03
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo013oool00ol0VOoo
ooooo`1koooo001Voooo00<0I_ooooooool03?ooo`040000oooooooo00000_ooo`0306Kooooooooo
00Coool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000@oooo00?o09Woooooool0Nooo
o`00I_ooo`0306Kooooooooo00coool010000?ooooooo`0000;oool00`1Vooooooooo`05oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool006Koool0
0`1Vooooooooo`0<oooo00@0003oooooool00002oooo00<0I_ooooooool00oooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00I_oo
o`0306Kooooooooo00goool200000oooo`0306Kooooooooo00Coool200001?ooo`<00004oooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_oooooo
ool04Oooo`80000Aoooo00?o09Woooooool0Noooo`00I_ooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Aoooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0B
oooo00<0I_ooooooool04Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0
I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo0P00017oool00ol0VOooooooo`1k
oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool04?ooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Ooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0I_ooooooool04_ooo`0306Ko
oooooooo017oool200004Oooo`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0
I_ooooooool04Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo001Voooo00<0I_oooooo
ool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00I_oo
o`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`80000Aoooo00?o09Wooooo
ool0Noooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool006Koool00`1Vooooooooo`0Boooo00<0I_l0000000001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00I_ooo`0306Kooooooooo
01;oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00I_oooaD0I_l010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
013oool00ol0VOooooooo`1koooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00O?ooo`80000:oooo0`0000Coool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1k
oooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool200004Oooo`03o`2I
oooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00MOooo`040000oooooooo00002_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0000@oooo00?o09Woooooool0Noooo`00MOooo`040000oooooooo00002oooo`040000oooooooo
oooo0P0000Goool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00MOooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0003ooooo
ool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOoo
ooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1k
oooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008Ooool500000oooo`030000oooooooo
013oool00ol0VOooooooo`1koooo0029oooo00<0003oooooool00oooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo0029oooo00<0003oooooool00oooo`<0000@oooo00?o09Woooooool0Nooo
o`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool0
0?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001e
oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000_oool010000?ooooooooooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.56817 .30902 L
.57355 .30902 L
.57861 .30902 L
.58137 .30902 L
.58213 .30902 L
.58293 .30902 L
s
.58293 .30902 m
.583 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34055 .30902 L
.34186 .30902 L
.34309 .30902 L
.34425 .30902 L
.34549 .46353 L
.3462 .46353 L
.34686 .46353 L
.34811 .46353 L
.35271 .46353 L
.36173 .46353 L
.3815 .46353 L
.39126 .46353 L
.40158 .46353 L
.41038 .46353 L
.4128 .46353 L
.41412 .46353 L
.41538 .46353 L
.41655 .46353 L
.41782 .30902 L
.41898 .30902 L
.42005 .30902 L
.45932 .30902 L
.49707 .30902 L
.53727 .30902 L
.57596 .30902 L
.6171 .30902 L
.65672 .30902 L
.69483 .30902 L
.73539 .30902 L
.77444 .30902 L
.81593 .30902 L
.85592 .30902 L
.89438 .30902 L
.9353 .30902 L
.9747 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`02oooo00<0
I_ooooooool01oooo`030000oooooooo00Koool00`1Vooooooooo`03oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`03oooo00?o09Woooooool01_ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool04Oooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo02Coool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Iooo
o`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`80000Coooo00?o09Wooooo
ool0NOooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo
01;oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Ioooo`0306Kooooooooo013oool0
0`1Vooooooooo`0Boooo0P0001?oool00ol0VOooooooo`1ioooo001Woooo00<0I_ooooooool04?oo
o`0306Kooooooooo01;oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Ioooo`0306Ko
oooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
06Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool200004oooo`03o`2I
oooooooo07Woool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo
01;oool00ol0VOooooooo`1ioooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Ioooo`0306Kooooooooo013oool00`1Voooo
ooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool006Ooool00`1Vooooooooo`0@
oooo00<0I_ooooooool04_ooo`80000Coooo00?o09Woooooool0NOooo`00Ioooo`0306Kooooooooo
013oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool006Ooool0
0`1Vooooooooo`0<oooo0P0000;oool0101Vooooo`00000000?oool400000oooo`800005oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool006Ooool00`1Vooooooooo`0;oooo00H0003ooooo
ool0003oool0I_l6oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
01;oool00ol0VOooooooo`1ioooo001Woooo00<0I_ooooooool02oooo`060000oooooooo0000oooo
06Ko1oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001;oool00ol0VOooooooo`1i
oooo001Xoooo00<0I_ooooooool02_ooo`060000oooooooo0000oooo06Ko2?ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo001Xoooo00<0I_oooooo
ool02_ooo`060000oooooooo0000oooo06Ko1_ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00J?ooo`0306Kooooooooo00_oool2
00000_ooo`0306Kooooooooo00Goool200001?ooo`<00004oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`80000Coooo00?o
09Woooooool0NOooo`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_oo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo001Xoooo00<0I_ooooooool03oooo`0306Ko
oooooooo01;oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00J?ooo`0306Kooooooooo
00ooool00`1Vooooooooo`0Boooo0P0001?oool00ol0VOooooooo`1ioooo001Xoooo00<0I_oooooo
ool03oooo`0306Kooooooooo01;oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00J?oo
o`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool200004ooo
o`03o`2Ioooooooo07Woool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo
01;oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00J?ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool006Soool00`1Voooo
ooooo`0?oooo00<0I_ooooooool04_ooo`80000Coooo00?o09Woooooool0NOooo`00J?ooo`0306Ko
oooooooo00ooool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
06Soool00`1Vooooooooo`0?oooo00@0I_ooool000000004oooo0P0000Coool200001Oooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo001Xoooo00<0I_ooooooool03oooo`0506Ko0000oooo
oooo000000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00J?oooa<0I_l010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0001;oool00ol0VOoo
ooooo`1ioooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`0Boooo00?o09Woooooool0NOooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool008ooool200004oooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool200004oooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool2
00004oooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000Boooo00?o
09Woooooool0NOooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P00
01?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?oooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool008Ooool500000oooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo0029oooo00<0003oooooool00oooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo0029oooo00<0003oooooool00oooo`<0000Boooo00?o09Woooooool0NOooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001joooo001hoooo00D0003oooooooooool0
00005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.56817 .30902 L
.57861 .30902 L
.58157 .30902 L
.58436 .30902 L
.58686 .30902 L
.58755 .30902 L
.58827 .30902 L
s
.58827 .30902 m
.5884 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34309 .30902 L
.34566 .30902 L
.34811 .30902 L
.34918 .30902 L
.35031 .30902 L
.35156 .46353 L
.35271 .46353 L
.36173 .46353 L
.3815 .46353 L
.39178 .46353 L
.39719 .46353 L
.40291 .46353 L
.40533 .46353 L
.40792 .46353 L
.40868 .46353 L
.40941 .46353 L
.41006 .46353 L
.41076 .30902 L
.41143 .30902 L
.41214 .30902 L
.41342 .30902 L
.42308 .30902 L
.46083 .30902 L
.50104 .30902 L
.53972 .30902 L
.58086 .30902 L
.62049 .30902 L
.65859 .30902 L
.69916 .30902 L
.7382 .30902 L
.7797 .30902 L
.81968 .30902 L
.85815 .30902 L
.89907 .30902 L
.93847 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`04oooo00<0
I_ooooooool01Oooo`030000oooooooo00Coool00`1Vooooooooo`05oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`04oooo00?o09Woooooool01Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool04oooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003ooooo
ool04oooo`03o`2Ioooooooo02?oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00JOoo
o`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`80000Doooo00?o09Wooooo
ool0N?ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo
01Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo00coool0
0`1Vooooooooo`0Doooo0P0001Coool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?oo
o`0306Kooooooooo01Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Ko
oooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
06Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool200005?ooo`03o`2I
oooooooo07Soool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo00coool00`1Voooo
ooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool006Woool00`1Vooooooooo`0<
oooo00<0I_ooooooool05?ooo`80000Doooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool006Woool0
0`1Vooooooooo`0:oooo0P00000406Kooooooooooooo0P0000?oool400000oooo`800005oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool006Woool00`1Vooooooooo`09oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool02Oooo`040000oooooooo00002Oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0001?oool00ol0VOooooooo`1hoooo001Yoooo00<0
I_ooooooool02Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool02Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00JOooo`0306Kooooooooo00[oool2000000<0I_ooooooool01oooo`800004
oooo0`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo0P0001Coool00ol0VOooooooo`1hoooo001Yoooo00<0I_oooooo
ool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOoo
o`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool200005?oo
o`03o`2Ioooooooo07Soool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo
01Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo00coool0
0`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool006Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool05?ooo`80000Doooo00?o09Woooooool0N?ooo`00JOooo`0306Ko
oooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
06Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P00
01Coool00ol0VOooooooo`1hoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOooo`0306Kooooooooo00coool0101Voooo
ooooooooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo001Yoooo00<0I_ooooooool03?ooo`0406Kooooooooo00000_ooo`030000oooooooo00Koool0
10000?ooooooo`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00JOoooa00I_l2
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Coooo00?o09Woooooool0N?oo
o`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool007coool200002_ooo`<00004oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool200005?ooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?
oooo0P0001Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool007Koool2
00001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300004oooo`03o`2Ioooooooo
07Soool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo07Soool007Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool007Koool2
00002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo0027oooo1@0000?oool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00ROoo
o`030000oooooooo00?oool300004oooo`03o`2Ioooooooo07Soool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool0
0`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00goool200001?ooo`800003oooo100000?oool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.57861 .30902 L
.58392 .30902 L
.58957 .30902 L
.59232 .30902 L
.59367 .30902 L
.59491 .30902 L
s
.59491 .30902 m
.59502 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35028 .30902 L
.35271 .30902 L
.35496 .30902 L
.35624 .30902 L
.35742 .46353 L
.35852 .46353 L
.35951 .46353 L
.36173 .46353 L
.3815 .46353 L
.39086 .46353 L
.39597 .46353 L
.40075 .46353 L
.40324 .46353 L
.40396 .46353 L
.40464 .46353 L
.40592 .30902 L
.4066 .30902 L
.40733 .30902 L
.40863 .30902 L
.41159 .30902 L
.42157 .30902 L
.45932 .30902 L
.49952 .30902 L
.53821 .30902 L
.57935 .30902 L
.61897 .30902 L
.65708 .30902 L
.69764 .30902 L
.73669 .30902 L
.77818 .30902 L
.81817 .30902 L
.85663 .30902 L
.89755 .30902 L
.93695 .30902 L
.97484 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`06oooo00?o09Woooooool00oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo027oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Jooo
o`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`80000Foooo00?o09Wooooo
ool0M_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo
01Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0Eoooo0P0001Koool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Ooo
o`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Ko
oooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
06_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool200005_ooo`03o`2I
oooooooo07Koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`80000Foooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool006_oool0
0`1Vooooooooo`08oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo00Ooool010000?ooo`1Vo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool006_oool00`1Vooooooooo`07oooo00@0003oool0I_l00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool300005Oooo`03o`2Ioooooooo07Koool006_oool00`1Vooooooooo`07
oooo00@0003oool0I_l0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool006_oool00`1Vooooooooo`07oooo00@0003oool0I_l00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo001[oooo00<0I_ooooooool02?ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool2
00005_ooo`03o`2Ioooooooo07Koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Ooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Ko
oooooooo01Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`80000Foooo00?o09Woooooool0M_ooo`00Jooo
o`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?oo
ooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0E
oooo0P0001Koool00ol0VOooooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo
01Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo001[
oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool200005_ooo`03o`2Ioooooooo07Koool0
06_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo00;oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Joooo`0306Kooooooooo
00Woool01@1Vooooooooooooo`000002oooo00<0003oooooool01_ooo`040000oooooooo00001?oo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo001[oooo3@1Vo`?oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`0001Goool00ol0VOooooooo`1foooo001koooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Eoooo00?o09Woooooool0M_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`80000Foooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2I
oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00M_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00MOoo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0000Eoooo00?o09Woooooool0M_ooo`00MOooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00M_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?oo
ooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P00
01Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08Ooool500000oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00ooo
o`<0000Eoooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59405 .30902 L
.59698 .30902 L
.59842 .30902 L
.59975 .30902 L
.60102 .30902 L
s
.60102 .30902 m
.60109 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.35742 .30902 L
.35948 .30902 L
.36173 .30902 L
.36294 .30902 L
.36405 .46353 L
.36512 .46353 L
.36626 .46353 L
.37114 .46353 L
.3815 .46353 L
.39178 .46353 L
.3946 .46353 L
.39614 .46353 L
.39758 .46353 L
.39881 .46353 L
.40012 .30902 L
.40087 .30902 L
.40158 .30902 L
.40291 .30902 L
.42308 .30902 L
.46141 .30902 L
.50219 .30902 L
.54146 .30902 L
.57921 .30902 L
.61941 .30902 L
.6581 .30902 L
.69924 .30902 L
.73886 .30902 L
.77697 .30902 L
.81753 .30902 L
.85658 .30902 L
.89808 .30902 L
.93806 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`07oooo00<0
I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`07oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`08oooo00Go09Woooooooooool000003_ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0Foooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0Goooo00?o
09Woooooool07oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo001/oooo00<0I_oooooo
ool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00K?oo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo0P0001Soool00ol0VOooooooo`1doooo001/
oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00K?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo
01Koool200006?ooo`03o`2Ioooooooo07Coool006coool00`1Vooooooooo`07oooo00<0I_oooooo
ool05_ooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001/oooo00<0I_ooooooool01ooo
o`0306Kooooooooo01Koool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00K?ooo`0306Ko
oooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
06coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`80000Hoooo00?o09Woooooool0M?oo
o`00K?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool05oooo`03o`2I
oooooooo07Coool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00K?ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0Foooo0P0001Soool00ol0VOooooooo`1doooo001/oooo00<0I_ooooooool01oooo`0306Ko
oooooooo01Koool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00K?ooo`0306Kooooooooo
00Ooool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo001/oooo00<0I_ooooooool01_ooo`04000006Kooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00K?oo
o`0306Kooooooooo00Koool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000Goooo00?o09Woooooool0M?ooo`00KOooo`0306Kooooooooo00Goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00KOooo`0306Kooooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool006goool0
0`1Vooooooooo`05oooo00<0I_l0000000002_ooo`800004oooo0`0000Coool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo0P00
01Soool00ol0VOooooooo`1doooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00KOooo`0306Kooooooooo00Goool00`1Voooo
ooooo`0Goooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool006goool00`1Vooooooooo`05
oooo00<0I_ooooooool05oooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001]oooo00<0
I_ooooooool01Oooo`0306Kooooooooo01Ooool200006?ooo`03o`2Ioooooooo07Coool006goool0
0`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00?o
09Woooooool0M?ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05ooo
o`80000Hoooo00?o09Woooooool0M?ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0G
oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool006goool00`1Vooooooooo`05oooo00<0
I_ooooooool05oooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001]oooo00<0I_oooooo
ool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00KOoo
o`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo0P0001Soool00ol0VOooooooo`1doooo001]
oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`04oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool006goool00`1Vooooooooo`05
oooo00<0I_ooooooool00oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo001]oooo2@1Vo`Goool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0001Ooool00ol0VOooooooo`1doooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`80000H
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool200006?ooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08ooool200006?ooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool008ooool200006?ooo`03o`2Ioooooooo07Coool008ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`<0000Goooo00?o09Woooooool0M?ooo`00MOooo`040000oooooooo
00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00M_ooo`800009oooo100000?oool300001?oo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008Ooool5
00000oooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo0029oooo00<0003oooooool00ooo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo0029oooo00<0003oooooool00oooo`<0000G
oooo00?o09Woooooool0M?ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2D
oooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool0
0`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?oo
ooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000?oool500000_ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007Ooool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000B
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59405 .30902 L
.59975 .30902 L
.60256 .30902 L
.60394 .30902 L
.60521 .30902 L
.60637 .30902 L
s
.60637 .30902 m
.60649 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.36173 .30902 L
.36626 .30902 L
.36757 .30902 L
.36881 .30902 L
.36992 .46353 L
.37114 .46353 L
.3815 .46353 L
.38681 .46353 L
.38942 .46353 L
.39056 .46353 L
.39182 .46353 L
.39295 .30902 L
.394 .30902 L
.39631 .30902 L
.40117 .30902 L
.42214 .30902 L
.46105 .30902 L
.50241 .30902 L
.54226 .30902 L
.58059 .30902 L
.62137 .30902 L
.66064 .30902 L
.69839 .30902 L
.73859 .30902 L
.77728 .30902 L
.81842 .30902 L
.85804 .30902 L
.89615 .30902 L
.93671 .30902 L
.97576 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`09oooo00@0
I_ooooooool00002oooo00<0I_ooooooool02Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool02Oooo`04o`2Ioooooooo00003_ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0Hoooo00<0I_oooooo
ool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o09Woooooool07_ooo`030000
oooooooo03[oool00`000?ooooooo`0Eoooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo
01Soool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool0
0`1Vooooooooo`0Hoooo0P0001Woool00ol0VOooooooo`1coooo001^oooo00<0I_ooooooool00ooo
o`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00K_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
06koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool200006Oooo`03o`2I
oooooooo07?oool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool00`1Voooo
ooooo`0Hoooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03
oooo00<0I_ooooooool06?ooo`80000Ioooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool006koool0
0`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo0P0001Woool0
0ol0VOooooooo`1coooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool0101Vooooo`000000
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00K_ooo`0306Kooooooooo00?oool01@1Vo`000?ooooooo`000008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001^oooo00<0
I_ooooooool00oooo`0506Ko0000oooooooo000000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000Hoooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool01@1Vo`00
0?ooooooo`00000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool006koool00`1Vooooooooo`03oooo00D0I_l0003oooooool000002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00K_ooo`0306Kooooooooo00?oool0101Vooooo`00000000[oool200001?ooo`<00004oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`80000Ioooo00?o09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool00`1Voooo
ooooo`0Hoooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03
oooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo0P0001Woool00ol0VOooooooo`1c
oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?oo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo001^oooo00<0I_ooooooool00oooo`0306Ko
oooooooo01Soool200006Oooo`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03oooo00<0
I_ooooooool06?ooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001^oooo00<0I_oooooo
ool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`80000Ioooo00?o09Wooooo
ool0Loooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool006koool00`1Vooooooooo`03oooo00<0I_ooooooool01Oooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00K_ooo`L0I_l6oooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000Hoooo00?o09Woooooool0Loooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool007coool200002_ooo`<00004oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo0P0001Woool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool300006?ooo`03o`2Ioooooooo07?oool007Goool0
10000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`80000Ioooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`80000Ioooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo0027oooo1@0000?oool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00ROooo`030000oooooooo
00?oool300006?ooo`03o`2Ioooooooo07?oool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00goool200001?ooo`800003oooo1@0000;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.60756 .30902 L
.61016 .30902 L
.61135 .30902 L
.6126 .30902 L
s
.6126 .30902 m
.61267 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.36626 .30902 L
.37114 .30902 L
.37257 .30902 L
.37328 .30902 L
.37393 .30902 L
.37515 .46353 L
.3758 .46353 L
.37649 .46353 L
.3815 .46353 L
.3841 .46353 L
.38553 .46353 L
.38622 .46353 L
.38686 .46353 L
.38799 .30902 L
.38921 .30902 L
.39178 .30902 L
.40291 .30902 L
.42308 .30902 L
.46293 .30902 L
.50126 .30902 L
.54204 .30902 L
.5813 .30902 L
.61906 .30902 L
.65926 .30902 L
.69795 .30902 L
.73909 .30902 L
.77871 .30902 L
.81682 .30902 L
.85738 .30902 L
.89642 .30902 L
.93792 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0:oooo00D0
I_ooool0003oool0I_l03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool02oooo`03o`2I0000oooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool06Oooo`0506Kooooooooooooo06Ko01_oool0
0`000?ooooooo`0Joooo00?o09Woooooool07?ooo`030000oooooooo03[oool00`000?ooooooo`0E
oooo001_oooo00D0I_ooooooooooool0I_l06oooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo001_oooo00D0I_ooooooooooool0I_l06oooo`80000Koooo00?o09Woooooool0LOooo`00Kooo
o`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Kooo
o`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Kooo
o`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Kooo
o`0506Kooooooooooooo06Ko01_oool200006oooo`03o`2Ioooooooo077oool006ooool01@1Voooo
ooooooooo`1Vo`0Koooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool006ooool01@1Voooo
ooooooooo`1Vo`0Koooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool006ooool01@1Voooo
ooooooooo`1Vo`0Koooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool006ooool01@1Voooo
ooooooooo`1Vo`0Koooo0P0001_oool00ol0VOooooooo`1aoooo001_oooo00D0I_ooooooooooool0
I_l06oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001_oooo00D0I_ooooooooooool0
I_l06oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001_oooo00D0I_ooooooooooool0
I_l06oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001_oooo00D0I_ooooooooooool0
I_l06oooo`80000Koooo00?o09Woooooool0LOooo`00Koooo`0506Kooooooooooooo06Ko01_oool0
0`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Koooo`0506Kooooooooooooo06Ko00;oool2
00001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo001_oooo00L0I_ooooooooooool0I_ooool000000_ooo`030000oooooooo00Koool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
06ooool0101Vooooooooo`1Vo`;oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<0000Joooo00?o09Woooooool0LOooo`00Koooo`0406Kooooooooo06Ko0_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo001_oooo00@0I_ooooooool0I_l2oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo001_oooo00@0I_ooooooool0I_l3oooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool006ooool0101Vooooooooo`1Voacoool200006oooo`03o`2I
oooooooo077oool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`0Joooo00?o09Wooooo
ool0LOooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
06ooool0101Vooooooooo`1Voacoool200006oooo`03o`2Ioooooooo077oool006ooool0101Voooo
ooooo`1Voacoool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Koooo`0406Kooooooooo
06Ko7?ooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001_oooo00@0I_ooooooool0I_lL
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool006ooool0101Vooooooooo`1Voacoool2
00006oooo`03o`2Ioooooooo077oool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool06_ooo`03o`2I
oooooooo077oool006ooool0101Vooooooooo`1Voacoool200006oooo`03o`2Ioooooooo077oool0
06ooool0101Vooooooooo`1Voacoool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Kooo
o`0406Kooooooooo06Ko2Oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo001_oooo00@0I_ooooooool0I_l8oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool006ooool406Ko2?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool300006_ooo`03o`2Ioooooooo077oool0
07_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo001loooo0P0000[oool300001?ooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o
09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001foooo0P00
00Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0001[oool00ol0VOooooooo`1a
oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001foooo0P00
00Woool400000oooo`<00004oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool2
00006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2I
oooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Qoooo`D00003oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Woool0
0`000?ooooooo`03oooo0`0001[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool0U?oo
o`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001f
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003ooooo
ool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?oo
ooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000
oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.61016 .30902 L
.61278 .30902 L
.61524 .30902 L
.61745 .30902 L
.61869 .30902 L
s
.61869 .30902 m
.6188 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
08koool007Goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool006ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100003Ooool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo01_oool00ol0VOooooooo`0K
oooo00<0003oooooool0>_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo
01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Wooooo
ool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?oo
o`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0001_oool00ol0VOooooooo`1`oooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000L
oooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo
01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Wooooo
ool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Koooo00?o09Woooooool0L?oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool300006oooo`03o`2Ioooooooo
073oool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01_oool00ol0VOooooooo`1`oooo001loooo0P0000[oool300001?ooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?oo
o`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000L
oooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0001_oool00ol0VOoo
ooooo`1`oooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool200007?ooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Wooooo
ool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool008ooool200007?ooo`03o`2Ioooooooo073oool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool200007?oo
o`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool200007?ooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0K
oooo00?o09Woooooool0L?ooo`00Qoooo`D00003oooo00<0003oooooool06oooo`03o`2Ioooooooo
073oool008Woool00`000?ooooooo`03oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08Woool00`000?ooooooo`03oooo0`0001_oool00ol0VOooooooo`1`oooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ooooo00<0003oooooool07?ooo`030000oooooooo07ooool007koool00`000?ooooooo`08
oooo00<0003oooooool04oooo`030000oooooooo07koool007koool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`030000oooooooo07koool007koool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Woool00`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000[oool00`000?ooooooo`1moooo001noooo00<0003oooooool01@00
00coool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001noooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooooooo07koool007ooool00`000?ooooooo`0A
oooo0P0000Woool00`000?ooooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61445 .30902 L
.61726 .30902 L
.61984 .30902 L
.62236 .30902 L
.62363 .30902 L
.62435 .30902 L
s
.62435 .30902 m
.62442 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.36626 .30902 L
.37114 .30902 L
.37257 .30902 L
.37328 .30902 L
.37393 .30902 L
.37515 .15451 L
.3758 .15451 L
.37649 .15451 L
.3815 .15451 L
.3841 .15451 L
.38553 .15451 L
.38622 .15451 L
.38686 .15451 L
.38799 .30902 L
.38921 .30902 L
.39178 .30902 L
.40291 .30902 L
.42308 .30902 L
.46293 .30902 L
.50126 .30902 L
.54204 .30902 L
.5813 .30902 L
.61906 .30902 L
.65926 .30902 L
.69795 .30902 L
.73909 .30902 L
.77871 .30902 L
.81682 .30902 L
.85738 .30902 L
.89642 .30902 L
.93792 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006ooool406Ko2?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00Koooo`0406Kooooooooo06Ko0_ooo`@00002oooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`2>oooo001_oooo00@0I_ooooooool0I_l8oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006ooool0101Vooooooooo`1V
o`Woool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo06Ko7?oo
o`80002?oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool0S_ooo`00Koooo`0406Ko
oooooooo06Ko7?ooo`030000oooooooo08koool006ooool0101Vooooooooo`1Voacoool00`000?oo
ooooo`2>oooo001_oooo00@0I_ooooooool0I_lLoooo0P0008ooool006ooool0101Vooooooooo`1V
oacoool00`000?ooooooo`2>oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool0S_oo
o`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo08koool006ooool0101Vooooooooo`1V
oacoool20000Soooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo08koool006ooool0
101Vooooooooo`1Voacoool00`000?ooooooo`2>oooo001_oooo00@0I_ooooooool0I_lLoooo00<0
003oooooool0S_ooo`00Koooo`0406Kooooooooo06Ko7?ooo`80002?oooo001_oooo00@0I_oooooo
ool0I_lLoooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo06Ko0oooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo06Ko0_oo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001_oooo00L0I_ooooooooooool0I_ooool000000_ooo`030000oooooooo00Ooool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0002>oooo001_oooo1000000306Kooooo0000
00;oool00`000?ooooooo`08oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_oo
o`00Koooo`0706Kooooooooooooo06Kooooo000000;oool00`000?ooooooo`06oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool006ooool01@1Voooooooooooo
o`1Vo`02oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_ooo`00Koooo`0506Ko
oooooooooooo06Ko01_oool20000Soooo`00Koooo`0506Kooooooooooooo06Ko01_oool00`000?oo
ooooo`2>oooo001_oooo00D0I_ooooooooooool0I_l06oooo`030000oooooooo08koool006ooool0
1@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool0S_ooo`006Oooo`<0000hoooo100001Ooool0
1@1Vooooooooooooo`1Vo`0Koooo0P0003Soool40000>oooo`<0000Eoooo000Joooo00<0003ooooo
ool0=oooo`030000oooooooo01Soool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool0=ooo
o`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?ooooooo`0G
oooo00D0I_ooooooooooool0I_l06oooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@00
01Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003oooooool05_oo
o`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000
oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0001Ooool01@1Voooo
ooooooooo`1Vo`0Koooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000I
oooo0P0003[oool200006?ooo`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0hoooo0P00
03coool200005_ooo`00Koooo`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`2>oooo001_
oooo00D0I_ooooooooooool0I_l06oooo`80002?oooo001_oooo00D0I_ooooooooooool0I_l06ooo
o`030000oooooooo08koool006ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool0S_oo
o`00Koooo`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`2>oooo000@ooooo`00017oool0
01Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo09T03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool0
0`000?ooooooo`0ioooo00<0003oooooool07Oooo`03o`2Ioooooooo01Woool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?
oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo
01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool0
0ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Ooo
o`03o`2Ioooooooo06koool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo001eoooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001e
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300007Ooo
o`03o`2Ioooooooo06koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Ooo
o`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Sooo
o`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^
oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0M
oooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?
oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo
01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool007coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001koooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000Moooo00?o09Woooooool0K_ooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool007coool200002_ooo`<00004oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
08ooool200007_ooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool0
0ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Ooo
o`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Sooo
o`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^
oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo01goool00ol0VOooooooo`1^oooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool300007Oooo`03o`2Ioooooooo06koool007Goool0
10000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000Noooo00?o
09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`80000Noooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool0
0ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000Noooo00?o09Woooooool0K_oo
o`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Ooo
o`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Sooo
o`80000Noooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo0027oooo1@0000?oool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00ROooo`030000oooooooo
00?oool300007Oooo`03o`2Ioooooooo06koool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61984 .30902 L
.6254 .30902 L
.62812 .30902 L
.62932 .30902 L
.63064 .30902 L
s
.63064 .30902 m
.63075 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.36173 .30902 L
.36626 .30902 L
.36757 .30902 L
.36881 .30902 L
.36992 .15451 L
.37114 .15451 L
.3815 .15451 L
.38681 .15451 L
.38942 .15451 L
.39056 .15451 L
.39182 .15451 L
.39295 .30902 L
.394 .30902 L
.39631 .30902 L
.40117 .30902 L
.42214 .30902 L
.46105 .30902 L
.50241 .30902 L
.54226 .30902 L
.58059 .30902 L
.62137 .30902 L
.66064 .30902 L
.69839 .30902 L
.73859 .30902 L
.77728 .30902 L
.81842 .30902 L
.85804 .30902 L
.89615 .30902 L
.93671 .30902 L
.97576 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006koool706Ko1_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00K_ooo`0306Kooooooooo00?oool00`1Vo`000000000200000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool0
0`1Vooooooooo`04oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool01Oooo`80000:oooo0`0000Coool0
0`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool20000Sooo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo0P0008ooool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?oo
o`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000
oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`80002?oooo001^
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_oooooo
ool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00ooo
o`0306Kooooooooo01Soool20000Soooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0H
oooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool0101Vooooo`00000000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00ooo
o`0506Ko0000oooooooo000000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool01@1Vo`000?ooooooo`000009oooo00<0
003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00K_ooo`0306Ko0000000000800000
0oooo`1Vo`000002oooo00<0003oooooool02?ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo08koool006koool00`1Vooooooooo`03oooo00D0I_l0003oooooool000002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001^oooo00<0I_oooooo
ool00oooo`0406Kooooo000000002_ooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001^
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool20000Soooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool0
0`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool00`1Voooo
ooooo`0Hoooo00<0003oooooool0S_ooo`006Oooo`<0000hoooo100001Koool00`1Vooooooooo`03
oooo00<0I_ooooooool06?ooo`80000hoooo100003_oool300005Oooo`006_ooo`030000oooooooo
03Ooool00`000?ooooooo`0Goooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?oo
ooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000
oooooooo01Koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo03Soool0
0`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004
oooo00<0003oooooool05Oooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003ooooo
ool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000i
oooo00@0003oooooool0000Foooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool20000>?oo
o`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_ooo`80000Goooo00<0
I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0hoooo0P0003coool200005_oo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo0P0008ooool006koool00`1Vooooooooo`03
oooo00<0I_ooooooool06?ooo`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0
I_ooooooool06?ooo`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool010000?ooooooool0V@_oool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
oooooooo01koool00ol0VOooooooo`0Hoooo00<0003oooooool0>_ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Wooooo
ool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOoo
o`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000O
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Noooo00?o09Wooooo
ool0KOooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0001koool00ol0VOooooooo`1]oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000O
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo
01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Wooooo
ool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOoo
o`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool300007_ooo`03o`2Ioooooooo06goool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P0001ooool00ol0VOoo
ooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000O
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo
01koool00ol0VOooooooo`1]oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0001koool00ol0VOooooooo`1]oooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
01koool00ol0VOooooooo`1]oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo06goool008ooool200007oooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool200007ooo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool200007oooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool200007oooo`03o`2Ioooooooo
06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Qoooo`D00003oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo06goool008Woool00`000?ooooooo`03oooo0`0001koool00ol0VOoo
ooooo`1]oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61984 .30902 L
.6254 .30902 L
.63064 .30902 L
.63292 .30902 L
.63534 .30902 L
.6366 .30902 L
s
.6366 .30902 m
.63667 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.35742 .30902 L
.35948 .30902 L
.36173 .30902 L
.36294 .30902 L
.36405 .15451 L
.36512 .15451 L
.36626 .15451 L
.37114 .15451 L
.3815 .15451 L
.39178 .15451 L
.3946 .15451 L
.39614 .15451 L
.39758 .15451 L
.39881 .15451 L
.40012 .30902 L
.40087 .30902 L
.40158 .30902 L
.40291 .30902 L
.42308 .30902 L
.46141 .30902 L
.50219 .30902 L
.54146 .30902 L
.57921 .30902 L
.61941 .30902 L
.6581 .30902 L
.69924 .30902 L
.73886 .30902 L
.77697 .30902 L
.81753 .30902 L
.85658 .30902 L
.89808 .30902 L
.93806 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006goool906Ko1Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00KOooo`0306Kooooooooo00Goool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0S_ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`03
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006goool0
0`1Vooooooooo`05oooo00<0I_ooooooool01?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>
oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool20000Soooo`00KOooo`0306Ko
oooooooo00Goool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00KOooo`0306Kooooooooo
00Goool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00KOooo`0306Kooooooooo00Goool0
0`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00KOooo`0306Kooooooooo00Goool00`1Voooo
ooooo`0Goooo0P0008ooool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000
oooooooo08koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo
08koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo08koool0
06goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`80002?oooo001]oooo00<0I_oooooo
ool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Ooo
o`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Ko
oooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo
01Ooool20000Soooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0003ooooo
ool0S_ooo`00KOooo`0306Kooooooooo00Goool00`1Vo`0000000004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0S_ooo`00KOooo`0306Kooooooooo00Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00K?oo
o`0306Kooooooooo00Koool01000001Vooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0002>oooo001/oooo00<0I_ooooooool0100000;oool01000001Vooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001/oooo00<0I_ooooooool01_oo
o`04000006Kooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo001/oooo00<0I_ooooooool01oooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo08koool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`80002?oooo001/
oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`2>oooo001/oooo00<0
I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`2>oooo001/oooo00<0I_oooooo
ool01oooo`0306Kooooooooo01Koool00`000?ooooooo`2>oooo000Ioooo0`0003Soool400005?oo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo0P0003Soool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool0=oooo`030000oooooooo01Goool00`1Vooooooooo`07oooo00<0I_oooooo
ool05_ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005ooo
o`D0000ioooo00<0003oooooool05?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0
003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003ooooo
ool0000coooo100000Coool00`000?ooooooo`0Coooo00<0I_ooooooool01oooo`0306Kooooooooo
01Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0001Coool00`1Vooooooooo`07oooo00<0I_oooooo
ool05_ooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000j
oooo0P0001Goool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000oooooooo03Soool2
0000??ooo`80000Foooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?oo
ooooo`2>oooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool20000Soooo`00K?oo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Ko
oooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo
00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00;oool00ol0VOoo
ooooo`07oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0Poooo00?o09Woooooool05_ooo`030000
oooooooo03[oool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo
06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool2
00008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool007Goool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool08?ooo`03o`2Ioooooooo
06_oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<0000Poooo00?o09Woooooool0Joooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[
oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2I
oooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000
oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo
06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001koooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool007_oool0
10000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00023oool00ol0VOooooooo`1[oooo001k
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Poooo00?o09Wooooo
ool0Joooo`00Soooo`80000Qoooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool2
00008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[
oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2I
oooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00M_ooo`800004
oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Poooo00?o09Wooooo
ool0Joooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000Poooo00?o09Woooooool0Jooo
o`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00M_ooo`800009
oooo100000?oool300001?ooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00
027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?oooo00<0003ooooo
ool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOoo
ooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[
oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008Ooool500000oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo0029
oooo00<0003oooooool00oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo0029oooo00<0
003oooooool00oooo`<0000Poooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000?oool500000_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.63527 .30902 L
.63796 .30902 L
.64043 .30902 L
.64164 .30902 L
.64277 .30902 L
s
.64277 .30902 m
.64289 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35028 .30902 L
.35271 .30902 L
.35496 .30902 L
.35624 .30902 L
.35742 .15451 L
.35852 .15451 L
.35951 .15451 L
.36173 .15451 L
.3815 .15451 L
.39086 .15451 L
.39597 .15451 L
.40075 .15451 L
.40324 .15451 L
.40396 .15451 L
.40464 .15451 L
.40592 .30902 L
.4066 .30902 L
.40733 .30902 L
.40863 .30902 L
.41159 .30902 L
.42157 .30902 L
.45932 .30902 L
.49952 .30902 L
.53821 .30902 L
.57935 .30902 L
.61897 .30902 L
.65708 .30902 L
.69764 .30902 L
.73669 .30902 L
.77818 .30902 L
.81817 .30902 L
.85663 .30902 L
.89755 .30902 L
.93695 .30902 L
.97484 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006_oool=06Ko0oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00Joooo`0306Kooooooooo00Ooool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool01@1Voooooooooooo
o`000002oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001[
oooo00<0I_ooooooool02Oooo`0306Kooooooooo00;oool200002_ooo`<00004oooo00<0003ooooo
ool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P0008ooool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09oooo00<0
I_ooooooool05Oooo`80002?oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?oo
ooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`2>
oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool20000Soooo`00Joooo`0306Ko
oooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0Eoooo0P0008ooool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000
oooooooo08koool006_oool00`1Vooooooooo`08oooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`2>oooo001[oooo00<0I_ooooooool01oooo`040000oooo06Ko00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001[oooo00<0
I_ooooooool01oooo`040000oooo06Ko00002Oooo`030000oooooooo00Goool00`000?ooooooo`02
oooo0`0008koool006_oool0101Vooooooooooooo`@00002oooo00@0003oool0I_l0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Ooool0
10000?ooo`1Vo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00Joooo`0306Kooooooooo00Soool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool20000Soooo`00Jooo
o`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Ko
oooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`006Oooo`<0000hoooo100001?oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`80000hoooo100003_oool300005Oooo`006_oo
o`030000oooooooo03Ooool00`000?ooooooo`0Doooo00<0I_ooooooool02Oooo`0306Kooooooooo
01Goool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool5
0000>Oooo`030000oooooooo01?oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000
oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo
0000<oooo`@00004oooo00<0003oooooool04_ooo`0306Kooooooooo00Woool00`1Vooooooooo`0E
oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool0
0`000?ooo`00000ioooo00@0003oooooool0000Coooo00<0I_ooooooool02Oooo`0306Kooooooooo
01Goool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_oo
o`80000Doooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0hoooo0P00
03coool200005_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003ooooo
ool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P0008ooool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`03oooo00?o09Wooooo
ool01_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0003oooooool08Oooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P00
02;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool007Koool200001?ooo`800003oooo100000?oool200001Ooo
o`030000oooooooo027oool00ol0VOooooooo`1Zoooo001eoooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool3
00008Oooo`03o`2Ioooooooo06[oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00MOooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007coool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Noooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001koooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<0000Qoooo00?o09Woooooool0J_ooo`00Nooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool007coool200002_ooo`<00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P00
02;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007Koool200001?oo
o`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001eoooo00@0003oooooool0000:
oooo00<0003oooooool01?ooo`030000oooooooo00;oool300008Oooo`03o`2Ioooooooo06[oool0
07Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool08Ooo
o`03o`2Ioooooooo06[oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007Koool200002Ooo
o`@00003oooo0`0000Coool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000R
oooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOoo
ooooo`1Zoooo0027oooo1@0000?oool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00ROooo`030000
oooooooo00?oool300008Oooo`03o`2Ioooooooo06[oool008Woool00`000?ooooooo`2Doooo0029
oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo100000?oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00<0003oooooool01?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.63527 .30902 L
.64043 .30902 L
.64524 .30902 L
.64656 .30902 L
.64728 .30902 L
.64796 .30902 L
s
.64796 .30902 m
.64808 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34309 .30902 L
.34566 .30902 L
.34811 .30902 L
.34918 .30902 L
.35031 .30902 L
.35156 .15451 L
.35271 .15451 L
.36173 .15451 L
.3815 .15451 L
.39178 .15451 L
.39719 .15451 L
.40291 .15451 L
.40533 .15451 L
.40792 .15451 L
.40868 .15451 L
.40941 .15451 L
.41006 .15451 L
.41076 .30902 L
.41143 .30902 L
.41214 .30902 L
.41342 .30902 L
.42308 .30902 L
.46083 .30902 L
.50104 .30902 L
.53972 .30902 L
.58086 .30902 L
.62049 .30902 L
.65859 .30902 L
.69916 .30902 L
.7382 .30902 L
.7797 .30902 L
.81968 .30902 L
.85815 .30902 L
.89907 .30902 L
.93847 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006Woool@06Ko0_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000S_ooo`00JOooo`0306Kooooooooo00Woool400000_ooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool0101Vooooooooo`00
00;oool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000oooooooo08koool006Woool0
0`1Vooooooooo`0<oooo00@0I_ooooooooooool200002_ooo`<00004oooo00<0003oooooool0S_oo
o`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P0008ooool006Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<
oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0
I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0I_oooooo
ool05?ooo`80002?oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`2>
oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo001Y
oooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool20000Soooo`00JOooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool0
0`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Voooo
ooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0D
oooo0P0008ooool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo
08koool006Woool00`1Vooooooooo`0:oooo0P00000406Kooooooooooooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00Woool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00JOoo
o`0306Kooooooooo00Woool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0002>oooo001Yoooo00<0I_ooooooool00oooo`@00002oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo
00Woool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0S_ooo`00JOooo`0306Kooooooooo00[oool2000000<0I_ooooooool01oooo`800004
oooo0`0000Coool00`000?ooooooo`2>oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo
01Coool20000Soooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003ooooo
ool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool0S_oo
o`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo1000017oool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`80000hoooo1000
03_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`0Boooo00<0I_oooooo
ool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool50000>Oooo`030000oooooooo017oool00`1Vooooooooo`0<oooo00<0
I_ooooooool05?ooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003oooooool04?ooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003oooooool0000Aoooo00<0I_oooooo
ool03?ooo`0306Kooooooooo01Coool20000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000>_ooo`80000Boooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`0hoooo0P0003coool200005_ooo`00JOooo`0306Kooooooooo00coool00`1Voooo
ooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0D
oooo0P0008ooool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo
08koool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool0
06Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool0013ooooo
00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`04oooo00?o09Woooooool01Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool08_ooo`03o`2I
oooooooo01Coool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_oo
o`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Sooo
o`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Y
oooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool300008_ooo`03o`2Ioooooooo06Woool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Roooo00?o09Woooooool0JOoo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Y
oooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0R
oooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?
oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Soooo00?o
09Woooooool0J?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool08oooo`03o`2Ioooooooo06Soool007coool200002_ooo`<00004oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1X
oooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?
oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo
06Soool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300008ooo
o`03o`2Ioooooooo06Soool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool08oooo`03o`2Ioooooooo
06Soool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Soooo00?o09Wooooo
ool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?oo
o`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1X
oooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000
oooooooo02?oool00ol0VOooooooo`1Xoooo0027oooo1@0000?oool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Soooo00?o09Wooooo
ool0J?ooo`00ROooo`030000oooooooo00?oool300008oooo`03o`2Ioooooooo06Soool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo100000?oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.64043 .30902 L
.64559 .30902 L
.64812 .30902 L
.65045 .30902 L
.65258 .30902 L
.65365 .30902 L
s
.65365 .30902 m
.65376 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34055 .30902 L
.34186 .30902 L
.34309 .30902 L
.34425 .30902 L
.34549 .15451 L
.3462 .15451 L
.34686 .15451 L
.34811 .15451 L
.35271 .15451 L
.36173 .15451 L
.3815 .15451 L
.39126 .15451 L
.40158 .15451 L
.41038 .15451 L
.4128 .15451 L
.41412 .15451 L
.41538 .15451 L
.41655 .15451 L
.41782 .30902 L
.41898 .30902 L
.42005 .30902 L
.45932 .30902 L
.49707 .30902 L
.53727 .30902 L
.57596 .30902 L
.6171 .30902 L
.65672 .30902 L
.69483 .30902 L
.73539 .30902 L
.77444 .30902 L
.81593 .30902 L
.85592 .30902 L
.89438 .30902 L
.9353 .30902 L
.9747 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006SooolC06Ko00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0002>oooo001Xoooo00<0I_ooooooool02_ooo`@000000oooo`1Vo`000002oooo00<0003ooooo
ool01oooo`800005oooo00<0003oooooool0S_ooo`00J?ooo`0306Kooooooooo00ooool01@1Vo`00
0?ooooooo`000009oooo00<0003oooooool01?ooo`030000oooooooo08koool006Soool00`1Voooo
ooooo`0?oooo00@0I_ooool00000000:oooo0`0000Coool00`000?ooooooo`2>oooo001Xoooo00<0
I_ooooooool03oooo`0306Kooooooooo01;oool20000Soooo`00J?ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00J?ooo`0306Kooooooooo00ooool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo0P00
08ooool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
06Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool006Soool0
0`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool006Soool00`1Voooo
ooooo`0?oooo00<0I_ooooooool04_ooo`80002?oooo001Xoooo00<0I_ooooooool03oooo`0306Ko
oooooooo01;oool00`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo
01;oool00`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool0
0`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool20000Sooo
o`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00J?oo
o`0306Kooooooooo00_oool200000_ooo`0406Kooooo000000000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool02_ooo`060000oooooooo0000oooo06Ko1_oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Woooo00<0
I_ooooooool02oooo`060000oooooooo0000oooo06Ko1oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0008koool006Ooool00`1Vooooooooo`05oooo100000;oool01P000?ooooooo`00
0?ooo`1Vo`Soool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Woooo00<0
I_ooooooool02oooo`060000oooooooo0000oooo06Ko1_ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`2>oooo001Woooo00<0I_ooooooool03?ooo`800002oooo00<0
I_ooooooool01Oooo`800004oooo0`0000Coool00`000?ooooooo`2>oooo001Woooo00<0I_oooooo
ool04?ooo`0306Kooooooooo01;oool20000Soooo`00Ioooo`0306Kooooooooo013oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0
003oooooool0S_ooo`006Oooo`<0000hoooo100000ooool00`1Vooooooooo`0@oooo00<0I_oooooo
ool04_ooo`80000hoooo100003_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?oo
ooooo`0@oooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?ooooooo`0goooo00<0
003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000oooooooo00ooool0
0`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo03Soool00`000?ooooooo`0i
oooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003ooooo
ool03_ooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool0>Oooo`030000
oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003ooooo
ool0000?oooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool20000>?ooo`040000oooooooo
0000>_ooo`030000oooo000001Koool001Woool20000>_ooo`80000@oooo00<0I_ooooooool04?oo
o`0306Kooooooooo01;oool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00Ioooo`0306Ko
oooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo
013oool00`1Vooooooooo`0Boooo0P0008ooool006Ooool00`1Vooooooooo`0@oooo00<0I_oooooo
ool04_ooo`030000oooooooo08koool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_oo
o`030000oooooooo08koool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`06oooo00?o09Woooooool00oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
003oooooool09?ooo`03o`2Ioooooooo01;oool00`000?ooooooo`0joooo00<0003oooooool05Ooo
o`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOoo
ooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1W
oooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P00
02Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
07Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001eoooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300009?ooo`03o`2Ioooooooo06Ooool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0T
oooo00?o09Woooooool0Ioooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P00
02Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Iooo
o`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOoo
ooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1W
oooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0000Toooo00?o09Woooooool0Ioooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007coool200002_oo
o`<00004oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool200009Oooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P00
02Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo06Ooool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool300009?ooo`03o`2Ioooooooo06Ooool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo06Ooool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000U
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo
02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Wooooo
ool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo0027oooo1@0000?oool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00ROooo`030000oooooooo00?oool300009?ooo`03o`2I
oooooooo06Ooool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002oooo`050000oooooooooooo000007goool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65519 .30902 L
.65726 .30902 L
.65844 .30902 L
.65954 .30902 L
.66062 .30902 L
s
.66062 .30902 m
.66073 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33692 .30902 L
.33823 .30902 L
.33944 .15451 L
.34013 .15451 L
.34076 .15451 L
.34309 .15451 L
.38221 .15451 L
.3925 .15451 L
.40363 .15451 L
.40873 .15451 L
.41413 .15451 L
.41874 .15451 L
.42 .15451 L
.4207 .15451 L
.42135 .15451 L
.42263 .30902 L
.4238 .30902 L
.46213 .30902 L
.50291 .30902 L
.54217 .30902 L
.57993 .30902 L
.62013 .30902 L
.65882 .30902 L
.69996 .30902 L
.73958 .30902 L
.77769 .30902 L
.81825 .30902 L
.85729 .30902 L
.89879 .30902 L
.93877 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006KooolE06Ko00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0002>oooo001Voooo00<0I_ooooooool03?ooo`@00002oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Ko
0000000000[oool300001?ooo`030000oooooooo08koool006Koool00`1Vooooooooo`0Boooo00<0
I_ooooooool04Oooo`80002?oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool0
0`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?oo
ooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>
oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool20000Soooo`00I_ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo
01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo01;oool0
0`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Aoooo0P0008ooool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000
oooooooo08koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo
08koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool0
06Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`80002?oooo001Voooo00<0I_oooooo
ool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool03Ooo
o`800003oooo00<0I_l0000000000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001V
oooo00<0I_ooooooool03?ooo`040000oooooooo00000_ooo`0306Kooooooooo00?oool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo
00coool010000?ooooooo`0000;oool00`1Vooooooooo`04oooo00<0003oooooool01Oooo`030000
oooooooo00;oool30000S_ooo`00I_ooo`0306Kooooooooo00Koool400000_ooo`040000oooooooo
00000_ooo`0306Kooooooooo00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>
oooo001Voooo00<0I_ooooooool03?ooo`040000oooooooo00000_ooo`0306Kooooooooo00?oool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00I_ooo`0306Ko
oooooooo00goool200000oooo`0306Kooooooooo00Coool200001?ooo`<00004oooo00<0003ooooo
ool0S_ooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo0P0008ooool006Koool0
0`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool006Koool00`1Voooo
ooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool006Koool00`1Vooooooooo`0B
oooo00<0I_ooooooool04Oooo`030000oooooooo08koool001Woool30000>?ooo`@0000>oooo00<0
I_ooooooool04_ooo`0306Kooooooooo017oool20000>?ooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0goooo00<0003oooooool03oooo`0306Kooooooooo01;oool00`1Vooooooooo`0A
oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
03Woool00`000?ooooooo`0>oooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?oo
ooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
03?oool400001?ooo`030000oooooooo00goool00`1Vooooooooo`0Boooo00<0I_ooooooool04Ooo
o`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool00000>Oooo`040000oooooooo00003_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0A
oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool2
00003oooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo
08koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`80002?oooo001Voooo00<0
I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>oooo001Voooo00<0I_oooooo
ool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_oo
o`0306Kooooooooo017oool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02?ooo`05o`2Ioooooooo
oooo000000koool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0003oooooool09_ooo`03o`2Ioooooooo013oool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P00
02Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
08ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
02Koool00ol0VOooooooo`1Uoooo001eoooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001eoooo00@0
003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300009_ooo`03o`2I
oooooooo06Goool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P00
02Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
08ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool007coool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001koooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0000Voooo00?o09Woooooool0IOooo`00Noooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
07coool200002_ooo`<00004oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool2
00009oooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007Koool200001?ooo`800005oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo001eoooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool300009_ooo`03o`2Ioooooooo06Goool007Goool010000?oo
ooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007Koool200002Oooo`@00003oooo0`00
00Coool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Sooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000W
oooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0027
oooo1@0000?oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool3
00009_ooo`03o`2Ioooooooo06Goool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
00001?ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66177 .30902 L
.66412 .30902 L
.66534 .30902 L
.66604 .30902 L
s
.66604 .30902 m
.66611 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.32831 .30902 L
.33073 .30902 L
.33193 .30902 L
.33304 .30902 L
.33433 .15451 L
.33502 .15451 L
.33575 .15451 L
.33823 .15451 L
.34309 .15451 L
.38467 .15451 L
.40553 .15451 L
.41469 .15451 L
.41954 .15451 L
.42221 .15451 L
.42473 .15451 L
.42716 .15451 L
.42783 .15451 L
.42854 .15451 L
.4298 .30902 L
.43094 .30902 L
.432 .30902 L
.43443 .30902 L
.44348 .30902 L
.46328 .30902 L
.50197 .30902 L
.54311 .30902 L
.58274 .30902 L
.62084 .30902 L
.66141 .30902 L
.70045 .30902 L
.74195 .30902 L
.78193 .30902 L
.8204 .30902 L
.86132 .30902 L
.90072 .30902 L
.93861 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006GooolF06Ko00@00000I_l0I_l0000;oooo00<0003oooooool00_oo
o`<0002>oooo001Uoooo00<0I_ooooooool03Oooo`@00002oooo00@0003oool0I_l00009oooo0P00
00Goool00`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool04oooo`040000oooo06Ko00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool05?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo
00ooool20000Soooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo0P0008ooool006Goool00`1Vooooooooo`0E
oooo00<0I_ooooooool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03ooo
o`80002?oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>
oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001U
oooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001Uoooo00<0
I_ooooooool05Oooo`0306Kooooooooo00ooool20000Soooo`00IOooo`0306Kooooooooo01Goool0
0`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00IOooo`0306Kooooooooo00koool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0=
oooo00@0003oooooool00004oooo00D0I_ooooooooooool000001Oooo`040000oooooooo00001?oo
o`030000oooooooo08koool006Goool00`1Vooooooooo`0=oooo00@0003oooooool00004oooo00<0
I_ooooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool006Goool0
0`1Vooooooooo`07oooo100000;oool010000?ooooooo`0000Coool00`1Vooooooooo`03oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00IOooo`0306Kooooooooo00goool0
10000?ooooooo`0000Coool01@1Vooooooooooooo`000002oooo00D0003oooooooooool000001_oo
o`030000oooooooo08koool006Goool00`1Vooooooooo`0>oooo0P0000Goool00`1Vooooooooo`02
oooo0P0000Coool300001?ooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool03oooo`80002?oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool0
0`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?oo
ooooo`2>oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>
oooo000Ioooo0`0003Soool400003Oooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo0P00
03Soool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo00koool0
0`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo03Ooool00`000?ooooooo`0m
oooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003oooooool03Oooo`0306Kooooooooo
01Goool00`1Vooooooooo`0?oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Ooo
o`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`0<oooo00<0
I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0ioooo00<0003oooooool0>?oo
o`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0000goool0
0`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`80000hoooo00@0003oooooool0000joooo00<0
003oool000005_ooo`006Oooo`80000joooo0P0000koool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool03oooo`030000oooooooo03Soool20000??ooo`80000Foooo001Uoooo00<0I_ooooooool05Ooo
o`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool05Oooo`0306Ko
oooooooo00ooool20000Soooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0
003oooooool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00Woool01?l0VOooooooo`0000koool00`000?ooooooo`0<oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool09oooo`03o`2Ioooooooo
00ooool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOoo
ooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2I
oooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000
oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool007Koool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001eoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool300009oooo`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o
09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P00
02Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
08ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOoo
ooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Woooo00?o09Wooooo
ool0I?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool09oooo`03o`2I
oooooooo06Coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool007coool200002_ooo`<00004oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool20000:?ooo`03o`2Ioooooooo06Coool008ooool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2I
oooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000
oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o
09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo0P00
02Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
07Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001eoooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool300009oooo`03o`2I
oooooooo06Coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0
003oooooool09oooo`03o`2Ioooooooo06Coool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
07Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Sooo
o`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2I
oooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`80000X
oooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o
09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo0027oooo1@0000?oool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00ROooo`030000oooooooo00?oool300009oooo`03o`2Ioooooooo06Coool008Woool00`000?oo
ooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`0000;oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo1@0000?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooo000000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000;oooo0P0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66412 .30902 L
.66652 .30902 L
.66906 .30902 L
.67129 .30902 L
.67255 .30902 L
s
.67255 .30902 m
.67267 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32145 .30902 L
.32392 .30902 L
.32499 .30902 L
.32617 .30902 L
.32728 .30902 L
.32831 .15451 L
.32951 .15451 L
.3306 .15451 L
.33304 .15451 L
.34309 .15451 L
.38315 .15451 L
.40153 .15451 L
.41196 .15451 L
.4217 .15451 L
.42664 .15451 L
.43133 .15451 L
.43258 .15451 L
.43326 .15451 L
.43391 .15451 L
.4346 .30902 L
.43537 .30902 L
.43672 .30902 L
.44164 .30902 L
.46271 .30902 L
.50139 .30902 L
.54253 .30902 L
.58216 .30902 L
.62027 .30902 L
.66083 .30902 L
.69987 .30902 L
.74137 .30902 L
.78135 .30902 L
.81982 .30902 L
.86074 .30902 L
.90014 .30902 L
.93803 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006?ooolH06Ko00@00000I_l0I_l0000;oooo00<0003oooooool00_oo
o`<0002>oooo001Soooo00<0I_ooooooool03oooo`@00002oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`2>oooo001Soooo00<0I_ooooooool05Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001Soooo00<0I_ooooooool05_ooo`800000
0`1Vooooooooo`07oooo0`0000Coool00`000?ooooooo`2>oooo001Soooo00<0I_ooooooool06?oo
o`0306Kooooooooo00koool20000Soooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003ooooo
ool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo0P0008ooool006?oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Voooo
ooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Vooooooooo`0H
oooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Vooooooooo`0Hoooo00<0
I_ooooooool03_ooo`80002?oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool0
0`000?ooooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?oo
ooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`2>
oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool20000Soooo`00Hoooo`0306Ko
oooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo
013oool200001?ooo`8000000`1Vooooooooo`0400000oooo`800005oooo00<0003oooooool0S_oo
o`00Hoooo`0306Kooooooooo00ooool010000?ooooooo`0000Goool0101Vooooooooo`0000Goool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Soooo00<0I_ooooooool03oooo`040000
oooooooo00001Oooo`0506Kooooooooooooo000000Ooool00`000?ooooooo`02oooo0`0008koool0
06?oool00`1Vooooooooo`09oooo100000;oool010000?ooooooo`0000Goool00`1Vooooooooo`02
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo
00ooool010000?ooooooo`0000Goool0101Vooooooooo`0000;oool01@000?ooooooooooo`000006
oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo013oool200001_ooo`0406Kooooooooo
oooo0P0000Coool300001?ooo`030000oooooooo08koool006?oool00`1Vooooooooo`0Hoooo00<0
I_ooooooool03_ooo`80002?oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool0
0`000?ooooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?oo
ooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`2>
oooo000Ioooo0`0003Soool400002oooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo0P00
03Soool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo00coool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo03Ooool00`000?ooooooo`0m
oooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003oooooool02oooo`0306Kooooooooo
01Soool00`1Vooooooooo`0>oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Ooo
o`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`0:oooo00<0
I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0ioooo00<0003oooooool0>?oo
o`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0000_oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`80000hoooo00@0003oooooool0000joooo00<0
003oool000005_ooo`006Oooo`80000joooo0P0000coool00`1Vooooooooo`0Hoooo00<0I_oooooo
ool03_ooo`030000oooooooo03Soool20000??ooo`80000Foooo001Soooo00<0I_ooooooool06?oo
o`0306Kooooooooo00koool00`000?ooooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Ko
oooooooo00koool20000Soooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003ooooo
ool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00_oool00ol0V@000?ooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo02Woool00ol0VOooooooo`0=
oooo00<0003oooooool0>_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Sooo
o`030000oooooooo02Woool00ol0VOooooooo`1Roooo001foooo0P0000Coool200000oooo`@00003
oooo0P0000Goool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00MOooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0`0002Woool00ol0VOooooooo`1Roooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800005oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool007Koool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Sooo
o`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Z
oooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000:Oooo`03o`2Ioooooooo
06;oool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo001loooo0P0000[oool300001?ooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo002?oooo0P0002[oool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Sooo
o`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`80000Z
oooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001f
oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00MOooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0002Woool00ol0VOoo
ooooo`1Roooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001f
oooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool0
0`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_oo
o`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Sooo
o`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00Qoooo`D00003oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008Woool00`000?ooooooo`03oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08Woool00`000?ooooooo`03oooo0`0002Woool00ol0VOooooooo`1Roooo0029oooo00<0003ooooo
ool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool0000;oooo00@0003oooooool00002oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008
oooo1@0000Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000
oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.66906 .30902 L
.67373 .30902 L
.67578 .30902 L
.67687 .30902 L
.67803 .30902 L
s
.67803 .30902 m
.67815 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.31304 .30902 L
.31574 .30902 L
.31865 .30902 L
.32006 .30902 L
.32076 .30902 L
.3214 .30902 L
.3226 .15451 L
.32392 .15451 L
.34309 .15451 L
.38221 .15451 L
.40219 .15451 L
.4127 .15451 L
.4238 .15451 L
.43374 .15451 L
.43647 .15451 L
.43797 .15451 L
.43871 .15451 L
.43939 .15451 L
.44071 .30902 L
.44141 .30902 L
.44215 .30902 L
.44466 .30902 L
.46386 .30902 L
.50161 .30902 L
.54182 .30902 L
.5805 .30902 L
.62164 .30902 L
.66127 .30902 L
.69938 .30902 L
.73994 .30902 L
.77898 .30902 L
.82048 .30902 L
.86046 .30902 L
.89893 .30902 L
.93985 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool006;ooolI06Ko00@00000I_l0I_l0000206Ko2Oooo`030000oooooooo
00;oool30000S_ooo`00H_ooo`0306Kooooooooo013oool400000_ooo`060000oooooooo0000oooo
06Ko1oooo`800005oooo00<0003oooooool0S_ooo`00H_ooo`0306Kooooooooo01Koool01P000?oo
ooooo`000?ooo`1Vo`Ooool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00H_ooo`0306Ko
oooooooo01Ooool200000_ooo`0306Kooooooooo00Goool300001?ooo`030000oooooooo08koool0
06;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80002?oooo001Roooo00<0I_oooooo
ool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool20000Soooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003ooooo
ool0S_ooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0S_oo
o`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00H_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo0P0008ooool006;oool00`1Vooooooooo`0K
oooo00<0I_ooooooool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0
I_ooooooool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`80002?oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>
oooo001Roooo00<0I_ooooooool04Oooo`800004oooo0P0000;oool00`1Vo`000000000200000ooo
o`800005oooo00<0003oooooool0S_ooo`00H_ooo`0306Kooooooooo013oool010000?ooooooo`00
00Ooool00`1Vo`000?ooo`04oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00H_oo
o`0306Kooooooooo013oool010000?ooooooo`0000Ooool00`1Vooooo`000007oooo00<0003ooooo
ool00_ooo`<0002>oooo001Roooo00<0I_ooooooool02_ooo`@00002oooo00@0003oooooool00007
oooo00@0I_ooooooool00004oooo0P0000Goool00`000?ooooooo`2>oooo001Roooo00<0I_oooooo
ool04?ooo`040000oooooooo00001oooo`0506Ko0000oooooooo000000?oool00`000?ooooooo`04
oooo00<0003oooooool0S_ooo`00H_ooo`0306Kooooooooo017oool200002?ooo`0406Kooooo0000
00001?ooo`<00004oooo00<0003oooooool0S_ooo`00H_ooo`0306Kooooooooo01_oool00`1Voooo
ooooo`0<oooo0P0008ooool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000
oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo
08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo08koool0
01Woool30000>?ooo`@0000:oooo00<0I_ooooooool06oooo`0306Kooooooooo00coool20000>?oo
o`@0000koooo0`0001Goool001[oool00`000?ooooooo`0goooo00<0003oooooool02oooo`0306Ko
oooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0=oooo`030000oooooooo03goool0
0`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?ooooooo`0:oooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000A
oooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo00Woool00`1Voooo
ooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo00<0003oool00000>Oooo`040000oooooooo00002_ooo`0306Ko
oooooooo01_oool00`1Vooooooooo`0<oooo0P0003Soool010000?ooooooo`0003[oool00`000?oo
o`00000Foooo000Ioooo0P0003[oool200002oooo`0306Kooooooooo01_oool00`1Vooooooooo`0<
oooo00<0003oooooool0>?ooo`80000loooo0P0001Koool006;oool00`1Vooooooooo`0Koooo00<0
I_ooooooool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool03?ooo`80002?oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?oo
ooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>
oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo000@
ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0:_ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Q
oooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?
oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo
02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool007Koool200001?ooo`800003oooo100000?oool2
00001Oooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001eoooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo
00;oool30000:_ooo`03o`2Ioooooooo067oool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Q
oooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool007coool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Noooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001k
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Zoooo00?o09Woooooool0HOoo
o`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool007coool200002_ooo`<00004oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?
oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo
02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool007Koool2
00001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000:_ooo`03o`2Ioooooooo
067oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo067oool007Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool007Koool2
00002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`80000[oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Q
oooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00Soooo`80000[oooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`80000[oooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`80000[oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo0027oooo1@0000?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00ROoo
o`030000oooooooo00?oool30000:_ooo`03o`2Ioooooooo067oool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002Ooo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.66906 .30902 L
.67803 .30902 L
.68044 .30902 L
.683 .30902 L
.68364 .30902 L
.68433 .30902 L
s
.68433 .30902 m
.6844 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31054 .30902 L
.31304 .30902 L
.31444 .30902 L
.31523 .30902 L
.31597 .15451 L
.31727 .15451 L
.31865 .15451 L
.32392 .15451 L
.34309 .15451 L
.38467 .15451 L
.40553 .15451 L
.42473 .15451 L
.43443 .15451 L
.43916 .15451 L
.44348 .15451 L
.4446 .15451 L
.44582 .15451 L
.44697 .30902 L
.44804 .30902 L
.45292 .30902 L
.46328 .30902 L
.50255 .30902 L
.5403 .30902 L
.5805 .30902 L
.61919 .30902 L
.66033 .30902 L
.69996 .30902 L
.73806 .30902 L
.77863 .30902 L
.81767 .30902 L
.85917 .30902 L
.89915 .30902 L
.93762 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0063ooolK06Ko00@00000I_l0I_l0000306Ko2?ooo`030000oooooooo
00;oool30000S_ooo`00H?ooo`0306Kooooooooo01;oool400000_ooo`040000oooooooo00000_oo
o`0306Kooooooooo00Coool200001Oooo`030000oooooooo08koool0063oool00`1Vooooooooo`0H
oooo00@0003oooooool00002oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo001Poooo00<0I_ooooooool06Oooo`800003oooo00<0I_ooooooool01?ooo`<00004
oooo00<0003oooooool0S_ooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo0P00
08ooool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo08koool0
063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo08koool0063oool0
0`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo08koool0063oool00`1Voooo
ooooo`0Noooo00<0I_ooooooool02oooo`80002?oooo001Poooo00<0I_ooooooool07_ooo`0306Ko
oooooooo00_oool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo
00_oool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool0
0`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool20000Sooo
o`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?oo
o`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Ko
oooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Kooooooooo
01koool00`1Vooooooooo`0;oooo0P0008ooool0063oool00`1Vooooooooo`0Noooo00<0I_oooooo
ool02oooo`030000oooooooo08koool0063oool00`1Vooooooooo`0Coooo0P0000Coool200000ooo
o`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool04_ooo`040000
oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001Poooo00<0I_ooooooool04_ooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0008koool0063oool00`1Vooooooooo`0<oooo100000;oool010000?oo
ooooo`0000Woool00`1Vo`000?ooo`03oooo0P0000Goool00`000?ooooooo`2>oooo001Poooo00<0
I_ooooooool04_ooo`040000oooooooo00002?ooo`04000006Kooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool04oooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo08koool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_oo
o`80002?oooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?ooooooo`2>
oooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?ooooooo`2>oooo001P
oooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?ooooooo`2>oooo000Ioooo0`00
03Soool400002?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo0P0003Soool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo00Woool00`1Vooooooooo`0O
oooo00<0I_ooooooool02_ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool02?ooo`0306Kooooooooo01ooool00`1Voooo
ooooo`0:oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002
oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`07oooo00<0I_ooooooool07ooo
o`0306Kooooooooo00[oool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0000Soool00`1Vooooooooo`0O
oooo00<0I_ooooooool02_ooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_oo
o`006Oooo`80000joooo0P0000Woool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000
oooooooo03Soool20000??ooo`80000Foooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo
00[oool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool2
0000Soooo`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool0S_oo
o`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool0S_ooo`00H?oo
o`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool0S_ooo`004?ooool0000A
oooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooool0V@0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool0>Oooo`030000oooooooo02coool00ol0VOooooooo`0:oooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOoo
ooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Sooo
o`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2I
oooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o
09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
02coool00ol0VOooooooo`1Ooooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0;?ooo`03o`2I
oooooooo05ooool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0/oooo00?o
09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOoo
ooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Sooo
o`030000oooooooo02coool00ol0VOooooooo`1Ooooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000;?ooo`03o`2Ioooooooo05ooool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo02coool00ol0VOoo
ooooo`1Ooooo001loooo0P0000[oool300001?ooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo0P0002goool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2I
oooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o
09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0002coool00ol0VOooooooo`1Ooooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo02coool0
0ol0VOooooooo`1Ooooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool20000;Ooo
o`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Sooo
o`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2I
oooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Wooooo
ool0Goooo`00Qoooo`D00003oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008Woool00`000?oo
ooooo`03oooo0`0002coool00ol0VOooooooo`1Ooooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;
oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000coool010000?ooooooo`0000Woool200001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.67803 .30902 L
.68335 .30902 L
.68596 .30902 L
.68711 .30902 L
.68837 .30902 L
.6895 .30902 L
s
.6895 .30902 m
.6896 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
.30992 .15451 L
.31059 .15451 L
.31304 .15451 L
.32392 .15451 L
.34309 .15451 L
.38221 .15451 L
.40219 .15451 L
.4238 .15451 L
.43394 .15451 L
.43949 .15451 L
.44466 .15451 L
.44908 .15451 L
.45035 .15451 L
.45156 .15451 L
.45264 .30902 L
.45382 .30902 L
.46386 .30902 L
.50465 .30902 L
.54391 .30902 L
.58166 .30902 L
.62187 .30902 L
.66055 .30902 L
.70169 .30902 L
.74132 .30902 L
.77943 .30902 L
.81999 .30902 L
.85903 .30902 L
.90053 .30902 L
.94051 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005oooolL06Ko00@00000I_l0I_l0000506Ko1_ooo`030000oooooooo
00;oool30000S_ooo`00Goooo`0306Kooooooooo01?oool400000_ooo`040000oooooooo00001?oo
o`0306Kooooooooo00;oool200001Oooo`030000oooooooo08koool005ooool00`1Vooooooooo`0I
oooo00@0003oooooool00004oooo00<0I_ooooooool00_ooo`030000oooooooo00Coool00`000?oo
ooooo`2>oooo001Ooooo00<0I_ooooooool06_ooo`800005oooo00<0I_ooooooool00_ooo`<00004
oooo00<0003oooooool0S_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo0P00
08ooool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool0
05ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool0
0`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool00`1Voooo
ooooo`0Qoooo00<0I_ooooooool02Oooo`80002?oooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo
00Woool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool0
0`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool20000Sooo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Ko
oooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Kooooooooo
027oool00`1Vooooooooo`09oooo0P0008ooool005ooool00`1Vooooooooo`0Qoooo00<0I_oooooo
ool02Oooo`030000oooooooo08koool005ooool00`1Vooooooooo`0Doooo0P0000Coool200000ooo
o`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool04oooo`040000
oooooooo00002?ooo`030000oooo06Ko00?oool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001Ooooo00<0I_ooooooool04oooo`040000oooooooo00002Oooo`03000006Kooooo00Goool0
0`000?ooooooo`02oooo0`0008koool005ooool00`1Vooooooooo`0=oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00<0
I_ooooooool04oooo`040000oooooooo00002?ooo`040000oooo06Ko00000oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool05?ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo08koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Ooo
o`80002?oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>
oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo001O
oooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`2>oooo000Ioooo0`00
03Soool400001oooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo0P0003Soool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo00Soool00`1Vooooooooo`0Q
oooo00<0I_ooooooool02Oooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool01oooo`0306Kooooooooo027oool00`1Voooo
ooooo`09oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002
oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`06oooo00<0I_ooooooool08Ooo
o`0306Kooooooooo00Woool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0000Ooool00`1Vooooooooo`0Q
oooo00<0I_ooooooool02Oooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_oo
o`006Oooo`80000joooo0P0000Soool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000
oooooooo03Soool20000??ooo`80000Foooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo
00Woool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool2
0000Soooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_oo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`004?ooool0000A
oooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool010000?ooooooool0V@_oool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0003oooooool0;Oooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P00
02koool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool007Koool200001?ooo`800003oooo100000?oool200001Ooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo001eoooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool3
0000;Oooo`03o`2Ioooooooo05koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000Goool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00MOooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007coool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Noooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001koooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<0000]oooo00?o09Woooooool0G_ooo`00Nooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool007coool200002_ooo`<00004oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008ooool20000;_ooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P00
02koool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007Koool200001?oo
o`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001eoooo00@0003oooooool0000:
oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000;Oooo`03o`2Ioooooooo05koool0
07Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0;Ooo
o`03o`2Ioooooooo05koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007Koool200002Ooo
o`@00003oooo0`0000Coool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^
oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo0027oooo1@0000?oool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00ROooo`030000
oooooooo00?oool30000;Oooo`03o`2Ioooooooo05koool008Woool00`000?ooooooo`2Doooo0029
oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.67803 .30902 L
.68335 .30902 L
.68837 .30902 L
.69287 .30902 L
.6941 .30902 L
.6954 .30902 L
s
.6954 .30902 m
.69551 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30059 .30902 L
.30182 .30902 L
.30246 .30902 L
.30316 .30902 L
.30442 .15451 L
.3056 .15451 L
.30791 .15451 L
.31304 .15451 L
.32392 .15451 L
.34309 .15451 L
.38467 .15451 L
.40553 .15451 L
.42473 .15451 L
.44348 .15451 L
.45292 .15451 L
.45551 .15451 L
.45693 .15451 L
.45763 .15451 L
.45828 .15451 L
.45953 .30902 L
.4602 .30902 L
.4609 .30902 L
.46328 .30902 L
.50104 .30902 L
.54124 .30902 L
.57993 .30902 L
.62107 .30902 L
.66069 .30902 L
.6988 .30902 L
.73936 .30902 L
.7784 .30902 L
.8199 .30902 L
.85988 .30902 L
.89835 .30902 L
.93927 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005gooolN06Ko00@00000I_l0I_l0000606Ko1Oooo`030000oooooooo
00;oool30000S_ooo`00GOooo`0306Kooooooooo01Goool400000_ooo`040000oooooooo00001Ooo
o`0406Kooooooooooooo0P0000Goool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool06ooo
o`040000oooooooo00001Oooo`0506Kooooooooooooo000000Koool00`000?ooooooo`2>oooo001M
oooo00<0I_ooooooool07?ooo`800006oooo00@0I_ooooooooooool300001?ooo`030000oooooooo
08koool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`80002?oooo001Moooo00<0
I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001Moooo00<0I_oooooo
ool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09?oo
o`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09?ooo`0306Ko
oooooooo00Soool20000Soooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0
003oooooool0S_ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003ooooo
ool0S_ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003oooooool0S_oo
o`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo0P0008ooool005goool00`1Voooo
ooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0T
oooo00<0I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0
I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0I_oooooo
ool02?ooo`80002?oooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`2>oooo001Moooo00<0I_ooooooool05_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool0S_ooo`00GOooo`0306Kooooooooo01Goool010000?ooooooo`0000Soool0
10000?ooooooo`1Vo`;oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Moooo00<0
I_ooooooool05Oooo`040000oooooooo00002Oooo`040000oooooooo06Ko1?ooo`030000oooooooo
00;oool30000S_ooo`00GOooo`0306Kooooooooo00ooool400000_ooo`040000oooooooo00002_oo
o`030000oooo06Ko00;oool200001Oooo`030000oooooooo08koool005goool00`1Vooooooooo`0E
oooo00@0003oooooool00008oooo00D0003oooooool00000I_l00_ooo`030000oooooooo00Coool0
0`000?ooooooo`2>oooo001Moooo00<0I_ooooooool05_ooo`80000:oooo0P000004oooo06Kooooo
oooo0`0000Coool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo
00Ooool20000Soooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003ooooo
ool0S_ooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool0S_oo
o`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool0S_ooo`006Ooo
o`<0000hoooo100000Goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`80000hoooo1000
03_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`06oooo00<0I_oooooo
ool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool50000>Oooo`030000oooooooo00Goool00`1Vooooooooo`0Uoooo00<0
I_ooooooool01oooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003oooooool01?ooo`0306Kooooooooo
02Goool00`1Vooooooooo`07oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003oooooool00005oooo00<0I_oooooo
ool09Oooo`0306Kooooooooo00Ooool20000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000>_ooo`800006oooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool0
0`000?ooooooo`0hoooo0P0003coool200005_ooo`00GOooo`0306Kooooooooo02Goool00`1Voooo
ooooo`07oooo00<0003oooooool0S_ooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07
oooo0P0008ooool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo
08koool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo08koool0
05goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo08koool0013ooooo
00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool00_ooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0;oooo`03o`2I
oooooooo00Ooool00`000?ooooooo`0joooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0_oooo00?o09Woooooool0G?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000_oooo00?o
09Woooooool0G?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool007coool200002_ooo`<00004oooo00<0003ooooo
ool0;oooo`03o`2Ioooooooo05coool008ooool20000<?ooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000;ooo
o`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?oo
o`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1L
oooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo0027oooo1@0000?oool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00ROooo`030000oooooooo00?oool30000;oooo`03o`2Ioooooooo05coool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.6883 .30902 L
.69289 .30902 L
.69774 .30902 L
.70025 .30902 L
.70094 .30902 L
.70168 .30902 L
.70238 .30902 L
s
.70238 .30902 m
.70244 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29088 .30902 L
.29349 .30902 L
.2957 .30902 L
.29695 .30902 L
.29809 .15451 L
.29933 .15451 L
.30069 .15451 L
.30316 .15451 L
.3438 .15451 L
.38293 .15451 L
.40291 .15451 L
.42451 .15451 L
.43466 .15451 L
.44538 .15451 L
.45453 .15451 L
.45704 .15451 L
.45973 .15451 L
.46103 .15451 L
.46227 .15451 L
.46337 .15451 L
.46458 .30902 L
.4658 .30902 L
.46691 .30902 L
.46943 .30902 L
.47398 .30902 L
.48435 .30902 L
.50536 .30902 L
.54499 .30902 L
.58309 .30902 L
.62365 .30902 L
.6627 .30902 L
.7042 .30902 L
.74418 .30902 L
.78265 .30902 L
.82356 .30902 L
.86297 .30902 L
.90085 .30902 L
.94119 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005cooolO06Ko00@00000I_l0I_l0000806Ko0oooo`030000oooooooo
00;oool30000S_ooo`00G?ooo`0306Kooooooooo01Koool400000_ooo`040000oooooooo00001ooo
o`0406Kooooo000000001Oooo`030000oooooooo08koool005coool00`1Vooooooooo`0Loooo00@0
003oooooool00007oooo00<0I_ooool000001_ooo`030000oooooooo08koool005coool00`1Voooo
ooooo`0Moooo0P0000Soool00`1Vooooo`00000200001?ooo`030000oooooooo08koool005coool0
0`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`80002?oooo001Loooo00<0I_ooooooool09ooo
o`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Loooo00<0I_ooooooool09oooo`0306Ko
oooooooo00Koool00`000?ooooooo`2>oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool2
0000Soooo`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_oo
o`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00G?oo
o`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00G?ooo`0306Ko
oooooooo02Ooool00`1Vooooooooo`06oooo0P0008ooool005coool00`1Vooooooooo`0Woooo00<0
I_ooooooool01_ooo`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_oooooo
ool01_ooo`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_oo
o`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`80002?
oooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001L
oooo00<0I_ooooooool05oooo`800004oooo0P0000?oool4000000?oool0I_ooool00P0000Goool0
0`000?ooooooo`2>oooo001Loooo00<0I_ooooooool05_ooo`040000oooooooo00002?ooo`030000
oooooooo00;oool01@1Vo`000?ooooooo`000004oooo00<0003oooooool0S_ooo`00Foooo`0306Ko
oooooooo01Ooool010000?ooooooo`0000Woool01@000?ooooooooooo`1Vo`03oooo00<0003ooooo
ool00_ooo`<0002>oooo001Koooo00<0I_ooooooool04Oooo`@00002oooo00@0003oooooool0000:
oooo00D0003oooooool0I_ooool00P0000Goool00`000?ooooooo`2>oooo001Koooo00<0I_oooooo
ool05oooo`040000oooooooo00002?ooo`080000oooooooo0000oooo06Kooooo00001_ooo`030000
oooooooo08koool005_oool00`1Vooooooooo`0Hoooo0P0000[oool200000_ooo`0306Kooooo0000
00800004oooo00<0003oooooool0S_ooo`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06
oooo0P0008ooool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo
08koool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo08koool0
05_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo08koool001Woool3
0000>?ooo`@00003oooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool20000>?ooo`@0000k
oooo0`0001Goool001[oool00`000?ooooooo`0goooo00<0003oooooool01?ooo`0306Kooooooooo
02Soool00`1Vooooooooo`06oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?oo
ooooo`0Doooo000Goooo1@0003Woool00`000?ooooooo`03oooo00<0I_ooooooool0:?ooo`0306Ko
oooooooo00Koool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo1000
00;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo00;oool00`1Vooooooooo`0X
oooo00<0I_ooooooool01_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003ooooo
ool0000Foooo000Hoooo00<0003oool00000>Oooo`040000oooooooo00000oooo`0306Kooooooooo
02Soool00`1Vooooooooo`06oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000F
oooo000Ioooo0P0003[oool200001?ooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0
003oooooool0>?ooo`80000loooo0P0001Koool005_oool00`1Vooooooooo`0Xoooo00<0I_oooooo
ool01_ooo`030000oooooooo08koool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_oo
o`80002?oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`2>
oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001K
oooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo000@ooooo`00
017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00?oool00ol0VOooooooo`06oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo033oool00ol0VOoo
ooooo`06oooo00<0003oooooool0>_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o
09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001foooo0P0000Coool200000ooo
o`@00003oooo0P0000Goool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00MOooo`040000
oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`00033oool00ol0VOooooooo`1Koooo001eoooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool007Koool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o
09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001loooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool007_oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000<?ooo`03o`2I
oooooooo05_oool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo001loooo0P0000[oool300001?ooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00033oool0
0ol0VOooooooo`1Koooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Ooo
o`030000oooooooo033oool00ol0VOooooooo`1Koooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool2
0000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?oo
ooooo`0`oooo00?o09Woooooool0Foooo`00Qoooo`D00003oooo00<0003oooooool0<?ooo`03o`2I
oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008Woool00`000?ooooooo`03oooo0`00033oool00ol0VOooooooo`1Koooo0029oooo00<0
003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.69774 .30902 L
.7026 .30902 L
.70516 .30902 L
.70656 .30902 L
.70787 .30902 L
s
.70787 .30902 m
.70798 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28302 .30902 L
.288 .30902 L
.28936 .30902 L
.29012 .30902 L
.29083 .30902 L
.2915 .30902 L
.29222 .15451 L
.29349 .15451 L
.30316 .15451 L
.3438 .15451 L
.38293 .15451 L
.42451 .15451 L
.44538 .15451 L
.45453 .15451 L
.45938 .15451 L
.46458 .15451 L
.46718 .15451 L
.46846 .15451 L
.46965 .15451 L
.47072 .30902 L
.47186 .30902 L
.47427 .30902 L
.48333 .30902 L
.50313 .30902 L
.54088 .30902 L
.58108 .30902 L
.61977 .30902 L
.66091 .30902 L
.70054 .30902 L
.73864 .30902 L
.7792 .30902 L
.81825 .30902 L
.85975 .30902 L
.89973 .30902 L
.9382 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005[ooolQ06Ko00@00000I_l0I_l0000906Ko0_ooo`030000oooooooo
00;oool30000S_ooo`00F_ooo`0306Kooooooooo01Soool400000_ooo`040000oooooooo00002?oo
o`0306Ko0000000000Goool00`000?ooooooo`2>oooo001Joooo00<0I_ooooooool07_ooo`040000
oooooooo00002?ooo`0306Ko0000oooo00Goool00`000?ooooooo`2>oooo001Joooo00<0I_oooooo
ool07oooo`800009oooo00@0I_l0000000000004oooo00<0003oooooool0S_ooo`00F_ooo`0306Ko
oooooooo02[oool00`1Vooooooooo`05oooo0P0008ooool005[oool00`1Vooooooooo`0Zoooo00<0
I_ooooooool01Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool01Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Ooo
o`030000oooooooo08koool005[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Oooo`80002?
oooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001J
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001Joooo00<0
I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001Joooo00<0I_oooooo
ool0:_ooo`0306Kooooooooo00Goool20000Soooo`00F_ooo`0306Kooooooooo02[oool00`1Voooo
ooooo`05oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05
oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0
003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo0P0008ooool0
05[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Oooo`030000oooooooo08koool005[oool0
0`1Vooooooooo`0Ioooo0P0000Coool200000oooo`@00002oooo00<0I_l0000000001Oooo`030000
oooooooo08koool005[oool00`1Vooooooooo`0Hoooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0H
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`0306Kooooo000000Coool30000S_oo
o`00F_ooo`0306Kooooooooo01;oool400000_ooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0Hoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo08koool0
05[oool00`1Vooooooooo`0Ioooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0S_oo
o`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo0P0008ooool005[oool00`1Voooo
ooooo`0[oooo00<0I_ooooooool01?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[
oooo00<0I_ooooooool01?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0
I_ooooooool01?ooo`030000oooooooo08koool001Woool30000>?ooo`@00002oooo00<0I_oooooo
ool0:oooo`0306Kooooooooo00Coool20000>?ooo`@0000koooo0`0001Goool001[oool00`000?oo
ooooo`0goooo00<0003oooooool00oooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0
003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool0
0`000?ooooooo`02oooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`0h
oooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool4
00001?ooo`050000oooooooooooo06Ko02goool00`1Vooooooooo`04oooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0
003oooooool00002oooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool20000>?ooo`040000
oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_ooo`800003oooo00<0I_oooooo
ool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00F_oo
o`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool0S_ooo`00F_ooo`0306Ko
oooooooo02_oool00`1Vooooooooo`04oooo0P0008ooool005[oool00`1Vooooooooo`0[oooo00<0
I_ooooooool01?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0I_oooooo
ool01?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?oo
o`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01Oooo`03o`2Ioooooooo
00Coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo00Coool00`000?ooooooo`0joooo00<0003ooooo
ool05Oooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1I
oooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001eoooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000<_ooo`03o`2Ioooooooo
05Woool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`0boooo00?o09Woooooool0FOooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00M_oo
o`80000:oooo0P0000Coool300001?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000boooo00?o09Woooooool0FOooo`00Noooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool007coool2
00002_ooo`<00004oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool20000<ooo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1I
oooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool007Koool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool30000<_ooo`03o`2Ioooooooo05Woool007Goool010000?ooooooo`00
00_oool010000?ooooooooooo`800005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool007Koool200002Oooo`@00003oooo0`0000Coool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`80000coooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1I
oooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOooo`00Soooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0027oooo1@00
00?oool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00ROooo`030000oooooooo00?oool30000<_oo
o`03o`2Ioooooooo05Woool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?oo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800005oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?oo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800009
oooo100000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.69774 .30902 L
.7026 .30902 L
.70787 .30902 L
.71028 .30902 L
.7116 .30902 L
.71284 .30902 L
.71389 .30902 L
s
.71389 .30902 m
.714 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28025 .30902 L
.28302 .30902 L
.28425 .30902 L
.28542 .30902 L
.28606 .15451 L
.28676 .15451 L
.288 .15451 L
.29349 .15451 L
.30316 .15451 L
.3438 .15451 L
.38293 .15451 L
.42451 .15451 L
.44538 .15451 L
.45453 .15451 L
.46458 .15451 L
.46926 .15451 L
.47183 .15451 L
.4731 .15451 L
.47427 .15451 L
.47537 .15451 L
.47654 .30902 L
.47771 .30902 L
.47901 .30902 L
.48333 .30902 L
.50313 .30902 L
.54333 .30902 L
.58202 .30902 L
.62316 .30902 L
.66278 .30902 L
.70089 .30902 L
.74145 .30902 L
.7805 .30902 L
.822 .30902 L
.86198 .30902 L
.90044 .30902 L
.94136 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005WooolR06Ko00@00000I_l0I_l0000;06Ko00<0003oooooool00_oo
o`<0002>oooo001Ioooo00<0I_ooooooool06Oooo`@00002oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`2>oooo001Ioooo00<0I_ooooooool07oooo`040000oooooooo00002Ooo
o`03000006Kooooo00Coool00`000?ooooooo`2>oooo001Ioooo00<0I_ooooooool08?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo
00?oool20000Soooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003ooooo
ool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0S_oo
o`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00FOoo
o`0306Kooooooooo02goool00`1Vooooooooo`03oooo0P0008ooool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0
I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_oooooo
ool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00ooo
o`80002?oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>
oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001I
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001Ioooo00<0
I_ooooooool0;Oooo`0306Kooooooooo00?oool20000Soooo`00FOooo`0306Kooooooooo02goool0
0`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00FOooo`0306Kooooooooo01[oool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0I
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooo06Ko00001?ooo`030000
oooooooo08koool005Woool00`1Vooooooooo`0Ioooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`0306Ko0000oooo00?oool30000S_ooo`00FOooo`0306Kooooooooo01?oool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool0
05Woool00`1Vooooooooo`0Ioooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
0000I_ooool01?ooo`030000oooooooo08koool005Woool00`1Vooooooooo`0Joooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Voooo
ooooo`03oooo0P0008ooool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000
oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo
08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo08koool0
01Woool30000>?ooo`@000000oooo`1Vooooo`0^oooo00<0I_ooooooool00oooo`80000hoooo1000
03_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`02oooo00<0I_oooooo
ool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool50000>Oooo`050000oooooooooooo06Ko02ooool00`1Vooooooooo`03
oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0
003oooooool0000coooo100000Coool010000?ooooooo`1Vobooool00`1Vooooooooo`03oooo00<0
003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000ioooo00H0003oooooool0003oool0I_l_oooo00<0I_ooooooool00oooo`80000hoooo00@0
003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0000;oool00`1Voooo
ooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo03Soool20000??ooo`80000Foooo001I
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001Ioooo00<0
I_ooooooool0;Oooo`0306Kooooooooo00?oool20000Soooo`00FOooo`0306Kooooooooo02goool0
0`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Voooo
ooooo`03oooo00<0003oooooool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03
oooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00?o09Wooooo
ool00oooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`000?ooooooo`0coooo00?o09Woooooool00oooo`030000oooooooo03[oool00`000?oo
ooooo`0Eoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?oo
o`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Sooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2I
oooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
08ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007Goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000coooo00?o09Wooooo
ool0F?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo03?oool00ol0VOooooooo`1Hoooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001f
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
08ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?oo
o`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Sooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2I
oooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo001koooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool007_oool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0003?oool00ol0VOooooooo`1Hoooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`80000d
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
08ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`<0000coooo00?o09Woooooool0F?ooo`00MOooo`040000oooooooo
00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00M_ooo`800009oooo100000?oool300001?oo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool0
0ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008Ooool5
00000oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo0029oooo00<0003oooooool00ooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo0029oooo00<0003oooooool00oooo`<0000c
oooo00?o09Woooooool0F?ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2D
oooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Woool200001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.70787 .30902 L
.71284 .30902 L
.71741 .30902 L
.71874 .30902 L
.71998 .30902 L
s
.71998 .30902 m
.72011 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27279 .30902 L
.27513 .30902 L
.27765 .30902 L
.2784 .30902 L
.2791 .30902 L
.28042 .15451 L
.28166 .15451 L
.28302 .15451 L
.30316 .15451 L
.3438 .15451 L
.38293 .15451 L
.42451 .15451 L
.44538 .15451 L
.45453 .15451 L
.46458 .15451 L
.46926 .15451 L
.47427 .15451 L
.47671 .15451 L
.47901 .15451 L
.48001 .15451 L
.48108 .15451 L
.48224 .30902 L
.48333 .30902 L
.50313 .30902 L
.54088 .30902 L
.58108 .30902 L
.61977 .30902 L
.66091 .30902 L
.70054 .30902 L
.73864 .30902 L
.7792 .30902 L
.81825 .30902 L
.85975 .30902 L
.89973 .30902 L
.9382 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005OooolT06Ko00@00000I_l0I_l0000;06Ko00<0003oooooool00_oo
o`<0002>oooo001Goooo00<0I_ooooooool06oooo`@00002oooo00@0003oooooool00009oooo0P00
000306Kooooooooo00;oool00`000?ooooooo`2>oooo001Goooo00<0I_ooooooool08Oooo`040000
oooooooo00002Oooo`030000oooo06Ko00Coool00`000?ooooooo`2>oooo001Goooo00<0I_oooooo
ool08_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Goooo00<0I_ooooooool0<?oo
o`0306Kooooooooo00;oool20000Soooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0
003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0003ooooo
ool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P0008ooool005Ooool0
0`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Voooo
ooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`
oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`oooo00<0
I_ooooooool00_ooo`80002?oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
0`000?ooooooo`2>oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?oo
ooooo`2>oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>
oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool20000Soooo`00Eoooo`0306Ko
oooooooo033oool00`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo
01coool200001?ooo`800003oooo100000?oool2000000<0I_ooooooool00_ooo`030000oooooooo
08koool005Ooool00`1Vooooooooo`0Koooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0Koooo00@0
003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000S_ooo`00Eooo
o`0306Kooooooooo01Goool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
000000<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0Koooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oool0I_l01?ooo`030000oooooooo
08koool005Ooool00`1Vooooooooo`0Loooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P0008ooool005Ooool0
0`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Voooo
ooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`
oooo00<0I_ooooooool00_ooo`030000oooooooo08koool001Woool30000>?ooo`@0000boooo00<0
I_ooooooool00_ooo`80000hoooo100003_oool300005Oooo`006_ooo`030000oooooooo03Ooool0
10000?ooooooo`1Voc;oool00`1Vooooooooo`02oooo00<0003oooooool0=oooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?ooo`1Vo`0boooo00<0I_oooooo
ool00_ooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_oo
o`040000oooooooo0000<oooo`@00004oooo00<00000I_ooool0<Oooo`0306Kooooooooo00;oool0
0`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000
oooo000003Woool010000?ooooooo`0003;oool00`1Vooooooooo`02oooo0P0003Soool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool2000000<0I_ooooooool0<?oo
o`0306Kooooooooo00;oool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00Eoooo`0306Ko
oooooooo033oool00`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo
033oool00`1Vooooooooo`02oooo0P0008ooool005Ooool00`1Vooooooooo`0`oooo00<0I_oooooo
ool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`030000oooooooo08koool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02?ooo`05o`2Ioooooooooooo0000
00koool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0e
oooo00Go09Woooooooooool00000??ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001foooo0P0000Coool200000ooo
o`@00003oooo0P0000Goool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00MOooo`040000
oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0003Goool00ol0VOooooooo`1Foooo001eoooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool007Koool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1F
oooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001loooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool007_oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000=Oooo`03o`2I
oooooooo05Koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo001loooo0P0000[oool300001?ooo`030000oooooooo
03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1F
oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo
03Goool00ol0VOooooooo`1Foooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`0003Goool0
0ol0VOooooooo`1Foooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool200001Ooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo03Goool00ol0VOooooooo`1F
oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool2
0000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Qoooo`D00003oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008Woool00`000?ooooooo`03oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008Woool00`000?ooooooo`03oooo0`0003Goool00ol0VOooooooo`1Foooo0029oooo00<0
003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.70787 .30902 L
.71741 .30902 L
.72269 .30902 L
.72414 .30902 L
.72493 .30902 L
.72567 .30902 L
s
.72567 .30902 m
.7258 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.26171 .30902 L
.26709 .30902 L
.27003 .30902 L
.27147 .30902 L
.27279 .30902 L
.27399 .15451 L
.27513 .15451 L
.27765 .15451 L
.28302 .15451 L
.30316 .15451 L
.34135 .15451 L
.38199 .15451 L
.42112 .15451 L
.4411 .15451 L
.46271 .15451 L
.47285 .15451 L
.4784 .15451 L
.48357 .15451 L
.48584 .15451 L
.48696 .15451 L
.48799 .15451 L
.48918 .30902 L
.49047 .30902 L
.49273 .30902 L
.50277 .30902 L
.54204 .30902 L
.57979 .30902 L
.61999 .30902 L
.65868 .30902 L
.69982 .30902 L
.73944 .30902 L
.77755 .30902 L
.81811 .30902 L
.85716 .30902 L
.89866 .30902 L
.93864 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005KooolU06Ko00@00000I_l0I_l0000;06Ko00<00000I_l0I_l00_oo
o`<0002>oooo001Foooo00<0I_ooooooool07?ooo`@00002oooo00@0003oooooool00009oooo0P00
00;oool0101Vooooooooo`00093oool005Koool00`1Vooooooooo`0Roooo00@0003oooooool00009
oooo00D0003oooooooooool0I_l00_ooo`030000oooooooo08koool005Koool00`1Vooooooooo`0S
oooo0P0000[oool3000000Goool0I_ooooooool00000T?ooo`00E_ooo`0306Kooooooooo03?oool0
0`1Vooooooooo`020000Soooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00093oool0
05Koool00`1Vooooooooo`0coooo00@0I_ooooooool0002@oooo001Foooo00<0I_ooooooool0<ooo
o`0406Kooooooooo0000T?ooo`00E_ooo`0306Kooooooooo03?oool00`1Vooooooooo`020000Sooo
o`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00093oool005Koool00`1Vooooooooo`0c
oooo00@0I_ooooooool0002@oooo001Foooo00<0I_ooooooool0<oooo`0406Kooooooooo0000T?oo
o`00E_ooo`0306Kooooooooo03?oool00`1Vooooooooo`020000Soooo`00E_ooo`0306Kooooooooo
03?oool0101Vooooooooo`00093oool005Koool00`1Vooooooooo`0coooo00@0I_ooooooool0002@
oooo001Foooo00<0I_ooooooool0<oooo`0406Kooooooooo0000T?ooo`00E_ooo`0306Kooooooooo
03?oool00`1Vooooooooo`020000Soooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00
093oool005Koool00`1Vooooooooo`0Moooo0P0000Coool200000oooo`@00003oooo0P0000;oool0
101Vooooooooo`00093oool005Koool00`1Vooooooooo`0Loooo00@0003oooooool00008oooo00<0
003oooooool00oooo`060000oooooooo0000oooo06Ko0_ooo`030000oooooooo08koool005Goool0
0`1Vooooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooo06Ko
00;oool30000S_ooo`00EOooo`0306Kooooooooo01Ooool400000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200000_ooo`0406Kooooooooo0000T?ooo`00EOooo`0306Kooooooooo
01goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool01@000?ooooooooooo`1Vo`02
oooo00<0003oooooool0S_ooo`00EOooo`0306Kooooooooo01koool200002_ooo`800004oooo0`00
0005oooo06Kooooooooo0000093oool005Goool00`1Vooooooooo`0doooo00<0I_ooooooool00P00
08ooool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0002@oooo001Eoooo00<0I_oooooo
ool0=?ooo`0406Kooooooooo0000T?ooo`00EOooo`0306Kooooooooo03Coool0101Vooooooooo`00
093oool001Woool30000>?ooo`@0000doooo00<0I_ooooooool00P0003Soool40000>oooo`<0000E
oooo000Joooo00<0003oooooool0=oooo`03000006Kooooo03Goool0101Vooooooooo`0003Woool0
0`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003oooooool0=?oo
o`0406Kooooooooo0000>_ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0
003oooooool0000coooo100000?oool00`1Vo`000?ooo`0doooo00@0I_ooooooool0000koooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool01000001V
ooooo`0003Coool00`1Vooooooooo`020000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000>_ooo`80000eoooo00@0I_ooooooool0000joooo0P0003coool200005_oo
o`00EOooo`0306Kooooooooo03Coool0101Vooooooooo`00093oool005Goool00`1Vooooooooo`0d
oooo00<0I_ooooooool00P0008ooool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0002@
oooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo0000T?ooo`00EOooo`0306Kooooooooo
03Coool0101Vooooooooo`00093oool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02Oooo`04o`2I
oooooooo00003_ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
oooooooo03Koool01?l0VOooooooo`0003coool00`000?ooooooo`0Eoooo002?oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=ooo
o`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Sooo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0f
oooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?
oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00M_ooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool007Goool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo05Goool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0000foooo00?o09Woooooool0EOooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo03Koool00ol0VOooooooo`1E
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo001foooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo
03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool0
08ooool20000=oooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=ooo
o`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00O?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo001k
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0003Koool0
0ol0VOooooooo`1Eoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0f
oooo00?o09Woooooool0EOooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0foooo00?o09Woooooool0EOooo`00Soooo`80000goooo00?o09Woooooool0EOooo`00Sooo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0f
oooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?
oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo
03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool0
08ooool20000=oooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`0foooo00?o09Woooooool0EOooo`00MOooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000f
oooo00?o09Woooooool0EOooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo0P0003Ooool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_oo
o`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Sooo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo0P0003Ooool00ol0VOooooooo`1E
oooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0f
oooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?
oooo0P0003Ooool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo
03Koool00ol0VOooooooo`1Eoooo002?oooo0P0003Ooool00ol0VOooooooo`1Eoooo002?oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo05Goool008Ooool500000oooo`030000oooooooo03Koool0
0ol0VOooooooo`1Eoooo0029oooo00<0003oooooool00oooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo0029oooo00<0003oooooool00oooo`<0000foooo00?o09Woooooool0EOooo`00ROoo
o`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool300001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009oooo0`00
00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72585 .30902 L
.72841 .30902 L
.73074 .30902 L
.73191 .30902 L
s
.73191 .30902 m
.73204 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.26171 .30902 L
.26425 .30902 L
.26565 .30902 L
.26698 .30902 L
.26773 .30902 L
.26855 .15451 L
.26929 .15451 L
.26998 .15451 L
.27279 .15451 L
.28302 .15451 L
.30316 .15451 L
.34228 .15451 L
.38387 .15451 L
.42393 .15451 L
.46248 .15451 L
.48242 .15451 L
.48727 .15451 L
.48994 .15451 L
.49246 .15451 L
.49316 .15451 L
.49389 .15451 L
.4947 .30902 L
.49545 .30902 L
.49817 .30902 L
.50349 .30902 L
.54124 .30902 L
.58144 .30902 L
.62013 .30902 L
.66127 .30902 L
.70089 .30902 L
.739 .30902 L
.77956 .30902 L
.81861 .30902 L
.86011 .30902 L
.90009 .30902 L
.93855 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005CooolW06Ko00@00000I_l0I_l0000;06Ko00D00000I_l0I_l0I_oo
ool00`0008koool005Coool00`1Vooooooooo`0Noooo100000;oool010000?ooooooo`0000Woool2
00000oooo`0306Kooooo0000093oool005Coool00`1Vooooooooo`0Toooo00@0003oooooool00009
oooo00<0003oooooool00_ooo`0306Kooooo0000093oool005Coool00`1Vooooooooo`0Uoooo0P00
00[oool300000_ooo`0306Kooooo0000093oool005Coool00`1Vooooooooo`0foooo00@0I_ooool0
0000002?oooo001Doooo00<0I_ooooooool0=_ooo`0306Kooooo0000093oool005Coool00`1Voooo
ooooo`0foooo00<0I_ooool00000T?ooo`00E?ooo`0306Kooooooooo03Koool00`1Vooooo`00002@
oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo00000000Soooo`00E?ooo`0306Kooooooooo
03Koool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool0=_ooo`0306Kooooo0000093oool0
05Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?ooo`00E?ooo`0306Kooooooooo03Koool0
101Vooooo`00000008ooool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?ooo`00E?oo
o`0306Kooooooooo03Koool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool0=_ooo`0306Ko
oooo0000093oool005Coool00`1Vooooooooo`0foooo00@0I_ooool00000002?oooo001Doooo00<0
I_ooooooool0=_ooo`0306Kooooo0000093oool005Coool00`1Vooooooooo`0Ooooo0P0000Coool2
00000oooo`@00003oooo0P0000?oool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool07_oo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000;oool00`1Voooo
o`00002@oooo001Doooo00<0I_ooooooool07_ooo`040000oooooooo00002Oooo`030000oooooooo
00Goool01@000?ooooooooooo`1Vo`030000S_ooo`00E?ooo`0306Kooooooooo01Soool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001?ooo`0306Ko0000oooo08ooool0
05Coool00`1Vooooooooo`0Noooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`0306Ko0000oooo08ooool005Coool00`1Vooooooooo`0Ooooo0P0000[oool2
00001?ooo`<00003oooo00<0I_l0003oool0Soooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`00
0000002?oooo001Doooo00<0I_ooooooool0=oooo`0306Ko0000oooo08ooool005Coool00`1Voooo
ooooo`0goooo00<0I_l0003oool0Soooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?ooo`2?
oooo000Ioooo0`0003Soool40000=_ooo`0306Ko0000000003Soool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool0=oooo`030000oooooooo03Ooool00`1Vo`000?ooo`0hoooo00<0003ooooo
ool0?Oooo`030000oooooooo01Coool001Ooool50000>?ooo`0306Ko0000oooo03Ooool00`1Vo`00
0?ooo`0ioooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
03?oool400000_ooo`0306Kooooo000003Ooool00`1Vo`000?ooo`0joooo00<0003oooooool0>?oo
o`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0003Koool0
0`1Vo`000000000hoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000i
oooo00<0I_l000000000=oooo`0306Ko0000oooo03Woool20000??ooo`80000Foooo001Doooo00<0
I_ooooooool0=oooo`0306Ko0000oooo08ooool005Coool00`1Vooooooooo`0goooo00<0I_l00000
0000Soooo`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?ooo`2?oooo001Doooo00<0I_oooooo
ool0=oooo`0306Ko0000oooo08ooool005Coool00`1Vooooooooo`0goooo00<0I_l0003oool0Sooo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0;oooo00?o09T0003oool03Oooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo03Soool00ol0V@000?ooo`0k
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?
oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo
05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0
003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Wooooo
ool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool0
0ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool0
0`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOoo
ooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo03Soool00ol0VOooooooo`1Coooo001eoooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo001e
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000>?oo
o`03o`2Ioooooooo05?oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0hoooo00?o09Wooooo
ool0Doooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo03Soool00ol0VOoo
ooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Sooo
o`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1C
oooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0h
oooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?
oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo
05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0
003oooooool0>?ooo`03o`2Ioooooooo05?oool007coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo001koooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000hoooo00?o09Woooooool0Doooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0>?ooo`03o`2Ioooooooo
05?oool007coool200002_ooo`<00004oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool0
08ooool20000>Oooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Wooooo
ool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool0
0ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool0
0`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOoo
ooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Sooo
o`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1C
oooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo03Soool00ol0VOooooooo`1Coooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool30000>?ooo`03o`2Ioooooooo05?oool007Goool0
10000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0>?ooo`03o`2I
oooooooo05?oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`80000ioooo00?o
09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo00<0
003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Wooooo
ool0Doooo`00Soooo`80000ioooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool0
0ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool0
0`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`80000ioooo00?o09Woooooool0Dooo
o`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Sooo
o`80000ioooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1C
oooo0027oooo1@0000?oool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00ROooo`030000oooooooo
00?oool30000>?ooo`03o`2Ioooooooo05?oool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009oooo0`0000Goool0
0`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:
oooo0`0000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72841 .30902 L
.7332 .30902 L
.73451 .30902 L
.7359 .30902 L
.73708 .30902 L
s
.73708 .30902 m
.73721 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.25666 .30902 L
.2593 .30902 L
.26045 .30902 L
.26171 .30902 L
.26301 .15451 L
.26425 .15451 L
.26698 .15451 L
.27279 .15451 L
.28302 .15451 L
.30316 .15451 L
.3438 .15451 L
.38293 .15451 L
.42451 .15451 L
.44538 .15451 L
.46458 .15451 L
.48333 .15451 L
.49277 .15451 L
.49535 .15451 L
.49678 .15451 L
.49813 .15451 L
.49938 .15451 L
.50009 .30902 L
.50074 .30902 L
.50313 .30902 L
.5424 .30902 L
.58015 .30902 L
.62035 .30902 L
.65904 .30902 L
.70018 .30902 L
.7398 .30902 L
.77791 .30902 L
.81847 .30902 L
.85752 .30902 L
.89901 .30902 L
.939 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool005?ooolX06Ko00@00000I_l0I_l0000;06Ko00<00000I_l0I_l00P1V
o`<0002>oooo001Coooo00<0I_ooooooool07oooo`@00002oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool09Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool09_ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0
I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool0
05?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_oooooo
ool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_oo
o`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Ooo
o`80002?oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Voooo
ooooo`0Poooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool07oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool07oooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool005?oool00`1Voooo
ooooo`0Ioooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`2>oooo001Coooo00<0I_ooooooool07oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001Coooo00<0I_oooooo
ool08?ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo08koool005?oool00`1Voooo
ooooo`0ioooo0P0008ooool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`030000
oooooooo08koool001Woool30000=oooo`0306Ko000000000080000goooo0P0003Soool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool0=_ooo`0306Ko0000oooo03Woool00`000?ooooooo`0g
oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000=oooo`0306Kooooo0000
03Woool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool0
10000?ooooooo`0003?oool4000000Goool0I_ooooooool00000>?ooo`030000oooooooo03Woool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool00000>?ooo`0506Ko
0000oooooooo000003Ooool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool0
01Woool20000>?ooo`0406Kooooo00000000>?ooo`030000oooooooo03Soool20000??ooo`80000F
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0i
oooo0P0008ooool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Ko
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo
08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0003ooooo
ool0>_ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000j
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
03Woool00ol0VOooooooo`1Boooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000>Oooo`03o`2Ioooooooo05;oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo001loooo0P0000[oool300001?ooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000j
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0003Woool00ol0VOooooooo`1Boooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_oo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Qoooo`D00003oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Woool00`000?oo
ooooo`03oooo0`0003Woool00ol0VOooooooo`1Boooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ooooo00<0
003oooooool07?ooo`030000oooooooo07ooool007koool00`000?ooooooo`08oooo00<0003ooooo
ool04oooo`030000oooooooo07koool007koool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@0000;oool200001?ooo`030000oooooooo07koool007koool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02Oooo`030000oooooooo07goool007koool00`000?ooooooo`0500003_ooo`030000oooooooo
00Soool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000004Oooo`030000oooooooo
00Soool00`000?ooooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0003ooooo
ool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.72912 .30902 L
.73838 .30902 L
.74082 .30902 L
.74201 .30902 L
.74309 .30902 L
s
.74309 .30902 m
.7432 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.24276 .30902 L
.24754 .30902 L
.25016 .30902 L
.25261 .30902 L
.2547 .30902 L
.25587 .30902 L
.25694 .15451 L
.25811 .15451 L
.25939 .15451 L
.26171 .15451 L
.30236 .15451 L
.34148 .15451 L
.38307 .15451 L
.42313 .15451 L
.46168 .15451 L
.48162 .15451 L
.48647 .15451 L
.48914 .15451 L
.49166 .15451 L
.49309 .15451 L
.4939 .15451 L
.49465 .1549 L
.49737 .15665 L
.4987 .1575 L
.49995 .15829 L
.50125 .15753 L
.50269 .15661 L
.50386 .15586 L
.50512 .15505 L
.50631 .30902 L
.50738 .30902 L
.51252 .30902 L
.52287 .30902 L
.54137 .30902 L
.58136 .30902 L
.61982 .30902 L
.66074 .30902 L
.70014 .30902 L
.73803 .30902 L
.77837 .30902 L
.8172 .30902 L
.85847 .30902 L
Mistroke
.89823 .30902 L
.93648 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0057ooolZ06Ko00@00000I_l0I_l0000;06Ko00<00000I_l0I_l00P1V
o`<0002>oooo001Aoooo00<0I_ooooooool08Oooo`@00002oooo00@0003oooooool00009oooo0P00
00Coool00`1Vo`00001Vo`2?oooo001Aoooo00<0I_ooooooool09oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`00001Vooooo`2>oooo001Aoooo00<0I_ooooooool0:?ooo`80000:
oooo0`0000Coool00`00001Vooooo`2>oooo001Aoooo00<0I_ooooooool0>oooo`80002?oooo001A
oooo00<0I_ooooooool0>oooo`03000006Kooooo08koool0057oool00`1Vooooooooo`0koooo00<0
0000I_ooool0S_ooo`00DOooo`0306Kooooooooo03_oool00`00001Vooooo`2>oooo001Aoooo00<0
I_ooooooool0>oooo`80002?oooo001Aoooo00<0I_ooooooool0>oooo`03000006Kooooo08koool0
057oool00`1Vooooooooo`0koooo00<00000I_ooool0S_ooo`00DOooo`0306Kooooooooo03_oool0
0`00001Vooooo`2>oooo001Aoooo00<0I_ooooooool0>oooo`80002?oooo001Aoooo00<0I_oooooo
ool0>oooo`03000006Kooooo08koool0057oool00`1Vooooooooo`0koooo00<00000I_ooool0S_oo
o`00DOooo`0306Kooooooooo03_oool00`00001Vooooo`2>oooo001Aoooo00<0I_ooooooool0>ooo
o`80002?oooo001Aoooo00<0I_ooooooool0>oooo`03000006Kooooo08koool0057oool00`1Voooo
ooooo`0Roooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`00001Vooooo`2>oooo001A
oooo00<0I_ooooooool08Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`00001Vooooo`2>oooo001Aoooo00<0I_ooooooool08Oooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0008koool0057oool00`1Voooo
ooooo`0Koooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooo`1Vo`2>oooo001Aoooo00<0I_ooooooool08Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooo`1Vo`2>oooo001Aoooo00<0I_oooooo
ool08_ooo`80000:oooo0P0000Coool300001?ooo`030000oooo06Ko08koool0057oool00`1Voooo
ooooo`0koooo0P00000306Kooooooooo08coool0057oool00`1Vooooooooo`0koooo00<0003oool0
I_l0S_ooo`00DOooo`0306Kooooooooo03_oool00`000?ooo`1Vo`2>oooo001Aoooo00<0I_oooooo
ool0>oooo`030000oooo06Ko08koool001Woool30000=Oooo`0306Kooooooooo00@0000goooo0P00
000306Kooooooooo03Goool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=?ooo`0406Ko
oooooooo0000>_ooo`030000oooo06Ko03Ooool00`000?ooooooo`0moooo00<0003oooooool05?oo
o`005oooo`D0000eoooo00D0I_ooooooooooool00000>Oooo`030000oooo06Ko03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool0=_ooo`030000oooo06Ko03Woool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool00000=_ooo`0406Kooooooooo00000_ooo`030000oooooooo03Goool2
000000<0I_ooooooool0=Oooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool2
0000=_ooo`0406Kooooooooooooo0P0003Soool00`000?ooo`1Vo`0hoooo0P0003coool200005_oo
o`00DOooo`0306Kooooooooo03_oool00`000?ooo`1Vo`2>oooo001Aoooo00<0I_ooooooool0>ooo
o`8000000`1Vooooooooo`2<oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko08koool0
057oool00`1Vooooooooo`0koooo00<0003oool0I_l0S_ooo`00DOooo`0306Kooooooooo03_oool0
0`000?ooo`1Vo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooool0V@0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Ooo
o`030000ooooo`2I03[oool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0k
oooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
08ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00M_ooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007Goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000koooo00?o09Woooooool0D?ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??oo
o`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Sooo
o`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0k
oooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0003_oool00ol0VOooooooo`1@
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0k
oooo00?o09Woooooool0D?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool0
08ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??oo
o`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00M_oo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0000koooo00?o09Wooooo
ool0D?ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00M_oo
o`800009oooo100000?oool300001?ooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?
oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool0
0ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>ooo
o`03o`2Ioooooooo053oool008Ooool500000oooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo0029oooo00<0003oooooool00oooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo0029
oooo00<0003oooooool00oooo`<0000koooo00?o09Woooooool0D?ooo`00ROooo`030000oooooooo
09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74309 .30902 L
.74566 .30902 L
.74806 .30902 L
.74932 .30902 L
s
.74932 .30902 m
.74939 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24276 .30902 L
.24502 .30902 L
.24745 .30902 L
.24816 .30902 L
.24884 .30902 L
.25012 .15451 L
.25131 .15451 L
.25261 .15451 L
.26171 .15451 L
.30236 .15451 L
.34148 .15451 L
.38307 .15451 L
.42313 .15451 L
.46168 .15451 L
.472 .15451 L
.48162 .15451 L
.48411 .15451 L
.48647 .15451 L
.48777 .15451 L
.48851 .15478 L
.48919 .15522 L
.49166 .15681 L
.49701 .16019 L
.49831 .161 L
.49899 .16142 L
.49971 .16186 L
.50051 .16173 L
.50124 .16127 L
.50269 .16038 L
.50526 .15876 L
.50769 .15722 L
.50987 .15582 L
.5111 .15503 L
.51223 .30902 L
.51345 .30902 L
.51459 .30902 L
.51719 .30902 L
.52243 .30902 L
.5408 .30902 L
.57962 .30902 L
.6209 .30902 L
Mistroke
.66066 .30902 L
.6989 .30902 L
.7396 .30902 L
.77878 .30902 L
.82042 .30902 L
.86054 .30902 L
.89914 .30902 L
.94019 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0053oool[06Ko00@00000I_l0I_l0000;06Ko00<00000I_l0I_l00_oo
o`<000000`1Vooooooooo`2;oooo001@oooo00<0I_ooooooool08_ooo`@00002oooo00@0003ooooo
ool00009oooo0P0000?oool00`1Vooooo`00000306KoSOooo`00D?ooo`0306Kooooooooo02Soool0
10000?ooooooo`0000Woool00`000?ooooooo`03oooo00D0I_l00000I_ooool0I_l0SOooo`00D?oo
o`0306Kooooooooo02Woool200002_ooo`<00004oooo00@0003oooooool0I_n=oooo001@oooo00<0
I_ooooooool0??ooo`8000000oooo`1Vooooo`2<oooo001@oooo00<0I_ooooooool0??ooo`040000
oooooooo06KoSOooo`00D?ooo`0306Kooooooooo03coool010000?ooooooo`1Vohgoool0053oool0
0`1Vooooooooo`0loooo00@0003oooooool0I_n=oooo001@oooo00<0I_ooooooool0??ooo`800000
0oooo`1Vooooo`2<oooo001@oooo00<0I_ooooooool0??ooo`040000oooooooo06KoSOooo`00D?oo
o`0306Kooooooooo03coool010000?ooooooo`1Vohgoool0053oool00`1Vooooooooo`0loooo00@0
003oooooool0I_n=oooo001@oooo00<0I_ooooooool0??ooo`8000000oooo`1Vooooo`2<oooo001@
oooo00<0I_ooooooool0??ooo`040000oooooooo06KoSOooo`00D?ooo`0306Kooooooooo03coool0
10000?ooooooo`1Vohgoool0053oool00`1Vooooooooo`0loooo00@0003oooooool0I_n=oooo001@
oooo00<0I_ooooooool0??ooo`8000000oooo`1Vooooo`2<oooo001@oooo00<0I_ooooooool0??oo
o`040000oooooooo06KoSOooo`00D?ooo`0306Kooooooooo02?oool200001?ooo`800003oooo1000
00?oool200001Oooo`040000oooooooo06KoSOooo`00D?ooo`0306Kooooooooo02;oool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00@0003oooooool0I_n=
oooo001?oooo00<0I_ooooooool08oooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`00000306Kooooooooo08_oool004ooool00`1Vooooooooo`0Moooo1000
00;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool010000?ooooooo`1V
ohgoool004ooool00`1Vooooooooo`0Soooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`040000oooooooo06KoSOooo`00Coooo`0306Kooooooooo02Coool2
00002_ooo`800004oooo0`0000Coool010000?ooooooo`1Vohgoool004ooool00`1Vooooooooo`0m
oooo0P000003oooo06Kooooo08coool004ooool00`1Vooooooooo`0moooo00@0003oooooool0I_n=
oooo001?oooo00<0I_ooooooool0?Oooo`040000oooooooo06KoSOooo`00Coooo`0306Kooooooooo
03goool010000?ooooooo`1Vohgoool001Woool30000<oooo`0306Kooooooooo00;oool40000=ooo
o`8000000oooo`1Vooooo`0eoooo100003_oool300005Oooo`006_ooo`030000oooooooo03;oool0
0`1Vooooooooo`02oooo00<0003oooooool0>?ooo`040000oooooooo06Ko=_ooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0003?oool00`1Vooooooooo`03oooo00<0003ooooo
ool0=oooo`040000oooooooo06Ko=oooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002
oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`0foooo00@0003oooooool0I_lh
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Coool0
0`1Vooooooooo`02oooo00@0003oooooool0000goooo0P000003oooo06Kooooo03Goool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003Coool00`1Vooooooooo`03oooo0P00
03Soool010000?ooooooo`1VocOoool20000??ooo`80000Foooo001?oooo00<0I_ooooooool0?Ooo
o`040000oooooooo06KoSOooo`00Coooo`0306Kooooooooo03goool2000000?oool0I_ooool0S?oo
o`00Coooo`0306Kooooooooo03goool010000?ooooooo`1Vohgoool004ooool00`1Vooooooooo`0m
oooo00@0003oooooool0I_n=oooo001?oooo00<0I_ooooooool0?Oooo`040000oooooooo06KoSOoo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00@0003ooooooooo09T;oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`040000oooooooo
o`2I>Oooo`030000oooooooo01Goool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o09Woooooool0Coooo`00Sooo
o`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000m
oooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o
09Woooooool0Coooo`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0loooo00?o09Woooooool0Coooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
03coool00ol0VOooooooo`1?oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0loooo00?o
09Woooooool0Coooo`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool0
08ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o09Woooooool0Coooo`00Sooo
o`030000oooooooo03coool00ol0VOooooooo`1?oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000??ooo`03o`2Ioooooooo04ooool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo03coool00ol0VOooooooo`1?oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo001loooo0P0000[oool300001?ooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo002?oooo0P0003goool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000m
oooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o
09Woooooool0Coooo`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool0
08ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0003coool00ol0VOooooooo`1?oooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo03coool0
0ol0VOooooooo`1?oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo03coool00ol0VOooooooo`1?oooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Ooo
o`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Sooo
o`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool008ooool20000?Oooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0l
oooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Oooo`03o`2Ioooooooo
04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool0
08ooool20000?Oooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Qoooo`D00003oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008Woool00`000?oo
ooooo`03oooo0`0003coool00ol0VOooooooo`1?oooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@0000;oool200000oooo`D00002oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool02Ooo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75071 .30902 L
.75351 .30902 L
.75467 .30902 L
.75591 .30902 L
s
.75591 .30902 m
.75598 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24016 .30902 L
.24152 .30902 L
.24276 .30902 L
.24392 .30902 L
.24502 .15451 L
.24618 .15451 L
.24745 .15451 L
.25261 .15451 L
.26171 .15451 L
.30236 .15451 L
.34148 .15451 L
.38307 .15451 L
.42313 .15451 L
.46168 .15451 L
.472 .15451 L
.47703 .15451 L
.47923 .15451 L
.48039 .15451 L
.48162 .15451 L
.48292 .15501 L
.48411 .15578 L
.48647 .15729 L
.49166 .16057 L
.4969 .1638 L
.49834 .16467 L
.49909 .16513 L
.49989 .1656 L
.50058 .16532 L
.50135 .16486 L
.50269 .16405 L
.50797 .16079 L
.51296 .15765 L
.51514 .15626 L
.51633 .1555 L
.51744 .15478 L
.51865 .30902 L
.51928 .30902 L
.51997 .30902 L
.5223 .30902 L
.54325 .30902 L
.58453 .30902 L
Mistroke
.62429 .30902 L
.66253 .30902 L
.70323 .30902 L
.74241 .30902 L
.78404 .30902 L
.82416 .30902 L
.86277 .30902 L
.90382 .30902 L
.94336 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004koool]06Ko00@00000I_l0I_l0000;06Ko00<00000I_ooool00_oo
o`<000000oooo`1Vooooo`2;oooo001>oooo00<0I_ooooooool09?ooo`@00002oooo00@0003ooooo
ool00009oooo0P000003oooo06Ko06Ko00;oool00`000?ooooooo`0206KoS?ooo`00C_ooo`0306Ko
oooooooo02[oool010000?ooooooo`0000Woool00`000?ooooooo`02oooo00L0I_ooool0003oool0
I_ooool0I_l0S?ooo`00C_ooo`0306Kooooooooo02_oool200002_ooo`<00003oooo00<0I_l00000
I_l00_ooo`0306Kooooooooo08[oool004koool00`1Vooooooooo`0noooo0P0000;oool00`1Voooo
ooooo`2:oooo001>oooo00<0I_ooooooool0?_ooo`050000oooooooooooo06Ko08coool004koool0
0`1Vooooooooo`0noooo00D0003oooooooooool0I_l0S?ooo`00C_ooo`0306Kooooooooo03koool0
1@000?ooooooooooo`1Vo`2<oooo001>oooo00<0I_ooooooool0?_ooo`800002oooo00<0I_oooooo
ool0R_ooo`00C_ooo`0306Kooooooooo03koool01@000?ooooooooooo`1Vo`2<oooo001>oooo00<0
I_ooooooool0?_ooo`050000oooooooooooo06Ko08coool004koool00`1Vooooooooo`0noooo00D0
003oooooooooool0I_l0S?ooo`00C_ooo`0306Kooooooooo03koool200000_ooo`0306Kooooooooo
08[oool004koool00`1Vooooooooo`0noooo00D0003oooooooooool0I_l0S?ooo`00C_ooo`0306Ko
oooooooo03koool01@000?ooooooooooo`1Vo`2<oooo001>oooo00<0I_ooooooool0?_ooo`050000
oooooooooooo06Ko08coool004koool00`1Vooooooooo`0noooo0P0000;oool00`1Vooooooooo`2:
oooo001>oooo00<0I_ooooooool0?_ooo`050000oooooooooooo06Ko08coool004koool00`1Voooo
ooooo`0Uoooo0P0000Coool200000oooo`@00003oooo0P0000Goool01@000?ooooooooooo`1Vo`2<
oooo001>oooo00<0I_ooooooool09?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool01@000?ooooooooooo`1Vo`2<oooo001>oooo00<0I_ooooooool09?oo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000;oool0
0`1Vooooooooo`29oooo001>oooo00<0I_ooooooool07_ooo`@00002oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool00_ooo`0306Kooooooooo08Woool0
04koool00`1Vooooooooo`0Toooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo00;oool00`1Vooooooooo`29oooo001>oooo00<0I_oooooo
ool09Oooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo00;oool00`1Vooooooooo`29
oooo001>oooo00<0I_ooooooool0?_ooo`800003oooo00<0I_ooooooool0ROooo`00C_ooo`0306Ko
oooooooo03koool00`000?ooooooo`02oooo00<0I_ooooooool0ROooo`00C_ooo`0306Kooooooooo
03koool00`000?ooooooo`02oooo00<0I_ooooooool0ROooo`00C_ooo`0306Kooooooooo03koool0
0`000?ooooooo`02oooo00<0I_ooooooool0ROooo`006Oooo`<0000boooo00<0I_ooooooool00ooo
o`@0000goooo0P0000?oool00`1Vooooooooo`0boooo100003_oool300005Oooo`006_ooo`030000
oooooooo037oool00`1Vooooooooo`03oooo00<0003oooooool0>?ooo`030000oooooooo00;oool0
0`1Vooooooooo`0boooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000<_oo
o`0306Kooooooooo00Coool00`000?ooooooo`0goooo00<0003oooooool00_ooo`0306Kooooooooo
03?oool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<ooo
o`@00004oooo00<0003oooooool0=_ooo`030000oooooooo00;oool00`1Vooooooooo`0doooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003?oool00`1Voooo
ooooo`03oooo00@0003oooooool0000goooo0P0000?oool00`1Vooooooooo`0boooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000coooo00<0I_ooooooool01?ooo`80000h
oooo00<0003oooooool00_ooo`0306Kooooooooo03?oool20000??ooo`80000Foooo001>oooo00<0
I_ooooooool0?_ooo`030000oooooooo00;oool00`1Vooooooooo`29oooo001>oooo00<0I_oooooo
ool0?_ooo`800003oooo00<0I_ooooooool0ROooo`00C_ooo`0306Kooooooooo03koool00`000?oo
ooooo`02oooo00<0I_ooooooool0ROooo`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`02
oooo00<0I_ooooooool0ROooo`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`02oooo00<0
I_ooooooool0ROooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00_oo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool0
0`000?ooooooo`0ioooo00<0003oooooool00_ooo`03o`2Ioooooooo03Goool00`000?ooooooo`0E
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2I
oooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool20000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o
09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo04goool0
08ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool2
0000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0?_ooo`03o`2I
oooooooo04goool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool007Goool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000noooo00?o09Woooooool0COoo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo
03koool00ol0VOooooooo`1=oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo03koool00ol0VOooooooo`1=oooo001foooo0P00
00[oool200001?ooo`<00004oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool2
0000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_oo
o`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2I
oooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool20000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o
09Woooooool0COooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool007_oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`0003koool00ol0VOooooooo`1=oooo001koooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Noooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00O?ooo`80000:
oooo0`0000Coool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`80000ooooo00?o
09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo04goool0
08ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool2
0000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_oo
o`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02
oooo0P0000Goool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00MOooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0?_oo
o`03o`2Ioooooooo04goool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0
003oooooool00_ooo`<0000noooo00?o09Woooooool0COooo`00MOooo`040000oooooooo00002ooo
o`040000oooooooooooo0P0000Goool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00MOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00M_ooo`800009oooo100000?oool300001?ooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOooooooo`1=oooo002?
oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o
09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P00
03ooool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool0
08ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOooooooo`1=oooo002?oooo00<0003ooooo
ool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOoo
ooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008Ooool500000ooo
o`030000oooooooo03koool00ol0VOooooooo`1=oooo0029oooo00<0003oooooool00oooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo0029oooo00<0003oooooool00oooo`<0000noooo00?o
09Woooooool0COooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028
oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool500000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Woool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Aoooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75315 .30902 L
.75593 .30902 L
.75853 .30902 L
.7597 .30902 L
.76081 .30902 L
s
.76081 .30902 m
.76093 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23496 .30902 L
.2364 .30902 L
.23711 .30902 L
.23775 .30902 L
.2389 .15451 L
.24014 .15451 L
.24276 .15451 L
.26171 .15451 L
.30142 .15451 L
.33961 .15451 L
.38026 .15451 L
.41939 .15451 L
.43936 .15451 L
.44987 .15451 L
.46097 .15451 L
.46577 .15451 L
.47092 .15451 L
.47243 .15451 L
.47387 .15451 L
.47516 .15451 L
.47589 .15451 L
.47656 .15475 L
.47778 .15554 L
.47912 .1564 L
.48184 .15813 L
.49119 .16394 L
.49365 .16544 L
.49629 .16702 L
.49757 .16778 L
.49878 .16849 L
.49986 .16913 L
.50104 .1686 L
.50586 .16573 L
.51113 .16252 L
.51553 .15979 L
.52038 .15672 L
.52169 .15587 L
.52242 .15541 L
.52311 .15496 L
.52374 .15455 L
.52444 .30902 L
.52565 .30902 L
Mistroke
.53123 .30902 L
.54124 .30902 L
.58194 .30902 L
.62112 .30902 L
.66275 .30902 L
.70287 .30902 L
.74147 .30902 L
.78253 .30902 L
.82207 .30902 L
.86009 .30902 L
.90057 .30902 L
.93953 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004goool^06Ko00@00000I_l0I_l0000;06Ko00<0003oooooool00_oo
o`<00003oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo02Goool400000_ooo`040000
oooooooo00002Oooo`8000000`1Vooooooooo`02oooo00<0003oooooool00_ooo`80I_n:oooo001=
oooo00<0I_ooooooool0:oooo`040000oooooooo00002Oooo`030000oooooooo0080I_l2oooo00<0
003oooooool00P1Vo`03oooo06Kooooo08Woool004goool00`1Vooooooooo`0/oooo0P0000[oool3
00000_ooo`80I_l00`00001Vo`1Vo`03oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo
03koool00`1Vo`0000000004oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo03ooool0
0`000?ooooooo`03oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo03ooool00`000?oo
ooooo`03oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`03
oooo00<0I_ooooooool0R?ooo`00COooo`0306Kooooooooo03ooool200001?ooo`0306Kooooooooo
08Soool004goool00`1Vooooooooo`0ooooo00<0003oooooool00oooo`0306Kooooooooo08Soool0
04goool00`1Vooooooooo`0ooooo00<0003oooooool00oooo`0306Kooooooooo08Soool004goool0
0`1Vooooooooo`0ooooo00<0003oooooool00oooo`0306Kooooooooo08Soool004goool00`1Voooo
ooooo`0ooooo0P0000Coool00`1Vooooooooo`28oooo001=oooo00<0I_ooooooool0?oooo`030000
oooooooo00?oool00`1Vooooooooo`28oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo
00?oool00`1Vooooooooo`28oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo00?oool0
0`1Vooooooooo`28oooo001=oooo00<0I_ooooooool0?oooo`800004oooo00<0I_ooooooool0R?oo
o`00COooo`0306Kooooooooo03ooool00`000?ooooooo`03oooo00<0I_ooooooool0R?ooo`00COoo
o`0306Kooooooooo02Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
00?oool00`1Vooooooooo`28oooo001=oooo00<0I_ooooooool09Oooo`040000oooooooo00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0I_oooooo
ool0R?ooo`00C?ooo`0306Kooooooooo02Koool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<00003oooo00<0I_ooooooool0R?ooo`00C?ooo`0306Kooooooooo
023oool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo00?oool00`1Vooooooooo`28oooo001<oooo00<0I_ooooooool09_ooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0
I_ooooooool0R?ooo`00C?ooo`0306Kooooooooo02Ooool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`03oooo00<0I_ooooooool0R?ooo`00C?ooo`0306Kooooooooo043oool200001?oo
o`0306Kooooooooo08Soool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Ko
oooooooo08Soool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo
08Soool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo08Soool0
01Woool30000<?ooo`0306Kooooooooo00Goool40000=oooo`800004oooo00<0I_ooooooool0<Ooo
o`@0000koooo0`0001Goool001[oool00`000?ooooooo`0_oooo00<0I_ooooooool01Oooo`030000
oooooooo03Soool00`000?ooooooo`03oooo00<0I_ooooooool0<Oooo`030000oooooooo03goool0
0`000?ooooooo`0Doooo000Goooo1@00033oool00`1Vooooooooo`06oooo00<0003oooooool0=ooo
o`030000oooooooo00?oool00`1Vooooooooo`0boooo00<0003oooooool0>Oooo`D0000Eoooo000A
oooo100000;oool010000?ooooooo`00037oool00`1Vooooo`00000300001?ooo`030000oooooooo
03Koool00`000?ooooooo`03oooo00<0I_ooooooool0<oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000aoooo00<0I_ooooooool01Oooo`040000oooooooo
0000=oooo`800004oooo00<0I_ooooooool0<Oooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000<Oooo`0306Kooooooooo00Koool20000>?ooo`030000oooooooo00?oool0
0`1Vooooooooo`0boooo0P0003coool200005_ooo`00C?ooo`0306Kooooooooo043oool00`000?oo
ooooo`03oooo00<0I_ooooooool0R?ooo`00C?ooo`0306Kooooooooo043oool200001?ooo`0306Ko
oooooooo08Soool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo
08Soool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo08Soool0
04coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo08Soool0013ooooo
00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00?oool00ol0VOooooooo`06oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000
oooooooo00?oool00ol0VOooooooo`0doooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000ooooo00?o
09Woooooool0C?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool007coool200002_ooo`<00004oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008ooool20000@?ooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000?ooo
o`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000
oooooooo03ooool00ol0VOooooooo`1<oooo0027oooo1@0000?oool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00ROooo`030000oooooooo00?oool30000?oooo`03o`2Ioooooooo04coool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo100000?oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75315 .30902 L
.75853 .30902 L
.76324 .30902 L
.76453 .30902 L
.76592 .30902 L
.76723 .30902 L
s
.76723 .30902 m
.76734 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.22272 .30902 L
.22738 .30902 L
.22974 .30902 L
.23038 .30902 L
.23107 .30902 L
.23233 .15451 L
.23302 .15451 L
.23366 .15451 L
.23512 .15451 L
.23778 .15451 L
.24276 .15451 L
.26171 .15451 L
.30084 .15451 L
.34242 .15451 L
.38249 .15451 L
.42104 .15451 L
.44059 .15451 L
.45094 .15451 L
.45664 .15451 L
.46204 .15451 L
.46716 .15451 L
.46856 .15451 L
.46933 .15451 L
.47005 .15451 L
.47132 .15521 L
.47272 .15611 L
.48246 .16224 L
.49157 .16775 L
.49406 .16922 L
.49673 .17078 L
.49802 .17153 L
.49924 .17223 L
.50034 .17247 L
.50153 .17178 L
.51136 .166 L
.51639 .16295 L
.52171 .15965 L
.5263 .15674 L
.52755 .15594 L
.52825 .15549 L
.5289 .15507 L
.53018 .30902 L
.53134 .30902 L
Mistroke
.54022 .30902 L
.57846 .30902 L
.61916 .30902 L
.65834 .30902 L
.69998 .30902 L
.74009 .30902 L
.7787 .30902 L
.81975 .30902 L
.85929 .30902 L
.89732 .30902 L
.93779 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004_oool`06Ko00@00000I_l0I_l0000:06Ko00?oool0003oool00ooo
o`<00004oooo00<0I_ooooooool0Qoooo`00Boooo`0306Kooooooooo02Ooool400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool01?ooo`0306Kooooooooo08Ooool004_oool0
0`1Vooooooooo`0]oooo00@0003oooooool00009oooo00@0003oool0I_l0I_l3oooo00@0003ooooo
ooooool406KoROooo`00Boooo`0306Kooooooooo02koool200002_ooo`<000001Oooo`1Voooooooo
o`000002oooo00D0I_ooooooooooool0I_l0ROooo`00Boooo`0306Kooooooooo03ooool206Ko0P00
000306Kooooooooo00;oool00`1Vooooooooo`27oooo001;oooo00<0I_ooooooool0@?ooo`0306Ko
0000oooo00Goool00`1Vooooooooo`27oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo
00Coool00`1Vooooooooo`27oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo00Coool0
0`1Vooooooooo`27oooo001;oooo00<0I_ooooooool0@Oooo`800005oooo00<0I_ooooooool0Qooo
o`00Boooo`0306Kooooooooo047oool00`000?ooooooo`04oooo00<0I_ooooooool0Qoooo`00Booo
o`0306Kooooooooo047oool00`000?ooooooo`04oooo00<0I_ooooooool0Qoooo`00Boooo`0306Ko
oooooooo047oool00`000?ooooooo`04oooo00<0I_ooooooool0Qoooo`00Boooo`0306Kooooooooo
047oool200001Oooo`0306Kooooooooo08Ooool004_oool00`1Vooooooooo`11oooo00<0003ooooo
ool01?ooo`0306Kooooooooo08Ooool004_oool00`1Vooooooooo`11oooo00<0003oooooool01?oo
o`0306Kooooooooo08Ooool004_oool00`1Vooooooooo`11oooo00<0003oooooool01?ooo`0306Ko
oooooooo08Ooool004_oool00`1Vooooooooo`11oooo0P0000Goool00`1Vooooooooo`27oooo001;
oooo00<0I_ooooooool0@Oooo`030000oooooooo00Coool00`1Vooooooooo`27oooo001;oooo00<0
I_ooooooool0:?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool01?oo
o`0306Kooooooooo08Ooool004_oool00`1Vooooooooo`0Woooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo00Coool00`1Vooooooooo`27
oooo001;oooo00<0I_ooooooool09oooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0000Goool00`1Vooooooooo`26oooo001;oooo00<0I_ooooooool08Ooo
o`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool01Oooo`0306Kooooooooo08Koool004_oool00`1Vooooooooo`0Woooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo00Goool00`1Voooo
ooooo`26oooo001;oooo00<0I_ooooooool0:?ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo00Goool00`1Vooooooooo`26oooo001;oooo00<0I_ooooooool0@Oooo`800006oooo00<0
I_ooooooool0Q_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_oooooo
ool0Q_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0Q_oo
o`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`006Ooo
o`<0000_oooo00<0I_ooooooool01_ooo`@0000goooo0P0000Koool00`1Vooooooooo`0_oooo1000
03_oool300005Oooo`006_ooo`030000oooooooo02koool00`1Vooooooooo`06oooo00<0003ooooo
ool0>?ooo`030000oooooooo00Goool00`1Vooooooooo`0_oooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool50000;oooo`0306Kooooooooo00Ooool00`000?ooooooo`0goooo00<0
003oooooool01Oooo`0306Kooooooooo033oool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo0000<?ooo`0306Kooooooooo00@00004oooo00<0003oooooool0=_oo
o`030000oooooooo00Goool00`1Vooooooooo`0aoooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`030000oooo0000033oool00`1Vooooooooo`06oooo00@0003oooooool0000g
oooo0P0000Koool00`1Vooooooooo`0_oooo00@0003oooooool0000joooo00<0003oool000005_oo
o`006Oooo`80000`oooo00<0I_ooooooool01oooo`80000hoooo00<0003oooooool01Oooo`0306Ko
oooooooo033oool20000??ooo`80000Foooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo
00Goool00`1Vooooooooo`26oooo001;oooo00<0I_ooooooool0@Oooo`800006oooo00<0I_oooooo
ool0Q_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0Q_oo
o`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Booo
o`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`004?ooool0000A
oooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool01Oooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo03;oool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0@Ooo
o`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00M_ooo`800004oooo0P0000?oool4
00000oooo`800005oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool007Goool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0@Ooo
o`03o`2Ioooooooo04[oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<00011oooo00?o09Woooooool0B_ooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001e
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool0
0ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool2
0000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Ooo
o`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00O?ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001koooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00047oool00ol0VOoo
ooooo`1:oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`11
oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool0
0ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool2
0000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`11
oooo00?o09Woooooool0B_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<00011oooo00?o
09Woooooool0B_ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool0
0`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00MOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?
oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo0P00
04;oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool0
0ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008Ooool500000oooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo0029oooo00<0003oooooool00oooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo0029oooo00<0003oooooool00oooo`<00011oooo00?o09Woooooool0B_ooo`00ROooo`030000
oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool400000oooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`03oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool02?ooo`030000oooooooo00Goool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75853 .30902 L
.76334 .30902 L
.76842 .30902 L
.77051 .30902 L
.77166 .30902 L
.77275 .30902 L
s
.77275 .30902 m
.77288 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.21345 .30902 L
.21786 .30902 L
.22037 .30902 L
.22272 .30902 L
.22387 .30902 L
.22496 .30902 L
.22623 .15451 L
.22738 .15451 L
.23233 .15451 L
.24276 .15451 L
.26171 .15451 L
.2999 .15451 L
.34055 .15451 L
.37968 .15451 L
.42126 .15451 L
.44213 .15451 L
.45128 .15451 L
.45613 .15451 L
.4588 .15451 L
.46133 .15451 L
.4625 .15451 L
.46376 .15451 L
.46441 .15459 L
.46513 .15505 L
.4664 .15587 L
.47102 .15882 L
.48007 .16442 L
.4904 .17056 L
.49493 .17317 L
.49732 .17453 L
.49855 .17522 L
.49924 .1756 L
.49988 .17596 L
.50119 .17536 L
.50244 .17466 L
.50476 .17335 L
.5093 .17073 L
.51922 .16485 L
.52935 .15858 L
.53182 .15702 L
.53317 .15615 L
.53446 .15532 L
.53519 .15485 L
.53598 .30902 L
Mistroke
.5367 .30902 L
.53736 .30902 L
.54008 .30902 L
.57926 .30902 L
.6209 .30902 L
.66102 .30902 L
.69962 .30902 L
.74067 .30902 L
.78021 .30902 L
.81824 .30902 L
.85871 .30902 L
.89767 .30902 L
.93909 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004[ooola06Ko00@00000I_l0I_l0000806Ko0oooo`030000oooooooo
00;oool300001_ooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`0Xoooo100000;oool0
10000?ooooooo`0000Ooool206Ko0P0000Goool00`000?ooooooo`04oooo0`1VohOoool004[oool0
0`1Vooooooooo`0^oooo00@0003oooooool00009oooo00<00000I_ooool01?ooo`030000oooooooo
00?oool0101Vooooooooo`1VohOoool004[oool00`1Vooooooooo`0_oooo0P0000[oool3000000D0
I_ooooooooooool000000oooo`80I_l3oooo00<0I_ooooooool0QOooo`00B_ooo`0306Kooooooooo
03ooool206Ko00?oool0000000000P1Vo`Goool00`1Vooooooooo`25oooo001:oooo00<0I_oooooo
ool0@Oooo`0306Ko000006Ko00Ooool00`1Vooooooooo`25oooo001:oooo00<0I_ooooooool0@_oo
o`030000oooooooo00Koool00`1Vooooooooo`25oooo001:oooo00<0I_ooooooool0@_ooo`030000
oooooooo00Koool00`1Vooooooooo`25oooo001:oooo00<0I_ooooooool0@_ooo`800007oooo00<0
I_ooooooool0QOooo`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`06oooo00<0I_oooooo
ool0QOooo`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`06oooo00<0I_ooooooool0QOoo
o`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`06oooo00<0I_ooooooool0QOooo`00B_oo
o`0306Kooooooooo04;oool200001oooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`12
oooo00<0003oooooool01_ooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`12oooo00<0
003oooooool01_ooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`12oooo00<0003ooooo
ool01_ooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`12oooo0P0000Ooool00`1Voooo
ooooo`25oooo001:oooo00<0I_ooooooool0@_ooo`030000oooooooo00Koool00`1Vooooooooo`25
oooo001:oooo00<0I_ooooooool0:Oooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool01_ooo`0306Kooooooooo08Goool004[oool00`1Vooooooooo`0Xoooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo00Koool0
0`1Vooooooooo`25oooo0019oooo00<0I_ooooooool0:Oooo`040000oooooooo00002Oooo`030000
oooooooo00Goool00`000?ooooooo`02oooo0`0000Koool00`1Vooooooooo`25oooo0019oooo00<0
I_ooooooool08oooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool01_ooo`0306Kooooooooo08Goool004Woool00`1Vooooooooo`0Yoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
00Koool00`1Vooooooooo`25oooo0019oooo00<0I_ooooooool0:_ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo00Koool00`1Vooooooooo`25oooo0019oooo00<0I_ooooooool0@ooo
o`800007oooo00<0I_ooooooool0QOooo`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`06
oooo00<0I_ooooooool0QOooo`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`06oooo00<0
I_ooooooool0QOooo`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`06oooo00<0I_oooooo
ool0QOooo`006Oooo`<0000]oooo00<0I_ooooooool02?ooo`@0000goooo0P0000Ooool00`1Voooo
ooooo`0^oooo100003_oool300005Oooo`006_ooo`030000oooooooo02coool00`1Vooooooooo`08
oooo00<0003oooooool0>?ooo`030000oooooooo00Koool00`1Vooooooooo`0^oooo00<0003ooooo
ool0?Oooo`030000oooooooo01Coool001Ooool50000;Oooo`0306Kooooooooo00Woool00`000?oo
ooooo`0goooo00<0003oooooool01_ooo`0306Kooooooooo02ooool00`000?ooooooo`0ioooo1@00
01Goool0017oool400000_ooo`040000oooooooo0000;_ooo`0306Kooooooooo00;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`06oooo00<0I_ooooooool0<?ooo`030000oooooooo
03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000^oooo00<0I_ooooooool02?oo
o`040000oooooooo0000=oooo`800007oooo00<0I_ooooooool0;_ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000;_ooo`0306Kooooooooo00Woool20000>?ooo`030000
oooooooo00Koool00`1Vooooooooo`0_oooo0P0003coool200005_ooo`00BOooo`0306Kooooooooo
04?oool00`000?ooooooo`06oooo00<0I_ooooooool0QOooo`00BOooo`0306Kooooooooo04?oool2
00001oooo`0306Kooooooooo08Goool004Woool00`1Vooooooooo`13oooo00<0003oooooool01_oo
o`0306Kooooooooo08Goool004Woool00`1Vooooooooo`13oooo00<0003oooooool01_ooo`0306Ko
oooooooo08Goool004Woool00`1Vooooooooo`13oooo00<0003oooooool01_ooo`0306Kooooooooo
08Goool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00Koool00ol0VOoo
ooooo`03oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo00Koool00ol0VOooooooo`0aoooo00<0003oooooool05Oooo`00Sooo
o`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19
oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?
oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo
04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool0
0ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool007Koool2
00001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo04;oool00ol0VOooooooo`19
oooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?oo
o`030000oooooooo04;oool00ol0VOooooooo`19oooo001eoooo00@0003oooooool00009oooo00<0
003oooooool01Oooo`030000oooooooo00;oool30000@_ooo`03o`2Ioooooooo04Woool007Goool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`12oooo00?o
09Woooooool0BOooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00M_ooo`80000:oooo0P00
00Coool300001?ooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool0
0ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool0
0`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOoo
ooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_oo
o`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Sooo
o`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19
oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?
oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo
04Woool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<00012oooo00?o09Woooooool0BOooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool007coool200002_ooo`<00004
oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool20000@oooo`03o`2Ioooooooo
04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool0
0ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool0
0`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOoo
ooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_oo
o`03o`2Ioooooooo04Woool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool007Goool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo04;oool00ol0VOoo
ooooo`19oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo
00;oool30000@_ooo`03o`2Ioooooooo04Woool007Goool010000?ooooooo`0000_oool010000?oo
ooooooooo`800005oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool007Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0@_oo
o`03o`2Ioooooooo04Woool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Soooo`800013oooo00?o09Woooooool0BOooo`00Soooo`030000
oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo
04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`800013oooo00?o
09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Soooo`800013oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool0
0ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool0
0`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`800013oooo00?o09Woooooool0BOoo
o`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo0027oooo1@0000?oool00`000?oo
ooooo`12oooo00?o09Woooooool0BOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00ROooo`030000oooooooo00?oool30000@_ooo`03o`2Ioooooooo
04Woool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002F
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>
oooo00<0003oooooool02_ooo`050000oooooooooooo000007goool007_oool01@000?oooooooooo
o`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77247 .30902 L
.77511 .30902 L
.77751 .30902 L
.77883 .30902 L
s
.77883 .30902 m
.77895 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21274 .30902 L
.21753 .30902 L
.21884 .30902 L
.21955 .30902 L
.22022 .30902 L
.22141 .15451 L
.22272 .15451 L
.26149 .15451 L
.30271 .15451 L
.34242 .15451 L
.38061 .15451 L
.40193 .15451 L
.42126 .15451 L
.43094 .15451 L
.44141 .15451 L
.44622 .15451 L
.45129 .15451 L
.45563 .15451 L
.45682 .15451 L
.45809 .15451 L
.45929 .15513 L
.46039 .15584 L
.48109 .16859 L
.49019 .17386 L
.49502 .17657 L
.49756 .17798 L
.49823 .17835 L
.49895 .17874 L
.50023 .17919 L
.50149 .1785 L
.50262 .17788 L
.50524 .17643 L
.50982 .17385 L
.51882 .16865 L
.52909 .16246 L
.5336 .15965 L
.536 .15815 L
.53856 .15651 L
.53986 .15568 L
.54108 .15489 L
.54218 .30902 L
.54338 .30902 L
.54788 .30902 L
Mistroke
.55775 .30902 L
.57855 .30902 L
.61924 .30902 L
.65843 .30902 L
.70006 .30902 L
.74018 .30902 L
.77878 .30902 L
.81984 .30902 L
.85938 .30902 L
.8974 .30902 L
.93788 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Sooolc06Ko00@00000I_l0I_l0000706Ko1?ooo`030000oooooooo
00;oool300001oooo`0306Kooooooooo08Coool004Soool00`1Vooooooooo`0Zoooo100000;oool0
10000?ooooooo`0000Koool00`1Vooooooooo`0200001Oooo`030000oooooooo00Koool206KoQ_oo
o`00B?ooo`0306Kooooooooo033oool010000?ooooooo`0000Ooool206Ko00<0003oooooool01?oo
o`030000oooooooo00Coool206Ko00?oool0I_ooool0QOooo`00B?ooo`0306Kooooooooo037oool2
00002_ooo`<00004oooo00<0003oooooool00oooo`0506Kooooooooooooo06Ko08Koool004Soool0
0`1Vooooooooo`0ooooo00<0I_ooooooool00_ooo`800002oooo0P1Vo`Coool00`1Vooooooooo`24
oooo0018oooo00<0I_ooooooool0@?ooo`80I_l2oooo00@0003oool0I_l0I_l6oooo00<0I_oooooo
ool0Q?ooo`00B?ooo`0306Kooooooooo04;oool206Ko00<00000I_ooool01oooo`0306Kooooooooo
08Coool004Soool00`1Vooooooooo`14oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0
04Soool00`1Vooooooooo`14oooo0P0000Soool00`1Vooooooooo`24oooo0018oooo00<0I_oooooo
ool0A?ooo`030000oooooooo00Ooool00`1Vooooooooo`24oooo0018oooo00<0I_ooooooool0A?oo
o`030000oooooooo00Ooool00`1Vooooooooo`24oooo0018oooo00<0I_ooooooool0A?ooo`030000
oooooooo00Ooool00`1Vooooooooo`24oooo0018oooo00<0I_ooooooool0A?ooo`800008oooo00<0
I_ooooooool0Q?ooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`07oooo00<0I_oooooo
ool0Q?ooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`07oooo00<0I_ooooooool0Q?oo
o`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00B?oo
o`0306Kooooooooo04Coool200002?ooo`0306Kooooooooo08Coool004Soool00`1Vooooooooo`14
oooo00<0003oooooool01oooo`0306Kooooooooo08Coool004Soool00`1Vooooooooo`0[oooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`07oooo00<0I_ooooooool0Q?oo
o`00B?ooo`0306Kooooooooo02[oool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool01oooo`0306Kooooooooo08Coool004Soool00`1Voooo
ooooo`0Zoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool3
00002?ooo`0306Kooooooooo08?oool004Soool00`1Vooooooooo`0Toooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`08oooo00<0I_oooooo
ool0Poooo`00B?ooo`0306Kooooooooo02[oool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool02?ooo`0306Kooooooooo08?oool004Soool0
0`1Vooooooooo`0[oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool02?ooo`0306Ko
oooooooo08?oool004Soool00`1Vooooooooo`14oooo0P0000Woool00`1Vooooooooo`23oooo0018
oooo00<0I_ooooooool0A?ooo`030000oooooooo00Soool00`1Vooooooooo`23oooo0018oooo00<0
I_ooooooool0A?ooo`030000oooooooo00Soool00`1Vooooooooo`23oooo0018oooo00<0I_oooooo
ool0A?ooo`030000oooooooo00Soool00`1Vooooooooo`23oooo000Ioooo0`0002coool00`1Voooo
ooooo`09oooo100003Ooool200002Oooo`0306Kooooooooo02coool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool0:oooo`0306Kooooooooo00Woool00`000?ooooooo`0hoooo00<0003ooooo
ool02?ooo`0306Kooooooooo02coool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005ooo
o`D0000/oooo00<0I_ooooooool02_ooo`030000oooooooo03Ooool00`000?ooooooo`08oooo00<0
I_ooooooool0;Oooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003ooooo
ool0000]oooo00<0I_ooooooool00oooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo
00Soool00`1Vooooooooo`0^oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000002goool00`1Vooooooooo`09oooo00@0003oooooool0000goooo0P0000Woool0
0`1Vooooooooo`0/oooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000]
oooo00<0I_ooooooool02_ooo`80000hoooo00<0003oooooool02?ooo`0306Kooooooooo02goool2
0000??ooo`80000Foooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo00Soool00`1Voooo
ooooo`23oooo0018oooo00<0I_ooooooool0A?ooo`800009oooo00<0I_ooooooool0Poooo`00B?oo
o`0306Kooooooooo04Coool00`000?ooooooo`08oooo00<0I_ooooooool0Poooo`00B?ooo`0306Ko
oooooooo04Coool00`000?ooooooo`08oooo00<0I_ooooooool0Poooo`00B?ooo`0306Kooooooooo
04Coool00`000?ooooooo`08oooo00<0I_ooooooool0Poooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool02?ooo`05o`2Ioooooooooooo000000ooool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000oooooooo03Woool00`000?ooooooo`08oooo00?o09Woooooool0;ooo
o`030000oooooooo01Goool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Sooo
o`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17
oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14
oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o
09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool0
0ol0VOooooooo`17oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`14oooo00?o09Woooooool0Aoooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00MOoo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0004Coool0
0ol0VOooooooo`17oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool0
0ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool0
0`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aooo
o`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?oo
o`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Sooo
o`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17
oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14
oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool007_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Noooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000A?ooo`03o`2Ioooooooo04Ooool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo04Coool00ol0VOooooooo`17oooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo04Coool00ol0VOooooooo`17
oooo001loooo0P0000[oool300001?ooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?
oooo0P0004Goool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o
09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool0
0ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool0
0`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o09Woooooool0Aooo
o`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo001foooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo04Coool00ol0VOooooooo`17oooo001e
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0004Coool00ol0VOooooooo`17oooo001eoooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo04Coool00ol0VOoo
ooooo`17oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo04Coool00ol0VOooooooo`17oooo001foooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool20000AOooo`03o`2I
oooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool20000AOooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o
09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool20000AOooo`03o`2Ioooooooo04Ooool0
08ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool0
0ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool2
0000AOooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aooo
o`00Qoooo`D00003oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008Woool00`000?ooooooo`03
oooo0`0004Coool00ol0VOooooooo`17oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000
oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@0000;oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000oooooooo00[oool010000?ooooooooooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77751 .30902 L
.78008 .30902 L
.78283 .30902 L
.78364 .30902 L
.78441 .30902 L
.7851 .30902 L
s
.7851 .30902 m
.78517 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21019 .30902 L
.2114 .30902 L
.21274 .30902 L
.21394 .30902 L
.21506 .15451 L
.21625 .15451 L
.21753 .15451 L
.22272 .15451 L
.26394 .15451 L
.30365 .15451 L
.34184 .15451 L
.38249 .15451 L
.42162 .15451 L
.4319 .15451 L
.43731 .15451 L
.44303 .15451 L
.44804 .15451 L
.44941 .15451 L
.45088 .15451 L
.45159 .15451 L
.45227 .15451 L
.45353 .15526 L
.4632 .16137 L
.48142 .17225 L
.48641 .17509 L
.49179 .17808 L
.49427 .17943 L
.49687 .18084 L
.49795 .18142 L
.4991 .18204 L
.50036 .18233 L
.50153 .1817 L
.5213 .17068 L
.53223 .16418 L
.54231 .15791 L
.54488 .15627 L
.54614 .15547 L
.54729 .15472 L
.5485 .30902 L
.5498 .30902 L
.55255 .30902 L
.56366 .30902 L
.58381 .30902 L
Mistroke
.62357 .30902 L
.66182 .30902 L
.70251 .30902 L
.74169 .30902 L
.78333 .30902 L
.82345 .30902 L
.86205 .30902 L
.90311 .30902 L
.94265 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Oooold06Ko00@00000I_l0I_l0000506Ko1_ooo`030000oooooooo
00;oool300002Oooo`0306Kooooooooo08;oool004Ooool00`1Vooooooooo`0[oooo100000;oool0
10000?ooooooo`0000Goool206Ko0_ooo`800005oooo00<0003oooooool02?ooo`80I_n4oooo0017
oooo00<0I_ooooooool0<Oooo`040000oooooooo00001oooo`0306Kooooo000000Koool00`000?oo
ooooo`06oooo0P1Vo`03oooo06Kooooo08?oool004Ooool00`1Vooooooooo`0boooo0P0000Woool0
101Vo`000000000000Coool00`000?ooooooo`04oooo0P1Vo`?oool00`1Vooooooooo`22oooo0017
oooo00<0I_ooooooool0?_ooo`80I_l5oooo0P0000?oool206Ko1Oooo`0306Kooooooooo08;oool0
04Ooool00`1Vooooooooo`10oooo0`1Vo`;oool00`000?ooooooo`0206Ko1oooo`0306Kooooooooo
08;oool004Ooool00`1Vooooooooo`13oooo00<0I_ooool000000P1Vo`Woool00`1Vooooooooo`22
oooo0017oooo00<0I_ooooooool0A?ooo`0306Ko0000oooo00[oool00`1Vooooooooo`22oooo0017
oooo00<0I_ooooooool0AOooo`80000:oooo00<0I_ooooooool0P_ooo`00Aoooo`0306Kooooooooo
04Goool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Aoooo`0306Kooooooooo04Goool0
0`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Aoooo`0306Kooooooooo04Goool00`000?oo
ooooo`09oooo00<0I_ooooooool0P_ooo`00Aoooo`0306Kooooooooo04Goool200002_ooo`0306Ko
oooooooo08;oool004Ooool00`1Vooooooooo`15oooo00<0003oooooool02Oooo`0306Kooooooooo
08;oool004Ooool00`1Vooooooooo`15oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool0
04Ooool00`1Vooooooooo`15oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool004Ooool0
0`1Vooooooooo`15oooo0P0000[oool00`1Vooooooooo`22oooo0017oooo00<0I_ooooooool0AOoo
o`030000oooooooo00Woool00`1Vooooooooo`22oooo0017oooo00<0I_ooooooool0;?ooo`800004
oooo0P0000?oool400000oooo`800005oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool0
04Ooool00`1Vooooooooo`0[oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo00Woool00`1Vooooooooo`22oooo0016oooo00<0I_oooooo
ool0;?ooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
00Woool00`1Vooooooooo`22oooo0016oooo00<0I_ooooooool09_ooo`@00002oooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool02Oooo`0306Kooooooooo
08;oool004Koool00`1Vooooooooo`0/oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo00Woool00`1Vooooooooo`22oooo0016oooo00<0
I_ooooooool0;Oooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo00Woool00`1Voooo
ooooo`22oooo0016oooo00<0I_ooooooool0A_ooo`80000:oooo00<0I_ooooooool0P_ooo`00A_oo
o`0306Kooooooooo04Koool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00A_ooo`0306Ko
oooooooo04Koool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00A_ooo`0306Kooooooooo
04Koool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`006Oooo`<0000Zoooo00<0I_oooooo
ool02oooo`@0000goooo0P0000[oool00`1Vooooooooo`0[oooo100003_oool300005Oooo`006_oo
o`030000oooooooo02Woool00`1Vooooooooo`0;oooo00<0003oooooool0>?ooo`030000oooooooo
00Woool00`1Vooooooooo`0[oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool5
0000:_ooo`0306Kooooooooo00coool00`000?ooooooo`0goooo00<0003oooooool02Oooo`0306Ko
oooooooo02coool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo
0000:oooo`0306Kooooooooo00Goool400001?ooo`030000oooooooo03Koool00`000?ooooooo`09
oooo00<0I_ooooooool0;Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool0
0`000?ooo`00000[oooo00<0I_ooooooool02oooo`040000oooooooo0000=oooo`80000:oooo00<0
I_ooooooool0:oooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000:ooo
o`0306Kooooooooo00coool20000>?ooo`030000oooooooo00Woool00`1Vooooooooo`0/oooo0P00
03coool200005_ooo`00A_ooo`0306Kooooooooo04Koool00`000?ooooooo`09oooo00<0I_oooooo
ool0P_ooo`00A_ooo`0306Kooooooooo04Koool200002_ooo`0306Kooooooooo08;oool004Koool0
0`1Vooooooooo`16oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool004Koool00`1Voooo
ooooo`16oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool004Koool00`1Vooooooooo`16
oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00Woool01?l0VOooooooo`0000ooool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000oooooooo03Woool00`000?ooooooo`09oooo00?o09Woooooool0;_ooo`030000
oooooooo01Goool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0004Goool00ol0VOoo
ooooo`16oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2I
oooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000AOooo`03o`2Ioooooooo04Koool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P00
04Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0004Goool00ol0VOooooooo`16oooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo
04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_oo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Qooo
o`D00003oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Woool00`000?ooooooo`03
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Woool00`000?ooooooo`03oooo0`00
04Goool00ol0VOooooooo`16oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00[oool01@000?oo
ooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.77751 .30902 L
.78293 .30902 L
.7859 .30902 L
.78866 .30902 L
.78988 .30902 L
.79102 .30902 L
.79166 .30902 L
s
.79166 .30902 m
.79173 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.20178 .30902 L
.20433 .30902 L
.20573 .30902 L
.20704 .30902 L
.20772 .30902 L
.20845 .15451 L
.20926 .15451 L
.21 .15451 L
.21274 .15451 L
.22272 .15451 L
.26243 .15451 L
.30062 .15451 L
.34126 .15451 L
.38039 .15451 L
.40037 .15451 L
.42198 .15451 L
.43212 .15451 L
.43767 .15451 L
.44037 .15451 L
.44284 .15451 L
.44393 .15451 L
.44511 .15451 L
.44623 .15451 L
.44726 .15505 L
.452 .15808 L
.46204 .16432 L
.48229 .17612 L
.48713 .17879 L
.49221 .18154 L
.49656 .18384 L
.49775 .18447 L
.49902 .18513 L
.50022 .18553 L
.50131 .18496 L
.51948 .17512 L
.52966 .16927 L
.53906 .16364 L
.54838 .15784 L
.55064 .1564 L
.55189 .1556 L
.55308 .15483 L
.55374 .30902 L
.55447 .30902 L
.55575 .30902 L
Mistroke
.55824 .30902 L
.57904 .30902 L
.61974 .30902 L
.65892 .30902 L
.70055 .30902 L
.74067 .30902 L
.77928 .30902 L
.82033 .30902 L
.85987 .30902 L
.8979 .30902 L
.93837 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Gooolf06Ko00@00000I_l0I_l0000406Ko1oooo`030000oooooooo
00;oool300002_ooo`0306Kooooooooo087oool004Goool00`1Vooooooooo`0]oooo100000;oool0
10000?ooooooo`0000Coool00`1Vooooooooo`02oooo0P0000Goool00`000?ooooooo`09oooo0P1V
oh?oool004Goool00`1Vooooooooo`0coooo00@0003oooooool00005oooo00D0I_ooooooooooool0
00001_ooo`030000oooooooo00Soool00`1Vooooo`1Vo`23oooo0015oooo00<0I_ooooooool0=?oo
o`800007oooo00<0I_ooooooool00`0000Coool00`000?ooooooo`06oooo0P1Vo`;oool00`1Voooo
ooooo`21oooo0015oooo00<0I_ooooooool0?_ooo`80I_l7oooo0P0000Goool206Ko1?ooo`0306Ko
oooooooo087oool004Goool00`1Vooooooooo`10oooo0P1Vo`Goool00`000?ooooooo`02oooo0P1V
o`Koool00`1Vooooooooo`21oooo0015oooo00<0I_ooooooool0@_ooo`<0I_l2oooo00<0003ooooo
ool00P1Vo`Soool00`1Vooooooooo`21oooo0015oooo00<0I_ooooooool0AOooo`0306Kooooo0000
0080I_l:oooo00<0I_ooooooool0POooo`00AOooo`0306Kooooooooo04Koool00`1Vo`000000000;
oooo00<0I_ooooooool0POooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0:oooo00<0
I_ooooooool0POooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0:oooo00<0I_oooooo
ool0POooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0:oooo00<0I_ooooooool0POoo
o`00AOooo`0306Kooooooooo04Ooool200002oooo`0306Kooooooooo087oool004Goool00`1Voooo
ooooo`17oooo00<0003oooooool02_ooo`0306Kooooooooo087oool004Goool00`1Vooooooooo`17
oooo00<0003oooooool02_ooo`0306Kooooooooo087oool004Goool00`1Vooooooooo`17oooo00<0
003oooooool02_ooo`0306Kooooooooo087oool004Goool00`1Vooooooooo`17oooo0P0000_oool0
0`1Vooooooooo`21oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo00[oool00`1Voooo
ooooo`21oooo0015oooo00<0I_ooooooool0;_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool02_ooo`0306Kooooooooo087oool004Goool00`1Vooooooooo`0]oooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
00[oool00`1Vooooooooo`21oooo0015oooo00<0I_ooooooool0;Oooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0000_oool00`1Vooooooooo`20oooo0015
oooo00<0I_ooooooool09oooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool02oooo`0306Kooooooooo083oool004Goool00`1Vooooooooo`0]
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo00_oool00`1Vooooooooo`20oooo0015oooo00<0I_ooooooool0;_ooo`80000:oooo0P00
00Coool300001?ooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0015oooo00<0I_oooooo
ool0Aoooo`80000<oooo00<0I_ooooooool0P?ooo`00AOooo`0306Kooooooooo04Ooool00`000?oo
ooooo`0;oooo00<0I_ooooooool0P?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0;
oooo00<0I_ooooooool0P?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0;oooo00<0
I_ooooooool0P?ooo`006Oooo`<0000Yoooo00<0I_ooooooool03?ooo`@0000goooo0P0000coool0
0`1Vooooooooo`0Yoooo100003_oool300005Oooo`006_ooo`030000oooooooo02Soool00`1Voooo
ooooo`0<oooo00<0003oooooool0>?ooo`030000oooooooo00_oool00`1Vooooooooo`0Yoooo00<0
003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000:Oooo`0306Kooooooooo00goool0
0`000?ooooooo`0goooo00<0003oooooool02oooo`0306Kooooooooo02[oool00`000?ooooooo`0i
oooo1@0001Goool0017oool400000_ooo`040000oooooooo0000:_ooo`0306Kooooooooo00Koool4
00001?ooo`030000oooooooo03Koool00`000?ooooooo`0;oooo00<0I_ooooooool0:oooo`030000
oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000Zoooo00<0I_oooooo
ool03?ooo`040000oooooooo0000=oooo`80000<oooo00<0I_ooooooool0:Oooo`040000oooooooo
0000>_ooo`030000oooo000001Koool001Woool20000:_ooo`0306Kooooooooo00goool20000>?oo
o`030000oooooooo00_oool00`1Vooooooooo`0Zoooo0P0003coool200005_ooo`00AOooo`0306Ko
oooooooo04Ooool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00AOooo`0306Kooooooooo
04Ooool200003?ooo`0306Kooooooooo083oool004Goool00`1Vooooooooo`17oooo00<0003ooooo
ool02oooo`0306Kooooooooo083oool004Goool00`1Vooooooooo`17oooo00<0003oooooool02ooo
o`0306Kooooooooo083oool004Goool00`1Vooooooooo`17oooo00<0003oooooool02oooo`0306Ko
oooooooo083oool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00_oool0
0ol0V@000?ooo`0>oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0
003oooooool02oooo`03o`2Ioooooooo02coool00`000?ooooooo`0Eoooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?oo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00M_ooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool007Goool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<00017oooo00?o09Woooooool0A?ooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo001foooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?oo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00O?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo001k
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0004Ooool0
0ol0VOooooooo`14oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`17
oooo00?o09Woooooool0A?ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<00017
oooo00?o09Woooooool0A?ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aooo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14
oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008Ooool500000oooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo0029oooo00<0003oooooool00oooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo0029oooo00<0003oooooool00oooo`<00017oooo00?o09Woooooool0A?ooo`00ROoo
o`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool300000_ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01oooo`030000oooooooo00[oool010000?ooooooo`0000;oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo1@0000Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0
003oool000000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000;oooo0P0000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.77751 .30902 L
.78293 .30902 L
.78866 .30902 L
.79355 .30902 L
.79489 .30902 L
.79563 .30902 L
.79633 .30902 L
.79698 .30902 L
s
.79698 .30902 m
.79705 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.19227 .30902 L
.19721 .30902 L
.19939 .30902 L
.20054 .30902 L
.20178 .30902 L
.2031 .15451 L
.20433 .15451 L
.20704 .15451 L
.21274 .15451 L
.22272 .15451 L
.26394 .15451 L
.30365 .15451 L
.34184 .15451 L
.38249 .15451 L
.40128 .15451 L
.42162 .15451 L
.42704 .15451 L
.43277 .15451 L
.43766 .15451 L
.439 .15451 L
.43974 .15451 L
.44044 .15451 L
.44109 .1549 L
.44179 .15536 L
.44303 .15616 L
.4632 .16857 L
.48258 .17955 L
.4879 .18241 L
.49362 .18542 L
.49625 .18678 L
.49769 .18751 L
.49839 .18787 L
.49903 .18819 L
.50017 .1886 L
.50139 .18798 L
.50398 .18666 L
.52441 .17569 L
.54325 .16472 L
.55257 .15896 L
.55483 .15752 L
.55727 .15597 L
.55798 .15551 L
.55866 .15507 L
.55994 .30902 L
.56113 .30902 L
Mistroke
.56243 .30902 L
.58323 .30902 L
.62393 .30902 L
.66311 .30902 L
.70474 .30902 L
.74486 .30902 L
.78347 .30902 L
.82452 .30902 L
.86406 .30902 L
.90209 .30902 L
.94256 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004Cooolg06Ko00@00000I_l0I_l0000206Ko2Oooo`030000oooooooo
00;oool300003?ooo`0306Kooooooooo07ooool004Coool00`1Vooooooooo`0^oooo100000;oool0
10000?ooooooo`0000;oool00`1Vooooooooo`04oooo0P0000Goool00`000?ooooooo`0:oooo0`1V
oh7oool004Coool00`1Vooooooooo`0doooo00@0003oooooool00003oooo0P1Vo`Coool00`000?oo
ooooo`04oooo00<0003oooooool02Oooo`0406Kooooooooo06KoPOooo`00A?ooo`0306Kooooooooo
03Goool200001_ooo`80I_l2oooo0`0000Coool00`000?ooooooo`08oooo00D0I_ooooooooooool0
I_l0POooo`00A?ooo`0306Kooooooooo03ooool00`1Vooooooooo`06oooo0P0000Ooool206Ko1?oo
o`0306Kooooooooo07ooool004Coool00`1Vooooooooo`10oooo0P1Vo`Koool00`000?ooooooo`04
oooo0P1Vo`Koool00`1Vooooooooo`1ooooo0014oooo00<0I_ooooooool0@_ooo`80I_l4oooo00<0
003oooooool00_ooo`80I_l8oooo00<0I_ooooooool0Ooooo`00A?ooo`0306Kooooooooo04Coool2
06Ko0_ooo`030000oooooooo0080I_l:oooo00<0I_ooooooool0Ooooo`00A?ooo`0306Kooooooooo
04Koool206Ko0P00000306Kooooooooo00[oool00`1Vooooooooo`1ooooo0014oooo00<0I_oooooo
ool0Aoooo`0306Ko0000oooo00goool00`1Vooooooooo`1ooooo0014oooo00<0I_ooooooool0B?oo
o`030000oooooooo00coool00`1Vooooooooo`1ooooo0014oooo00<0I_ooooooool0B?ooo`030000
oooooooo00coool00`1Vooooooooo`1ooooo0014oooo00<0I_ooooooool0B?ooo`80000=oooo00<0
I_ooooooool0Ooooo`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`0<oooo00<0I_oooooo
ool0Ooooo`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`0<oooo00<0I_ooooooool0Oooo
o`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`0<oooo00<0I_ooooooool0Ooooo`00A?oo
o`0306Kooooooooo04Soool200003Oooo`0306Kooooooooo07ooool004Coool00`1Vooooooooo`18
oooo00<0003oooooool03?ooo`0306Kooooooooo07ooool004Coool00`1Vooooooooo`0_oooo0P00
00Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0<oooo00<0I_ooooooool0Oooo
o`00A?ooo`0306Kooooooooo02koool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool03?ooo`0306Kooooooooo07ooool004?oool00`1Voooo
ooooo`0_oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool3
00003?ooo`0306Kooooooooo07ooool004?oool00`1Vooooooooo`0Yoooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0<oooo00<0I_oooooo
ool0Ooooo`00@oooo`0306Kooooooooo02ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool03?ooo`0306Kooooooooo07ooool004?oool0
0`1Vooooooooo`0`oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool03?ooo`0306Ko
oooooooo07ooool004?oool00`1Vooooooooo`19oooo0P0000goool00`1Vooooooooo`1ooooo0013
oooo00<0I_ooooooool0BOooo`030000oooooooo00coool00`1Vooooooooo`1ooooo0013oooo00<0
I_ooooooool0BOooo`030000oooooooo00coool00`1Vooooooooo`1ooooo0013oooo00<0I_oooooo
ool0BOooo`030000oooooooo00coool00`1Vooooooooo`1ooooo000Ioooo0`0002Ooool00`1Voooo
ooooo`0>oooo100003Ooool200003Oooo`0306Kooooooooo02Soool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool09_ooo`0306Kooooooooo00koool00`000?ooooooo`0hoooo00<0003ooooo
ool03?ooo`0306Kooooooooo02Soool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005ooo
o`D0000Woooo00<0I_ooooooool03oooo`030000oooooooo03Ooool00`000?ooooooo`0<oooo00<0
I_ooooooool0:Oooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003ooooo
ool0000Xoooo00<0I_ooooooool02?ooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo
00coool00`1Vooooooooo`0Zoooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000002Soool00`1Vooooooooo`0>oooo00@0003oooooool0000goooo0P0000goool0
0`1Vooooooooo`0Xoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000X
oooo00<0I_ooooooool03oooo`80000hoooo00<0003oooooool03?ooo`0306Kooooooooo02Woool2
0000??ooo`80000Foooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo00coool00`1Voooo
ooooo`1ooooo0013oooo00<0I_ooooooool0BOooo`80000=oooo00<0I_ooooooool0Ooooo`00@ooo
o`0306Kooooooooo04Woool00`000?ooooooo`0<oooo00<0I_ooooooool0Ooooo`00@oooo`0306Ko
oooooooo04Woool00`000?ooooooo`0<oooo00<0I_ooooooool0Ooooo`00@oooo`0306Kooooooooo
04Woool00`000?ooooooo`0<oooo00<0I_ooooooool0Ooooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000oooooooo03Woool00`000?ooooooo`0<oooo00?o09Woooooool0:oooo`030000
oooooooo01Goool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019
oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00Soooo`800019oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo
04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
08ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o09Wooooo
ool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@ooo
o`00Soooo`800019oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`18
oooo00?o09Woooooool0@oooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0004Soool00ol0VOoo
ooooo`13oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0B?ooo`03o`2Ioooooooo04?oool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`18oooo00?o09Woooooool0@ooo
o`00Soooo`800019oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?oo
ooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019
oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00Soooo`800019oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo
04Soool00ol0VOooooooo`13oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04?oool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000B?ooo`03o`2Ioooooooo04?oool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo04Soool00ol0VOooooooo`13oooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo04Soool00ol0VOooooooo`13oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo0P00
04Woool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
08ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o09Wooooo
ool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@ooo
o`00Soooo`800019oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?oo
ooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo04Soool00ol0VOooooooo`13oooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`18oooo00?o09Woooooool0@oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0004Soool00ol0VOooooooo`13oooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo04Soool00ol0VOooooooo`13
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool20000BOooo`03o`2Ioooooooo
04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo
04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
08ooool20000BOooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Wooooo
ool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04?oool008ooool20000BOooo`03o`2Ioooooooo04?oool008ooool0
0`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool20000BOoo
o`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Qooo
o`D00003oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008Woool00`000?ooooooo`03oooo0`00
04Soool00ol0VOooooooo`13oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?oo
ooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79321 .30902 L
.79616 .30902 L
.79892 .30902 L
.80134 .30902 L
.80204 .30902 L
.8027 .30902 L
s
.8027 .30902 m
.80282 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.18221 .30902 L
.18703 .30902 L
.18957 .30902 L
.19227 .30902 L
.19462 .30902 L
.19527 .30902 L
.19596 .30902 L
.19721 .15451 L
.19844 .15451 L
.1996 .15451 L
.20178 .15451 L
.22272 .15451 L
.26091 .15451 L
.30156 .15451 L
.34068 .15451 L
.38227 .15451 L
.40313 .15451 L
.41229 .15451 L
.42233 .15451 L
.42701 .15451 L
.42959 .15451 L
.43203 .15451 L
.43313 .15451 L
.4343 .15451 L
.43558 .15519 L
.43676 .15595 L
.44108 .1587 L
.46088 .1707 L
.48058 .18168 L
.4892 .18621 L
.49409 .18871 L
.49643 .18988 L
.49863 .19098 L
.49978 .19155 L
.50102 .19115 L
.50215 .19059 L
.50319 .19007 L
.50806 .18762 L
.51798 .18245 L
.53884 .17086 L
.54788 .16551 L
.5576 .15954 L
.56046 .15773 L
.56187 .15683 L
.56317 .156 L
Mistroke
.56435 .15524 L
.56561 .30902 L
.56633 .30902 L
.567 .30902 L
.56826 .30902 L
.57824 .30902 L
.61684 .30902 L
.6579 .30902 L
.69744 .30902 L
.73546 .30902 L
.77594 .30902 L
.8149 .30902 L
.85631 .30902 L
.89621 .30902 L
.93459 .30902 L
.97543 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool004;oooli06Ko00D00000I_l0I_l00000I_l02_ooo`030000oooooooo
00;oool300003Oooo`0306Kooooooooo07koool004;oool00`1Vooooooooo`0`oooo100000;oool0
10000?ooooooo`000080I_l7oooo0P0000Goool00`000?ooooooo`0<oooo0P1Voh3oool004;oool0
0`1Vooooooooo`0foooo00@0003oooooool00002oooo0P1Vo`Goool00`000?ooooooo`04oooo00<0
003oooooool02oooo`<0I_n0oooo0012oooo00<0I_ooooooool0=oooo`800005oooo0P1Vo`?oool3
00001?ooo`030000oooooooo00Woool206Ko0_ooo`0306Kooooooooo07koool004;oool00`1Voooo
ooooo`10oooo00<0I_ooooooool01oooo`800008oooo0P1Vo`Coool00`1Vooooooooo`1noooo0012
oooo00<0I_ooooooool0@Oooo`80I_l7oooo00<0003oooooool01Oooo`80I_l6oooo00<0I_oooooo
ool0O_ooo`00@_ooo`0306Kooooooooo04?oool206Ko1Oooo`030000oooooooo00?oool206Ko2?oo
o`0306Kooooooooo07koool004;oool00`1Vooooooooo`15oooo00<0I_ooooooool00_ooo`030000
oooooooo00;oool00`1Vooooooooo`08oooo00<0I_ooooooool0O_ooo`00@_ooo`0306Kooooooooo
04Koool206Ko0_ooo`8000000oooo`1Vo`1Vo`0;oooo00<0I_ooooooool0O_ooo`00@_ooo`0306Ko
oooooooo04Soool206Ko00<00000I_l0I_l03Oooo`0306Kooooooooo07koool004;oool00`1Voooo
ooooo`1:oooo00<0003oooooool03Oooo`0306Kooooooooo07koool004;oool00`1Vooooooooo`1:
oooo00<0003oooooool03Oooo`0306Kooooooooo07koool004;oool00`1Vooooooooo`1:oooo0P00
00koool00`1Vooooooooo`1noooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool0
0`1Vooooooooo`1noooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool00`1Voooo
ooooo`1noooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool00`1Vooooooooo`1n
oooo0012oooo00<0I_ooooooool0B_ooo`80000>oooo00<0I_ooooooool0O_ooo`00@_ooo`0306Ko
oooooooo04[oool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00@_ooo`0306Kooooooooo
037oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo00goool00`1Voooo
ooooo`1noooo0012oooo00<0I_ooooooool0<?ooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00@_oo
o`0306Kooooooooo033oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`<0000>oooo00<0I_ooooooool0OOooo`00@_ooo`0306Kooooooooo02[oool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo00koool0
0`1Vooooooooo`1moooo0012oooo00<0I_ooooooool0<?ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0>oooo00<0I_ooooooool0OOoo
o`00@_ooo`0306Kooooooooo037oool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0>
oooo00<0I_ooooooool0OOooo`00@_ooo`0306Kooooooooo04[oool200003oooo`0306Kooooooooo
07goool004;oool00`1Vooooooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo07goool0
04;oool00`1Vooooooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo07goool004;oool0
0`1Vooooooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo07goool001Woool300009_oo
o`0306Kooooooooo00ooool40000=oooo`80000?oooo00<0I_ooooooool09_ooo`@0000koooo0`00
01Goool001[oool00`000?ooooooo`0Uoooo00<0I_ooooooool03oooo`030000oooooooo03Soool0
0`000?ooooooo`0>oooo00<0I_ooooooool09_ooo`030000oooooooo03goool00`000?ooooooo`0D
oooo000Goooo1@0002Koool00`1Vooooooooo`0@oooo00<0003oooooool0=oooo`030000oooooooo
00koool00`1Vooooooooo`0Woooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool0
10000?ooooooo`0002Ooool00`1Vooooooooo`09oooo100000Coool00`000?ooooooo`0foooo00<0
003oooooool03_ooo`0306Kooooooooo02Soool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo00<0003oool000009oooo`0306Kooooooooo00ooool010000?ooooooo`0003Ooool2
00003oooo`0306Kooooooooo02Koool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000I
oooo0P0002Ooool00`1Vooooooooo`0@oooo0P0003Soool00`000?ooooooo`0>oooo00<0I_oooooo
ool09oooo`80000loooo0P0001Koool004;oool00`1Vooooooooo`1:oooo00<0003oooooool03_oo
o`0306Kooooooooo07goool004;oool00`1Vooooooooo`1:oooo0P0000ooool00`1Vooooooooo`1m
oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00koool00`1Vooooooooo`1moooo0012
oooo00<0I_ooooooool0B_ooo`030000oooooooo00koool00`1Vooooooooo`1moooo0012oooo00<0
I_ooooooool0B_ooo`030000oooooooo00koool00`1Vooooooooo`1moooo000@ooooo`00017oool0
01Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo09T03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool0
0`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000oooooooo00koool00ol0VOooooooo`0Y
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?
oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo
047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo
04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0
003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo04[oool00ol0VOooooooo`11oooo001eoooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo04[oool00ol0VOooooooo`11oooo001e
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000B_oo
o`03o`2Ioooooooo047oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11
oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:
oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?
oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo
047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo
04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0
003oooooool0B_ooo`03o`2Ioooooooo047oool007coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo04[oool00ol0VOooooooo`11oooo001koooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0001:oooo00?o09Woooooool0@Oooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0B_ooo`03o`2Ioooooooo
047oool007coool200002_ooo`<00004oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool0
08ooool20000Boooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11
oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool007Koool200001?ooo`800005
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool0
07Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo001eoooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo00;oool30000B_ooo`03o`2Ioooooooo047oool007Goool0
10000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0B_ooo`03o`2I
oooooooo047oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool007Koool200002Oooo`@00003
oooo0`0000Coool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`80001;oooo00?o
09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0
003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00Soooo`80001;oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`80001;oooo00?o09Woooooool0@Ooo
o`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`80001;oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11
oooo0027oooo1@0000?oool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00ROooo`030000oooooooo
00?oool30000B_ooo`03o`2Ioooooooo047oool008Woool00`000?ooooooo`2Doooo0029oooo00<0
003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02_ooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0003oooooool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool3
00000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79892 .30902 L
.80403 .30902 L
.80682 .30902 L
.80819 .30902 L
.80943 .30902 L
s
.80943 .30902 m
.80954 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.18221 .30902 L
.18475 .30902 L
.18744 .30902 L
.18855 .30902 L
.18974 .30902 L
.19104 .15451 L
.19227 .15451 L
.20178 .15451 L
.22272 .15451 L
.26394 .15451 L
.30365 .15451 L
.34184 .15451 L
.38249 .15451 L
.40128 .15451 L
.41117 .15451 L
.42162 .15451 L
.42418 .15451 L
.42693 .15451 L
.42774 .15451 L
.42851 .15451 L
.4292 .15492 L
.42995 .1554 L
.43277 .15721 L
.44303 .16361 L
.4632 .17542 L
.48258 .18587 L
.4879 .18858 L
.49362 .19145 L
.49625 .19274 L
.49769 .19344 L
.49839 .19378 L
.49903 .19409 L
.50017 .19447 L
.50139 .19388 L
.50398 .19262 L
.54325 .17175 L
.55257 .16628 L
.56243 .16024 L
.56759 .15698 L
.569 .15608 L
.56978 .15558 L
.57051 .1551 L
.5712 .15466 L
.57195 .30902 L
Mistroke
.57325 .30902 L
.58323 .30902 L
.62393 .30902 L
.66311 .30902 L
.70474 .30902 L
.74486 .30902 L
.78347 .30902 L
.82452 .30902 L
.86406 .30902 L
.90209 .30902 L
.94256 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0047ooolj06Ko00@00000I_l0I_l0000;oooo00<0003oooooool00_oo
o`<0000?oooo00<0I_ooooooool0O?ooo`00@Oooo`0306Kooooooooo037oool400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool03_ooo`80I_mnoooo0011oooo00<0I_oooooo
ool0=oooo`040000oooooooo00000P1Vo`Ooool00`000?ooooooo`04oooo00<0003oooooool03?oo
o`80I_l00oooo`1Vooooo`1moooo0011oooo00<0I_ooooooool0>?ooo`800003oooo00<0I_oooooo
ool01?ooo`<00004oooo00<0003oooooool02_ooo`80I_l3oooo00<0I_ooooooool0O?ooo`00@Ooo
o`0306Kooooooooo03koool206Ko2oooo`80000:oooo00<0I_ooooooool00oooo`0306Kooooooooo
07coool0047oool00`1Vooooooooo`10oooo0P1Vo`Woool00`000?ooooooo`08oooo00<0I_oooooo
ool01?ooo`0306Kooooooooo07coool0047oool00`1Vooooooooo`12oooo0P1Vo`Ooool00`000?oo
ooooo`06oooo0P1Vo`Ooool00`1Vooooooooo`1loooo0011oooo00<0I_ooooooool0A?ooo`80I_l5
oooo00<0003oooooool01?ooo`80I_l9oooo00<0I_ooooooool0O?ooo`00@Oooo`0306Kooooooooo
04Koool206Ko0oooo`800003oooo0P1Vo`_oool00`1Vooooooooo`1loooo0011oooo00<0I_oooooo
ool0B?ooo`0406Kooooooooo00000_ooo`80I_l=oooo00<0I_ooooooool0O?ooo`00@Oooo`0306Ko
oooooooo04Woool206Ko00<00000I_l0I_l03oooo`0306Kooooooooo07coool0047oool00`1Voooo
ooooo`1;oooo00<0003oooooool03oooo`0306Kooooooooo07coool0047oool00`1Vooooooooo`1;
oooo0P00013oool00`1Vooooooooo`1loooo0011oooo00<0I_ooooooool0Boooo`030000oooooooo
00ooool00`1Vooooooooo`1loooo0011oooo00<0I_ooooooool0Boooo`030000oooooooo00ooool0
0`1Vooooooooo`1loooo0011oooo00<0I_ooooooool0Boooo`030000oooooooo00ooool00`1Voooo
ooooo`1loooo0011oooo00<0I_ooooooool0Boooo`80000@oooo00<0I_ooooooool0O?ooo`00@Ooo
o`0306Kooooooooo04_oool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00@Oooo`0306Ko
oooooooo03;oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo00ooool0
0`1Vooooooooo`1loooo0011oooo00<0I_ooooooool0<Oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0?oooo00<0I_ooooooool0O?oo
o`00@?ooo`0306Kooooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<0000?oooo00<0I_ooooooool0O?ooo`00@?ooo`0306Kooooooooo02coool4
00000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo
00ooool00`1Vooooooooo`1loooo0010oooo00<0I_ooooooool0<_ooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0?oooo00<0I_oooooo
ool0O?ooo`00@?ooo`0306Kooooooooo03?oool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0?oooo00<0I_ooooooool0O?ooo`00@?ooo`0306Kooooooooo04coool200004?ooo`0306Ko
oooooooo07coool0043oool00`1Vooooooooo`1<oooo00<0003oooooool03oooo`0306Kooooooooo
07coool0043oool00`1Vooooooooo`1<oooo00<0003oooooool03oooo`0306Kooooooooo07coool0
043oool00`1Vooooooooo`1<oooo00<0003oooooool03oooo`0306Kooooooooo07coool001Woool3
00009?ooo`0306Kooooooooo017oool40000=oooo`80000@oooo00<0I_ooooooool09Oooo`@0000k
oooo0`0001Goool001[oool00`000?ooooooo`0Soooo00<0I_ooooooool04Oooo`030000oooooooo
03Soool00`000?ooooooo`0?oooo00<0I_ooooooool09Oooo`030000oooooooo03goool00`000?oo
ooooo`0Doooo000Goooo1@0002Coool00`1Vooooooooo`0Boooo00<0003oooooool0=oooo`030000
oooooooo00ooool00`1Vooooooooo`0Voooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo1000
00;oool010000?ooooooo`0002Goool00`1Vooooooooo`0;oooo100000Coool00`000?ooooooo`0f
oooo00<0003oooooool03oooo`0306Kooooooooo02Ooool00`000?ooooooo`0hoooo00@0003ooooo
ool0000Foooo000Hoooo00<0003oool000009Oooo`0306Kooooooooo017oool010000?ooooooo`00
03Ooool200004?ooo`0306Kooooooooo02Goool010000?ooooooo`0003[oool00`000?ooo`00000F
oooo000Ioooo0P0002Goool00`1Vooooooooo`0Boooo0P0003Soool00`000?ooooooo`0?oooo00<0
I_ooooooool09_ooo`80000loooo0P0001Koool0043oool00`1Vooooooooo`1<oooo00<0003ooooo
ool03oooo`0306Kooooooooo07coool0043oool00`1Vooooooooo`1<oooo0P00013oool00`1Voooo
ooooo`1loooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`1l
oooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo0010
oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo000@ooooo`00
017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00@0003ooooooooo09T<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0003oooooool03oooo`03o`2I
oooooooo02Soool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool0
08ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool2
0000C?ooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007Goool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<0001;oooo00?o09Woooooool0@?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool0
08ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo001koooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007_oool0
10000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0004_oool00ol0VOooooooo`10oooo001k
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool2
0000C?ooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00M_ooo`800004
oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001;oooo00?o09Woooooool0@?oo
o`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1;
oooo00?o09Woooooool0@?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00M_ooo`800009
oooo100000?oool300001?ooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P00
04coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool0
08ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008Ooool500000oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo0029
oooo00<0003oooooool00oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo0029oooo00<0
003oooooool00oooo`<0001;oooo00?o09Woooooool0@?ooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool300001?oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?oo
o`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79892 .30902 L
.80403 .30902 L
.80943 .30902 L
.81165 .30902 L
.81404 .30902 L
.81474 .30902 L
.8154 .30902 L
s
.8154 .30902 m
.81553 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.16408 .30902 L
.17277 .30902 L
.17735 .30902 L
.17986 .30902 L
.18221 .30902 L
.18341 .30902 L
.1847 .15451 L
.18543 .15451 L
.18613 .15451 L
.18744 .15451 L
.19227 .15451 L
.20178 .15451 L
.22272 .15451 L
.26091 .15451 L
.30156 .15451 L
.34068 .15451 L
.38227 .15451 L
.40313 .15451 L
.41229 .15451 L
.41714 .15451 L
.4198 .15451 L
.42112 .15451 L
.42233 .15451 L
.42351 .15509 L
.42476 .15589 L
.4274 .15758 L
.43203 .1605 L
.44108 .16604 L
.46088 .17745 L
.48058 .18789 L
.4892 .1922 L
.49409 .19457 L
.49643 .19569 L
.49863 .19674 L
.49978 .19728 L
.50102 .1969 L
.50215 .19637 L
.50319 .19587 L
.50806 .19354 L
.51798 .18862 L
.53884 .1776 L
.5576 .16683 L
.56274 .16372 L
.56826 .16031 L
.57094 .15863 L
.57348 .15702 L
Mistroke
.57576 .15556 L
.57705 .15473 L
.57824 .30902 L
.57953 .30902 L
.5809 .30902 L
.58333 .30902 L
.58884 .30902 L
.5988 .30902 L
.61742 .30902 L
.65545 .30902 L
.69592 .30902 L
.73488 .30902 L
.7763 .30902 L
.81619 .30902 L
.85458 .30902 L
.89541 .30902 L
.93473 .30902 L
.97253 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003ooooll06Ko00@00000I_ooool0000;oooo00<0003oooooool00_oo
o`<0000Aoooo00<0I_ooooooool0N_ooo`00?oooo`0306Kooooooooo03?oool400000_ooo`040000
06Ko06Ko00002Oooo`800005oooo00<0003oooooool03oooo`<0I_mloooo000ooooo00<0I_oooooo
ool0>Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0>oooo00@0
I_ooooooool0I_mloooo000ooooo00<0I_ooooooool0>_ooo`8000000oooo`1Vo`1Vo`07oooo0`00
00Coool00`000?ooooooo`0<oooo0P1Vo`?oool00`1Vooooooooo`1joooo000ooooo00<0I_oooooo
ool0?oooo`80I_l<oooo0P0000_oool206Ko1Oooo`0306Kooooooooo07[oool003ooool00`1Voooo
ooooo`11oooo0P1Vo`[oool00`000?ooooooo`08oooo0P1Vo`Ooool00`1Vooooooooo`1joooo000o
oooo00<0I_ooooooool0@oooo`0306Kooooooooo00Ooool00`000?ooooooo`07oooo00<0I_oooooo
ool01oooo`0306Kooooooooo07[oool003ooool00`1Vooooooooo`14oooo0P1Vo`Ooool00`000?oo
ooooo`05oooo0P1Vo`[oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0A_ooo`80I_l5
oooo0P0000Coool206Ko3?ooo`0306Kooooooooo07[oool003ooool00`1Vooooooooo`18oooo00<0
I_ooooooool00_ooo`040000oooooooooooo0P1Vo`koool00`1Vooooooooo`1joooo000ooooo00<0
I_ooooooool0BOooo`<0I_l00oooo`000?ooo`0206Ko4?ooo`0306Kooooooooo07[oool003ooool0
0`1Vooooooooo`1<oooo00<0I_l00000I_l04_ooo`0306Kooooooooo07[oool003ooool00`1Voooo
ooooo`1=oooo0P0001;oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0COooo`030000
oooooooo017oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0COooo`030000oooooooo
017oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool0
0`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0COooo`80000Boooo00<0I_ooooooool0N_oo
o`00?oooo`0306Kooooooooo04goool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00?ooo
o`0306Kooooooooo03Coool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
017oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0<oooo`040000oooooooo00002?oo
o`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0N_ooo`00?oooo`0306Kooooooooo03?oool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0000Aoooo00<0I_ooooooool0N_ooo`00?oooo`0306Kooooooooo
02goool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo017oool00`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0<oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Aoooo00<0
I_ooooooool0N_ooo`00?oooo`0306Kooooooooo03Coool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00?oooo`0306Kooooooooo04goool200004_oo
o`0306Kooooooooo07[oool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Ko
oooooooo07[oool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo
07[oool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo07[oool0
01Woool300008oooo`0306Kooooooooo01;oool40000=oooo`80000Boooo00<0I_ooooooool08ooo
o`@0000koooo0`0001Goool001[oool00`000?ooooooo`0Roooo00<0I_ooooooool04_ooo`030000
oooooooo03Soool00`000?ooooooo`0Aoooo00<0I_ooooooool08oooo`030000oooooooo03goool0
0`000?ooooooo`0Doooo000Goooo1@0002?oool00`1Vooooooooo`0Coooo00<0003oooooool0=ooo
o`030000oooooooo017oool00`1Vooooooooo`0Toooo00<0003oooooool0>Oooo`D0000Eoooo000A
oooo100000;oool010000?ooooooo`0002Coool00`1Vooooooooo`0<oooo100000Coool00`000?oo
ooooo`0foooo00<0003oooooool04Oooo`0306Kooooooooo02Goool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo00<0003oool000009?ooo`0306Kooooooooo01;oool010000?oo
ooooo`0003Ooool200004_ooo`0306Kooooooooo02?oool010000?ooooooo`0003[oool00`000?oo
o`00000Foooo000Ioooo0P0002Coool00`1Vooooooooo`0Coooo0P0003Soool00`000?ooooooo`0A
oooo00<0I_ooooooool09?ooo`80000loooo0P0001Koool003ooool00`1Vooooooooo`1=oooo00<0
003oooooool04Oooo`0306Kooooooooo07[oool003ooool00`1Vooooooooo`1=oooo0P0001;oool0
0`1Vooooooooo`1joooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Voooo
ooooo`1joooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`1j
oooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`1joooo000@
ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00_oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo03Woool0
0`000?ooooooo`0Aoooo00?o09Woooooool09_ooo`030000oooooooo01Goool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Sooo
o`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>
oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
08ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo001foooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00MOoo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0`0004goool00ol0VOooooooo`0noooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool007Koool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Sooo
o`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>
oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
07_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000COoo
o`03o`2Ioooooooo03koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
04goool00ol0VOooooooo`0noooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo04goool00ol0VOooooooo`0noooo001loooo0P0000[oool300001?ooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o
09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
08ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo04goool00ol0VOooooooo`0noooo001eoooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
04goool00ol0VOooooooo`0noooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001Oooo`030000oooooooo04goool00ol0VOooooooo`0noooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool20000C_ooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=
oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?
oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool20000C_ooo`03o`2Ioooooooo
03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
08ooool20000C_ooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool20000C_ooo`03o`2Ioooooooo03koool008ooool0
0`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Qoooo`D00003oooo00<0003oooooool0COoo
o`03o`2Ioooooooo03koool008Woool00`000?ooooooo`03oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008Woool00`000?ooooooo`03oooo0`0004goool00ol0VOooooooo`0noooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`<00004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000
oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81373 .30902 L
.81654 .30902 L
.81776 .30902 L
.81909 .30902 L
.82037 .30902 L
s
.82037 .30902 m
.82049 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.16254 .30902 L
.16783 .30902 L
.17284 .30902 L
.17502 .30902 L
.17733 .30902 L
.17854 .30902 L
.17922 .15451 L
.17987 .15451 L
.18221 .15451 L
.22098 .15451 L
.2622 .15451 L
.30191 .15451 L
.34011 .15451 L
.36142 .15451 L
.38075 .15451 L
.39043 .15451 L
.4009 .15451 L
.40571 .15451 L
.41079 .15451 L
.41288 .15451 L
.41512 .15451 L
.41641 .15451 L
.41758 .1551 L
.41988 .15658 L
.45973 .18007 L
.47795 .18957 L
.48832 .19466 L
.4934 .19708 L
.49562 .19812 L
.4968 .19866 L
.49806 .19924 L
.49931 .19982 L
.50046 .19993 L
.50161 .1994 L
.50269 .1989 L
.50757 .19662 L
.51783 .19167 L
.53884 .18085 L
.55716 .1706 L
.56756 .16441 L
.57265 .16129 L
.5773 .15837 L
.57966 .15688 L
.5809 .15608 L
.58222 .15523 L
Mistroke
.58349 .30902 L
.58464 .30902 L
.58689 .30902 L
.59718 .30902 L
.61822 .30902 L
.65834 .30902 L
.69694 .30902 L
.738 .30902 L
.77754 .30902 L
.81556 .30902 L
.85604 .30902 L
.895 .30902 L
.93641 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003kooolm06Ko00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Boooo00<0I_ooooooool0NOooo`00?_ooo`0306Kooooooooo03Coool400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool04Oooo`80I_mkoooo000noooo00<0I_oooooo
ool0>_ooo`04000006Ko06Ko00002Oooo`030000oooooooo00Coool00`000?ooooooo`0?oooo0P1V
o`03oooo06Kooooo07[oool003koool00`1Vooooooooo`0koooo0P000080I_l8oooo0`0000Coool0
0`000?ooooooo`0=oooo0P1Vo`?oool00`1Vooooooooo`1ioooo000noooo00<0I_ooooooool0?ooo
o`0306Kooooooooo00coool200003?ooo`80I_l5oooo00<0I_ooooooool0NOooo`00?_ooo`0306Ko
oooooooo043oool206Ko3?ooo`030000oooooooo00[oool00`1Vooooooooo`05oooo00<0I_oooooo
ool0NOooo`00?_ooo`0306Kooooooooo04;oool206Ko2_ooo`030000oooooooo00Soool206Ko2?oo
o`0306Kooooooooo07Woool003koool00`1Vooooooooo`14oooo00<0I_ooooooool01oooo`030000
oooooooo00Ooool00`1Vooooooooo`08oooo00<0I_ooooooool0NOooo`00?_ooo`0306Kooooooooo
04Goool206Ko1oooo`800006oooo0P1Vo`_oool00`1Vooooooooo`1ioooo000noooo00<0I_oooooo
ool0Aoooo`<0I_l4oooo00<0003oooooool00oooo`80I_l=oooo00<0I_ooooooool0NOooo`00?_oo
o`0306Kooooooooo04[oool206Ko0_ooo`040000oooooooooooo0P1Vo`ooool00`1Vooooooooo`1i
oooo000noooo00<0I_ooooooool0C?ooo`80I_l01000001Vo`1Vo`1Voa7oool00`1Vooooooooo`1i
oooo000noooo00<0I_ooooooool0COooo`0306Ko0000000001?oool00`1Vooooooooo`1ioooo000n
oooo00<0I_ooooooool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo000noooo00<0
I_ooooooool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo000noooo00<0I_oooooo
ool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo000noooo00<0I_ooooooool0C_oo
o`80000Coooo00<0I_ooooooool0NOooo`00?_ooo`0306Kooooooooo04koool00`000?ooooooo`0B
oooo00<0I_ooooooool0NOooo`00?_ooo`0306Kooooooooo03Goool200001?ooo`800003oooo1000
00?oool200001Oooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo000noooo00<0I_oooooo
ool0=?ooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00?Oooo`0306Kooooooooo03Goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Boooo00<0I_oooooo
ool0NOooo`00?Oooo`0306Kooooooooo02ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo000moooo00<0
I_ooooooool0=Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00?Oooo`0306Kooooooooo03Koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00?Ooo
o`0306Kooooooooo04ooool200004oooo`0306Kooooooooo07Woool003goool00`1Vooooooooo`1?
oooo00<0003oooooool04_ooo`0306Kooooooooo07Woool003goool00`1Vooooooooo`1?oooo00<0
003oooooool04_ooo`0306Kooooooooo07Woool003goool00`1Vooooooooo`1?oooo00<0003ooooo
ool04_ooo`0306Kooooooooo07Woool001Woool300008Oooo`0306Kooooooooo01Coool40000=ooo
o`80000Coooo00<0I_ooooooool08_ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0P
oooo00<0I_ooooooool05?ooo`030000oooooooo03Soool00`000?ooooooo`0Boooo00<0I_oooooo
ool08_ooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00027oool00`1Voooo
ooooo`0Eoooo00<0003oooooool0=oooo`030000oooooooo01;oool00`1Vooooooooo`0Soooo00<0
003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0002;oool00`1Voooo
ooooo`0>oooo100000Coool00`000?ooooooo`0foooo00<0003oooooool04_ooo`0306Kooooooooo
02Coool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000008_oo
o`0306Kooooooooo01Coool010000?ooooooo`0003Ooool200004oooo`0306Kooooooooo02;oool0
10000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0002;oool00`1Vooooooooo`0E
oooo0P0003Soool00`000?ooooooo`0Boooo00<0I_ooooooool08oooo`80000loooo0P0001Koool0
03goool00`1Vooooooooo`1?oooo00<0003oooooool04_ooo`0306Kooooooooo07Woool003goool0
0`1Vooooooooo`1?oooo0P0001?oool00`1Vooooooooo`1ioooo000moooo00<0I_ooooooool0Cooo
o`030000oooooooo01;oool00`1Vooooooooo`1ioooo000moooo00<0I_ooooooool0Coooo`030000
oooooooo01;oool00`1Vooooooooo`1ioooo000moooo00<0I_ooooooool0Coooo`030000oooooooo
01;oool00`1Vooooooooo`1ioooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool00oooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000oooooooo03Woool00`000?ooooooo`0Boooo00?o09Woooooool09Oooo`030000
oooooooo01Goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003ooooo
ool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Ooo
o`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1>
oooo00?o09Woooooool0?Oooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00MOooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0004koool00ol0VOoo
ooooo`0moooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool007Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
07Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1>oooo00?o09Woooooool0?Ooo
o`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?oo
ooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Sooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0C_ooo`03o`2Ioooooooo03goool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Noooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000C_ooo`03o`2Ioooooooo03goool007_oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo04koool00ol0VOooooooo`0moooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo04koool00ol0VOooooooo`0moooo001l
oooo0P0000[oool300001?ooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo0P00
04ooool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003ooooo
ool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Ooo
o`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?oo
ooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Sooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo001foooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001Oooo`030000oooooooo04koool00ol0VOooooooo`0moooo001eoooo00@0
003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1>oooo00?o09Woooooool0?Oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo0`0004koool00ol0VOooooooo`0moooo001eoooo00@0003ooooo
ool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo04koool00ol0VOooooooo`0m
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo04koool00ol0VOooooooo`0moooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool20000Coooo`03o`2Ioooooooo
03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool20000Coooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003ooooo
ool0C_ooo`03o`2Ioooooooo03goool008ooool20000Coooo`03o`2Ioooooooo03goool008ooool0
0`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool20000Cooo
o`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Qooo
o`D00003oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008Woool00`000?ooooooo`03
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008Woool00`000?ooooooo`03oooo0`00
04koool00ol0VOooooooo`0moooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo
09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?ooooooooooo`00001m
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`800009oooo100000;oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81373 .30902 L
.81909 .30902 L
.8239 .30902 L
.82528 .30902 L
.82659 .30902 L
s
.82659 .30902 m
.82671 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.16254 .30902 L
.16748 .30902 L
.16883 .30902 L
.17026 .30902 L
.17149 .30902 L
.17219 .30902 L
.17284 .15451 L
.17405 .15451 L
.1752 .15451 L
.17735 .15451 L
.18221 .15451 L
.2204 .15451 L
.26105 .15451 L
.30018 .15451 L
.34176 .15451 L
.36263 .15451 L
.38182 .15451 L
.40057 .15451 L
.40513 .15451 L
.40764 .15451 L
.40887 .15451 L
.41001 .15451 L
.41066 .15451 L
.41135 .15492 L
.41282 .15587 L
.41537 .1575 L
.42038 .16065 L
.45813 .18241 L
.4791 .19308 L
.48828 .19747 L
.49314 .19972 L
.49581 .20094 L
.49712 .20153 L
.49833 .20208 L
.49952 .20261 L
.50078 .20247 L
.50205 .20191 L
.50344 .20128 L
.50809 .19915 L
.51718 .19488 L
.53702 .18496 L
.5581 .17348 L
.57736 .16206 L
.58197 .15918 L
Mistroke
.5845 .15758 L
.58689 .15606 L
.58825 .15518 L
.58901 .15469 L
.58971 .30902 L
.59096 .30902 L
.59228 .30902 L
.59727 .30902 L
.61618 .30902 L
.6542 .30902 L
.69468 .30902 L
.73364 .30902 L
.77505 .30902 L
.81495 .30902 L
.85333 .30902 L
.89417 .30902 L
.93349 .30902 L
.97129 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003cooolm06Ko0_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300004oooo`80I_mioooo000loooo00<0I_ooooooool0=_ooo`@0000206Ko00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`0Boooo0`1VogWoool003coool00`1Vooooooooo`0l
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo017oool0101Voooo
ooooo`1VogWoool003coool00`1Vooooooooo`0moooo0P0000[oool300001?ooo`030000oooooooo
00ooool206Ko0oooo`0306Kooooooooo07Ooool003coool00`1Vooooooooo`0ooooo0P1Vo`ooool2
00003_ooo`80I_l5oooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo047oool206Ko3Ooo
o`030000oooooooo00coool00`1Vooooooooo`05oooo00<0I_ooooooool0Moooo`00??ooo`0306Ko
oooooooo04?oool206Ko2oooo`030000oooooooo00[oool206Ko2?ooo`0306Kooooooooo07Ooool0
03coool00`1Vooooooooo`15oooo00<0I_ooooooool02?ooo`030000oooooooo00Soool206Ko2_oo
o`0306Kooooooooo07Ooool003coool00`1Vooooooooo`16oooo0P1Vo`Soool200001_ooo`<0I_l<
oooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo04Soool206Ko1_ooo`030000oooooooo
00?oool206Ko3oooo`0306Kooooooooo07Ooool003coool00`1Vooooooooo`1:oooo0P1Vo`Coool0
10000?ooooooooooo`80I_lAoooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo04coool2
06Ko0_ooo`040000oooooooo06Ko4oooo`0306Kooooooooo07Ooool003coool00`1Vooooooooo`1>
oooo0P1Vo`8000000`1Vooooooooo`0Boooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo
053oool00`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool200005Oooo`0306Ko
oooooooo07Ooool003coool00`1Vooooooooo`1@oooo00<0003oooooool05?ooo`0306Kooooooooo
07Ooool003coool00`1Vooooooooo`0goooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo03Koool010000?oo
ooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool05?oo
o`0306Kooooooooo07Ooool003coool00`1Vooooooooo`0foooo00@0003oooooool00009oooo00<0
003oooooool01Oooo`030000oooooooo00;oool300005?ooo`0306Kooooooooo07Ooool003coool0
0`1Vooooooooo`0`oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo03Koool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool05?ooo`0306Kooooooooo07Ooool003coool00`1Vooooooooo`0goooo0P0000[oool200001?oo
o`<00004oooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool003coool00`1Vooooooooo`1@
oooo0P0001Goool00`1Vooooooooo`1goooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo
01Coool00`1Vooooooooo`1goooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool0
0`1Vooooooooo`1goooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool00`1Voooo
ooooo`1goooo000Ioooo0`00023oool00`1Vooooooooo`0Eoooo100003Ooool200005Oooo`0306Ko
oooooooo023oool40000>oooo`<0000Eoooo000Joooo00<0003oooooool07oooo`0306Kooooooooo
01Goool00`000?ooooooo`0hoooo00<0003oooooool05?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000Poooo00<0I_ooooooool05_ooo`030000
oooooooo03Ooool00`000?ooooooo`0Doooo00<0I_ooooooool08Oooo`030000oooooooo03Woool5
00005Oooo`004Oooo`@00002oooo00@0003oooooool0000Qoooo00<0I_ooooooool03oooo`@00004
oooo00<0003oooooool0=_ooo`030000oooooooo01Coool00`1Vooooooooo`0Roooo00<0003ooooo
ool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo0000027oool00`1Vooooooooo`0E
oooo00@0003oooooool0000goooo0P0001Goool00`1Vooooooooo`0Poooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`80000Qoooo00<0I_ooooooool05_ooo`80000hoooo00<0
003oooooool05?ooo`0306Kooooooooo027oool20000??ooo`80000Foooo000loooo00<0I_oooooo
ool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo000loooo00<0I_ooooooool0D?oo
o`80000Eoooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0D
oooo00<0I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0Doooo00<0
I_ooooooool0Moooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0Doooo00<0I_oooooo
ool0Moooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00Goool00ol0VOooooooo`05oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?oo
ooooo`0ioooo00<0003oooooool05?ooo`03o`2Ioooooooo02?oool00`000?ooooooo`0Eoooo002?
oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo
03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo
053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool0
08ooool20000DOooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Wooooo
ool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003ooooo
ool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo03_oool008ooool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00M_oo
o`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0D?ooo`03o`2Ioooooooo
03_oool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool007Goool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001@oooo00?o09Woooooool0>oooo`00MOoo
o`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo053oool0
0ol0VOooooooo`0koooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo053oool00ol0VOooooooo`0koooo001foooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@
oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?
oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo
03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo
053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool0
08ooool20000DOooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Wooooo
ool0>oooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool0D?ooo`03o`2Ioooooooo03_oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`00053oool00ol0VOooooooo`0koooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`80001Aoooo00?o09Wooooo
ool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003ooooo
ool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo03_oool008ooool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@
oooo00?o09Woooooool0>oooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00MOooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool00_ooo`<0001@oooo00?o09Woooooool0>oooo`00MOooo`040000oooooooo00002oooo`040000
oooooooooooo0P0000Goool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1@
oooo00?o09Woooooool0>oooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo
053oool00ol0VOooooooo`0koooo002?oooo0P00057oool00ol0VOooooooo`0koooo002?oooo00<0
003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Wooooo
ool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo0P00057oool0
0ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo002?oooo0P00057oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?oo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo0P00057oool00ol0VOooooooo`0k
oooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008Ooool500000oooo`030000
oooooooo053oool00ol0VOooooooo`0koooo0029oooo00<0003oooooool00oooo`030000oooooooo
053oool00ol0VOooooooo`0koooo0029oooo00<0003oooooool00oooo`<0001@oooo00?o09Wooooo
ool0>oooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`050000
oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`0:
oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800009oooo100000?oool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81909 .30902 L
.8239 .30902 L
.82904 .30902 L
.83056 .30902 L
.832 .30902 L
.83329 .30902 L
s
.83329 .30902 m
.83336 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.1536 .30902 L
.15825 .30902 L
.16254 .30902 L
.16494 .30902 L
.16615 .30902 L
.16683 .15451 L
.16748 .15451 L
.17284 .15451 L
.18221 .15451 L
.22098 .15451 L
.2622 .15451 L
.30191 .15451 L
.34011 .15451 L
.36142 .15451 L
.38075 .15451 L
.39043 .15451 L
.39552 .15451 L
.3983 .15451 L
.4009 .15451 L
.40317 .15451 L
.40445 .15451 L
.40561 .15506 L
.41079 .15837 L
.41988 .16401 L
.45973 .18636 L
.47795 .19539 L
.48832 .20024 L
.4934 .20253 L
.49562 .20353 L
.4968 .20405 L
.49806 .2046 L
.49931 .20515 L
.50046 .20525 L
.50161 .20475 L
.50269 .20427 L
.50757 .2021 L
.51783 .19739 L
.53884 .1871 L
.55716 .17735 L
.56756 .17146 L
.5773 .16572 L
.58689 .15983 L
.58965 .1581 L
.59227 .15643 L
.5934 .15569 L
Mistroke
.59462 .15491 L
.59531 .30902 L
.59595 .30902 L
.59718 .30902 L
.61822 .30902 L
.65834 .30902 L
.69694 .30902 L
.738 .30902 L
.77754 .30902 L
.81556 .30902 L
.85604 .30902 L
.895 .30902 L
.93641 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003[oooln06Ko0oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300005Oooo`0306Kooooooooo07Koool003[oool00`1Vooooooooo`0hoooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01Coool206KoN?ooo`00>_ooo`0306Ko
oooooooo03coool206Ko00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
01?oool00`1Vooooo`1Vo`1hoooo000joooo00<0I_ooooooool0?_ooo`0306Ko0000000000[oool3
00001?ooo`030000oooooooo017oool206Ko0_ooo`0306Kooooooooo07Koool003[oool00`1Voooo
ooooo`0ooooo0P1Voa7oool200004?ooo`80I_l4oooo00<0I_ooooooool0M_ooo`00>_ooo`0306Ko
oooooooo047oool206Ko3oooo`030000oooooooo00goool206Ko1_ooo`0306Kooooooooo07Koool0
03[oool00`1Vooooooooo`13oooo0P1Vo`goool00`000?ooooooo`0;oooo0P1Vo`Soool00`1Voooo
ooooo`1foooo000joooo00<0I_ooooooool0AOooo`80I_l;oooo00<0003oooooool02_ooo`0306Ko
oooooooo00Soool00`1Vooooooooo`1foooo000joooo00<0I_ooooooool0Aoooo`80I_l9oooo0P00
00Woool206Ko2oooo`0306Kooooooooo07Koool003[oool00`1Vooooooooo`19oooo00<0I_oooooo
ool01_ooo`030000oooooooo00Koool206Ko3Oooo`0306Kooooooooo07Koool003[oool00`1Voooo
ooooo`1:oooo0P1Vo`Koool00`000?ooooooo`03oooo0`1Vo`ooool00`1Vooooooooo`1foooo000j
oooo00<0I_ooooooool0C?ooo`80I_l4oooo00@0003oooooooooool206Ko4_ooo`0306Kooooooooo
07Koool003[oool00`1Vooooooooo`1>oooo0`1Vo`03oooo000000000080I_lDoooo00<0I_oooooo
ool0M_ooo`00>_ooo`0306Kooooooooo057oool00`1Vo`00001Vo`0Foooo00<0I_ooooooool0M_oo
o`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00>_oo
o`0306Kooooooooo05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00>_ooo`0306Ko
oooooooo05;oool200005_ooo`0306Kooooooooo07Koool003[oool00`1Vooooooooo`1Boooo00<0
003oooooool05Oooo`0306Kooooooooo07Koool003[oool00`1Vooooooooo`0ioooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00>_oo
o`0306Kooooooooo03Soool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool05Oooo`0306Kooooooooo07Koool003[oool00`1Vooooooooo`0h
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool300005Ooo
o`0306Kooooooooo07Koool003[oool00`1Vooooooooo`0boooo100000;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_oo
o`00>_ooo`0306Kooooooooo03Soool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool05Oooo`0306Kooooooooo07Koool003[oool00`1Voooo
ooooo`0ioooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool05Oooo`0306Kooooooooo
07Koool003[oool00`1Vooooooooo`1Boooo0P0001Koool00`1Vooooooooo`1foooo000joooo00<0
I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`1foooo000joooo00<0I_oooooo
ool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`1foooo000joooo00<0I_ooooooool0D_oo
o`030000oooooooo01Goool00`1Vooooooooo`1foooo000Ioooo0`0001koool00`1Vooooooooo`0G
oooo100003Ooool200005_ooo`0306Kooooooooo01ooool40000>oooo`<0000Eoooo000Joooo00<0
003oooooool07Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0hoooo00<0003oooooool05Ooo
o`0306Kooooooooo01ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000N
oooo00<0I_ooooooool06?ooo`030000oooooooo03Ooool00`000?ooooooo`0Eoooo00<0I_oooooo
ool08?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000O
oooo00<0I_ooooooool04Oooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo01Goool0
0`1Vooooooooo`0Qoooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000
oooo000001ooool00`1Vooooooooo`0Goooo00@0003oooooool0000goooo0P0001Koool00`1Voooo
ooooo`0Ooooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000Ooooo00<0
I_ooooooool06?ooo`80000hoooo00<0003oooooool05Oooo`0306Kooooooooo023oool20000??oo
o`80000Foooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`1f
oooo000joooo00<0I_ooooooool0D_ooo`80000Foooo00<0I_ooooooool0M_ooo`00>_ooo`0306Ko
oooooooo05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00>_ooo`0306Kooooooooo
05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00>_ooo`0306Kooooooooo05;oool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Koool00ol0VOooooooo`04oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0003oooooool05Oooo`03o`2Ioooooooo
02;oool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
08ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Wooooo
ool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool0
0`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_oo
o`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Sooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2I
oooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1A
oooo00?o09Woooooool0>_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0DOooo`03o`2Ioooooooo03[oool007Goool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
07Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001A
oooo00?o09Woooooool0>_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo057oool00ol0VOooooooo`0joooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0DOooo`03o`2I
oooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1A
oooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo
03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo
057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool0
08ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Wooooo
ool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003ooooo
ool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool0
0`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00O?ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool007_oool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`00057oool00ol0VOooooooo`0joooo001koooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Nooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Aoooo00?o09Wooooo
ool0>_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Aoooo00?o09Woooooool0>_oo
o`00Soooo`80001Boooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_oo
o`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Sooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2I
oooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1A
oooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool20000D_ooo`03o`2Ioooooooo
03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00M_ooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Aoooo00?o09Woooooool0>_oo
o`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool007Goool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001Aoooo00?o09Woooooool0>_ooo`00MOoo
o`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1Aoooo00?o
09Woooooool0>_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00M_ooo`800009oooo1000
00?oool300001?ooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo0P0005;oool0
0ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool0
0`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOoo
ooooo`0joooo002?oooo0P0005;oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOoo
o`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Sooo
o`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo0P0005;oool00ol0VOooooooo`0j
oooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo03[oool008ooool00`000?ooooooo`1A
oooo00?o09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?
oooo0P0005;oool00ol0VOooooooo`0joooo002?oooo00<0003oooooool0DOooo`03o`2Ioooooooo
03[oool008Ooool500000oooo`030000oooooooo057oool00ol0VOooooooo`0joooo0029oooo00<0
003oooooool00oooo`030000oooooooo057oool00ol0VOooooooo`0joooo0029oooo00<0003ooooo
ool00oooo`<0001Aoooo00?o09Woooooool0>_ooo`00ROooo`030000oooooooo09Coool008Woool0
0`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`D00002oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool2
00000oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81909 .30902 L
.82904 .30902 L
.83177 .30902 L
.83469 .30902 L
.83611 .30902 L
.83745 .30902 L
.83865 .30902 L
s
.83865 .30902 m
.83878 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.1536 .30902 L
.15586 .30902 L
.15825 .30902 L
.15923 .30902 L
.16029 .30902 L
.16145 .15451 L
.16254 .15451 L
.18221 .15451 L
.22343 .15451 L
.26314 .15451 L
.30133 .15451 L
.34198 .15451 L
.36078 .15451 L
.38111 .15451 L
.38653 .15451 L
.39226 .15451 L
.39462 .15451 L
.39715 .15451 L
.3979 .15451 L
.3986 .15451 L
.39924 .15479 L
.39993 .15523 L
.40252 .1569 L
.42269 .16925 L
.46347 .19126 L
.47322 .19598 L
.48373 .20086 L
.48856 .20303 L
.49365 .20527 L
.49575 .20618 L
.49799 .20715 L
.49928 .2077 L
.50045 .20781 L
.50163 .20731 L
.50274 .20683 L
.54049 .18928 L
.57896 .16828 L
.58923 .16208 L
.59425 .15895 L
.59644 .15756 L
.59883 .15603 L
.60012 .1552 L
.60131 .30902 L
Mistroke
.60245 .30902 L
.60366 .30902 L
.60885 .30902 L
.61988 .30902 L
.66151 .30902 L
.70163 .30902 L
.74023 .30902 L
.78129 .30902 L
.82083 .30902 L
.85885 .30902 L
.89933 .30902 L
.93829 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Woooln06Ko1?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300005_ooo`0306Kooooooooo07Goool003Woool00`1Vooooooooo`0ioooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01Goool206KoMoooo`00>Oooo`0306Ko
oooooooo03_oool206Ko0_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`0Doooo00<0I_ooool0I_l0Moooo`00>Oooo`0306Kooooooooo03goool206Ko00?oool00000
00002_ooo`<00004oooo00<0003oooooool04_ooo`80I_l2oooo00<0I_ooooooool0MOooo`00>Ooo
o`0306Kooooooooo03ooool00`1Vooooooooo`0Aoooo0P0001;oool00`1Vooooooooo`02oooo00<0
I_ooooooool0MOooo`00>Oooo`0306Kooooooooo043oool206Ko4Oooo`030000oooooooo00ooool2
06Ko1Oooo`0306Kooooooooo07Goool003Woool00`1Vooooooooo`12oooo0P1Vo`ooool00`000?oo
ooooo`0=oooo0P1Vo`Ooool00`1Vooooooooo`1eoooo000ioooo00<0I_ooooooool0A?ooo`80I_l=
oooo00<0003oooooool02oooo`80I_l9oooo00<0I_ooooooool0MOooo`00>Oooo`0306Kooooooooo
04Koool206Ko2oooo`80000:oooo0P1Vo`_oool00`1Vooooooooo`1eoooo000ioooo00<0I_oooooo
ool0B?ooo`80I_l9oooo00<0003oooooool01oooo`80I_l=oooo00<0I_ooooooool0MOooo`00>Ooo
o`0306Kooooooooo04[oool00`1Vooooooooo`06oooo00<0003oooooool01Oooo`80I_l?oooo00<0
I_ooooooool0MOooo`00>Oooo`0306Kooooooooo04_oool306Ko1Oooo`030000oooooooo00?oool2
06Ko4Oooo`0306Kooooooooo07Goool003Woool00`1Vooooooooo`1>oooo0P1Vo`?oool200000_oo
o`80I_lCoooo00<0I_ooooooool0MOooo`00>Oooo`0306Kooooooooo053oool306Ko00@0003oool0
I_l0I_lEoooo00<0I_ooooooool0MOooo`00>Oooo`0306Kooooooooo05;oool00`1Vo`00001Vo`0G
oooo00<0I_ooooooool0MOooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Foooo00<0
I_ooooooool0MOooo`00>Oooo`0306Kooooooooo05?oool200005oooo`0306Kooooooooo07Goool0
03Woool00`1Vooooooooo`1Coooo00<0003oooooool05_ooo`0306Kooooooooo07Goool003Woool0
0`1Vooooooooo`0joooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`0F
oooo00<0I_ooooooool0MOooo`00>Oooo`0306Kooooooooo03Woool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool05_ooo`0306Kooooooooo
07Goool003Woool00`1Vooooooooo`0ioooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool300005oooo`0306Kooooooooo07Coool003Woool00`1Vooooooooo`0c
oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`0Goooo00<0I_ooooooool0M?ooo`00>Oooo`0306Kooooooooo03Woool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool05oooo`0306Ko
oooooooo07Coool003Woool00`1Vooooooooo`0joooo0P0000[oool200001?ooo`<00004oooo00<0
003oooooool05oooo`0306Kooooooooo07Coool003Woool00`1Vooooooooo`1Coooo0P0001Soool0
0`1Vooooooooo`1doooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo01Ooool00`1Voooo
ooooo`1doooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo01Ooool00`1Vooooooooo`1d
oooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo01Ooool00`1Vooooooooo`1doooo000I
oooo0`0001goool00`1Vooooooooo`0Hoooo100003Ooool200006?ooo`0306Kooooooooo01goool4
0000>oooo`<0000Eoooo000Joooo00<0003oooooool07?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`0hoooo00<0003oooooool05oooo`0306Kooooooooo01goool00`000?ooooooo`0moooo00<0
003oooooool05?ooo`005oooo`D0000Moooo00<0I_ooooooool06Oooo`030000oooooooo03Ooool0
0`000?ooooooo`0Goooo00<0I_ooooooool07_ooo`030000oooooooo03Woool500005Oooo`004Ooo
o`@00002oooo00@0003oooooool0000Noooo00<0I_ooooooool04_ooo`@00004oooo00<0003ooooo
ool0=_ooo`030000oooooooo01Ooool00`1Vooooooooo`0Ooooo00<0003oooooool0>?ooo`040000
oooooooo00005_ooo`006?ooo`030000oooo000001koool00`1Vooooooooo`0Hoooo00@0003ooooo
ool0000goooo0P0001Soool00`1Vooooooooo`0Moooo00@0003oooooool0000joooo00<0003oool0
00005_ooo`006Oooo`80000Noooo00<0I_ooooooool06Oooo`80000hoooo00<0003oooooool05ooo
o`0306Kooooooooo01koool20000??ooo`80000Foooo000ioooo00<0I_ooooooool0Doooo`030000
oooooooo01Ooool00`1Vooooooooo`1doooo000ioooo00<0I_ooooooool0Doooo`80000Hoooo00<0
I_ooooooool0M?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Goooo00<0I_oooooo
ool0M?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Goooo00<0I_ooooooool0M?oo
o`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Goooo00<0I_ooooooool0M?ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00Soool0
0ol0VOooooooo`02oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0
003oooooool05oooo`03o`2Ioooooooo023oool00`000?ooooooo`0Eoooo002?oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool0
0`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?oo
o`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo
03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00M_ooo`800004oooo0P00
00?oool400000oooo`800005oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool007Goool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`<0001Coooo00?o09Woooooool0>?ooo`00MOooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo05?oool00ol0VOooooooo`0h
oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo001foooo0P0000[oool200001?ooo`<00004
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo
03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Wooooo
ool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003ooooo
ool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool0
0`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?oo
o`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00O?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo001k
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0005?oool0
0ol0VOooooooo`0hoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo
03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Wooooo
ool0>?ooo`00M_ooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`1Coooo00?o09Woooooool0>?ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001C
oooo00?o09Woooooool0>?ooo`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P00
00Goool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00MOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1Coooo00?o09Wooooo
ool0>?ooo`00M_ooo`800009oooo100000?oool300001?ooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo002?oooo0P0005Coool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Dooo
o`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo0P0005Coool00ol0VOooooooo`0h
oooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo0P0005Coool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo
03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo
05?oool00ol0VOooooooo`0hoooo002?oooo0P0005Coool00ol0VOooooooo`0hoooo002?oooo00<0
003oooooool0Doooo`03o`2Ioooooooo03Soool008Ooool500000oooo`030000oooooooo05?oool0
0ol0VOooooooo`0hoooo0029oooo00<0003oooooool00oooo`030000oooooooo05?oool00ol0VOoo
ooooo`0hoooo0029oooo00<0003oooooool00oooo`<0001Coooo00?o09Woooooool0>?ooo`00ROoo
o`030000oooooooo09Coool008Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83479 .30902 L
.83996 .30902 L
.84223 .30902 L
.84335 .30902 L
.84438 .30902 L
s
.84438 .30902 m
.8445 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.15107 .30902 L
.15238 .30902 L
.1536 .30902 L
.15467 .30902 L
.15581 .15451 L
.15709 .15451 L
.15825 .15451 L
.16254 .15451 L
.18221 .15451 L
.22192 .15451 L
.26011 .15451 L
.30075 .15451 L
.33988 .15451 L
.35986 .15451 L
.37037 .15451 L
.38147 .15451 L
.38627 .15451 L
.38891 .15451 L
.39141 .15451 L
.3921 .15451 L
.39283 .15451 L
.39363 .15501 L
.39437 .15549 L
.39706 .15721 L
.40233 .16054 L
.42153 .17204 L
.45928 .19212 L
.48026 .20198 L
.48944 .20603 L
.4943 .20811 L
.49697 .20924 L
.49828 .20978 L
.49949 .21029 L
.50068 .21022 L
.50194 .20969 L
.5046 .20858 L
.50925 .2066 L
.51833 .20261 L
.53817 .19337 L
.57606 .17342 L
.59551 .16188 L
.60111 .15837 L
.60387 .15662 L
Mistroke
.60521 .15576 L
.60643 .15497 L
.60762 .30902 L
.60874 .30902 L
.6112 .30902 L
.6164 .30902 L
.655 .30902 L
.69606 .30902 L
.7356 .30902 L
.77362 .30902 L
.8141 .30902 L
.85306 .30902 L
.89447 .30902 L
.93437 .30902 L
.97275 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Sooolm06Ko1_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300006?ooo`0306Kooooooooo07?oool003Soool00`1Vooooooooo`0joooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo01Ooool206KoMOooo`00>?ooo`0306Ko
oooooooo03_oool00`1Vooooooooo`02oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo01Goool206Ko00?oool0I_ooool0M?ooo`00>?ooo`0306Kooooooooo03coool2
06Ko0oooo`80000:oooo0`0000Coool00`000?ooooooo`0Coooo0P1Vo`?oool00`1Vooooooooo`1c
oooo000hoooo00<0I_ooooooool0?_ooo`80I_lDoooo0P0001;oool206Ko1Oooo`0306Kooooooooo
07?oool003Soool00`1Vooooooooo`10oooo00<0I_ooooooool04Oooo`030000oooooooo013oool0
0`1Vooooooooo`05oooo00<0I_ooooooool0Loooo`00>?ooo`0306Kooooooooo047oool206Ko4Ooo
o`030000oooooooo00koool206Ko2?ooo`0306Kooooooooo07?oool003Soool00`1Vooooooooo`13
oooo0P1Vo`ooool00`000?ooooooo`0<oooo0P1Vo`[oool00`1Vooooooooo`1coooo000hoooo00<0
I_ooooooool0AOooo`80I_l=oooo0P0000_oool206Ko3?ooo`0306Kooooooooo07?oool003Soool0
0`1Vooooooooo`17oooo0P1Vo`_oool00`000?ooooooo`08oooo0P1Vo`koool00`1Vooooooooo`1c
oooo000hoooo00<0I_ooooooool0BOooo`<0I_l8oooo00<0003oooooool01_ooo`80I_l@oooo00<0
I_ooooooool0Loooo`00>?ooo`0306Kooooooooo04coool206Ko1_ooo`030000oooooooo00Coool2
06Ko4_ooo`0306Kooooooooo07?oool003Soool00`1Vooooooooo`1>oooo0P1Vo`Coool200000_oo
o`<0I_lDoooo00<0I_ooooooool0Loooo`00>?ooo`0306Kooooooooo053oool206Ko0_ooo`040000
oooo06Ko06Ko5oooo`0306Kooooooooo07?oool003Soool00`1Vooooooooo`1Boooo0P1Vo`030000
06Kooooo01Soool00`1Vooooooooo`1coooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo
01Soool00`1Vooooooooo`1coooo000hoooo00<0I_ooooooool0E?ooo`80000Ioooo00<0I_oooooo
ool0Loooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`0Hoooo00<0I_ooooooool0Looo
o`00>?ooo`0306Kooooooooo03_oool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo01Soool00`1Vooooooooo`1coooo000hoooo00<0I_ooooooool0>_ooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Hoooo00<0
I_ooooooool0Loooo`00=oooo`0306Kooooooooo03_oool010000?ooooooo`0000Woool00`000?oo
ooooo`05oooo00<0003oooooool00_ooo`<0000Hoooo00<0I_ooooooool0Loooo`00=oooo`0306Ko
oooooooo03Goool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo01Soool00`1Vooooooooo`1coooo000goooo00<0I_ooooooool0>oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0H
oooo00<0I_ooooooool0Loooo`00=oooo`0306Kooooooooo03coool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`00=oooo`0306Kooooooooo05Goool2
00006Oooo`0306Kooooooooo07?oool003Ooool00`1Vooooooooo`1Eoooo00<0003oooooool06?oo
o`0306Kooooooooo07?oool003Ooool00`1Vooooooooo`1Eoooo00<0003oooooool06?ooo`0306Ko
oooooooo07?oool003Ooool00`1Vooooooooo`1Eoooo00<0003oooooool06?ooo`0306Kooooooooo
07?oool001Woool300006oooo`0306Kooooooooo01[oool40000=oooo`80000Ioooo00<0I_oooooo
ool07?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0Joooo00<0I_ooooooool06_oo
o`030000oooooooo03Soool00`000?ooooooo`0Hoooo00<0I_ooooooool07?ooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0001_oool00`1Vooooooooo`0Koooo00<0003ooooo
ool0=oooo`030000oooooooo01Soool00`1Vooooooooo`0Moooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`0001coool00`1Vooooooooo`0Doooo100000Coool0
0`000?ooooooo`0foooo00<0003oooooool06?ooo`0306Kooooooooo01koool00`000?ooooooo`0h
oooo00@0003oooooool0000Foooo000Hoooo00<0003oool000007?ooo`0306Kooooooooo01[oool0
10000?ooooooo`0003Ooool200006Oooo`0306Kooooooooo01coool010000?ooooooo`0003[oool0
0`000?ooo`00000Foooo000Ioooo0P0001coool00`1Vooooooooo`0Koooo0P0003Soool00`000?oo
ooooo`0Hoooo00<0I_ooooooool07Oooo`80000loooo0P0001Koool003Ooool00`1Vooooooooo`1E
oooo00<0003oooooool06?ooo`0306Kooooooooo07?oool003Ooool00`1Vooooooooo`1Eoooo0P00
01Woool00`1Vooooooooo`1coooo000goooo00<0I_ooooooool0EOooo`030000oooooooo01Soool0
0`1Vooooooooo`1coooo000goooo00<0I_ooooooool0EOooo`030000oooooooo01Soool00`1Voooo
ooooo`1coooo000goooo00<0I_ooooooool0EOooo`030000oooooooo01Soool00`1Vooooooooo`1c
oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool02Oooo`05o`2Ioooooooooooo000000koool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000
oooooooo01Soool00ol0VOooooooo`0Ooooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Wooooo
ool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0g
oooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo05Coool00ol0VOooooooo`0goooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
05Coool00ol0VOooooooo`0goooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000E?ooo`03o`2Ioooooooo03Ooool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Doooo00?o09Woooooool0=ooo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0g
oooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo
03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo
05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Wooooo
ool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Doooo00?o
09Woooooool0=oooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool007coool200002_ooo`<00004oooo00<0003ooooo
ool0E?ooo`03o`2Ioooooooo03Ooool008ooool20000EOooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0g
oooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo
03Ooool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0E?ooo`03o`2Ioooooooo03Ooool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo05Coool00ol0VOooooooo`0goooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000E?oo
o`03o`2Ioooooooo03Ooool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0E?ooo`03o`2Ioooooooo
03Ooool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Doooo00?o09Wooooo
ool0=oooo`00Soooo`80001Eoooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`80001Eoooo00?o09Woooooool0=ooo
o`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`80001Eoooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0g
oooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Soooo`80001Eoooo00?o09Woooooool0=oooo`00Soooo`030000
oooooooo05Coool00ol0VOooooooo`0goooo0027oooo1@0000?oool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Doooo00?o09Wooooo
ool0=oooo`00ROooo`030000oooooooo00?oool30000E?ooo`03o`2Ioooooooo03Ooool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo0`0000Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83996 .30902 L
.84438 .30902 L
.84681 .30902 L
.84911 .30902 L
.85042 .30902 L
.85115 .30902 L
s
.85115 .30902 m
.85122 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14635 .30902 L
.14756 .30902 L
.14868 .30902 L
.1499 .15451 L
.15055 .15451 L
.15124 .15451 L
.1536 .15451 L
.16254 .15451 L
.18221 .15451 L
.22343 .15451 L
.26314 .15451 L
.30133 .15451 L
.34198 .15451 L
.36078 .15451 L
.37066 .15451 L
.38111 .15451 L
.38367 .15451 L
.38509 .15451 L
.38578 .15451 L
.38643 .15451 L
.38718 .15469 L
.388 .15522 L
.38944 .15615 L
.39226 .15795 L
.40252 .16432 L
.42269 .17607 L
.46196 .19628 L
.48165 .20523 L
.49028 .20892 L
.49516 .21096 L
.4975 .21192 L
.49865 .21238 L
.49971 .21281 L
.50085 .21259 L
.5021 .21208 L
.50426 .21119 L
.50913 .20917 L
.51906 .20492 L
.53991 .1954 L
.56027 .18525 L
.57931 .17495 L
.59758 .16426 L
.60284 .16102 L
.60783 .15789 L
Mistroke
.61 .1565 L
.61119 .15574 L
.61232 .15501 L
.61295 .1546 L
.61365 .30902 L
.61485 .30902 L
.6172 .30902 L
.65826 .30902 L
.6978 .30902 L
.73582 .30902 L
.7763 .30902 L
.81526 .30902 L
.85667 .30902 L
.89657 .30902 L
.93495 .30902 L
.97578 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Koooln06Ko1oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300006Oooo`80I_mcoooo000foooo00<0I_ooooooool0>_ooo`80I_l400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool06?ooo`<0I_mcoooo000foooo00<0I_oooooo
ool0??ooo`0306Kooooooooo00?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool05oooo`0406Kooooooooo06KoLoooo`00=_ooo`0306Kooooooooo03goool00`1Voooo
ooooo`03oooo0P0000[oool300001?ooo`030000oooooooo01Goool206Ko0oooo`0306Kooooooooo
077oool003Koool00`1Vooooooooo`0noooo0P1VoaKoool200005?ooo`80I_l5oooo00<0I_oooooo
ool0LOooo`00=_ooo`0306Kooooooooo043oool206Ko5?ooo`030000oooooooo017oool206Ko1ooo
o`0306Kooooooooo077oool003Koool00`1Vooooooooo`12oooo00<0I_ooooooool04Oooo`030000
oooooooo00ooool206Ko2Oooo`0306Kooooooooo077oool003Koool00`1Vooooooooo`13oooo0P1V
oa7oool00`000?ooooooo`0=oooo0P1Vo`_oool00`1Vooooooooo`1aoooo000foooo00<0I_oooooo
ool0AOooo`80I_l?oooo0P0000goool00`1Vooooooooo`0;oooo00<0I_ooooooool0LOooo`00=_oo
o`0306Kooooooooo04Ooool206Ko3Oooo`030000oooooooo00[oool206Ko3_ooo`0306Kooooooooo
077oool003Koool00`1Vooooooooo`19oooo0P1Vo`_oool00`000?ooooooo`08oooo0P1Voa3oool0
0`1Vooooooooo`1aoooo000foooo00<0I_ooooooool0Boooo`<0I_l8oooo00<0003oooooool01_oo
o`80I_lBoooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo04koool206Ko1_ooo`800005
oooo0P1VoaCoool00`1Vooooooooo`1aoooo000foooo00<0I_ooooooool0D?ooo`<0I_l3oooo00@0
003oooooooooool306Ko5_ooo`0306Kooooooooo077oool003Koool00`1Vooooooooo`1Coooo0P1V
o`03oooo0000oooo0080I_lIoooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo05Goool0
0`1Vo`00001Vo`0Koooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo05Koool200006ooo
o`0306Kooooooooo077oool003Koool00`1Vooooooooo`1Foooo00<0003oooooool06_ooo`0306Ko
oooooooo077oool003Koool00`1Vooooooooo`0moooo0P0000Coool200000oooo`@00003oooo0P00
00Goool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo03coool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003ooooo
ool06_ooo`0306Kooooooooo077oool003Koool00`1Vooooooooo`0loooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool300006_ooo`0306Kooooooooo077oool0
03Koool00`1Vooooooooo`0foooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000Goool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo
03coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool06_ooo`0306Kooooooooo077oool003Koool00`1Vooooooooo`0moooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool06_ooo`0306Kooooooooo077oool003Koool00`1Voooo
ooooo`1Foooo0P0001_oool00`1Vooooooooo`1aoooo000foooo00<0I_ooooooool0E_ooo`030000
oooooooo01[oool00`1Vooooooooo`1aoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo
01[oool00`1Vooooooooo`1aoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool0
0`1Vooooooooo`1aoooo000Ioooo0`0001[oool00`1Vooooooooo`0Koooo100003Ooool200006ooo
o`0306Kooooooooo01[oool40000>oooo`<0000Eoooo000Joooo00<0003oooooool06Oooo`0306Ko
oooooooo01_oool00`000?ooooooo`0hoooo00<0003oooooool06_ooo`0306Kooooooooo01[oool0
0`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000Joooo00<0I_ooooooool07?oo
o`030000oooooooo03Ooool00`000?ooooooo`0Joooo00<0I_ooooooool06oooo`030000oooooooo
03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000Koooo00<0I_ooooooool05Ooo
o`@00004oooo00<0003oooooool0=_ooo`030000oooooooo01[oool00`1Vooooooooo`0Loooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000001_oool00`1Voooo
ooooo`0Koooo00@0003oooooool0000goooo0P0001_oool00`1Vooooooooo`0Joooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000Koooo00<0I_ooooooool07?ooo`80000h
oooo00<0003oooooool06_ooo`0306Kooooooooo01_oool20000??ooo`80000Foooo000foooo00<0
I_ooooooool0E_ooo`030000oooooooo01[oool00`1Vooooooooo`1aoooo000foooo00<0I_oooooo
ool0E_ooo`80000Koooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo05Koool00`000?oo
ooooo`0Joooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`0J
oooo00<0I_ooooooool0LOooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`0Joooo00<0
I_ooooooool0LOooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00_oool00ol0VOooo`00000>oooo00<0003oooooool03?ooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000oooooooo03Woool0
0`000?ooooooo`0Joooo00?o09Woooooool07Oooo`030000oooooooo01Goool008ooool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001G
oooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo001foooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00MOoo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00MOooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0`0005Koool00ol0VOooooooo`0eoooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0E_ooo`03o`2Ioooooooo
03Goool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool007Koool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Ooo
o`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001G
oooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
07_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool30000E_oo
o`03o`2Ioooooooo03Goool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo001loooo0P0000[oool300001?ooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo0P0005Ooool00ol0VOooooooo`0eoooo002?
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Ooo
o`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool200001Oooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo001eoooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1Foooo00?o09Woooooool0=Ooo
o`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo0`00
05Koool00ol0VOooooooo`0eoooo001eoooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001Oooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo001eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo001foooo0P0000Woool400000oooo`<00004oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1F
oooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo
03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Qoooo`D00003oooo00<0003oooooool0E_oo
o`03o`2Ioooooooo03Goool008Woool00`000?ooooooo`03oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008Woool00`000?ooooooo`03oooo0`0005Koool00ol0VOooooooo`0eoooo0029
oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`000?ooooooo`08oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83996 .30902 L
.84911 .30902 L
.85162 .30902 L
.85431 .30902 L
.85561 .30902 L
.85685 .30902 L
s
.85685 .30902 m
.85696 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13506 .30902 L
.13942 .30902 L
.14061 .30902 L
.14188 .30902 L
.14296 .15451 L
.14415 .15451 L
.18444 .15451 L
.22321 .15451 L
.26444 .15451 L
.30414 .15451 L
.34234 .15451 L
.36201 .15451 L
.36767 .15451 L
.37301 .15451 L
.3778 .15451 L
.37911 .15451 L
.37983 .15451 L
.3805 .15451 L
.38168 .15498 L
.38298 .15582 L
.42189 .17892 L
.46325 .19966 L
.47329 .20418 L
.48395 .20877 L
.49305 .21253 L
.49554 .21353 L
.49685 .21406 L
.49823 .2146 L
.49944 .21508 L
.50013 .21525 L
.50077 .215 L
.5031 .21408 L
.54143 .19749 L
.58047 .17762 L
.59071 .17184 L
.60182 .16529 L
.60691 .16219 L
.6123 .15882 L
.61452 .15742 L
.61691 .15589 L
.61761 .15544 L
.61827 .15501 L
.61952 .30902 L
Mistroke
.62069 .30902 L
.62197 .30902 L
.66267 .30902 L
.70185 .30902 L
.74348 .30902 L
.7836 .30902 L
.82221 .30902 L
.86326 .30902 L
.9028 .30902 L
.94082 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003Coooln06Ko2Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300006oooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`0joooo00@0I_oooooo
ooooool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool06Oooo`<0I_mb
oooo000doooo00<0I_ooooooool0>oooo`80I_l7oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo01Soool0101Vooooooooo`1Vog;oool003Coool00`1Vooooooooo`0m
oooo0P1Vo`Koool200002_ooo`<00004oooo00<0003oooooool05oooo`0506Kooooooooooooo06Ko
07;oool003Coool00`1Vooooooooo`0ooooo0P1VoaOoool200005_ooo`80I_l4oooo00<0I_oooooo
ool0L?ooo`00=?ooo`0306Kooooooooo047oool206Ko5Oooo`030000oooooooo01?oool206Ko1_oo
o`0306Kooooooooo073oool003Coool00`1Vooooooooo`13oooo0P1Voa?oool00`000?ooooooo`0A
oooo0P1Vo`Soool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0AOooo`80I_lAoooo00<0
003oooooool03oooo`80I_l:oooo00<0I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo04Ooool2
06Ko3oooo`80000>oooo0P1Vo`coool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0BOoo
o`80I_l=oooo00<0003oooooool02oooo`80I_l>oooo00<0I_ooooooool0L?ooo`00=?ooo`0306Ko
oooooooo04_oool206Ko2oooo`030000oooooooo00Woool206Ko4?ooo`0306Kooooooooo073oool0
03Coool00`1Vooooooooo`1=oooo0P1Vo`Woool00`000?ooooooo`06oooo0`1Voa;oool00`1Voooo
ooooo`1`oooo000doooo00<0I_ooooooool0Coooo`0306Kooooooooo00Koool200001Oooo`80I_lE
oooo00<0I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo053oool306Ko1Oooo`030000oooooooo
00;oool206Ko5oooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`1Coooo0P1Vo`?oool0
0`000?ooooooo`0206Ko6Oooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`1Eoooo0`1V
o`03000006Ko06Ko01_oool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0F?ooo`80000L
oooo00<0I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`0Koooo00<0
I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo03ooool200001?ooo`800003oooo100000?oool2
00001Oooo`030000oooooooo01_oool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0?_oo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`0Koooo00<0I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo03koool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Koooo00<0I_ooooooool0L?oo
o`00=?ooo`0306Kooooooooo03Soool400000_ooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo01_oool00`1Vooooooooo`1`oooo000doooo00<0I_oooooo
ool0?_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00=?ooo`0306Kooooooooo03ooool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00=?ooo`0306Ko
oooooooo05Soool200007?ooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`1Hoooo00<0
003oooooool06oooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`1Hoooo00<0003ooooo
ool06oooo`0306Kooooooooo073oool003Coool00`1Vooooooooo`1Hoooo00<0003oooooool06ooo
o`0306Kooooooooo073oool001Woool300006?ooo`0306Kooooooooo01goool40000=oooo`80000L
oooo00<0I_ooooooool06Oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0Goooo00<0
I_ooooooool07Oooo`030000oooooooo03Soool00`000?ooooooo`0Koooo00<0I_ooooooool06Ooo
o`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0001Soool00`1Vooooooooo`0N
oooo00<0003oooooool0=oooo`030000oooooooo01_oool00`1Vooooooooo`0Joooo00<0003ooooo
ool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0001Woool00`1Vooooooooo`0G
oooo100000Coool00`000?ooooooo`0foooo00<0003oooooool06oooo`0306Kooooooooo01_oool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000006Oooo`0306Ko
oooooooo01goool010000?ooooooo`0003Ooool200007?ooo`0306Kooooooooo01Woool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0001Woool00`1Vooooooooo`0Noooo0P00
03Soool00`000?ooooooo`0Koooo00<0I_ooooooool06_ooo`80000loooo0P0001Koool003Coool0
0`1Vooooooooo`1Hoooo00<0003oooooool06oooo`0306Kooooooooo073oool003Coool00`1Voooo
ooooo`1Hoooo0P0001coool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0F?ooo`030000
oooooooo01_oool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo
01_oool00`1Vooooooooo`1`oooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool0
0`1Vooooooooo`1`oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`03o`2I0000oooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Ooo
o`030000oooooooo01_oool00ol0VOooooooo`0Loooo00<0003oooooool05Oooo`00Soooo`030000
oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P00
05Soool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
08ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool0
0ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool007Koool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo001e
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000
oooooooo05Ooool00ol0VOooooooo`0doooo001eoooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool30000Eoooo`03o`2Ioooooooo03Coool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Goooo00?o09Wooooo
ool0=?ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00M_ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0d
oooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000
oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P00
05Soool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
07coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo05Ooool0
0ol0VOooooooo`0doooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001G
oooo00?o09Woooooool0=?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool007coool200002_ooo`<00004oooo00<0
003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool20000F?ooo`03o`2Ioooooooo03Coool0
08ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool0
0ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0d
oooo002?oooo0P0005Soool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0Eoooo`03o`2Ioooooooo03Coool007Goool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo05Ooool00ol0VOooooooo`0d
oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool3
0000Eoooo`03o`2Ioooooooo03Coool007Goool010000?ooooooo`0000_oool010000?oooooooooo
o`800005oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo
05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool0
08ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Wooooo
ool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003ooooo
ool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?oo
o`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Sooo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo0027oooo1@0000?oool00`000?ooooooo`1G
oooo00?o09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool30000Eoooo`03o`2Ioooooooo03Coool0
08Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_oo
o`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo00<0003ooooo
ool0O_ooo`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo00[oool00`000?ooooooo`1noooo001moooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool0OOooo`00O_ooo`030000
oooooooo00D0000>oooo00<0003oooooool02?ooo`030000oooooooo07koool007koool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool0O_ooo`00Ooooo`030000
oooooooo017oool200002Oooo`030000oooooooo07ooool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85396 .30902 L
.85663 .30902 L
.85916 .30902 L
.86159 .30902 L
.86226 .30902 L
.86296 .30902 L
s
.86296 .30902 m
.86309 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13273 .30902 L
.13384 .30902 L
.13506 .30902 L
.13615 .30902 L
.13718 .15451 L
.13826 .15451 L
.13942 .15451 L
.14415 .15451 L
.18538 .15451 L
.22508 .15451 L
.26328 .15451 L
.30392 .15451 L
.34305 .15451 L
.35334 .15451 L
.36446 .15451 L
.36957 .15451 L
.37236 .15451 L
.37373 .15451 L
.37497 .15451 L
.37611 .15523 L
.37719 .15593 L
.37958 .15745 L
.38463 .16064 L
.42296 .1827 L
.46375 .20258 L
.47349 .20685 L
.484 .21126 L
.48883 .21323 L
.49392 .21525 L
.49602 .21608 L
.49826 .21695 L
.49955 .21744 L
.50072 .21734 L
.5019 .21688 L
.50301 .21645 L
.54076 .20055 L
.57923 .18153 L
.59872 .17066 L
.60905 .16452 L
.61474 .16102 L
.61755 .15927 L
.62015 .15762 L
.62261 .15605 L
Mistroke
.62332 .15559 L
.62399 .15516 L
.62524 .30902 L
.62591 .30902 L
.62663 .30902 L
.62791 .30902 L
.63079 .30902 L
.64051 .30902 L
.65955 .30902 L
.69758 .30902 L
.73805 .30902 L
.77701 .30902 L
.81843 .30902 L
.85832 .30902 L
.89671 .30902 L
.93754 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool003?oooln06Ko2_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300007?ooo`0306Kooooooooo06ooool003?oool00`1Vooooooooo`0joooo00<0I_oooooo
ool00_ooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Koooo0P1V
og7oool003?oool00`1Vooooooooo`0koooo0P1Vo`Soool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool06_ooo`0306Kooooo06Ko077oool003?oool00`1Vooooooooo`0m
oooo0P1Vo`Ooool200002_ooo`<00004oooo00<0003oooooool06?ooo`80I_l2oooo00<0I_oooooo
ool0Koooo`00<oooo`0306Kooooooooo03ooool206Ko6?ooo`80000Goooo0P1Vo`Coool00`1Voooo
ooooo`1_oooo000coooo00<0I_ooooooool0@Oooo`80I_lFoooo00<0003oooooool05?ooo`80I_l6
oooo00<0I_ooooooool0Koooo`00<oooo`0306Kooooooooo04?oool206Ko5?ooo`030000oooooooo
01;oool206Ko2?ooo`0306Kooooooooo06ooool003?oool00`1Vooooooooo`15oooo0P1Voa;oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool02?ooo`0306Kooooooooo06ooool003?oool00`1Voooo
ooooo`17oooo0P1Voa3oool200004?ooo`80I_l;oooo00<0I_ooooooool0Koooo`00<oooo`0306Ko
oooooooo04Woool206Ko3_ooo`030000oooooooo00goool206Ko3Oooo`0306Kooooooooo06ooool0
03?oool00`1Vooooooooo`1;oooo0P1Vo`coool00`000?ooooooo`0;oooo0P1Vo`ooool00`1Voooo
ooooo`1_oooo000coooo00<0I_ooooooool0COooo`80I_l:oooo00<0003oooooool02Oooo`80I_lA
oooo00<0I_ooooooool0Koooo`00<oooo`0306Kooooooooo04ooool206Ko2?ooo`800007oooo0`1V
oa?oool00`1Vooooooooo`1_oooo000coooo00<0I_ooooooool0DOooo`0306Kooooooooo00Goool0
0`000?ooooooo`04oooo0P1VoaKoool00`1Vooooooooo`1_oooo000coooo00<0I_ooooooool0D_oo
o`80I_l5oooo00<0003oooooool00_ooo`80I_lHoooo00<0I_ooooooool0Koooo`00<oooo`0306Ko
oooooooo05Coool306Ko0_ooo`030000oooooooo0080I_lJoooo00<0I_ooooooool0Koooo`00<ooo
o`0306Kooooooooo05Ooool206Ko0P00000306Kooooooooo01[oool00`1Vooooooooo`1_oooo000c
oooo00<0I_ooooooool0FOooo`030000oooooooo01coool00`1Vooooooooo`1_oooo000coooo00<0
I_ooooooool0@?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool07?oo
o`0306Kooooooooo06ooool003?oool00`1Vooooooooo`0ooooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo01coool00`1Vooooooooo`1_
oooo000coooo00<0I_ooooooool0?oooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`0001goool00`1Vooooooooo`1^oooo000coooo00<0I_ooooooool0>Ooo
o`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool07Oooo`0306Kooooooooo06koool003?oool00`1Vooooooooo`0ooooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo01goool00`1Voooo
ooooo`1^oooo000coooo00<0I_ooooooool0@?ooo`80000:oooo0P0000Coool300001?ooo`030000
oooooooo01goool00`1Vooooooooo`1^oooo000coooo00<0I_ooooooool0FOooo`80000Noooo00<0
I_ooooooool0K_ooo`00<oooo`0306Kooooooooo05Woool00`000?ooooooo`0Moooo00<0I_oooooo
ool0K_ooo`00<oooo`0306Kooooooooo05Woool00`000?ooooooo`0Moooo00<0I_ooooooool0K_oo
o`00<oooo`0306Kooooooooo05Woool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`006Ooo
o`<0000Goooo00<0I_ooooooool07_ooo`@0000goooo0P0001koool00`1Vooooooooo`0Goooo1000
03_oool300005Oooo`006_ooo`030000oooooooo01Koool00`1Vooooooooo`0Noooo00<0003ooooo
ool0>?ooo`030000oooooooo01goool00`1Vooooooooo`0Goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool500005oooo`0306Kooooooooo01ooool00`000?ooooooo`0goooo00<0
003oooooool07Oooo`0306Kooooooooo01Soool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo00006?ooo`0306Kooooooooo01Soool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0Moooo00<0I_ooooooool06Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000Hoooo00<0I_ooooooool07_ooo`040000oooooooo
0000=oooo`80000Noooo00<0I_ooooooool05oooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool200006?ooo`0306Kooooooooo01ooool20000>?ooo`030000oooooooo01goool0
0`1Vooooooooo`0Hoooo0P0003coool200005_ooo`00<oooo`0306Kooooooooo05Woool00`000?oo
ooooo`0Moooo00<0I_ooooooool0K_ooo`00<oooo`0306Kooooooooo05Woool200007_ooo`0306Ko
oooooooo06koool003?oool00`1Vooooooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo
06koool003?oool00`1Vooooooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo06koool0
03?oool00`1Vooooooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo06koool0013ooooo
00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003o09Woool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool0>_ooo`030000oooooooo03Woool00`000?ooooooo`0ioooo00<0003oooooool07Oooo`03o`2I
oooooooo01[oool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo
03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0
003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool2
0000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOoo
o`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool007Goool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0FOooo`03o`2Ioooooooo
03;oool007Goool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<0001Ioooo00?o09Woooooool0<_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo
00;oool200001Oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo001eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0FOoo
o`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0b
oooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2I
oooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000
oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo
03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0
003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo001koooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool007_oool0
10000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0005Woool00ol0VOooooooo`0boooo001k
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Ioooo00?o09Wooooo
ool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool2
0000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOoo
o`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0b
oooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool20000F_ooo`03o`2I
oooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00M_ooo`800004
oooo0P0000Goool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Ioooo00?o09Wooooo
ool0<_ooo`00MOooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`<0001Ioooo00?o09Woooooool0<_oo
o`00MOooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1I
oooo00?o09Woooooool0<_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00M_ooo`800009
oooo100000?oool300001?ooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo0P00
05[oool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo002?oooo0P0005[oool00ol0VOooooooo`0boooo002?oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo0P0005[oool00ol0VOoo
ooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0b
oooo002?oooo0P0005[oool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2I
oooooooo03;oool008Ooool500000oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo0029
oooo00<0003oooooool00oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo0029oooo00<0
003oooooool00oooo`<0001Ioooo00?o09Woooooool0<_ooo`00ROooo`030000oooooooo09Coool0
08Woool00`000?ooooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`@00003oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00Woool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08
oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85916 .30902 L
.86384 .30902 L
.86642 .30902 L
.86768 .30902 L
.86886 .30902 L
s
.86886 .30902 m
.86897 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.11992 .30902 L
.12507 .30902 L
.12739 .30902 L
.12867 .30902 L
.12986 .30902 L
.13115 .15451 L
.13183 .15451 L
.13256 .15451 L
.13506 .15451 L
.14415 .15451 L
.18538 .15451 L
.22508 .15451 L
.26328 .15451 L
.30392 .15451 L
.34305 .15451 L
.35334 .15451 L
.35875 .15451 L
.3617 .15451 L
.36446 .15451 L
.36688 .15451 L
.36758 .15451 L
.36824 .15451 L
.36947 .15478 L
.37014 .15521 L
.37084 .15567 L
.37211 .15648 L
.37497 .1583 L
.38463 .1643 L
.42239 .18552 L
.46259 .20471 L
.48107 .21249 L
.49154 .21665 L
.49416 .21766 L
.49664 .21861 L
.49886 .21945 L
.50012 .21983 L
.50128 .21939 L
.51097 .21567 L
.52132 .21152 L
.54242 .20249 L
.58182 .18332 L
.60162 .17242 L
.61971 .16164 L
.62448 .15865 L
.627 .15705 L
Mistroke
.62838 .15617 L
.62968 .15533 L
.63092 .15453 L
.63162 .30902 L
.63226 .30902 L
.6346 .30902 L
.63915 .30902 L
.66005 .30902 L
.69959 .30902 L
.73761 .30902 L
.77809 .30902 L
.81705 .30902 L
.85846 .30902 L
.89836 .30902 L
.93674 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0037oooln06Ko3?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300007_ooo`0306Kooooooooo06goool0037oool00`1Vooooooooo`0joooo0P1Vo`Goool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool07Oooo`80I_m_oooo000a
oooo00<0I_ooooooool0??ooo`80I_l9oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo01_oool206Ko00?oool0I_ooool0K_ooo`00<Oooo`0306Kooooooooo03koool0
0`1Vooooooooo`07oooo0P0000[oool300001?ooo`030000oooooooo01[oool01@1Voooooooooooo
o`1Vo`1_oooo000aoooo00<0I_ooooooool0?oooo`80I_lJoooo0P0001Woool206Ko1?ooo`0306Ko
oooooooo06goool0037oool00`1Vooooooooo`11oooo0P1VoaSoool00`000?ooooooo`0Goooo00<0
I_ooooooool01?ooo`0306Kooooooooo06goool0037oool00`1Vooooooooo`13oooo0P1VoaKoool0
0`000?ooooooo`0Eoooo0P1Vo`Ooool00`1Vooooooooo`1]oooo000aoooo00<0I_ooooooool0AOoo
o`80I_lDoooo00<0003oooooool04oooo`80I_l9oooo00<0I_ooooooool0KOooo`00<Oooo`0306Ko
oooooooo04Ooool00`1Vooooooooo`0Aoooo0P0001;oool206Ko2oooo`0306Kooooooooo06goool0
037oool00`1Vooooooooo`18oooo0P1Voa7oool00`000?ooooooo`0?oooo0P1Vo`goool00`1Voooo
ooooo`1]oooo000aoooo00<0I_ooooooool0B_ooo`80I_l?oooo00<0003oooooool03?ooo`<0I_l?
oooo00<0I_ooooooool0KOooo`00<Oooo`0306Kooooooooo04coool206Ko3Oooo`030000oooooooo
00[oool206Ko4_ooo`0306Kooooooooo06goool0037oool00`1Vooooooooo`1>oooo0P1Vo`_oool2
00002Oooo`80I_lDoooo00<0I_ooooooool0KOooo`00<Oooo`0306Kooooooooo053oool306Ko2?oo
o`030000oooooooo00Koool206Ko5_ooo`0306Kooooooooo06goool0037oool00`1Vooooooooo`1C
oooo0P1Vo`Koool00`000?ooooooo`04oooo0P1VoaSoool00`1Vooooooooo`1]oooo000aoooo00<0
I_ooooooool0EOooo`<0I_l3oooo00<0003oooooool00_ooo`80I_lJoooo00<0I_ooooooool0KOoo
o`00<Oooo`0306Kooooooooo05Soool306Ko0P0000<0I_lLoooo00<0I_ooooooool0KOooo`00<Ooo
o`0306Kooooooooo05_oool00`00001Vooooo`0Noooo00<0I_ooooooool0KOooo`00<Oooo`0306Ko
oooooooo04;oool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo01koool0
0`1Vooooooooo`1]oooo000aoooo00<0I_ooooooool0@Oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Noooo00<0I_ooooooool0KOoo
o`00<Oooo`0306Kooooooooo047oool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`<0000Noooo00<0I_ooooooool0KOooo`00<Oooo`0306Kooooooooo03_oool4
00000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo
01koool00`1Vooooooooo`1]oooo000aoooo00<0I_ooooooool0@Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Noooo00<0I_oooooo
ool0KOooo`00<Oooo`0306Kooooooooo04;oool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`0Noooo00<0I_ooooooool0KOooo`00<Oooo`0306Kooooooooo05_oool200007oooo`0306Ko
oooooooo06goool0037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo
06goool0037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo06goool0
037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo06goool001Woool3
00005Oooo`0306Kooooooooo023oool40000=oooo`80000Ooooo00<0I_ooooooool05_ooo`@0000k
oooo0`0001Goool001[oool00`000?ooooooo`0Doooo00<0I_ooooooool08?ooo`030000oooooooo
03Soool00`000?ooooooo`0Noooo00<0I_ooooooool05_ooo`030000oooooooo03goool00`000?oo
ooooo`0Doooo000Goooo1@0001Goool00`1Vooooooooo`0Qoooo00<0003oooooool0=oooo`030000
oooooooo01koool00`1Vooooooooo`0Goooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo1000
00;oool010000?ooooooo`0001Koool00`1Vooooooooo`0Joooo100000Coool00`000?ooooooo`0f
oooo00<0003oooooool07_ooo`0306Kooooooooo01Soool00`000?ooooooo`0hoooo00@0003ooooo
ool0000Foooo000Hoooo00<0003oool000005_ooo`0306Kooooooooo023oool010000?ooooooo`00
03Ooool200007oooo`0306Kooooooooo01Koool010000?ooooooo`0003[oool00`000?ooo`00000F
oooo000Ioooo0P0001Koool00`1Vooooooooo`0Qoooo0P0003Soool00`000?ooooooo`0Noooo00<0
I_ooooooool05oooo`80000loooo0P0001Koool0037oool00`1Vooooooooo`1Koooo00<0003ooooo
ool07_ooo`0306Kooooooooo06goool0037oool00`1Vooooooooo`1Koooo0P0001ooool00`1Voooo
ooooo`1]oooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`1]
oooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`1]oooo000a
oooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`1]oooo000@ooooo`00
017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000
ooooo`2I00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000oooooooo01koool00ol0VOoo
ooooo`0Ioooo00<0003oooooool05Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0a
oooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2I
oooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000
oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?
oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o
09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo0P00
05_oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool0
08ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool0
0ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?oooo00<0003ooooo
ool0F_ooo`03o`2Ioooooooo037oool007Koool200001?ooo`800003oooo100000?oool200001Ooo
o`030000oooooooo05[oool00ol0VOooooooo`0aoooo001eoooo00@0003oooooool00008oooo00<0
003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo05[oool00ol0VOooooooo`0a
oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool3
0000F_ooo`03o`2Ioooooooo037oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo0P0000Goool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00MOooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1Joooo00?o
09Woooooool0<Oooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo05[oool0
0ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?oooo00<0003ooooo
ool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Ooo
o`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOoo
ooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?oo
ooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0a
oooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2I
oooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000
oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?
oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool007coool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Noooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo001koooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<0001Koooo00?o09Woooooool0<?ooo`00Nooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0Foooo`03o`2I
oooooooo033oool007coool200002_ooo`<00004oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool008ooool20000G?ooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o
09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P00
05coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
08ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool0
0ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003ooooo
ool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?oo
o`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOoo
ooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool007Koool200001?oo
o`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo001eoooo00@0003oooooool0000:
oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000Foooo`03o`2Ioooooooo033oool0
07Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool007Koool200002Ooo
o`@00003oooo0`0000Coool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`80001L
oooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o
09Woooooool0<?ooo`00Soooo`80001Loooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
08ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`80001Loooo00?o09Wooooo
ool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo00<0003ooooo
ool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?oo
o`00Soooo`80001Loooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOoo
ooooo`0`oooo0027oooo1@0000?oool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00ROooo`030000
oooooooo00?oool30000Foooo`03o`2Ioooooooo033oool008Woool00`000?ooooooo`2Doooo0029
oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool400000oooo`800003oooo1@0000;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003ooooo
ool02oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool00oooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85916 .30902 L
.86384 .30902 L
.86886 .30902 L
.87129 .30902 L
.87248 .30902 L
.87359 .30902 L
.87459 .30902 L
s
.87459 .30902 m
.8747 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.11531 .30902 L
.11999 .30902 L
.12127 .30902 L
.12263 .30902 L
.12379 .30902 L
.12507 .15451 L
.12634 .15451 L
.12755 .15451 L
.12981 .15451 L
.13492 .15451 L
.14415 .15451 L
.18234 .15451 L
.22299 .15451 L
.26212 .15451 L
.3037 .15451 L
.32457 .15451 L
.34377 .15451 L
.35346 .15451 L
.3582 .15451 L
.36027 .15451 L
.36136 .15451 L
.36251 .15451 L
.36373 .15492 L
.36485 .15565 L
.36707 .15707 L
.37196 .16015 L
.38232 .16649 L
.42007 .18739 L
.46027 .20629 L
.47875 .21396 L
.48922 .21805 L
.49432 .21998 L
.49674 .22087 L
.49896 .22169 L
.50012 .22203 L
.50135 .22158 L
.50394 .22062 L
.50865 .21886 L
.519 .21485 L
.5401 .20613 L
.57799 .18838 L
.59907 .17721 L
.61833 .16611 L
.62786 .16027 L
Mistroke
.63047 .15863 L
.63325 .15686 L
.6346 .156 L
.63587 .15518 L
.63701 .30902 L
.63824 .30902 L
.65715 .30902 L
.69821 .30902 L
.73775 .30902 L
.77577 .30902 L
.81625 .30902 L
.85521 .30902 L
.89662 .30902 L
.93652 .30902 L
.9749 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0033ooolm06Ko3_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300007oooo`0306Kooooooooo06coool0033oool00`1Vooooooooo`0joooo00<0I_oooooo
ool01Oooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Noooo0P1V
ofkoool0033oool00`1Vooooooooo`0koooo0P1Vo`_oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool07Oooo`0306Kooooo06Ko06koool0033oool00`1Vooooooooo`0m
oooo0P1Vo`[oool200002_ooo`<00004oooo00<0003oooooool06oooo`80I_l2oooo00<0I_oooooo
ool0K?ooo`00<?ooo`0306Kooooooooo03ooool206Ko6oooo`80000Joooo0P1Vo`Coool00`1Voooo
ooooo`1/oooo000`oooo00<0I_ooooooool0@Oooo`80I_lIoooo00<0003oooooool05oooo`80I_l6
oooo00<0I_ooooooool0K?ooo`00<?ooo`0306Kooooooooo04?oool00`1Vooooooooo`0Foooo00<0
003oooooool05_ooo`0306Kooooooooo00Koool00`1Vooooooooo`1/oooo000`oooo00<0I_oooooo
ool0A?ooo`80I_lFoooo00<0003oooooool05?ooo`80I_l9oooo00<0I_ooooooool0K?ooo`00<?oo
o`0306Kooooooooo04Koool206Ko5?ooo`80000Coooo0P1Vo`_oool00`1Vooooooooo`1/oooo000`
oooo00<0I_ooooooool0B?ooo`80I_lBoooo00<0003oooooool04?ooo`80I_l=oooo00<0I_oooooo
ool0K?ooo`00<?ooo`0306Kooooooooo04[oool206Ko4?ooo`030000oooooooo00koool206Ko3ooo
o`0306Kooooooooo06coool0033oool00`1Vooooooooo`1<oooo0`1Vo`goool00`000?ooooooo`0;
oooo0`1Voa7oool00`1Vooooooooo`1/oooo000`oooo00<0I_ooooooool0Coooo`80I_l;oooo0P00
00[oool206Ko5?ooo`0306Kooooooooo06coool0033oool00`1Vooooooooo`1Aoooo0`1Vo`Soool0
0`000?ooooooo`07oooo0P1VoaKoool00`1Vooooooooo`1/oooo000`oooo00<0I_ooooooool0E?oo
o`80I_l6oooo00<0003oooooool01Oooo`80I_lHoooo00<0I_ooooooool0K?ooo`00<?ooo`0306Ko
oooooooo05Koool206Ko1?ooo`030000oooooooo00?oool206Ko6_ooo`0306Kooooooooo06coool0
033oool00`1Vooooooooo`1Hoooo0P1Vo`;oool200000_ooo`80I_lLoooo00<0I_ooooooool0K?oo
o`00<?ooo`0306Kooooooooo05[oool206Ko00@00000I_l0I_l0I_lNoooo00<0I_ooooooool0K?oo
o`00<?ooo`0306Kooooooooo04?oool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo01ooool00`1Vooooooooo`1/oooo000`oooo00<0I_ooooooool0@_ooo`040000oooooooo
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0Ooooo00<0
I_ooooooool0K?ooo`00<?ooo`0306Kooooooooo04;oool010000?ooooooo`0000Woool00`000?oo
ooooo`05oooo00<0003oooooool00_ooo`<0000Poooo00<0I_ooooooool0Joooo`00<?ooo`0306Ko
oooooooo03coool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo023oool00`1Vooooooooo`1[oooo000`oooo00<0I_ooooooool0@_ooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0P
oooo00<0I_ooooooool0Joooo`00<?ooo`0306Kooooooooo04?oool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0Poooo00<0I_ooooooool0Joooo`00<?ooo`0306Kooooooooo05coool2
00008Oooo`0306Kooooooooo06_oool0033oool00`1Vooooooooo`1Loooo00<0003oooooool08?oo
o`0306Kooooooooo06_oool0033oool00`1Vooooooooo`1Loooo00<0003oooooool08?ooo`0306Ko
oooooooo06_oool0033oool00`1Vooooooooo`1Loooo00<0003oooooool08?ooo`0306Kooooooooo
06_oool001Woool300005?ooo`0306Kooooooooo027oool40000=oooo`80000Qoooo00<0I_oooooo
ool05?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0Coooo00<0I_ooooooool08Ooo
o`030000oooooooo03Soool00`000?ooooooo`0Poooo00<0I_ooooooool05?ooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0001Coool00`1Vooooooooo`0Roooo00<0003ooooo
ool0=oooo`030000oooooooo023oool00`1Vooooooooo`0Eoooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`0001Goool00`1Vooooooooo`0Koooo100000Coool0
0`000?ooooooo`0foooo00<0003oooooool08?ooo`0306Kooooooooo01Koool00`000?ooooooo`0h
oooo00@0003oooooool0000Foooo000Hoooo00<0003oool000005Oooo`0306Kooooooooo027oool0
10000?ooooooo`0003Ooool200008Oooo`0306Kooooooooo01Coool010000?ooooooo`0003[oool0
0`000?ooo`00000Foooo000Ioooo0P0001Goool00`1Vooooooooo`0Roooo0P0003Soool00`000?oo
ooooo`0Poooo00<0I_ooooooool05Oooo`80000loooo0P0001Koool0033oool00`1Vooooooooo`1L
oooo00<0003oooooool08?ooo`0306Kooooooooo06_oool0033oool00`1Vooooooooo`1Loooo0P00
027oool00`1Vooooooooo`1[oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool0
0`1Vooooooooo`1[oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool00`1Voooo
ooooo`1[oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool00`1Vooooooooo`1[
oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03Oooo`050000ooooooooooooo`2I00[oool00`000?ooooooo`0<oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000
oooooooo023oool00ol0VOooooooo`0Goooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0
003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool0
0ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOoo
ooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Sooo
o`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo05coool00ol0VOooooooo`0_oooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000G?ooo`03o`2Ioooooooo02ooool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Loooo00?o09Woooooool0;ooo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?
oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0
003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool0
0ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo05coool00ol0VOoo
ooooo`0_oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Loooo00?o
09Woooooool0;oooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0G?ooo`03o`2Ioooooooo02ooool007coool200002_ooo`<00004oooo00<0003ooooo
ool0G?ooo`03o`2Ioooooooo02ooool008ooool20000GOooo`03o`2Ioooooooo02ooool008ooool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOoo
ooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Sooo
o`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?
oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0G?ooo`03o`2Ioooooooo02ooool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo05coool00ol0VOooooooo`0_oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000G?oo
o`03o`2Ioooooooo02ooool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`80001Moooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool0
0ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`80001Moooo00?o09Woooooool0;ooo
o`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Sooo
o`80001Moooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`80001Moooo00?o09Woooooool0;oooo`00Soooo`030000
oooooooo05coool00ol0VOooooooo`0_oooo0027oooo1@0000?oool00`000?ooooooo`1Loooo00?o
09Woooooool0;oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00ROooo`030000oooooooo00?oool30000G?ooo`03o`2Ioooooooo02ooool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo1@0000;oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`0;oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.86886 .30902 L
.87359 .30902 L
.87791 .30902 L
.87903 .30902 L
.88025 .30902 L
s
.88025 .30902 m
.88036 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.1128 .30902 L
.11531 .30902 L
.11758 .30902 L
.11872 .30902 L
.11999 .15451 L
.12125 .15451 L
.12261 .15451 L
.12507 .15451 L
.14415 .15451 L
.18538 .15451 L
.22508 .15451 L
.26328 .15451 L
.30392 .15451 L
.32272 .15451 L
.34305 .15451 L
.34848 .15451 L
.35144 .15451 L
.3542 .15451 L
.35542 .15451 L
.35656 .15451 L
.3572 .15454 L
.35789 .15499 L
.3591 .15577 L
.36446 .15919 L
.38463 .17136 L
.42542 .19303 L
.46468 .21066 L
.47428 .21455 L
.48438 .21847 L
.493 .22169 L
.49536 .22255 L
.49789 .22347 L
.49911 .2239 L
.50027 .22412 L
.50131 .22375 L
.50243 .22335 L
.52178 .2161 L
.54264 .20759 L
.58356 .18857 L
.60391 .17782 L
.62296 .1669 L
.63233 .16119 L
.63694 .1583 L
.63919 .15687 L
Mistroke
.64122 .15556 L
.64245 .15477 L
.6436 .30902 L
.64482 .30902 L
.64613 .30902 L
.65148 .30902 L
.66085 .30902 L
.7019 .30902 L
.74144 .30902 L
.77947 .30902 L
.81994 .30902 L
.8589 .30902 L
.90032 .30902 L
.94021 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002oooolm06Ko3oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300008Oooo`0306Kooooooooo06[oool002ooool00`1Vooooooooo`0ioooo0`1Vo`Ooool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool08?ooo`80I_m/oooo000_
oooo00<0I_ooooooool0??ooo`0306Kooooooooo00[oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool07_ooo`80I_l00oooo`1Vooooo`1[oooo000_oooo00<0I_oooooo
ool0?Oooo`80I_l;oooo0P0000[oool300001?ooo`030000oooooooo01coool206Ko0oooo`0306Ko
oooooooo06[oool002ooool00`1Vooooooooo`0ooooo00<0I_ooooooool06oooo`80000Koooo0P1V
o`Goool00`1Vooooooooo`1Zoooo000_oooo00<0I_ooooooool0@?ooo`0306Kooooooooo01[oool0
0`000?ooooooo`0Hoooo0P1Vo`Ooool00`1Vooooooooo`1Zoooo000_oooo00<0I_ooooooool0@Ooo
o`80I_lJoooo00<0003oooooool05oooo`0306Kooooooooo00Ooool00`1Vooooooooo`1Zoooo000_
oooo00<0I_ooooooool0@oooo`80I_lHoooo00<0003oooooool05Oooo`80I_l:oooo00<0I_oooooo
ool0J_ooo`00;oooo`0306Kooooooooo04Goool206Ko5_ooo`80000Doooo0P1Vo`coool00`1Voooo
ooooo`1Zoooo000_oooo00<0I_ooooooool0Aoooo`80I_lDoooo00<0003oooooool04_ooo`0306Ko
oooooooo00coool00`1Vooooooooo`1Zoooo000_oooo00<0I_ooooooool0BOooo`<0I_lAoooo00<0
003oooooool04?ooo`80I_l?oooo00<0I_ooooooool0J_ooo`00;oooo`0306Kooooooooo04coool2
06Ko3oooo`030000oooooooo00koool206Ko4Oooo`0306Kooooooooo06[oool002ooool00`1Voooo
ooooo`1>oooo0`1Vo`coool200003Oooo`80I_lCoooo00<0I_ooooooool0J_ooo`00;oooo`0306Ko
oooooooo057oool206Ko2_ooo`030000oooooooo00[oool206Ko5Oooo`0306Kooooooooo06[oool0
02ooool00`1Vooooooooo`1Coooo0P1Vo`Soool00`000?ooooooo`07oooo0`1VoaOoool00`1Voooo
ooooo`1Zoooo000_oooo00<0I_ooooooool0EOooo`<0I_l5oooo00<0003oooooool01?ooo`<0I_lJ
oooo00<0I_ooooooool0J_ooo`00;oooo`0306Kooooooooo05Soool206Ko0oooo`800003oooo0P1V
oagoool00`1Vooooooooo`1Zoooo000_oooo00<0I_ooooooool0F_ooo`<0I_l00`000?ooooooo`02
06Ko7oooo`0306Kooooooooo06[oool002ooool00`1Vooooooooo`14oooo0P0000Coool200000ooo
o`@00003oooo0P0000Coool0101Vo`00001Vo`1Vob7oool00`1Vooooooooo`1Zoooo000_oooo00<0
I_ooooooool0@oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_ooo`00;_ooo`0306Kooooooooo04Coool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Qoooo00<0
I_ooooooool0J_ooo`00;_ooo`0306Kooooooooo03koool400000_ooo`040000oooooooo00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo027oool00`1Vooooooooo`1Zoooo000^
oooo00<0I_ooooooool0A?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_ooo`00;_ooo`0306Kooooooooo
04Goool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_oo
o`00;_ooo`0306Kooooooooo05koool200008_ooo`0306Kooooooooo06[oool002koool00`1Voooo
ooooo`1Noooo00<0003oooooool08Oooo`0306Kooooooooo06[oool002koool00`1Vooooooooo`1N
oooo00<0003oooooool08Oooo`0306Kooooooooo06[oool002koool00`1Vooooooooo`1Noooo00<0
003oooooool08Oooo`0306Kooooooooo06[oool001Woool300004_ooo`0306Kooooooooo02?oool4
0000=oooo`80000Roooo00<0I_ooooooool04oooo`@0000koooo0`0001Goool001[oool00`000?oo
ooooo`0Aoooo00<0I_ooooooool08oooo`030000oooooooo03Soool00`000?ooooooo`0Qoooo00<0
I_ooooooool04oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0001;oool0
0`1Vooooooooo`0Toooo00<0003oooooool0=oooo`030000oooooooo027oool00`1Vooooooooo`0D
oooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0001?oool0
0`1Vooooooooo`0Moooo100000Coool00`000?ooooooo`0foooo00<0003oooooool08Oooo`0306Ko
oooooooo01Goool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool0
00004oooo`0306Kooooooooo02?oool010000?ooooooo`0003Ooool200008_ooo`0306Kooooooooo
01?oool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0001?oool00`1Voooo
ooooo`0Toooo0P0003Soool00`000?ooooooo`0Qoooo00<0I_ooooooool05?ooo`80000loooo0P00
01Koool002koool00`1Vooooooooo`1Noooo00<0003oooooool08Oooo`0306Kooooooooo06[oool0
02koool00`1Vooooooooo`1Noooo0P0002;oool00`1Vooooooooo`1Zoooo000^oooo00<0I_oooooo
ool0G_ooo`030000oooooooo027oool00`1Vooooooooo`1Zoooo000^oooo00<0I_ooooooool0G_oo
o`030000oooooooo027oool00`1Vooooooooo`1Zoooo000^oooo00<0I_ooooooool0G_ooo`030000
oooooooo027oool00`1Vooooooooo`1Zoooo000@ooooo`00017oool001Koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00;oool00ol0VOooooooo`07
oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000oooooooo03Woool00`000?ooooooo`0Qoooo00?o09Woooooool05_oo
o`030000oooooooo01Goool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Sooo
o`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1M
oooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Wooooo
ool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`1Moooo00?o09Woooooool0;_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo
00?oool010000?ooooooo`0000Coool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00MOoo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0005goool0
0ol0VOooooooo`0^oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Moooo00?o09Wooooo
ool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool0
0`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOoo
o`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Sooo
o`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1M
oooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool007_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Noooo`040000oooooooo
00002oooo`030000oooooooo00;oool30000GOooo`03o`2Ioooooooo02koool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo05goool00ol0VOooooooo`0^oooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo001loooo0P0000[oool300001?ooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?
oooo0P0005koool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Wooooo
ool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool0
0`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`80001Noooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo001foooo0P0000Coool200001Ooo
o`030000oooooooo00;oool200001Oooo`030000oooooooo05goool00ol0VOooooooo`0^oooo001e
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00MOooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo0`0005goool00ol0VOooooooo`0^oooo001eoooo00@0
003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo05goool00ol0VOoo
ooooo`0^oooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo05goool00ol0VOooooooo`0^oooo001foooo0P0000Woool400000ooo
o`<00004oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2I
oooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000
oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool20000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o
09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0
003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo02koool0
08ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool2
0000G_ooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00Qoooo`D00003oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008Woool00`000?ooooooo`03
oooo0`0005goool00ol0VOooooooo`0^oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000
oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo100000?oool200000oooo`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Woool0
0`000?ooooooo`04oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.86886 .30902 L
.87791 .30902 L
.88246 .30902 L
.88378 .30902 L
.88502 .30902 L
.88613 .30902 L
s
.88613 .30902 m
.88626 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.09905 .30902 L
.10458 .30902 L
.10972 .30902 L
.11113 .30902 L
.1119 .30902 L
.11263 .30902 L
.1139 .15451 L
.11458 .15451 L
.11531 .15451 L
.12507 .15451 L
.14415 .15451 L
.18538 .15451 L
.22508 .15451 L
.26328 .15451 L
.30392 .15451 L
.32272 .15451 L
.33261 .15451 L
.34305 .15451 L
.34562 .15451 L
.34837 .15451 L
.34918 .15451 L
.34995 .15451 L
.35064 .15451 L
.35139 .15464 L
.3521 .1551 L
.35285 .15558 L
.3542 .15645 L
.36446 .16289 L
.38463 .17476 L
.42239 .19444 L
.46259 .21224 L
.48107 .21947 L
.49154 .22332 L
.49416 .22426 L
.49664 .22514 L
.49886 .22592 L
.50012 .22627 L
.50128 .22587 L
.51097 .22242 L
.52132 .21857 L
.54242 .21019 L
.58182 .1924 L
.61971 .17229 L
.62968 .16644 L
.63915 .16065 L
.64438 .15736 L
Mistroke
.64581 .15644 L
.64733 .15546 L
.64807 .15499 L
.64877 .15453 L
.65007 .30902 L
.65129 .30902 L
.65257 .30902 L
.65487 .30902 L
.66005 .30902 L
.69807 .30902 L
.73855 .30902 L
.77751 .30902 L
.81892 .30902 L
.85882 .30902 L
.8972 .30902 L
.93803 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002gooolm06Ko4Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300008_ooo`80I_mZoooo000]oooo00<0I_ooooooool0>_ooo`80I_l9oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02;oool206KoJ_ooo`00;Oooo`0306Ko
oooooooo03coool206Ko3Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`0Poooo0P1Vo`03oooo06Kooooo06Woool002goool00`1Vooooooooo`0noooo0P1Vo`coool2
00002_ooo`<00004oooo00<0003oooooool07_ooo`80I_l3oooo00<0I_ooooooool0J?ooo`00;Ooo
o`0306Kooooooooo043oool206Ko7Oooo`80000Moooo0P1Vo`Goool00`1Vooooooooo`1Xoooo000]
oooo00<0I_ooooooool0@_ooo`0306Kooooooooo01[oool00`000?ooooooo`0Koooo00<0I_oooooo
ool01Oooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`13oooo0P1Voa[oool00`000?oo
ooooo`0Ioooo0P1Vo`Soool00`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0AOooo`80I_lH
oooo00<0003oooooool05oooo`80I_l:oooo00<0I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo
04Ooool206Ko5_ooo`80000Foooo0P1Vo`coool00`1Vooooooooo`1Xoooo000]oooo00<0I_oooooo
ool0BOooo`80I_lDoooo00<0003oooooool04oooo`80I_l>oooo00<0I_ooooooool0J?ooo`00;Ooo
o`0306Kooooooooo04_oool00`1Vooooooooo`0Aoooo00<0003oooooool04Oooo`80I_l@oooo00<0
I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo04coool206Ko4Oooo`030000oooooooo00ooool2
06Ko4_ooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`1>oooo0P1Vo`ooool200003Ooo
o`<0I_lDoooo00<0I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo053oool206Ko3Oooo`030000
oooooooo00[oool206Ko5oooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`1Boooo0P1V
o`_oool00`000?ooooooo`07oooo0`1VoaWoool00`1Vooooooooo`1Xoooo000]oooo00<0I_oooooo
ool0E?ooo`<0I_l8oooo00<0003oooooool01?ooo`<0I_lLoooo00<0I_ooooooool0J?ooo`00;Ooo
o`0306Kooooooooo05Ooool206Ko1_ooo`800003oooo0P1Voaooool00`1Vooooooooo`1Xoooo000]
oooo00<0I_ooooooool0FOooo`<0I_l3oooo00<0003oool0I_l00P1Vob7oool00`1Vooooooooo`1X
oooo000]oooo00<0I_ooooooool0A_ooo`800004oooo0P0000?oool400000oooo`800002oooo0`1V
o`03000006Kooooo02?oool00`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0AOooo`040000
oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`0S
oooo00<0I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo04Goool010000?ooooooo`0000Woool0
0`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000Soooo00<0I_ooooooool0J?ooo`00;Ooo
o`0306Kooooooooo03ooool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo02?oool00`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0AOoo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`0Soooo00<0I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo04Koool200002_ooo`800004
oooo0`0000Coool00`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00;Oooo`0306Kooooooooo
05ooool200009?ooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`1Ooooo00<0003ooooo
ool08oooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08ooo
o`0306Kooooooooo06Soool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08oooo`0306Ko
oooooooo06Soool001Woool300004Oooo`0306Kooooooooo02Coool40000=oooo`80000Toooo00<0
I_ooooooool04Oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0@oooo00<0I_oooooo
ool09?ooo`030000oooooooo03Soool00`000?ooooooo`0Soooo00<0I_ooooooool04Oooo`030000
oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00017oool00`1Vooooooooo`0Uoooo00<0
003oooooool0=oooo`030000oooooooo02?oool00`1Vooooooooo`0Boooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0001;oool00`1Vooooooooo`0Noooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool08oooo`0306Kooooooooo01?oool00`000?oo
ooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000004_ooo`0306Kooooooooo
02Coool010000?ooooooo`0003Ooool200009?ooo`0306Kooooooooo017oool010000?ooooooo`00
03[oool00`000?ooo`00000Foooo000Ioooo0P0001;oool00`1Vooooooooo`0Uoooo0P0003Soool0
0`000?ooooooo`0Soooo00<0I_ooooooool04_ooo`80000loooo0P0001Koool002goool00`1Voooo
ooooo`1Ooooo00<0003oooooool08oooo`0306Kooooooooo06Soool002goool00`1Vooooooooo`1O
oooo0P0002Coool00`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo
02?oool00`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool0
0`1Vooooooooo`1Xoooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool00`1Voooo
ooooo`1Xoooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00Coool00ol0VOooooooo`05oooo00<0003oooooool03?oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
oooooooo03Woool00`000?ooooooo`0Soooo00?o09Woooooool05?ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Wooooo
ool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003ooooo
ool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?oo
o`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOoo
ooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?oo
ooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Sooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001P
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1Ooooo00?o09Wooooo
ool0;?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0005ooool00ol0VOooooooo`0/oooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Gooo
o`03o`2Ioooooooo02coool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001P
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o
09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo
05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool0
08ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Wooooo
ool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003ooooo
ool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?oo
o`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOoo
ooooo`0/oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`1Ooooo00?o09Woooooool0;?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Goooo`03o`2Ioooooooo02coool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo0P00063oool00ol0VOoo
ooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?oo
ooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Sooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001P
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o
09Woooooool0;?ooo`00Soooo`80001Poooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo
05ooool00ol0VOooooooo`0/oooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1Ooooo00?o
09Woooooool0;?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0005ooool00ol0VOooooooo`0/oooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
05ooool00ol0VOooooooo`0/oooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0Goooo`03o`2Ioooooooo02coool008ooool20000H?ooo`03o`2Ioooooooo02coool008ooool0
0`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOoo
ooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool20000H?oo
o`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Sooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool008ooool20000H?ooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1O
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool20000H?ooo`03o`2Ioooooooo
02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Qoooo`D00003oooo00<0
003oooooool0Goooo`03o`2Ioooooooo02coool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0Goooo`03o`2Ioooooooo02coool008Woool00`000?ooooooo`03oooo0`0005ooool00ol0VOoo
ooooo`0/oooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200000ooo
o`@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`030000oooooooo
00?oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`09oooo00<0003oooooool01Oooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`09
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.87791 .30902 L
.88735 .30902 L
.88993 .30902 L
.89136 .30902 L
.89206 .30902 L
.89271 .30902 L
s
.89271 .30902 m
.89283 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.09905 .30902 L
.10192 .30902 L
.10458 .30902 L
.10587 .30902 L
.10708 .30902 L
.10834 .15451 L
.109 .15451 L
.10972 .15451 L
.11531 .15451 L
.12507 .15451 L
.14415 .15451 L
.18538 .15451 L
.22508 .15451 L
.26328 .15451 L
.30392 .15451 L
.32272 .15451 L
.33261 .15451 L
.33801 .15451 L
.34065 .15451 L
.34305 .15451 L
.34437 .15451 L
.34562 .15476 L
.34694 .15561 L
.34837 .15653 L
.3542 .16022 L
.36446 .16649 L
.38463 .17807 L
.42542 .19868 L
.46468 .21546 L
.47428 .21915 L
.48438 .22289 L
.493 .22595 L
.49536 .22677 L
.49789 .22764 L
.49911 .22806 L
.50027 .22827 L
.50131 .22791 L
.50243 .22753 L
.52178 .22063 L
.54264 .21254 L
.58356 .19445 L
.60391 .18422 L
.62296 .17383 L
.64122 .16305 L
.64648 .15979 L
.64908 .15816 L
Mistroke
.65148 .15663 L
.6526 .15591 L
.65365 .15523 L
.65486 .30902 L
.65596 .30902 L
.66085 .30902 L
.69945 .30902 L
.7405 .30902 L
.78004 .30902 L
.81807 .30902 L
.85854 .30902 L
.89751 .30902 L
.93892 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002cooolm06Ko4_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300009?ooo`0306Kooooooooo06Ooool002coool00`1Vooooooooo`0ioooo0P1Vo`_oool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool08oooo`80I_mYoooo000/
oooo00<0I_ooooooool0>oooo`80I_l?oooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo027oool206Ko00?oool0I_ooool0J?ooo`00;?ooo`0306Kooooooooo03goool2
06Ko3_ooo`80000:oooo0`0000Coool00`000?ooooooo`0Ooooo0P1Vo`?oool00`1Vooooooooo`1W
oooo000/oooo00<0I_ooooooool0?oooo`80I_lOoooo0P0001koool206Ko1Oooo`0306Kooooooooo
06Ooool002coool00`1Vooooooooo`11oooo0P1Voagoool00`000?ooooooo`0Loooo00<0I_oooooo
ool01Oooo`0306Kooooooooo06Ooool002coool00`1Vooooooooo`13oooo00<0I_ooooooool06_oo
o`030000oooooooo01[oool206Ko2?ooo`0306Kooooooooo06Ooool002coool00`1Vooooooooo`14
oooo0P1Voa[oool00`000?ooooooo`0Hoooo0P1Vo`[oool00`1Vooooooooo`1Woooo000/oooo00<0
I_ooooooool0A_ooo`80I_lHoooo0P0001Ooool206Ko3?ooo`0306Kooooooooo06Ooool002coool0
0`1Vooooooooo`18oooo0P1VoaKoool00`000?ooooooo`0Doooo0P1Vo`koool00`1Vooooooooo`1W
oooo000/oooo00<0I_ooooooool0B_ooo`80I_lDoooo00<0003oooooool04_ooo`80I_l@oooo00<0
I_ooooooool0Ioooo`00;?ooo`0306Kooooooooo04coool206Ko4_ooo`030000oooooooo013oool2
06Ko4_ooo`0306Kooooooooo06Ooool002coool00`1Vooooooooo`1>oooo0P1Voa3oool200003ooo
o`80I_lDoooo00<0I_ooooooool0Ioooo`00;?ooo`0306Kooooooooo053oool206Ko3_ooo`030000
oooooooo00coool206Ko5_ooo`0306Kooooooooo06Ooool002coool00`1Vooooooooo`1Boooo0P1V
o`coool00`000?ooooooo`0:oooo0P1VoaSoool00`1Vooooooooo`1Woooo000/oooo00<0I_oooooo
ool0E?ooo`80I_l:oooo00<0003oooooool01oooo`<0I_lJoooo00<0I_ooooooool0Ioooo`00;?oo
o`0306Kooooooooo05Koool206Ko2?ooo`800005oooo0`1Voagoool00`1Vooooooooo`1Woooo000/
oooo00<0I_ooooooool0F?ooo`<0I_l5oooo00<0003oooooool00_ooo`80I_lPoooo00<0I_oooooo
ool0Ioooo`00;?ooo`0306Kooooooooo04Ooool200001?ooo`800003oooo100000?oool20000101V
o`04oooo0000oooooooo0P1Vob;oool00`1Vooooooooo`1Woooo000/oooo00<0I_ooooooool0A_oo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000?oool0101Vo`00
001Vo`1VobCoool00`1Vooooooooo`1Woooo000[oooo00<0I_ooooooool0Aoooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`0002Coool00`1Vooooooooo`1W
oooo000[oooo00<0I_ooooooool0@Oooo`@00002oooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool002_oool00`1Voooo
ooooo`17oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?oo
o`030000oooooooo02Coool00`1Vooooooooo`1Woooo000[oooo00<0I_ooooooool0B?ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo000[oooo00<0
I_ooooooool0HOooo`80000Uoooo00<0I_ooooooool0Ioooo`00:oooo`0306Kooooooooo067oool0
0`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00:oooo`0306Kooooooooo067oool00`000?oo
ooooo`0Toooo00<0I_ooooooool0Ioooo`00:oooo`0306Kooooooooo067oool00`000?ooooooo`0T
oooo00<0I_ooooooool0Ioooo`006Oooo`<0000?oooo00<0I_ooooooool09_ooo`@0000goooo0P00
02Goool00`1Vooooooooo`0@oooo100003_oool300005Oooo`006_ooo`030000oooooooo00koool0
0`1Vooooooooo`0Voooo00<0003oooooool0>?ooo`030000oooooooo02Coool00`1Vooooooooo`0@
oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool500003oooo`0306Kooooooooo
02Ooool00`000?ooooooo`0goooo00<0003oooooool09?ooo`0306Kooooooooo017oool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo00004?ooo`0306Kooooooooo
023oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0Toooo00<0I_ooooooool04_oo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000@oooo00<0
I_ooooooool09_ooo`040000oooooooo0000=oooo`80000Uoooo00<0I_ooooooool04?ooo`040000
oooooooo0000>_ooo`030000oooo000001Koool001Woool200004?ooo`0306Kooooooooo02Ooool2
0000>?ooo`030000oooooooo02Coool00`1Vooooooooo`0Aoooo0P0003coool200005_ooo`00:ooo
o`0306Kooooooooo067oool00`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00:oooo`0306Ko
oooooooo067oool200009Oooo`0306Kooooooooo06Ooool002_oool00`1Vooooooooo`1Qoooo00<0
003oooooool09?ooo`0306Kooooooooo06Ooool002_oool00`1Vooooooooo`1Qoooo00<0003ooooo
ool09?ooo`0306Kooooooooo06Ooool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool09?oo
o`0306Kooooooooo06Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool01_ooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00<0003oooooool0>Oooo`030000oooooooo02Goool00ol0VOooooooo`0Boooo00<0003ooooo
ool05Oooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool0
0ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool0
0`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOoo
ooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOoo
o`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Sooo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Z
oooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Q
oooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo
02[oool007Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo067oool0
0ol0VOooooooo`0Zoooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo001eoooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000HOooo`03o`2Ioooooooo
02[oool007Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?oo
ooooo`1Qoooo00?o09Woooooool0:_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00M_oo
o`80000:oooo0P0000Coool300001?ooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo
02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo
067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0
003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Wooooo
ool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool0
0ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool0
0`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOoo
ooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOoo
o`03o`2Ioooooooo02[oool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Q
oooo00?o09Woooooool0:_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo001koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0001Qoooo00?o09Woooooool0:_ooo`00Noooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007coool2
00002_ooo`<00004oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool20000H_oo
o`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Sooo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Z
oooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Q
oooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo
02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo
067oool00ol0VOooooooo`0Zoooo002?oooo0P0006;oool00ol0VOooooooo`0Zoooo002?oooo00<0
003oooooool0HOooo`03o`2Ioooooooo02[oool007Koool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800005oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
067oool00ol0VOooooooo`0Zoooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool30000HOooo`03o`2Ioooooooo02[oool007Goool010000?ooooooo`00
00_oool010000?ooooooooooo`800005oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool0
07Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0
003oooooool0HOooo`03o`2Ioooooooo02[oool007Koool200002Oooo`@00003oooo0`0000Coool0
0`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_oo
o`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOoo
o`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Sooo
o`80001Roooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Z
oooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Q
oooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_ooo`00Soooo`030000
oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo
02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o
09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo0027oooo1@00
00?oool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00ROooo`030000oooooooo00?oool30000HOoo
o`03o`2Ioooooooo02[oool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?oo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000ooo
o`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_oo
o`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000>oooo00<0003oooooool02_ooo`050000oooooooooooo000007goool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89307 .30902 L
.89548 .30902 L
.89654 .30902 L
.89771 .30902 L
s
.89771 .30902 m
.89783 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09396 .30902 L
.09682 .30902 L
.09822 .30902 L
.09952 .30902 L
.1007 .30902 L
.10195 .15451 L
.1032 .15451 L
.10458 .15451 L
.14487 .15451 L
.18364 .15451 L
.22486 .15451 L
.26457 .15451 L
.30277 .15451 L
.32244 .15451 L
.3281 .15451 L
.33344 .15451 L
.33577 .15451 L
.33704 .15451 L
.33823 .15451 L
.33952 .15466 L
.3402 .1551 L
.34093 .15557 L
.34341 .15716 L
.38477 .18138 L
.42462 .20105 L
.46295 .2171 L
.48272 .22443 L
.49271 .2279 L
.49544 .22883 L
.49688 .22931 L
.49839 .22981 L
.49903 .23003 L
.49972 .23026 L
.50047 .23019 L
.50118 .22996 L
.50373 .22911 L
.54523 .21389 L
.58521 .1965 L
.62367 .17677 L
.64355 .16525 L
.65357 .15908 L
.65632 .15734 L
.65783 .15637 L
.65927 .15545 L
.65991 .15503 L
Mistroke
.6606 .15458 L
.66135 .30902 L
.66205 .30902 L
.66459 .30902 L
.70623 .30902 L
.74635 .30902 L
.78495 .30902 L
.826 .30902 L
.86554 .30902 L
.90357 .30902 L
.94405 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002[ooolm06Ko5?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool300009Oooo`80I_mWoooo000Zoooo00<0I_ooooooool0>_ooo`0306Kooooooooo00_oool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool09?ooo`<0I_mWoooo000Z
oooo00<0I_ooooooool0>oooo`80I_lAoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02;oool206Ko0_ooo`0306Kooooooooo06Goool002[oool00`1Vooooooooo`0m
oooo0P1Voa3oool200002_ooo`<00004oooo00<0003oooooool08Oooo`0306Kooooooooo00;oool0
0`1Vooooooooo`1Uoooo000Zoooo00<0I_ooooooool0?oooo`80I_lQoooo0P00023oool206Ko1Ooo
o`0306Kooooooooo06Goool002[oool00`1Vooooooooo`11oooo0P1Voaooool00`000?ooooooo`0M
oooo0P1Vo`Ooool00`1Vooooooooo`1Uoooo000Zoooo00<0I_ooooooool0@oooo`80I_lMoooo00<0
003oooooool07?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`1Uoooo000Zoooo00<0I_oooooo
ool0AOooo`0306Kooooooooo01[oool00`000?ooooooo`0Joooo0P1Vo`[oool00`1Vooooooooo`1U
oooo000Zoooo00<0I_ooooooool0A_ooo`80I_lJoooo0P0001Woool206Ko3?ooo`0306Kooooooooo
06Goool002[oool00`1Vooooooooo`18oooo0P1VoaSoool00`000?ooooooo`0Foooo0P1Vo`koool0
0`1Vooooooooo`1Uoooo000Zoooo00<0I_ooooooool0B_ooo`80I_lFoooo00<0003oooooool05?oo
o`80I_l@oooo00<0I_ooooooool0IOooo`00:_ooo`0306Kooooooooo04coool206Ko5?ooo`030000
oooooooo01;oool206Ko4_ooo`0306Kooooooooo06Goool002[oool00`1Vooooooooo`1>oooo0`1V
oa7oool200004?ooo`<0I_lDoooo00<0I_ooooooool0IOooo`00:_ooo`0306Kooooooooo057oool2
06Ko3oooo`030000oooooooo00goool206Ko5oooo`0306Kooooooooo06Goool002[oool00`1Voooo
ooooo`1Coooo0`1Vo`coool00`000?ooooooo`0:oooo0`1VoaWoool00`1Vooooooooo`1Uoooo000Z
oooo00<0I_ooooooool0E_ooo`80I_l:oooo00<0003oooooool01oooo`<0I_lLoooo00<0I_oooooo
ool0IOooo`00:_ooo`0306Kooooooooo05Soool306Ko1oooo`800006oooo0P1Voaooool00`1Voooo
ooooo`1Uoooo000Zoooo00<0I_ooooooool0Foooo`80I_l5oooo00<0003oooooool00_ooo`<0I_lQ
oooo00<0I_ooooooool0IOooo`00:_ooo`0306Kooooooooo04Woool200001?ooo`800003oooo1000
00?oool200000P1Vo`?oool00`000?ooooooo`0206Ko9?ooo`0306Kooooooooo06Goool002[oool0
0`1Vooooooooo`18oooo00@0003oooooool00008oooo00<0003oooooool00oooo`050000oooooooo
0000oooo00<0I_l00`00001Vo`1Vo`0Voooo00<0I_ooooooool0IOooo`00:_ooo`0306Kooooooooo
04Soool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0000V
oooo00<0I_ooooooool0IOooo`00:_ooo`0306Kooooooooo04;oool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo02Koool00`1Vooooooooo`1U
oooo000Zoooo00<0I_ooooooool0B?ooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`0Voooo00<0I_ooooooool0IOooo`00:_ooo`0306Ko
oooooooo04Woool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Voooo00<0I_oooooo
ool0IOooo`00:_ooo`0306Kooooooooo06;oool200009oooo`0306Kooooooooo06Goool002[oool0
0`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo06Goool002[oool00`1Voooo
ooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo06Goool002[oool00`1Vooooooooo`1R
oooo00<0003oooooool09_ooo`0306Kooooooooo06Goool001Woool300003_ooo`0306Kooooooooo
02Ooool40000=oooo`80000Woooo00<0I_ooooooool03_ooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0=oooo00<0I_ooooooool09oooo`030000oooooooo03Soool00`000?ooooooo`0V
oooo00<0I_ooooooool03_ooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
00koool00`1Vooooooooo`0Xoooo00<0003oooooool0=oooo`030000oooooooo02Koool00`1Voooo
ooooo`0?oooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
00ooool00`1Vooooooooo`0Qoooo100000Coool00`000?ooooooo`0foooo00<0003oooooool09_oo
o`0306Kooooooooo013oool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool000003oooo`0306Kooooooooo02Ooool010000?ooooooo`0003Ooool200009oooo`0306Ko
oooooooo00koool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0000ooool0
0`1Vooooooooo`0Xoooo0P0003Soool00`000?ooooooo`0Voooo00<0I_ooooooool03oooo`80000l
oooo0P0001Koool002[oool00`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo
06Goool002[oool00`1Vooooooooo`1Roooo0P0002Ooool00`1Vooooooooo`1Uoooo000Zoooo00<0
I_ooooooool0H_ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo000Zoooo00<0I_oooooo
ool0H_ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo000Zoooo00<0I_ooooooool0H_oo
o`030000oooooooo02Koool00`1Vooooooooo`1Uoooo000@ooooo`00017oool001Koool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00Ooool00ol0VOoo
ooooo`02oooo00<0003oooooool03?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool0>Oooo`030000oooooooo03Woool00`000?ooooooo`0Voooo00?o09Wooooo
ool04Oooo`030000oooooooo01Goool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Ooo
o`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?oo
ooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001S
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo
06;oool00ol0VOooooooo`0Yoooo001foooo0P0000Coool200000oooo`@00003oooo0P0000Goool0
0`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00MOooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`1Roooo00?o09Woooooool0:Ooo
o`00MOooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0`00
06;oool00ol0VOooooooo`0Yoooo001eoooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool007Koool200002_ooo`800004oooo0`0000Coool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo
06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Wooooo
ool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003ooooo
ool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Ooo
o`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?oo
ooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool007_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Noooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000H_ooo`03o`2Ioooooooo02Woool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo001loooo0P0000[oool300001?ooo`030000oooooooo06;oool00ol0VOooooooo`0Y
oooo002?oooo0P0006?oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001S
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo
06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Wooooo
ool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo06;oool00ol0VOooooooo`0Y
oooo001eoooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00MOooo`040000oooooooo00002_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo0`0006;oool00ol0VOooooooo`0Yoooo001e
oooo00@0003oooooool0000;oooo00@0003oooooooooool200001Oooo`030000oooooooo06;oool0
0ol0VOooooooo`0Yoooo001eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo001foooo0P0000Woool4
00000oooo`<00004oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool20000Hooo
o`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1R
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo
02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo
06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Wooooo
ool0:Oooo`00Qoooo`D00003oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008Woool00`000?oo
ooooo`03oooo0`0006;oool00ol0VOooooooo`0Yoooo0029oooo00<0003oooooool0U?ooo`00ROoo
o`030000oooooooo09Coool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003_ooo`030000oooooooo00[oool010000?ooooooooooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89307 .30902 L
.89771 .30902 L
.90008 .30902 L
.90133 .30902 L
.90265 .30902 L
.90381 .30902 L
s
.90381 .30902 m
.90394 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09109 .30902 L
.09258 .30902 L
.09324 .30902 L
.09396 .30902 L
.09525 .15451 L
.09596 .15451 L
.09662 .15451 L
.09952 .15451 L
.10458 .15451 L
.14335 .15451 L
.18458 .15451 L
.22428 .15451 L
.26248 .15451 L
.28379 .15451 L
.30312 .15451 L
.3128 .15451 L
.32327 .15451 L
.32808 .15451 L
.33071 .15451 L
.33199 .15451 L
.33316 .15451 L
.33423 .15509 L
.33525 .15575 L
.33749 .15718 L
.34225 .16019 L
.38058 .18232 L
.42136 .20226 L
.46063 .21849 L
.48032 .22568 L
.48895 .22864 L
.49383 .23028 L
.49617 .23105 L
.49838 .23177 L
.49953 .23214 L
.50077 .23204 L
.5019 .23168 L
.50294 .23134 L
.50781 .22973 L
.51773 .22636 L
.53858 .21879 L
.57799 .20255 L
.61587 .18419 L
.63695 .17264 L
.65621 .16114 L
.66083 .15825 L
Mistroke
.66336 .15664 L
.6646 .15584 L
.66574 .15511 L
.66641 .15468 L
.6671 .30902 L
.6678 .30902 L
.66857 .30902 L
.67113 .30902 L
.67613 .30902 L
.69504 .30902 L
.73552 .30902 L
.77448 .30902 L
.81589 .30902 L
.85579 .30902 L
.89417 .30902 L
.935 .30902 L
.97432 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Soooln06Ko5Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool300009oooo`0306Kooooooooo06Coool002Soool00`1Vooooooooo`0joooo0P1Vo`koool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool09_ooo`80I_mVoooo000X
oooo00<0I_ooooooool0??ooo`0306Kooooooooo017oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool09Oooo`0306Kooooo06Ko06Koool002Soool00`1Vooooooooo`0m
oooo0P1Voa;oool200002_ooo`<00004oooo00<0003oooooool08oooo`80I_l2oooo00<0I_oooooo
ool0I?ooo`00:?ooo`0306Kooooooooo03ooool206Ko8oooo`80000Roooo0P1Vo`Coool00`1Voooo
ooooo`1Toooo000Xoooo00<0I_ooooooool0@Oooo`80I_lQoooo00<0003oooooool08?ooo`0306Ko
oooooooo00Coool00`1Vooooooooo`1Toooo000Xoooo00<0I_ooooooool0@oooo`80I_lOoooo00<0
003oooooool07_ooo`80I_l7oooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo04Goool2
06Ko7Oooo`030000oooooooo01coool206Ko2Oooo`0306Kooooooooo06Coool002Soool00`1Voooo
ooooo`17oooo0P1Voa_oool200006_ooo`<0I_l;oooo00<0I_ooooooool0I?ooo`00:?ooo`0306Ko
oooooooo04Woool206Ko6Oooo`030000oooooooo01Ooool206Ko3_ooo`0306Kooooooooo06Coool0
02Soool00`1Vooooooooo`1;oooo0P1VoaOoool00`000?ooooooo`0Eoooo0P1Voa3oool00`1Voooo
ooooo`1Toooo000Xoooo00<0I_ooooooool0COooo`80I_lEoooo00<0003oooooool04oooo`80I_lB
oooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo04ooool306Ko4_ooo`80000Boooo0P1V
oaCoool00`1Vooooooooo`1Toooo000Xoooo00<0I_ooooooool0D_ooo`80I_l@oooo00<0003ooooo
ool03oooo`80I_lFoooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo05Coool306Ko3Ooo
o`030000oooooooo00goool206Ko6?ooo`0306Kooooooooo06Coool002Soool00`1Vooooooooo`1G
oooo0P1Vo`_oool00`000?ooooooo`0;oooo0P1Voa[oool00`1Vooooooooo`1Toooo000Xoooo00<0
I_ooooooool0FOooo`<0I_l8oooo0P0000[oool206Ko7?ooo`0306Kooooooooo06Coool002Soool0
0`1Vooooooooo`1Loooo0P1Vo`Koool00`000?ooooooo`05oooo101Voakoool00`1Vooooooooo`1T
oooo000Xoooo00<0I_ooooooool0Boooo`800004oooo0P0000?oool400000oooo`8000000`1Voooo
ooooo`02oooo00@0003oooooooooool406Ko8_ooo`0306Kooooooooo06Coool002Soool00`1Voooo
ooooo`1:oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00000`1V
o`03oooo0000oooo0080I_lVoooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo04[oool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00D0003oooooooooool0I_l00`0002Ooool0
0`1Vooooooooo`1Toooo000Xoooo00<0I_ooooooool0A?ooo`@00002oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool09oooo`0306Kooooooooo06Coool0
02Soool00`1Vooooooooo`1:oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo02Ooool00`1Vooooooooo`1Toooo000Xoooo00<0I_oooooo
ool0Boooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo02Ooool00`1Vooooooooo`1T
oooo000Xoooo00<0I_ooooooool0I?ooo`80000Xoooo00<0I_ooooooool0I?ooo`00:?ooo`0306Ko
oooooooo06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo
06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`00:?ooo`0306Kooooooooo06Coool0
0`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`006Oooo`<0000<oooo00<0I_ooooooool0:Ooo
o`@0000goooo0P0002Soool00`1Vooooooooo`0=oooo100003_oool300005Oooo`006_ooo`030000
oooooooo00_oool00`1Vooooooooo`0Yoooo00<0003oooooool0>?ooo`030000oooooooo02Ooool0
0`1Vooooooooo`0=oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool500003?oo
o`0306Kooooooooo02[oool00`000?ooooooo`0goooo00<0003oooooool09oooo`0306Kooooooooo
00koool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo00003Ooo
o`0306Kooooooooo02?oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0Woooo00<0
I_ooooooool03oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000=oooo00<0I_ooooooool0:Oooo`040000oooooooo0000=oooo`80000Xoooo00<0I_oooooo
ool03Oooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool200003Oooo`0306Ko
oooooooo02[oool20000>?ooo`030000oooooooo02Ooool00`1Vooooooooo`0>oooo0P0003coool2
00005_ooo`00:?ooo`0306Kooooooooo06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0I?oo
o`00:?ooo`0306Kooooooooo06Coool20000:?ooo`0306Kooooooooo06Coool002Soool00`1Voooo
ooooo`1Toooo00<0003oooooool09oooo`0306Kooooooooo06Coool002Soool00`1Vooooooooo`1T
oooo00<0003oooooool09oooo`0306Kooooooooo06Coool002Soool00`1Vooooooooo`1Toooo00<0
003oooooool09oooo`0306Kooooooooo06Coool0013ooooo00004Oooo`005_ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool02?ooo`05o`2Ioooooooo
oooo000000koool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`000?ooooooo`0ioooo00<0003oooooool09oooo`03o`2Ioooooooo013oool00`000?oo
ooooo`0Eoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?oo
o`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1S
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo
02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0Hooo
o`03o`2Ioooooooo02Soool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool007Goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001Soooo00?o09Wooooo
ool0:?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo06?oool00ol0VOooooooo`0Xoooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo001f
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003ooooo
ool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?oo
o`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1S
oooo00?o09Woooooool0:?ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo001koooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool007_oool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0006?oool00ol0VOooooooo`0Xoooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001T
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo
02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool0
08ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003ooooo
ool0Hoooo`03o`2Ioooooooo02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0Hoooo`03o`2Ioooooooo02Soool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`<0001Soooo00?o09Woooooool0:?ooo`00MOooo`040000oooooooo
00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1Soooo00?o09Woooooool0:?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00M_ooo`800009oooo100000?oool300001?oo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo0P0006Coool00ol0VOooooooo`0X
oooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1S
oooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?
oooo0P0006Coool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo
02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo
06?oool00ol0VOooooooo`0Xoooo002?oooo0P0006Coool00ol0VOooooooo`0Xoooo002?oooo00<0
003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo0P0006Coool0
0ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008Ooool5
00000oooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo0029oooo00<0003oooooool00ooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo0029oooo00<0003oooooool00oooo`<0001S
oooo00?o09Woooooool0:?ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2D
oooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
oooo0P0000Goool300000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0<oooo00D0003ooooo
ooooool00000OOooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02?ooo`D00003oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89771 .30902 L
.90265 .30902 L
.90733 .30902 L
.90859 .30902 L
.90992 .30902 L
.91061 .30902 L
s
.91061 .30902 m
.91069 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.07216 .30902 L
.08255 .30902 L
.08562 .30902 L
.08713 .30902 L
.08779 .30902 L
.08852 .30902 L
.08979 .15451 L
.09048 .15451 L
.09113 .15451 L
.09396 .15451 L
.10458 .15451 L
.14335 .15451 L
.18458 .15451 L
.22428 .15451 L
.26248 .15451 L
.28379 .15451 L
.30312 .15451 L
.3128 .15451 L
.31789 .15451 L
.32067 .15451 L
.32327 .15451 L
.32555 .15451 L
.32682 .15451 L
.32798 .1549 L
.32926 .15572 L
.33064 .15661 L
.33316 .15821 L
.34225 .16386 L
.38303 .18671 L
.4223 .20531 L
.46005 .22051 L
.48102 .22798 L
.49021 .23104 L
.49507 .23262 L
.49774 .23347 L
.49905 .23388 L
.50025 .2341 L
.50145 .23373 L
.50271 .23333 L
.50537 .23248 L
.51002 .23097 L
.5191 .22793 L
.53894 .22089 L
.57683 .20569 L
.61717 .18661 L
.63574 .17668 L
.65599 .16493 L
Mistroke
.66132 .16167 L
.66698 .15812 L
.66974 .15637 L
.67109 .1555 L
.67233 .1547 L
.67346 .30902 L
.67465 .30902 L
.67717 .30902 L
.69727 .30902 L
.73529 .30902 L
.77577 .30902 L
.81473 .30902 L
.85614 .30902 L
.89604 .30902 L
.93442 .30902 L
.97526 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Oooolm06Ko5oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000:?ooo`80I_mToooo000Woooo00<0I_ooooooool0>_ooo`80I_l?oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02Ooool306KoI?ooo`009oooo`0306Ko
oooooooo03coool00`1Vooooooooo`0Boooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02Koool0101Vooooooooo`1VofCoool002Ooool00`1Vooooooooo`0moooo00<0
I_ooooooool04_ooo`80000:oooo0`0000Coool00`000?ooooooo`0Uoooo00D0I_ooooooooooool0
I_l0I?ooo`009oooo`0306Kooooooooo03koool206Ko9Oooo`80000Toooo0P1Vo`Coool00`1Voooo
ooooo`1Roooo000Woooo00<0I_ooooooool0@?ooo`80I_lSoooo00<0003oooooool08Oooo`80I_l6
oooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo04;oool206Ko8Oooo`030000oooooooo
01ooool206Ko2?ooo`0306Kooooooooo06;oool002Ooool00`1Vooooooooo`14oooo0P1Voaooool0
0`000?ooooooo`0Moooo0P1Vo`[oool00`1Vooooooooo`1Roooo000Woooo00<0I_ooooooool0A_oo
o`80I_lMoooo0P0001_oool306Ko3?ooo`0306Kooooooooo06;oool002Ooool00`1Vooooooooo`18
oooo0P1Voa_oool00`000?ooooooo`0Hoooo0P1Vo`ooool00`1Vooooooooo`1Roooo000Woooo00<0
I_ooooooool0B_ooo`80I_lIoooo00<0003oooooool05_ooo`80I_lAoooo00<0I_ooooooool0H_oo
o`009oooo`0306Kooooooooo04coool206Ko5oooo`030000oooooooo01Coool206Ko4oooo`0306Ko
oooooooo06;oool002Ooool00`1Vooooooooo`1>oooo0P1VoaGoool200004oooo`80I_lEoooo00<0
I_ooooooool0H_ooo`009oooo`0306Kooooooooo053oool306Ko4_ooo`030000oooooooo00ooool3
06Ko5oooo`0306Kooooooooo06;oool002Ooool00`1Vooooooooo`1Coooo0P1Voa3oool00`000?oo
ooooo`0=oooo0P1Voa[oool00`1Vooooooooo`1Roooo000Woooo00<0I_ooooooool0EOooo`<0I_l=
oooo00<0003oooooool02oooo`80I_lLoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo
05Soool206Ko2oooo`80000:oooo0P1Voakoool00`1Vooooooooo`1Roooo000Woooo00<0I_oooooo
ool0F_ooo`<0I_l8oooo00<0003oooooool01_ooo`<0I_lPoooo00<0I_ooooooool0H_ooo`009ooo
o`0306Kooooooooo04coool200001?ooo`800003oooo100000;oool00`1Vo`0000000005oooo00<0
003oooooool01?ooo`80I_lSoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo04_oool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oool0I_l00004oooo00<0003ooooo
ool00_ooo`80I_lUoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo04_oool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<00000I_l0I_l00P1Vo`<0000206Ko9oooo`0306Ko
oooooooo06;oool002Ooool00`1Vooooooooo`15oooo100000;oool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`009ooo
o`0306Kooooooooo04_oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`04oooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool002Ooool00`1Vooooooooo`1<
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool0
02Ooool00`1Vooooooooo`1Uoooo0P0002[oool00`1Vooooooooo`1Roooo000Woooo00<0I_oooooo
ool0IOooo`030000oooooooo02Woool00`1Vooooooooo`1Roooo000Woooo00<0I_ooooooool0IOoo
o`030000oooooooo02Woool00`1Vooooooooo`1Roooo000Woooo00<0I_ooooooool0IOooo`030000
oooooooo02Woool00`1Vooooooooo`1Roooo000Ioooo0`0000_oool00`1Vooooooooo`0Zoooo1000
03Ooool20000:_ooo`0306Kooooooooo00_oool40000>oooo`<0000Eoooo000Joooo00<0003ooooo
ool02_ooo`0306Kooooooooo02[oool00`000?ooooooo`0hoooo00<0003oooooool0:Oooo`0306Ko
oooooooo00_oool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000;oooo00<0
I_ooooooool0:oooo`030000oooooooo03Ooool00`000?ooooooo`0Yoooo00<0I_ooooooool03?oo
o`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000<oooo00<0
I_ooooooool09?ooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo02Woool00`1Voooo
ooooo`0=oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo0000
00coool00`1Vooooooooo`0Zoooo00@0003oooooool0000goooo0P0002[oool00`1Vooooooooo`0;
oooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000<oooo00<0I_oooooo
ool0:oooo`80000hoooo00<0003oooooool0:Oooo`0306Kooooooooo00coool20000??ooo`80000F
oooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo02Woool00`1Vooooooooo`1Roooo000W
oooo00<0I_ooooooool0IOooo`80000Zoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo
06Goool00`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo06Goool0
0`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`009oooo`0306Kooooooooo06Goool00`000?oo
ooooo`0Yoooo00<0I_ooooooool0H_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0:oooo00?o09Woool000003_oo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
oooooooo03Woool00`000?ooooooo`0Yoooo00?o09Woooooool03_ooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Wooooo
ool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_oo
o`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?oo
ooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2I
oooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001V
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0006Goool00ol0VOooooooo`0Voooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001V
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool0
08ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Wooooo
ool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_oo
o`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0IOooo`03o`2I
oooooooo02Koool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`1Uoooo00?o09Woooooool09_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000IOooo`03o`2Ioooooooo02Koool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001loooo0P0000[oool3
00001?ooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo0P0006Koool00ol0VOoo
ooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?oo
ooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2I
oooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001V
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00Soooo`80001Voooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0006Goool00ol0VOooooooo`0Voooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
06Goool00ol0VOooooooo`0Voooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_oo
o`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2I
oooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1U
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo
02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Qoooo`D00003oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0IOooo`03o`2Ioooooooo02Koool008Woool00`000?ooooooo`03oooo0`0006Goool00ol0VOoo
ooooo`0Voooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001Ooo
o`<00002oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool03?ooo`040000oooooooo
00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03_ooo`030000oooooooo00Soool500001?ooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89771 .30902 L
.90733 .30902 L
.91011 .30902 L
.91273 .30902 L
.91509 .30902 L
.91573 .30902 L
.91642 .30902 L
s
.91642 .30902 m
.91654 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.07216 .30902 L
.0775 .30902 L
.08013 .30902 L
.08128 .30902 L
.08255 .30902 L
.08327 .30902 L
.08394 .15451 L
.08465 .15451 L
.08542 .15451 L
.08852 .15451 L
.09396 .15451 L
.10458 .15451 L
.1458 .15451 L
.18551 .15451 L
.22371 .15451 L
.26435 .15451 L
.28315 .15451 L
.30348 .15451 L
.3089 .15451 L
.31463 .15451 L
.31699 .15451 L
.31952 .15451 L
.32027 .15451 L
.32098 .15451 L
.32161 .15463 L
.3223 .15507 L
.32489 .15674 L
.34506 .16911 L
.38585 .19113 L
.42511 .20906 L
.46286 .22371 L
.47308 .2273 L
.48384 .23091 L
.49302 .23386 L
.49554 .23465 L
.49692 .23508 L
.49822 .23549 L
.49944 .23586 L
.50076 .2358 L
.50196 .23543 L
.50307 .23509 L
.54175 .22204 L
.58116 .20639 L
.61904 .18869 L
.64012 .17755 L
.65938 .16647 L
.66891 .16065 L
Mistroke
.67152 .15902 L
.6743 .15725 L
.67565 .15639 L
.67692 .15557 L
.67807 .15484 L
.6793 .30902 L
.68048 .30902 L
.68159 .30902 L
.68409 .30902 L
.68915 .30902 L
.69821 .30902 L
.73717 .30902 L
.77858 .30902 L
.81848 .30902 L
.85686 .30902 L
.89769 .30902 L
.93701 .30902 L
.97482 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Goooln06Ko6?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000:_ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`0koooo00<0I_oooooo
ool03oooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Xoooo0`1V
of?oool002Goool00`1Vooooooooo`0loooo0P1VoaGoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool09oooo`80I_l00oooo`1Vooooo`1Roooo000Uoooo00<0I_oooooo
ool0?_ooo`80I_lDoooo0P0000[oool300001?ooo`030000oooooooo02Goool206Ko0oooo`0306Ko
oooooooo067oool002Goool00`1Vooooooooo`10oooo00<0I_ooooooool09?ooo`80000Toooo0P1V
o`Goool00`1Vooooooooo`1Qoooo000Uoooo00<0I_ooooooool0@Oooo`80I_lToooo00<0003ooooo
ool08Oooo`80I_l7oooo00<0I_ooooooool0HOooo`009Oooo`0306Kooooooooo04?oool206Ko8_oo
o`030000oooooooo023oool00`1Vooooooooo`07oooo00<0I_ooooooool0HOooo`009Oooo`0306Ko
oooooooo04Goool00`1Vooooooooo`0Ooooo00<0003oooooool07_ooo`80I_l:oooo00<0I_oooooo
ool0HOooo`009Oooo`0306Kooooooooo04Koool206Ko7oooo`80000Moooo0P1Vo`coool00`1Voooo
ooooo`1Qoooo000Uoooo00<0I_ooooooool0B?ooo`80I_lMoooo00<0003oooooool06_ooo`80I_l>
oooo00<0I_ooooooool0HOooo`009Oooo`0306Kooooooooo04[oool206Ko6oooo`030000oooooooo
01Soool206Ko4?ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`1<oooo0P1VoaWoool0
0`000?ooooooo`0Foooo0P1Voa;oool00`1Vooooooooo`1Qoooo000Uoooo00<0I_ooooooool0C_oo
o`<0I_lFoooo0P0001Goool206Ko5?ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`1A
oooo0P1VoaCoool00`000?ooooooo`0Aoooo0`1VoaKoool00`1Vooooooooo`1Qoooo000Uoooo00<0
I_ooooooool0Doooo`<0I_lAoooo00<0003oooooool03oooo`80I_lIoooo00<0I_ooooooool0HOoo
o`009Oooo`0306Kooooooooo05Koool206Ko3oooo`030000oooooooo00coool306Ko6oooo`0306Ko
oooooooo067oool002Goool00`1Vooooooooo`1Hoooo0`1Vo`coool200002oooo`80I_lNoooo00<0
I_ooooooool0HOooo`009Oooo`0306Kooooooooo05_oool206Ko2_ooo`030000oooooooo00Ooool3
06Ko8?ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`1>oooo0P0000Coool200000ooo
o`@0000206Ko00?oool0000000001Oooo`030000oooooooo00Goool206Ko8oooo`0306Kooooooooo
067oool002Goool00`1Vooooooooo`1=oooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`04000006Ko06Ko00001?ooo`030000oooooooo00;oool306Ko9Oooo`0306Kooooooooo067oool0
02Goool00`1Vooooooooo`1=oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`050000
06Ko06Ko06Kooooo00<0000206Ko:?ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`17
oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Coool0101Vo`00
001Vo`1Vob[oool00`1Vooooooooo`1Qoooo000Uoooo00<0I_ooooooool0COooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0Zoooo00<0
I_ooooooool0HOooo`009Oooo`0306Kooooooooo04koool200002_ooo`800004oooo0`0000Coool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`009Oooo`0306Kooooooooo06Ooool20000:ooo
o`0306Kooooooooo067oool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Ko
oooooooo067oool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo
067oool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo067oool0
01Woool300002Oooo`0306Kooooooooo02coool40000=oooo`80000[oooo00<0I_ooooooool02_oo
o`@0000koooo0`0001Goool001[oool00`000?ooooooo`08oooo00<0I_ooooooool0;?ooo`030000
oooooooo03Soool00`000?ooooooo`0Zoooo00<0I_ooooooool02_ooo`030000oooooooo03goool0
0`000?ooooooo`0Doooo000Goooo1@0000Woool00`1Vooooooooo`0]oooo00<0003oooooool0=ooo
o`030000oooooooo02[oool00`1Vooooooooo`0;oooo00<0003oooooool0>Oooo`D0000Eoooo000A
oooo100000;oool010000?ooooooo`0000[oool00`1Vooooooooo`0Voooo100000Coool00`000?oo
ooooo`0foooo00<0003oooooool0:_ooo`0306Kooooooooo00coool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo00<0003oool000002_ooo`0306Kooooooooo02coool010000?oo
ooooo`0003Ooool20000:oooo`0306Kooooooooo00[oool010000?ooooooo`0003[oool00`000?oo
o`00000Foooo000Ioooo0P0000[oool00`1Vooooooooo`0]oooo0P0003Soool00`000?ooooooo`0Z
oooo00<0I_ooooooool02oooo`80000loooo0P0001Koool002Goool00`1Vooooooooo`1Woooo00<0
003oooooool0:_ooo`0306Kooooooooo067oool002Goool00`1Vooooooooo`1Woooo0P0002_oool0
0`1Vooooooooo`1Qoooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Voooo
ooooo`1Qoooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`1Q
oooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`1Qoooo000@
ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000oooooooo02_oool0
0ol0VOooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo06Ooool00ol0VOoo
ooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Iooo
o`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0T
oooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?
oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo
06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool007Koool200001?ooo`800003oooo100000?oool2
00001Oooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo001eoooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo06Ooool00ol0VOoo
ooooo`0Toooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo
00;oool30000Ioooo`03o`2Ioooooooo02Coool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00MOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00M_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool0
0ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOoo
ooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Iooo
o`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0T
oooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool007coool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Noooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo001k
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Woooo00?o09Woooooool09?oo
o`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0Iooo
o`03o`2Ioooooooo02Coool007coool200002_ooo`<00004oooo00<0003oooooool0Ioooo`03o`2I
oooooooo02Coool008ooool20000J?ooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?
oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo
06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool0
0ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool007Koool2
00001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Ioooo`03o`2I
oooooooo02Coool007Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo001eoooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000Ioooo`03o`2Ioooooooo
02Coool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005oooo00<0003ooooo
ool0Ioooo`03o`2Ioooooooo02Coool007Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool007Koool2
00002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0T
oooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1W
oooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000
oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo
02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`80001Xoooo00?o
09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool0
0ol0VOooooooo`0Toooo0027oooo1@0000?oool00`000?ooooooo`1Woooo00?o09Woooooool09?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00ROoo
o`030000oooooooo00?oool30000Ioooo`03o`2Ioooooooo02Coool008Woool00`000?ooooooo`2D
oooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00_oool00`000?ooooooo`02oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.90802 .30902 L
.91765 .30902 L
.92014 .30902 L
.92136 .30902 L
.9225 .30902 L
s
.9225 .30902 m
.92263 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.06747 .30902 L
.07024 .30902 L
.07286 .30902 L
.07529 .30902 L
.07596 .30902 L
.07666 .30902 L
.07793 .15451 L
.07907 .15451 L
.08013 .15451 L
.08255 .15451 L
.10458 .15451 L
.14335 .15451 L
.18458 .15451 L
.22428 .15451 L
.26248 .15451 L
.28379 .15451 L
.30312 .15451 L
.30783 .15451 L
.3128 .15451 L
.31406 .15451 L
.31475 .15451 L
.3154 .15451 L
.31617 .15496 L
.31688 .15541 L
.31825 .1563 L
.32327 .15949 L
.34225 .17094 L
.38058 .19147 L
.42136 .20998 L
.46063 .22504 L
.48032 .2317 L
.48895 .23445 L
.49383 .23597 L
.49617 .23668 L
.49838 .23735 L
.49953 .23769 L
.50077 .2376 L
.5019 .23726 L
.50294 .23695 L
.50781 .23546 L
.51773 .23233 L
.53858 .22531 L
.57799 .21025 L
.61587 .19321 L
.63695 .18249 L
.65621 .17183 L
.66574 .16623 L
Mistroke
.67077 .16318 L
.67613 .15986 L
.67878 .15819 L
.68128 .1566 L
.68237 .1559 L
.68352 .15516 L
.68478 .30902 L
.68594 .30902 L
.69504 .30902 L
.73306 .30902 L
.77354 .30902 L
.8125 .30902 L
.85391 .30902 L
.89381 .30902 L
.93219 .30902 L
.97303 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002Coooln06Ko6Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000;?ooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`0joooo00<0I_oooooo
ool04Oooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Zoooo0`1V
of7oool002Coool00`1Vooooooooo`0koooo0P1VoaOoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0:?ooo`<0I_l00oooo`1Vooooo`1Poooo000Toooo00<0I_oooooo
ool0?Oooo`80I_lFoooo0P0000[oool300001?ooo`030000oooooooo02Ooool00`1Vooooooooo`02
oooo00<0I_ooooooool0Goooo`009?ooo`0306Kooooooooo03ooool206Ko9oooo`80000Woooo00<0
I_ooooooool00oooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`11oooo0P1VobGoool0
0`000?ooooooo`0Toooo0P1Vo`Koool00`1Vooooooooo`1Ooooo000Toooo00<0I_ooooooool0@ooo
o`80I_lSoooo00<0003oooooool08_ooo`80I_l8oooo00<0I_ooooooool0Goooo`009?ooo`0306Ko
oooooooo04Goool00`1Vooooooooo`0Poooo00<0003oooooool08?ooo`80I_l:oooo00<0I_oooooo
ool0Goooo`009?ooo`0306Kooooooooo04Koool206Ko8?ooo`80000Ooooo0P1Vo`coool00`1Voooo
ooooo`1Ooooo000Toooo00<0I_ooooooool0B?ooo`80I_lNoooo00<0003oooooool07?ooo`80I_l>
oooo00<0I_ooooooool0Goooo`009?ooo`0306Kooooooooo04[oool206Ko7?ooo`030000oooooooo
01Woool306Ko4?ooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1<oooo0P1Voa[oool0
0`000?ooooooo`0Goooo0P1Voa?oool00`1Vooooooooo`1Ooooo000Toooo00<0I_ooooooool0C_oo
o`<0I_lGoooo0P0001Koool206Ko5Oooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1A
oooo0P1VoaGoool00`000?ooooooo`0Coooo0P1VoaOoool00`1Vooooooooo`1Ooooo000Toooo00<0
I_ooooooool0Doooo`<0I_lBoooo00<0003oooooool04?ooo`<0I_lIoooo00<0I_ooooooool0Gooo
o`009?ooo`0306Kooooooooo05Koool206Ko4?ooo`030000oooooooo00koool206Ko7?ooo`0306Ko
oooooooo05ooool002Coool00`1Vooooooooo`1Hoooo0`1Vo`goool200003?ooo`<0I_lNoooo00<0
I_ooooooool0Goooo`009?ooo`0306Kooooooooo05_oool206Ko2oooo`030000oooooooo00Woool2
06Ko8Oooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1?oooo0P0000Coool200000ooo
o`@0000206Ko00?oool0000000001Oooo`030000oooooooo00Koool306Ko8oooo`0306Kooooooooo
05ooool002Coool00`1Vooooooooo`1>oooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`04000006Kooooo00001?ooo`030000oooooooo00?oool306Ko9_ooo`0306Kooooooooo05ooool0
02Coool00`1Vooooooooo`1>oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`0306Ko
0000oooo00?oool3000000?oool0I_l0I_l0:Oooo`0306Kooooooooo05ooool002Coool00`1Voooo
ooooo`18oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P000003oooo
06Ko06Ko0080I_l01000001Vo`1Vo`1Vob_oool00`1Vooooooooo`1Ooooo000Toooo00<0I_oooooo
ool0C_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`009?ooo`0306Kooooooooo04ooool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`009?ooo`0306Ko
oooooooo06Soool20000;Oooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1Xoooo00<0
003oooooool0;?ooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1Xoooo00<0003ooooo
ool0;?ooo`0306Kooooooooo05ooool002Coool00`1Vooooooooo`1Xoooo00<0003oooooool0;?oo
o`0306Kooooooooo05ooool001Woool300002?ooo`0306Kooooooooo02goool40000=oooo`80000]
oooo00<0I_ooooooool02?ooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`07oooo00<0
I_ooooooool0;Oooo`030000oooooooo03Soool00`000?ooooooo`0/oooo00<0I_ooooooool02?oo
o`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0000Soool00`1Vooooooooo`0^
oooo00<0003oooooool0=oooo`030000oooooooo02coool00`1Vooooooooo`09oooo00<0003ooooo
ool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0000Woool00`1Vooooooooo`0W
oooo100000Coool00`000?ooooooo`0foooo00<0003oooooool0;?ooo`0306Kooooooooo00[oool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000002Oooo`0306Ko
oooooooo02goool010000?ooooooo`0003Ooool20000;Oooo`0306Kooooooooo00Soool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0000Woool00`1Vooooooooo`0^oooo0P00
03Soool00`000?ooooooo`0/oooo00<0I_ooooooool02Oooo`80000loooo0P0001Koool002Coool0
0`1Vooooooooo`1Xoooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool002Coool00`1Voooo
ooooo`1Xoooo0P0002goool00`1Vooooooooo`1Ooooo000Toooo00<0I_ooooooool0J?ooo`030000
oooooooo02coool00`1Vooooooooo`1Ooooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo
02coool00`1Vooooooooo`1Ooooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo02coool0
0`1Vooooooooo`1Ooooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?l0VOooo`0<oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Ooo
o`030000oooooooo02coool00ol0VOooooooo`0;oooo00<0003oooooool05Oooo`00Soooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?
oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P00
06Woool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOoo
ooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool007Koool200001?oo
o`800003oooo100000?oool200001Oooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo001e
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo001eoooo00@0003oooooool00009oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool30000J?ooo`03o`2Ioooooooo02?oool007Goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Xoooo00?o09Wooooo
ool08oooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00M_ooo`80000:oooo0P0000Coool3
00001?ooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOoo
ooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2I
oooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?
oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P00
06Woool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool0
07coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001X
oooo00?o09Woooooool08oooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool007coool200002_ooo`<00004oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOoo
ooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2I
oooooooo02?oool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool007Goool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool3
0000J?ooo`03o`2Ioooooooo02?oool007Goool010000?ooooooo`0000_oool010000?oooooooooo
o`800005oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool007Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0J?ooo`03o`2I
oooooooo02?oool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`80001Yoooo00?o09Wooooo
ool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOoo
ooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Sooo
o`030000oooooooo06Soool00ol0VOooooooo`0Soooo0027oooo1@0000?oool00`000?ooooooo`1X
oooo00?o09Woooooool08oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00ROooo`030000oooooooo00?oool30000J?ooo`03o`2Ioooooooo02?oool0
08Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003oooooool02oooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91765 .30902 L
.9225 .30902 L
.92516 .30902 L
.92648 .30902 L
.92769 .30902 L
.92838 .30902 L
s
.92838 .30902 m
.92846 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.06244 .30902 L
.06525 .30902 L
.0679 .30902 L
.06905 .30902 L
.07027 .30902 L
.07091 .30902 L
.07162 .15451 L
.07286 .15451 L
.08255 .15451 L
.10458 .15451 L
.14487 .15451 L
.18364 .15451 L
.22486 .15451 L
.26457 .15451 L
.2846 .15451 L
.29333 .15451 L
.30277 .15451 L
.30533 .15451 L
.30673 .15451 L
.30804 .15451 L
.30916 .15451 L
.31036 .15505 L
.31104 .15549 L
.31168 .1559 L
.3129 .15668 L
.32244 .16267 L
.34341 .17501 L
.38174 .19493 L
.42252 .21289 L
.46179 .22751 L
.48148 .23398 L
.49011 .23665 L
.49499 .23812 L
.49733 .23881 L
.49848 .23915 L
.49954 .23946 L
.50068 .23939 L
.50193 .23903 L
.5041 .23839 L
.50896 .23693 L
.51889 .23386 L
.53974 .22698 L
.57915 .21222 L
.61703 .19552 L
.63811 .18501 L
.65737 .17456 L
.6669 .16907 L
Mistroke
.67729 .16283 L
.68204 .15989 L
.68465 .15824 L
.6871 .15668 L
.68822 .15597 L
.68939 .15521 L
.69069 .30902 L
.69187 .30902 L
.6962 .30902 L
.73422 .30902 L
.7747 .30902 L
.81366 .30902 L
.85507 .30902 L
.89497 .30902 L
.93335 .30902 L
.97418 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool002;oooln06Ko6oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000;Oooo`0306Kooooooooo05koool002;oool00`1Vooooooooo`0joooo0P1VoaCoool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;?ooo`80I_mPoooo000R
oooo00<0I_ooooooool0??ooo`80I_lHoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02[oool206Ko00?oool0I_ooool0Goooo`008_ooo`0306Kooooooooo03koool2
06Ko5oooo`80000:oooo0`0000Coool00`000?ooooooo`0Xoooo0P1Vo`?oool00`1Vooooooooo`1N
oooo000Roooo00<0I_ooooooool0@?ooo`80I_lXoooo0P0002Soool00`1Vooooooooo`03oooo00<0
I_ooooooool0G_ooo`008_ooo`0306Kooooooooo04;oool00`1Vooooooooo`0Uoooo00<0003ooooo
ool09Oooo`80I_l6oooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo04?oool206Ko9Ooo
o`030000oooooooo02?oool206Ko2?ooo`0306Kooooooooo05koool002;oool00`1Vooooooooo`15
oooo0P1Vob?oool00`000?ooooooo`0Qoooo0P1Vo`[oool00`1Vooooooooo`1Noooo000Roooo00<0
I_ooooooool0Aoooo`80I_lQoooo0P00027oool00`1Vooooooooo`0:oooo00<0I_ooooooool0G_oo
o`008_ooo`0306Kooooooooo04Woool206Ko7oooo`030000oooooooo01koool206Ko3Oooo`0306Ko
oooooooo05koool002;oool00`1Vooooooooo`1;oooo0P1Voagoool00`000?ooooooo`0Loooo0P1V
o`ooool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0COooo`80I_lKoooo00<0003ooooo
ool06_ooo`80I_lAoooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo04ooool206Ko6Ooo
o`80000Ioooo0P1Voa?oool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0DOooo`80I_lG
oooo00<0003oooooool05Oooo`<0I_lEoooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo
05?oool206Ko5Oooo`030000oooooooo01?oool206Ko6?ooo`0306Kooooooooo05koool002;oool0
0`1Vooooooooo`1Eoooo0`1Voa;oool00`000?ooooooo`0@oooo0`1Voa[oool00`1Vooooooooo`1N
oooo000Roooo00<0I_ooooooool0F?ooo`80I_l@oooo0P0000ooool206Ko7Oooo`0306Kooooooooo
05koool002;oool00`1Vooooooooo`1Joooo0`1Vo`goool00`000?ooooooo`0;oooo0`1Voaooool0
0`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0DOooo`800004oooo0P0000?oool400000ooo
o`800005oooo00<0003oooooool02Oooo`80I_lRoooo00<0I_ooooooool0G_ooo`008_ooo`0306Ko
oooooooo053oool010000?ooooooo`0000Soool00`000?ooooooo`0306Ko00@0003oooooool00004
oooo00<0003oooooool01Oooo`@0I_lToooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo
053oool010000?ooooooo`0000Woool00`000?ooooooo`03oooo0P1Vo`030000oooooooo00;oool3
000000?oool0I_l0I_l00P1VobSoool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0B_oo
o`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`8000000oooo`1Vo`1Vo`02
06Ko00@0003oool0I_l0I_l/oooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo053oool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0I_l00000
I_l0;_ooo`0306Kooooooooo05koool002;oool00`1Vooooooooo`1Aoooo0P0000[oool200001?oo
o`<00004oooo00<0003oooooool0;Oooo`0306Kooooooooo05koool002;oool00`1Vooooooooo`1Z
oooo0P0002koool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo
02goool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool0
0`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool00`1Voooo
ooooo`1Noooo000Ioooo0`0000Koool00`1Vooooooooo`0_oooo100003Ooool20000;_ooo`0306Ko
oooooooo00Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool01Oooo`0306Kooooooooo
02ooool00`000?ooooooo`0hoooo00<0003oooooool0;Oooo`0306Kooooooooo00Ooool00`000?oo
ooooo`0moooo00<0003oooooool05?ooo`005oooo`D00006oooo00<0I_ooooooool0<?ooo`030000
oooooooo03Ooool00`000?ooooooo`0]oooo00<0I_ooooooool02?ooo`030000oooooooo03Woool5
00005Oooo`004Oooo`@00002oooo00@0003oooooool00007oooo00<0I_ooooooool0:Oooo`@00004
oooo00<0003oooooool0=_ooo`030000oooooooo02goool00`1Vooooooooo`09oooo00<0003ooooo
ool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000000Ooool00`1Vooooooooo`0_
oooo00@0003oooooool0000goooo0P0002koool00`1Vooooooooo`07oooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`800007oooo00<0I_ooooooool0<?ooo`80000hoooo00<0
003oooooool0;Oooo`0306Kooooooooo00Soool20000??ooo`80000Foooo000Roooo00<0I_oooooo
ool0J_ooo`030000oooooooo02goool00`1Vooooooooo`1Noooo000Roooo00<0I_ooooooool0J_oo
o`80000^oooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]
oooo00<0I_ooooooool0G_ooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0
I_ooooooool0G_ooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0I_oooooo
ool0G_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00@0003ooooooooo09T;oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000
oooooooo02koool00ol0VOooooooo`09oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool0
0ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000J_ooo`03o`2Ioooooooo027oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1Zoooo00?o09Woooooool08Ooo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool0
0ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Zoooo00?o
09Woooooool08Oooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool007coool200002_ooo`<00004oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo027oool008ooool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000J_oo
o`03o`2Ioooooooo027oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`80001[oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool0
0ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool0
0`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`80001[oooo00?o09Woooooool08Ooo
o`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`80001[oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`80001[oooo00?o09Woooooool08Oooo`00Soooo`030000
oooooooo06[oool00ol0VOooooooo`0Qoooo0027oooo1@0000?oool00`000?ooooooo`1Zoooo00?o
09Woooooool08Oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00ROooo`030000oooooooo00?oool30000J_ooo`03o`2Ioooooooo027oool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?oo
ooooo`07oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91765 .30902 L
.92769 .30902 L
.93044 .30902 L
.93196 .30902 L
.9327 .30902 L
.93339 .30902 L
.93404 .30902 L
s
.93404 .30902 m
.93411 .61803 L
s
0 .4 1 r
.02381 .30902 m
.04262 .30902 L
.0522 .30902 L
.05746 .30902 L
.06244 .30902 L
.06371 .30902 L
.06441 .30902 L
.06506 .30902 L
.06576 .15451 L
.06653 .15451 L
.0679 .15451 L
.07286 .15451 L
.08255 .15451 L
.10458 .15451 L
.14335 .15451 L
.18458 .15451 L
.22428 .15451 L
.26248 .15451 L
.28379 .15451 L
.29386 .15451 L
.29828 .15451 L
.30078 .15451 L
.30201 .15451 L
.30312 .15451 L
.30429 .15497 L
.30539 .15569 L
.30783 .15725 L
.3128 .16038 L
.32327 .16678 L
.34225 .17768 L
.38058 .19721 L
.42136 .21481 L
.46063 .22913 L
.48032 .23547 L
.48895 .23809 L
.49383 .23953 L
.49617 .24021 L
.49838 .24084 L
.49953 .24117 L
.50077 .24109 L
.5019 .24076 L
.50294 .24047 L
.50781 .23905 L
.51773 .23607 L
.53858 .22939 L
.57799 .21506 L
.61587 .19886 L
.65621 .17852 L
.67479 .16793 L
.6846 .162 L
Mistroke
.68998 .15864 L
.69261 .15696 L
.69504 .15541 L
.69574 .15496 L
.69639 .15454 L
.69707 .30902 L
.69781 .30902 L
.7008 .30902 L
.70603 .30902 L
.71621 .30902 L
.73632 .30902 L
.77528 .30902 L
.81669 .30902 L
.85659 .30902 L
.89497 .30902 L
.9358 .30902 L
.97512 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool0027ooolm06Ko7Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000;_ooo`80I_mNoooo000Qoooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Coool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;Oooo`<0I_mNoooo000Q
oooo00<0I_ooooooool0>oooo`80I_lJoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02coool0101Vooooooooo`1Voekoool0027oool00`1Vooooooooo`0moooo0P1V
oaWoool200002_ooo`<00004oooo00<0003oooooool0:_ooo`80I_l3oooo00<0I_ooooooool0G?oo
o`008Oooo`0306Kooooooooo03ooool206Ko:_ooo`80000Zoooo00<0I_ooooooool00oooo`0306Ko
oooooooo05coool0027oool00`1Vooooooooo`11oooo0P1VobSoool00`000?ooooooo`0Woooo0P1V
o`Koool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0@oooo`0306Kooooooooo02Goool0
0`000?ooooooo`0Toooo0`1Vo`Soool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0A?oo
o`80I_lUoooo00<0003oooooool08_ooo`80I_l;oooo00<0I_ooooooool0G?ooo`008Oooo`0306Ko
oooooooo04Koool206Ko8oooo`80000Qoooo0P1Vo`goool00`1Vooooooooo`1Loooo000Qoooo00<0
I_ooooooool0B?ooo`80I_lQoooo00<0003oooooool07_ooo`80I_l?oooo00<0I_ooooooool0G?oo
o`008Oooo`0306Kooooooooo04[oool206Ko7oooo`030000oooooooo01coool206Ko4Oooo`0306Ko
oooooooo05coool0027oool00`1Vooooooooo`1<oooo0P1Voagoool00`000?ooooooo`0Joooo0P1V
oa?oool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0C_ooo`80I_lKoooo0P0001Woool2
06Ko5Oooo`0306Kooooooooo05coool0027oool00`1Vooooooooo`1@oooo0P1VoaWoool00`000?oo
ooooo`0Foooo0P1VoaOoool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0D_ooo`80I_lG
oooo00<0003oooooool05?ooo`80I_lIoooo00<0I_ooooooool0G?ooo`008Oooo`0306Kooooooooo
05Coool206Ko5Oooo`030000oooooooo01;oool206Ko6oooo`0306Kooooooooo05coool0027oool0
0`1Vooooooooo`1Foooo0`1Voa;oool200004Oooo`80I_lMoooo00<0I_ooooooool0G?ooo`008Ooo
o`0306Kooooooooo05Woool306Ko3oooo`030000oooooooo00goool306Ko7oooo`0306Kooooooooo
05coool0027oool00`1Vooooooooo`1Boooo0P0000Coool200000_ooo`0306Ko0000000000800003
oooo0P0000Goool00`000?ooooooo`09oooo101Vob;oool00`1Vooooooooo`1Loooo000Qoooo00<0
I_ooooooool0DOooo`040000oooooooo00002?ooo`030000oooooooo00<0I_l010000?ooooooo`00
00Coool00`000?ooooooo`06oooo0`1VobKoool00`1Vooooooooo`1Loooo000Qoooo00<0I_oooooo
ool0DOooo`040000oooooooo00002Oooo`030000oooooooo00;oool206Ko00?oool0003oool00ooo
o`<00003oooo0`1VobWoool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0Boooo`@00002
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`80000306Ko0_ooo`040000oooooooo
oooo0P1Vobcoool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0DOooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00;oool206Ko00@00000I_l0I_l0I_l^
oooo00<0I_ooooooool0G?ooo`008Oooo`0306Kooooooooo05;oool200002_ooo`800004oooo0`00
00Coool00`000?ooooooo`0_oooo00<0I_ooooooool0G?ooo`008Oooo`0306Kooooooooo06_oool2
0000<?ooo`0306Kooooooooo05coool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;ooo
o`0306Kooooooooo05coool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;oooo`0306Ko
oooooooo05coool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;oooo`0306Kooooooooo
05coool001Woool300001Oooo`0306Kooooooooo033oool40000=oooo`80000`oooo00<0I_oooooo
ool01Oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`04oooo00<0I_ooooooool0<?oo
o`030000oooooooo03Soool00`000?ooooooo`0_oooo00<0I_ooooooool01Oooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0000Goool00`1Vooooooooo`0aoooo00<0003ooooo
ool0=oooo`030000oooooooo02ooool00`1Vooooooooo`06oooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`0000Koool00`1Vooooooooo`0Zoooo100000Coool0
0`000?ooooooo`0foooo00<0003oooooool0;oooo`0306Kooooooooo00Ooool00`000?ooooooo`0h
oooo00@0003oooooool0000Foooo000Hoooo00<0003oool000001_ooo`0306Kooooooooo033oool0
10000?ooooooo`0003Ooool20000<?ooo`0306Kooooooooo00Goool010000?ooooooo`0003[oool0
0`000?ooo`00000Foooo000Ioooo0P0000Koool00`1Vooooooooo`0aoooo0P0003Soool00`000?oo
ooooo`0_oooo00<0I_ooooooool01_ooo`80000loooo0P0001Koool0027oool00`1Vooooooooo`1[
oooo00<0003oooooool0;oooo`0306Kooooooooo05coool0027oool00`1Vooooooooo`1[oooo0P00
033oool00`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool0
0`1Vooooooooo`1Loooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Voooo
ooooo`1Loooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Vooooooooo`1L
oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool01@000?ooooooooooool0V@0:oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0003oooooool0>Oooo`030000
oooooooo02ooool00ol0VOooooooo`08oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0
003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Wooooo
ool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool0
0ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool0
0`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOoo
ooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Jooo
o`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Sooo
o`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0P
oooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool007Koool200001?ooo`800003
oooo100000?oool200001Oooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo001eoooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo
06_oool00ol0VOooooooo`0Poooo001eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool30000Joooo`03o`2Ioooooooo023oool007Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1[oooo00?o09Woooooool08?oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00M_ooo`80000:oooo0P0000Coool300001?oo
o`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0P
oooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[
oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?
oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo
023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo
06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0
003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Wooooo
ool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool0
0ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06_oool00ol0VOoo
ooooo`0Poooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001[oooo00?o
09Woooooool08?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Jooo
o`03o`2Ioooooooo023oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0Joooo`03o`2Ioooooooo023oool007coool200002_ooo`<00004oooo00<0003ooooo
ool0Joooo`03o`2Ioooooooo023oool008ooool20000K?ooo`03o`2Ioooooooo023oool008ooool0
0`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOoo
ooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Jooo
o`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Sooo
o`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0P
oooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[
oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?
oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo
023oool007Koool200001?ooo`800005oooo00<0003oooooool00_ooo`800005oooo00<0003ooooo
ool0Joooo`03o`2Ioooooooo023oool007Goool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00;oool30000Jooo
o`03o`2Ioooooooo023oool007Goool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool007Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Joooo`03o`2Ioooooooo
023oool007Koool200002Oooo`@00003oooo0`0000Coool00`000?ooooooo`1[oooo00?o09Wooooo
ool08?ooo`00Soooo`80001/oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool0
0ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool0
0`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`80001/oooo00?o09Woooooool08?oo
o`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Jooo
o`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Sooo
o`80001/oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0P
oooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[
oooo00?o09Woooooool08?ooo`00Soooo`80001/oooo00?o09Woooooool08?ooo`00Soooo`030000
oooooooo06_oool00ol0VOooooooo`0Poooo0027oooo1@0000?oool00`000?ooooooo`1[oooo00?o
09Woooooool08?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1[oooo00?o09Wooooo
ool08?ooo`00ROooo`030000oooooooo00?oool30000Joooo`03o`2Ioooooooo023oool008Woool0
0`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo0`0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93331 .30902 L
.93612 .30902 L
.93735 .30902 L
.93871 .30902 L
.93993 .30902 L
s
.93993 .30902 m
.94004 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.05288 .30902 L
.05546 .30902 L
.05672 .30902 L
.05789 .30902 L
.05895 .30902 L
.06007 .15451 L
.0612 .15451 L
.06244 .15451 L
.10458 .15451 L
.14487 .15451 L
.18364 .15451 L
.22486 .15451 L
.24546 .15451 L
.26457 .15451 L
.28306 .15451 L
.28838 .15451 L
.29099 .15451 L
.29339 .15451 L
.29558 .15451 L
.29669 .15451 L
.2979 .15469 L
.29911 .15547 L
.30041 .15631 L
.30277 .15781 L
.34413 .18192 L
.38397 .20151 L
.4223 .21749 L
.46308 .2319 L
.47283 .23499 L
.48334 .23819 L
.49242 .24084 L
.4949 .24155 L
.49756 .2423 L
.49885 .24266 L
.50007 .24296 L
.50116 .24265 L
.50235 .24232 L
.51194 .23958 L
.52204 .23657 L
.5401 .23086 L
.58102 .21621 L
.62042 .19951 L
.65831 .18062 L
.67939 .16873 L
.68938 .16272 L
.69425 .1597 L
Mistroke
.69865 .15691 L
.69979 .15618 L
.70103 .15538 L
.70219 .15463 L
.70326 .30902 L
.70441 .30902 L
.70566 .30902 L
.70818 .30902 L
.71857 .30902 L
.73747 .30902 L
.77795 .30902 L
.81691 .30902 L
.85832 .30902 L
.89822 .30902 L
.9366 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001ooooln06Ko7_ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000<?ooo`0306Kooooooooo05_oool001ooool00`1Vooooooooo`0joooo0P1VoaOoool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;oooo`80I_mMoooo000O
oooo00<0I_ooooooool0??ooo`80I_lKoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02goool206Ko00?oool0I_ooool0G?ooo`007oooo`0306Kooooooooo03koool2
06Ko6_ooo`80000:oooo0`0000Coool00`000?ooooooo`0[oooo0P1Vo`?oool00`1Vooooooooo`1K
oooo000Ooooo00<0I_ooooooool0@?ooo`0306Kooooooooo02[oool20000:oooo`0306Kooooooooo
00?oool00`1Vooooooooo`1Koooo000Ooooo00<0I_ooooooool0@Oooo`80I_lZoooo00<0003ooooo
ool0:?ooo`80I_l6oooo00<0I_ooooooool0Foooo`007oooo`0306Kooooooooo04?oool206Ko:?oo
o`030000oooooooo02Koool206Ko2?ooo`0306Kooooooooo05_oool001ooool00`1Vooooooooo`15
oooo0P1VobKoool00`000?ooooooo`0Uoooo00<0I_ooooooool02?ooo`0306Kooooooooo05_oool0
01ooool00`1Vooooooooo`17oooo0P1VobCoool200009?ooo`80I_l;oooo00<0I_ooooooool0Fooo
o`007oooo`0306Kooooooooo04Woool206Ko8_ooo`030000oooooooo027oool206Ko3Oooo`0306Ko
oooooooo05_oool001ooool00`1Vooooooooo`1;oooo0P1Vob3oool00`000?ooooooo`0Ooooo0P1V
o`ooool00`1Vooooooooo`1Koooo000Ooooo00<0I_ooooooool0COooo`80I_lNoooo00<0003ooooo
ool07Oooo`80I_lAoooo00<0I_ooooooool0Foooo`007oooo`0306Kooooooooo04ooool306Ko6ooo
o`80000Loooo0P1Voa?oool00`1Vooooooooo`1Koooo000Ooooo00<0I_ooooooool0D_ooo`80I_lI
oooo00<0003oooooool06Oooo`80I_lEoooo00<0I_ooooooool0Foooo`007oooo`0306Kooooooooo
05Coool206Ko5oooo`030000oooooooo01Koool306Ko5oooo`0306Kooooooooo05_oool001ooool0
0`1Vooooooooo`1Foooo0P1VoaGoool00`000?ooooooo`0Doooo0P1Voa[oool00`1Vooooooooo`1K
oooo000Ooooo00<0I_ooooooool0F?ooo`<0I_lBoooo0P0001;oool306Ko7?ooo`0306Kooooooooo
05_oool001ooool00`1Vooooooooo`1Koooo0`1Vo`ooool00`000?ooooooo`0>oooo0`1Voaooool0
0`1Vooooooooo`1Koooo000Ooooo00<0I_ooooooool0E?ooo`800004oooo0P0000;oool00`1Vo`00
0000000200000oooo`800005oooo00<0003oooooool03?ooo`80I_lRoooo00<0I_ooooooool0Fooo
o`007oooo`0306Kooooooooo05?oool010000?ooooooo`0000Soool01000001Vo`1Vo`1Vo`;oool0
10000?ooooooo`0000Coool00`000?ooooooo`09oooo0`1VobCoool00`1Vooooooooo`1Koooo000O
oooo00<0I_ooooooool0Doooo`040000oooooooo00002Oooo`030000oooooooo0080I_l3oooo00<0
003oooooool00_ooo`<00006oooo0`1VobSoool00`1Vooooooooo`1Joooo000Ooooo00<0I_oooooo
ool0COooo`@00002oooo00@0003oooooool0000:oooo00D0003oooooooooool0I_l00P000080I_l3
oooo00<0003oooooool00_ooo`@0I_l[oooo00<0I_ooooooool0F_ooo`007oooo`0306Kooooooooo
05?oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool010000?ooooooooooo`<0I_l0
0`000?ooooooo`0206Ko;oooo`0306Kooooooooo05[oool001ooool00`1Vooooooooo`1Doooo0P00
00[oool200001?ooo`<00004oooo00<00000I_l0I_l0<Oooo`0306Kooooooooo05[oool001ooool0
0`1Vooooooooo`1]oooo0P0003;oool00`1Vooooooooo`1Joooo000Ooooo00<0I_ooooooool0KOoo
o`030000oooooooo037oool00`1Vooooooooo`1Joooo000Ooooo00<0I_ooooooool0KOooo`030000
oooooooo037oool00`1Vooooooooo`1Joooo000Ooooo00<0I_ooooooool0KOooo`030000oooooooo
037oool00`1Vooooooooo`1Joooo000Ioooo0`0000?oool00`1Vooooooooo`0boooo100003Ooool2
0000<_ooo`0306Kooooooooo00?oool40000>oooo`<0000Eoooo000Joooo00<0003oooooool00_oo
o`0306Kooooooooo03;oool00`000?ooooooo`0hoooo00<0003oooooool0<Oooo`0306Kooooooooo
00?oool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D00003oooo00<0I_oooooo
ool0<oooo`030000oooooooo03Ooool00`000?ooooooo`0aoooo00<0I_ooooooool01?ooo`030000
oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool00004oooo00<0I_oooooo
ool0;?ooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo037oool00`1Vooooooooo`05
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000000Coool0
0`1Vooooooooo`0boooo00@0003oooooool0000goooo0P0003;oool00`1Vooooooooo`03oooo00@0
003oooooool0000joooo00<0003oool000005_ooo`006Oooo`800004oooo00<0I_ooooooool0<ooo
o`80000hoooo00<0003oooooool0<Oooo`0306Kooooooooo00Coool20000??ooo`80000Foooo000O
oooo00<0I_ooooooool0KOooo`030000oooooooo037oool00`1Vooooooooo`1Joooo000Ooooo00<0
I_ooooooool0KOooo`80000boooo00<0I_ooooooool0F_ooo`007oooo`0306Kooooooooo06goool0
0`000?ooooooo`0aoooo00<0I_ooooooool0F_ooo`007oooo`0306Kooooooooo06goool00`000?oo
ooooo`0aoooo00<0I_ooooooool0F_ooo`007oooo`0306Kooooooooo06goool00`000?ooooooo`0a
oooo00<0I_ooooooool0F_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool00oooo`03o`2I
oooooooo00Koool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`000?ooooooo`0ioooo00<0003oooooool0<Oooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`0Eoooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_oo
o`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Sooo
o`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2I
oooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0KOoo
o`03o`2Ioooooooo01koool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool007Goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001]oooo00?o09Wooooo
ool07_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo06goool00ol0VOooooooo`0Noooo001eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo06goool00ol0VOooooooo`0Noooo001f
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOoo
ooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_oo
o`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Sooo
o`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2I
oooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo001koooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool007_oool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0006goool00ol0VOooooooo`0Noooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`80001^
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool20000K_ooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo01koool008ooool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00M_ooo`800004oooo0P0000Goool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00MOooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`<0001]oooo00?o09Woooooool07_ooo`00MOooo`040000oooooooo
00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1]oooo00?o09Woooooool07_oo
o`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool0
0`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00M_ooo`800009oooo100000?oool300001?oo
o`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo0P0006koool00ol0VOooooooo`0N
oooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0
003oooooool0KOooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Wooooo
ool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo0P0006koool0
0ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008Ooool5
00000oooo`030000oooooooo06goool00ol0VOooooooo`0Noooo0029oooo00<0003oooooool00ooo
o`030000oooooooo06goool00ol0VOooooooo`0Noooo0029oooo00<0003oooooool00oooo`<0001]
oooo00?o09Woooooool07_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?ooooooo`2D
oooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00_oool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOoo
o`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`800009oooo100000;oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93331 .30902 L
.93871 .30902 L
.94357 .30902 L
.9449 .30902 L
.94563 .30902 L
.94631 .30902 L
s
.94631 .30902 m
.94643 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.0503 .30902 L
.05164 .30902 L
.05288 .30902 L
.05405 .15451 L
.05528 .15451 L
.05789 .15451 L
.06244 .15451 L
.10458 .15451 L
.14241 .15451 L
.1827 .15451 L
.22147 .15451 L
.24118 .15451 L
.2627 .15451 L
.27267 .15451 L
.27814 .15451 L
.28329 .15451 L
.28811 .15451 L
.28943 .15451 L
.29015 .15451 L
.29082 .15451 L
.29201 .15473 L
.29332 .15558 L
.30241 .16132 L
.34132 .18359 L
.38268 .20359 L
.42252 .21984 L
.46085 .2331 L
.48024 .23903 L
.49053 .242 L
.49335 .24279 L
.49632 .24361 L
.49755 .24394 L
.49886 .2443 L
.49961 .2445 L
.5003 .24453 L
.50098 .24434 L
.50163 .24416 L
.52189 .23841 L
.5409 .23254 L
.57937 .21913 L
.62029 .20227 L
.65969 .18306 L
.67949 .17214 L
.69758 .16133 L
.70235 .15834 L
.70487 .15674 L
Mistroke
.70625 .15585 L
.70755 .15501 L
.70879 .30902 L
.70949 .30902 L
.71013 .30902 L
.71247 .30902 L
.71702 .30902 L
.73792 .30902 L
.77746 .30902 L
.81548 .30902 L
.85596 .30902 L
.89492 .30902 L
.93633 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001kooolm06Ko8?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000<_ooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`0joooo00<0I_oooooo
ool05oooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0`oooo0`1V
oe_oool001koool00`1Vooooooooo`0koooo0P1Voagoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0;oooo`0406Kooooooooo06KoFoooo`007_ooo`0306Kooooooooo
03goool206Ko7?ooo`80000:oooo0`0000Coool00`000?ooooooo`0]oooo0P1Vo`?oool00`1Voooo
ooooo`1Ioooo000Noooo00<0I_ooooooool0?oooo`80I_l]oooo0P0002coool206Ko1Oooo`0306Ko
oooooooo05Woool001koool00`1Vooooooooo`11oooo00<0I_ooooooool0:_ooo`030000oooooooo
02Woool206Ko1oooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`12oooo0P1Vob[oool0
0`000?ooooooo`0Woooo0P1Vo`Woool00`1Vooooooooo`1Ioooo000Noooo00<0I_ooooooool0A?oo
o`80I_lXoooo00<0003oooooool09Oooo`80I_l;oooo00<0I_ooooooool0FOooo`007_ooo`0306Ko
oooooooo04Koool00`1Vooooooooo`0Uoooo0P0002Coool206Ko3Oooo`0306Kooooooooo05Woool0
01koool00`1Vooooooooo`17oooo0P1VobGoool00`000?ooooooo`0Qoooo0P1Vo`ooool00`1Voooo
ooooo`1Ioooo000Noooo00<0I_ooooooool0BOooo`80I_lSoooo00<0003oooooool07oooo`80I_lA
oooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo04_oool206Ko8Oooo`030000oooooooo
01goool206Ko4oooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1=oooo0P1Voaooool2
00007?ooo`80I_lEoooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo04ooool306Ko7?oo
o`030000oooooooo01Woool206Ko5oooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1B
oooo0P1Voa[oool00`000?ooooooo`0Goooo0P1VoaWoool00`1Vooooooooo`1Ioooo000Noooo00<0
I_ooooooool0E?ooo`<0I_lGoooo00<0003oooooool05Oooo`80I_lKoooo00<0I_ooooooool0FOoo
o`007_ooo`0306Kooooooooo05Ooool206Ko5Oooo`80000Doooo0P1Voagoool00`1Vooooooooo`1I
oooo000Noooo00<0I_ooooooool0FOooo`<0I_lBoooo00<0003oooooool04?ooo`<0I_lOoooo00<0
I_ooooooool0FOooo`007_ooo`0306Kooooooooo05Goool200001?ooo`80000206Ko00?oool00000
00000P0000?oool200001Oooo`030000oooooooo00goool306Ko8_ooo`0306Kooooooooo05Woool0
01koool00`1Vooooooooo`1Doooo00@0003oooooool00007oooo00@0I_l00000I_l0I_l3oooo00@0
003oooooool00004oooo00<0003oooooool02Oooo`@0I_lUoooo00<0I_ooooooool0FOooo`007_oo
o`0306Kooooooooo05Coool010000?ooooooo`0000Woool00`000?ooo`1Vo`0206Ko0oooo`030000
oooooooo00;oool300001oooo`80I_lYoooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo
04koool400000_ooo`040000oooooooo00002_ooo`050000oooooooooooo06Ko00800005oooo00<0
003oooooool01Oooo`80I_l[oooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo05Coool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`00001Vo`1Vo`0306Ko00?oool0003o
ool00_ooo`@0I_l]oooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo05Goool200002_oo
o`800004oooo0`0000;oool206Ko00@00000I_l0I_l0I_laoooo00<0I_ooooooool0FOooo`007_oo
o`0306Kooooooooo06koool20000<oooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^
oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^oooo00<0
003oooooool0<_ooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^oooo00<0003ooooo
ool0<_ooo`0306Kooooooooo05Woool001Woool300000_ooo`0306Kooooooooo03?oool40000=ooo
o`80000coooo00<0I_ooooooool00_ooo`@0000koooo0`0001Goool001[oool01@000?oooooooooo
o`1Vo`0eoooo00<0003oooooool0>?ooo`030000oooooooo03;oool00`1Vooooooooo`02oooo00<0
003oooooool0?Oooo`030000oooooooo01Coool001Ooool500000_ooo`0306Kooooooooo03Coool0
0`000?ooooooo`0goooo00<0003oooooool0<_ooo`0306Kooooooooo00?oool00`000?ooooooo`0i
oooo1@0001Goool0017oool400000_ooo`040000oooooooo00000oooo`0306Kooooooooo02goool4
00001?ooo`030000oooooooo03Koool00`000?ooooooo`0boooo00<0I_ooooooool01?ooo`030000
oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`000003oooo00<0I_oooooo
ool0<oooo`040000oooooooo0000=oooo`80000coooo00<0I_ooooooool00_ooo`040000oooooooo
0000>_ooo`030000oooo000001Koool001Woool200000oooo`0306Kooooooooo03Coool20000>?oo
o`030000oooooooo03;oool00`1Vooooooooo`03oooo0P0003coool200005_ooo`007_ooo`0306Ko
oooooooo06koool00`000?ooooooo`0boooo00<0I_ooooooool0FOooo`007_ooo`0306Kooooooooo
06koool20000<oooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^oooo00<0003ooooo
ool0<_ooo`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_oo
o`0306Kooooooooo05Woool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_ooo`0306Ko
oooooooo05Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Coool00ol0VOooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
003oooooool0>Oooo`030000oooooooo03;oool00ol0VOooooooo`05oooo00<0003oooooool05Ooo
o`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOoo
ooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?oo
ooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0M
oooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2I
oooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000
oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?
oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o
09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P00
06ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool0
07Koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo06koool00ol0VOoo
ooooo`0Moooo001eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo06koool00ol0VOooooooo`0Moooo001eoooo00@0003oooooool00009
oooo00<0003oooooool01Oooo`030000oooooooo00;oool30000K_ooo`03o`2Ioooooooo01goool0
07Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1^
oooo00?o09Woooooool07Oooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00M_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P00
06ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool0
08ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool0
0ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?oooo00<0003ooooo
ool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Ooo
o`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOoo
ooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?oo
ooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0M
oooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2I
oooooooo01goool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`1^oooo00?o
09Woooooool07Oooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo06koool00ol0VOooooooo`0Moooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0001^oooo00?o09Woooooool07Oooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool007coool200002_oo
o`<00004oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool20000Koooo`03o`2I
oooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000
oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?
oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o
09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo0P00
06ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool0
08ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool0
0ol0VOooooooo`0Moooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?oooo00<0003ooooo
ool0K_ooo`03o`2Ioooooooo01goool007Koool200001?ooo`800005oooo00<0003oooooool00_oo
o`800005oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool007Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo06koool0
0ol0VOooooooo`0Moooo001eoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool30000K_ooo`03o`2Ioooooooo01goool007Goool010000?ooooooo`0000_oool0
10000?ooooooooooo`800005oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool007Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0K_ooo`03o`2Ioooooooo01goool007Koool200002Oooo`@00003oooo0`0000Coool00`000?oo
ooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`80001_oooo00?o09Woooooool07Oooo`00Sooo
o`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2I
oooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`80001_
oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?
oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o
09Woooooool07Oooo`00Soooo`80001_oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo
06koool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool0
08ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`80001_oooo00?o09Wooooo
ool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo0027oooo1@0000?oool0
0`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`1^oooo00?o09Woooooool07Oooo`00ROooo`030000oooooooo00?oool30000K_ooo`03o`2I
oooooooo01goool008Woool00`000?ooooooo`2Doooo0029oooo00<0003oooooool0U?ooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800005
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00_oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800009oooo100000?oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93871 .30902 L
.94392 .30902 L
.94648 .30902 L
.94885 .30902 L
.951 .30902 L
.95208 .30902 L
s
.95208 .30902 m
.9522 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04517 .30902 L
.04642 .30902 L
.04758 .30902 L
.04822 .15451 L
.04891 .15451 L
.05035 .15451 L
.05288 .15451 L
.06244 .15451 L
.10458 .15451 L
.14241 .15451 L
.1827 .15451 L
.22147 .15451 L
.24118 .15451 L
.2627 .15451 L
.27267 .15451 L
.27814 .15451 L
.28082 .15451 L
.28329 .15451 L
.2845 .15451 L
.28563 .15451 L
.28681 .15522 L
.28811 .15605 L
.29332 .15936 L
.30241 .16497 L
.34132 .18669 L
.38268 .20619 L
.42252 .22204 L
.46085 .23497 L
.48024 .24076 L
.49053 .24365 L
.49335 .24442 L
.49632 .24522 L
.49755 .24555 L
.49886 .2459 L
.49961 .2461 L
.5003 .24612 L
.50098 .24594 L
.50163 .24577 L
.52189 .24015 L
.5409 .23443 L
.57937 .22135 L
.62029 .20491 L
.65969 .18617 L
.67949 .17552 L
.69758 .16498 L
.70235 .16206 L
.70755 .15882 L
Mistroke
.70993 .15731 L
.71124 .15647 L
.71247 .15568 L
.71362 .15494 L
.71486 .30902 L
.71599 .30902 L
.71702 .30902 L
.73792 .30902 L
.77746 .30902 L
.81548 .30902 L
.85596 .30902 L
.89492 .30902 L
.93633 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001coooln06Ko8Oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000<oooo`0306Kooooooooo05Soool001coool00`1Vooooooooo`0joooo0`1VoaWoool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0<_ooo`80I_mJoooo000L
oooo00<0I_ooooooool0?Oooo`0306Kooooooooo01coool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0<?ooo`80I_l00oooo`1Vooooo`1Ioooo000Loooo00<0I_oooooo
ool0?_ooo`0306Kooooooooo01coool200002_ooo`<00004oooo00<0003oooooool0;oooo`0506Ko
oooooooooooo06Ko05[oool001coool00`1Vooooooooo`0ooooo0P1Vobooool20000;_ooo`80I_l4
oooo00<0I_ooooooool0F?ooo`007?ooo`0306Kooooooooo047oool206Ko;Oooo`030000oooooooo
02_oool206Ko1_ooo`0306Kooooooooo05Soool001coool00`1Vooooooooo`13oooo0P1Vob_oool0
0`000?ooooooo`0Yoooo0P1Vo`Soool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0AOoo
o`80I_lYoooo00<0003oooooool09oooo`80I_l:oooo00<0I_ooooooool0F?ooo`007?ooo`0306Ko
oooooooo04Ooool206Ko9oooo`80000Voooo0P1Vo`coool00`1Vooooooooo`1Hoooo000Loooo00<0
I_ooooooool0BOooo`80I_lUoooo00<0003oooooool08oooo`80I_l>oooo00<0I_ooooooool0F?oo
o`007?ooo`0306Kooooooooo04_oool206Ko8oooo`030000oooooooo027oool206Ko4?ooo`0306Ko
oooooooo05Soool001coool00`1Vooooooooo`1=oooo0P1Vob7oool00`000?ooooooo`0Ooooo0P1V
oa;oool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0Coooo`80I_lOoooo0P0001koool2
06Ko5?ooo`0306Kooooooooo05Soool001coool00`1Vooooooooo`1Aoooo0`1Voacoool00`000?oo
ooooo`0Joooo0`1VoaKoool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0E?ooo`80I_lJ
oooo00<0003oooooool06?ooo`80I_lIoooo00<0I_ooooooool0F?ooo`007?ooo`0306Kooooooooo
05Koool306Ko5oooo`030000oooooooo01Goool306Ko6oooo`0306Kooooooooo05Soool001coool0
0`1Vooooooooo`1Ioooo0P1VoaGoool200005?ooo`80I_lNoooo00<0I_ooooooool0F?ooo`007?oo
o`0306Kooooooooo05_oool306Ko4_ooo`030000oooooooo013oool306Ko8?ooo`0306Kooooooooo
05Soool001coool00`1Vooooooooo`1Goooo0P0000Coool2000000<0I_ooooooool0100000?oool2
00001Oooo`030000oooooooo00koool206Ko8oooo`0306Kooooooooo05Soool001coool00`1Voooo
ooooo`1Foooo00@0003oooooool00006oooo0P1Vo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0;oooo0`1VobGoool00`1Vooooooooo`1Hoooo000Loooo00<0I_oooooo
ool0E_ooo`040000oooooooo00002Oooo`03000006Kooooo00Goool00`000?ooooooo`02oooo0`00
00Woool206Ko:?ooo`0306Kooooooooo05Soool001coool00`1Vooooooooo`1@oooo100000;oool0
10000?ooooooo`0000[oool00`00001Vo`1Vo`0206Ko0P0000Goool00`000?ooooooo`06oooo0`1V
ob[oool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0E_ooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`04000006Ko06Ko06Ko0oooo`040000oooooooooooo1@1Vobgoool0
0`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0Eoooo`80000:oooo0P0000Coool3000000Go
ool0I_l0I_l0I_l000000`1Voc;oool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0L?oo
o`80000doooo00<0I_ooooooool0F?ooo`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0c
oooo00<0I_ooooooool0F?ooo`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0coooo00<0
I_ooooooool0F?ooo`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0coooo00<0I_oooooo
ool0F?ooo`006Oooo`<000000`1Vooooooooo`0eoooo100003Ooool20000=?ooo`0406Kooooooooo
oooo100003_oool300005Oooo`006_ooo`030000oooo06Ko03Ooool00`000?ooooooo`0hoooo00<0
003oooooool0<oooo`0506Kooooooooooooo000003ooool00`000?ooooooo`0Doooo000Goooo1@00
000306Kooooooooo03Koool00`000?ooooooo`0goooo00<0003oooooool0<oooo`0306Kooooooooo
00;oool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`060000oooooooo0000oooo
06Ko<Oooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo03?oool00`1Vooooooooo`03
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`050000oooo0000oooo06Ko
03Ooool010000?ooooooo`0003Ooool20000=?ooo`0506Kooooooooooooo000000;oool00`000?oo
ooooo`0hoooo00<0003oool000005_ooo`006Oooo`8000000oooo`1Vooooo`0goooo0P0003Soool0
0`000?ooooooo`0coooo00<0I_ooooooool00_ooo`80000loooo0P0001Koool001coool00`1Voooo
ooooo`1`oooo00<0003oooooool0<oooo`0306Kooooooooo05Soool001coool00`1Vooooooooo`1`
oooo0P0003Coool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo
03?oool00`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool0
0`1Vooooooooo`1Hoooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool00`1Voooo
ooooo`1Hoooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`06oooo00?o09Woooooool00ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
oooooooo03Woool00`000?ooooooo`0doooo00?o09Woooooool00oooo`030000oooooooo01Goool0
08ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Wooooo
ool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06ooo
o`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOoo
ooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Sooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2I
oooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001a
oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`00073oool00ol0VOooooooo`0Koooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0L?oo
o`03o`2Ioooooooo01_oool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001a
oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?
oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o
09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo
073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool0
08ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Wooooo
ool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06ooo
o`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOoo
ooooo`0Koooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0L?ooo`03o`2I
oooooooo01_oool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000L?ooo`03o`2Ioooooooo01_oool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001loooo0P0000[oool3
00001?ooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo0P00077oool00ol0VOoo
ooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Sooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2I
oooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`80001a
oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?
oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o
09Woooooool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo
073oool00ol0VOooooooo`0Koooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1`oooo00?o
09Woooooool06oooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`00073oool00ol0VOooooooo`0Koooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
073oool00ol0VOooooooo`0Koooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2Ioooooooo01_oool008ooool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOoo
ooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOoo
o`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Sooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2I
oooooooo01_oool008ooool20000LOooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`
oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?
oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2Ioooooooo
01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Qoooo`D00003oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool008Woool00`000?ooooooo`03oooo0`00073oool00ol0VOoo
ooooo`0Koooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001?oo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Woool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oo
ooooo`08oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000>oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.93871 .30902 L
.94807 .30902 L
.95322 .30902 L
.95575 .30902 L
.95687 .30902 L
.9581 .30902 L
s
.9581 .30902 m
.95821 .61803 L
s
0 .4 1 r
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03754 .30902 L
.0389 .30902 L
.0402 .30902 L
.04136 .30902 L
.04262 .15451 L
.04385 .15451 L
.045 .15451 L
.04762 .15451 L
.05293 .15451 L
.06244 .15451 L
.10458 .15451 L
.14335 .15451 L
.18458 .15451 L
.22428 .15451 L
.24432 .15451 L
.26248 .15451 L
.26734 .15451 L
.27261 .15451 L
.27502 .15451 L
.27758 .15451 L
.27863 .15451 L
.27976 .15451 L
.281 .15531 L
.28215 .15605 L
.30312 .16895 L
.34448 .19128 L
.38433 .20943 L
.42266 .22424 L
.46344 .23758 L
.47319 .24045 L
.48369 .24341 L
.48853 .24472 L
.49361 .24608 L
.49571 .24664 L
.49796 .24722 L
.49925 .24756 L
.50042 .24764 L
.5016 .24734 L
.50271 .24705 L
.54046 .2364 L
.57892 .22367 L
.61984 .20767 L
.65925 .18943 L
.69713 .1688 L
.70711 .1628 L
.71202 .15975 L
.71658 .15686 L
Mistroke
.71788 .15603 L
.71911 .15524 L
.71979 .1548 L
.72052 .30902 L
.7218 .30902 L
.7275 .30902 L
.73747 .30902 L
.77853 .30902 L
.81807 .30902 L
.85609 .30902 L
.89657 .30902 L
.93553 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001_ooolm06Ko8oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000=Oooo`0306Kooooooooo05Koool001_oool00`1Vooooooooo`0joooo00<0I_oooooo
ool06_ooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0doooo0P1V
oeSoool001_oool00`1Vooooooooo`0koooo0P1Vob3oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0<Oooo`<0I_l00oooo`1Vooooo`1Goooo000Koooo00<0I_oooooo
ool0?Oooo`80I_lOoooo0P0000[oool300001?ooo`030000oooooooo033oool00`1Vooooooooo`02
oooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo03ooool00`1Vooooooooo`0_oooo0P00
033oool00`1Vooooooooo`03oooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo043oool2
06Ko;oooo`030000oooooooo02goool206Ko1_ooo`0306Kooooooooo05Koool001_oool00`1Voooo
ooooo`12oooo0P1Vobgoool00`000?ooooooo`0[oooo0P1Vo`Soool00`1Vooooooooo`1Foooo000K
oooo00<0I_ooooooool0A?ooo`80I_l[oooo00<0003oooooool0:Oooo`80I_l:oooo00<0I_oooooo
ool0E_ooo`006oooo`0306Kooooooooo04Koool206Ko:Oooo`80000Xoooo0P1Vo`coool00`1Voooo
ooooo`1Foooo000Koooo00<0I_ooooooool0B?ooo`80I_lWoooo00<0003oooooool09Oooo`80I_l>
oooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo04[oool206Ko9Oooo`030000oooooooo
02?oool206Ko4?ooo`0306Kooooooooo05Koool001_oool00`1Vooooooooo`1<oooo0P1Vob?oool0
0`000?ooooooo`0Qoooo0P1Voa;oool00`1Vooooooooo`1Foooo000Koooo00<0I_ooooooool0C_oo
o`<0I_lPoooo0P00023oool206Ko5?ooo`0306Kooooooooo05Koool001_oool00`1Vooooooooo`1A
oooo0P1Voakoool00`000?ooooooo`0Moooo0P1VoaKoool00`1Vooooooooo`1Foooo000Koooo00<0
I_ooooooool0Doooo`<0I_lKoooo00<0003oooooool06_ooo`<0I_lHoooo00<0I_ooooooool0E_oo
o`006oooo`0306Kooooooooo05Koool206Ko6Oooo`030000oooooooo01Soool206Ko6oooo`0306Ko
oooooooo05Koool001_oool00`1Vooooooooo`1Hoooo0P1VoaOoool200005_ooo`<0I_lMoooo00<0
I_ooooooool0E_ooo`006oooo`0306Kooooooooo05[oool206Ko5Oooo`030000oooooooo01?oool2
06Ko8?ooo`0306Kooooooooo05Koool001_oool00`1Vooooooooo`1Hoooo0P0000;oool206Ko0P00
00?oool400000oooo`800005oooo00<0003oooooool04?ooo`<0I_lRoooo00<0I_ooooooool0E_oo
o`006oooo`0306Kooooooooo05Ooool010000?ooooooo`0000Coool406Ko00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo00goool306Ko9Oooo`0306Kooooooooo05Koool0
01_oool00`1Vooooooooo`1Goooo00@0003oooooool00008oooo00@0I_l00000I_l0I_l5oooo00<0
003oooooool00_ooo`<00009oooo101VobSoool00`1Vooooooooo`1Foooo000Koooo00<0I_oooooo
ool0DOooo`@00002oooo00@0003oooooool0000:oooo00D0003oool0I_l0I_ooool00P0000Goool0
0`000?ooooooo`06oooo0`1Vobcoool00`1Vooooooooo`1Foooo000Koooo00<0I_ooooooool0Eooo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`0306Ko000006Ko00Goool00`000?oo
ooooo`03oooo0`1Vobooool00`1Vooooooooo`1Foooo000Koooo00<0I_ooooooool0F?ooo`80000:
oooo0P0000Coool300000`1Vo`04oooo0000oooooooo0`1Voc;oool00`1Vooooooooo`1Foooo000K
oooo00<0I_ooooooool0L?ooo`0406Ko0000000006Ko=Oooo`0306Kooooooooo05Koool001_oool0
0`1Vooooooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool001_oool00`1Voooo
ooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool001_oool00`1Vooooooooo`1a
oooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool001Woool30000>?ooo`@0000goooo0P00
03Koool00`1Vooooo`0000030000>oooo`<0000Eoooo000Joooo00<00000I_ooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0eoooo00<0I_ooool00000?oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0eoooo00@0I_ooooooool0000k
oooo1@0001Goool0017oool400000_ooo`050000oooooooo000006Ko03;oool400001?ooo`030000
oooooooo03Koool00`000?ooooooo`0eoooo00D0I_ooooooooooool00000>_ooo`040000oooooooo
00005_ooo`006?ooo`040000oooo000006Ko>?ooo`040000oooooooo0000=oooo`80000foooo00<0
I_ooool000000_ooo`030000oooooooo03Soool00`000?ooo`00000Foooo000Ioooo0P00000306Ko
oooooooo03Ooool20000>?ooo`030000oooooooo03Goool00`1Vooooooooo`020000??ooo`80000F
oooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo03Goool00`1Vooooooooo`1Foooo000K
oooo00<0I_ooooooool0LOooo`80000foooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo
077oool00`000?ooooooo`0eoooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo077oool0
0`000?ooooooo`0eoooo00<0I_ooooooool0E_ooo`006oooo`0306Kooooooooo077oool00`000?oo
ooooo`0eoooo00<0I_ooooooool0E_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool01ooo
o`03o`2Ioooooooo00;oool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`000?ooooooo`0ioooo00<0003oooooool0=Oooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`0Eoooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool2
0000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_oo
o`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOoo
o`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?oo
ooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0J
oooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2I
oooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000
oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo
01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o
09Woooooool06_ooo`00M_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0LOooo`03o`2Ioooooooo01[oool007Goool010000?ooooooo`0000Soool00`000?ooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool007Goool0
10000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`<0001aoooo00?o
09Woooooool06_ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Ooo
o`030000oooooooo077oool00ol0VOooooooo`0Joooo001eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo077oool00ol0VOooooooo`0J
oooo001foooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0LOooo`03o`2Ioooooooo
01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o
09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0
003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool0
08ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool0
0ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool2
0000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_oo
o`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOoo
o`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?oo
ooooo`1aoooo00?o09Woooooool06_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo077oool00ol0VOooooooo`0Joooo001koooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool007_oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0`00077oool00ol0VOooooooo`0Joooo001koooo00@0003ooooo
ool00009oooo0P0000Goool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1aoooo00?o09Woooooool06_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Sooo
o`80001boooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0J
oooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2I
oooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000
oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo
01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o
09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0
003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool0
08ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00M_ooo`800004oooo0P0000Goool0
0`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00MOoo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0LOooo`03o`2Ioooooooo01[oool007Goool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`<0001aoooo00?o09Woooooool06_ooo`00MOooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Goool00`000?ooooooo`1aoooo00?o09Wooooo
ool06_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00M_ooo`800009oooo100000?oool3
00001?ooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo0P0007;oool00ol0VOoo
ooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool00`000?oo
ooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0J
oooo002?oooo0P0007;oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2I
oooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000
oooooooo077oool00ol0VOooooooo`0Joooo002?oooo0P0007;oool00ol0VOooooooo`0Joooo002?
oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o
09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo0P00
07;oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool0
08Ooool500000oooo`030000oooooooo077oool00ol0VOooooooo`0Joooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo077oool00ol0VOooooooo`0Joooo0029oooo00<0003oooooool00ooo
o`<0001aoooo00?o09Woooooool06_ooo`00ROooo`030000oooooooo09Coool008Woool00`000?oo
ooooo`2Doooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Woool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo00@0003ooooo
ool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000oooooooo00Soool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.93871 .30902 L
.94807 .30902 L
.95322 .30902 L
.9581 .30902 L
.96029 .30902 L
.96263 .30902 L
.96385 .30902 L
s
.96385 .30902 m
.96392 .61803 L
s
0 .4 1 r
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03406 .30902 L
.03527 .30902 L
.03636 .15451 L
.03754 .15451 L
.04262 .15451 L
.06244 .15451 L
.10458 .15451 L
.14545 .15451 L
.1848 .15451 L
.22263 .15451 L
.24367 .15451 L
.26292 .15451 L
.26752 .15451 L
.27004 .15451 L
.27242 .15451 L
.27308 .15451 L
.27378 .15451 L
.27454 .15498 L
.27524 .15544 L
.2778 .15708 L
.2828 .16023 L
.30169 .17158 L
.33966 .19184 L
.38009 .21014 L
.419 .22505 L
.46036 .23844 L
.48105 .24431 L
.49016 .24674 L
.49499 .24799 L
.49753 .24864 L
.4982 .24881 L
.49891 .24899 L
.5002 .24921 L
.50145 .2489 L
.50259 .24861 L
.5052 .24794 L
.50979 .24675 L
.51879 .24436 L
.53853 .23877 L
.57851 .22592 L
.61698 .21135 L
.6579 .19304 L
.67826 .18268 L
.6973 .17216 L
.71557 .16125 L
.72083 .15795 L
.72342 .1563 L
Mistroke
.72468 .15549 L
.72582 .15475 L
.72694 .30902 L
.72799 .30902 L
.7303 .30902 L
.73519 .30902 L
.77379 .30902 L
.81485 .30902 L
.85439 .30902 L
.89241 .30902 L
.93289 .30902 L
.97185 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-4)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-2)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.20238 .30902 m
.20238 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.79762 .30902 m
.79762 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001foooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08koool007Goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08koool007Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002>oooo001_oooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0S_ooo`00MOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001foooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08koool001Woooln06Ko9?ooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000=_ooo`0306Kooooooooo05Goool001Woool00`1Vooooooooo`0koooo00<0I_oooooo
ool06oooo`@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0eoooo0P1V
oeOoool001Woool00`1Vooooooooo`0loooo00<0I_ooooooool08?ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`0doooo00<0I_ooool0I_l0Eoooo`006Oooo`0306Ko
oooooooo03goool206Ko8Oooo`80000:oooo0`0000Coool00`000?ooooooo`0boooo0P1Vo`;oool0
0`1Vooooooooo`1Eoooo000Ioooo00<0I_ooooooool0?oooo`80I_lboooo0P00037oool206Ko1?oo
o`0306Kooooooooo05Goool001Woool00`1Vooooooooo`11oooo00<0I_ooooooool0;oooo`030000
oooooooo02koool206Ko1_ooo`0306Kooooooooo05Goool001Woool00`1Vooooooooo`12oooo0P1V
obooool00`000?ooooooo`0/oooo0P1Vo`Soool00`1Vooooooooo`1Eoooo000Ioooo00<0I_oooooo
ool0A?ooo`80I_l]oooo00<0003oooooool0:_ooo`80I_l:oooo00<0I_ooooooool0EOooo`006Ooo
o`0306Kooooooooo04Koool206Ko:oooo`80000Yoooo0P1Vo`coool00`1Vooooooooo`1Eoooo000I
oooo00<0I_ooooooool0B?ooo`80I_lYoooo00<0003oooooool09_ooo`80I_l>oooo00<0I_oooooo
ool0EOooo`006Oooo`0306Kooooooooo04[oool206Ko9oooo`030000oooooooo02Goool00`1Voooo
ooooo`0>oooo00<0I_ooooooool0EOooo`006Oooo`0306Kooooooooo04coool306Ko9?ooo`030000
oooooooo02?oool206Ko4Oooo`0306Kooooooooo05Goool001Woool00`1Vooooooooo`1?oooo0P1V
ob;oool200008_ooo`80I_lCoooo00<0I_ooooooool0EOooo`006Oooo`0306Kooooooooo057oool3
06Ko7oooo`030000oooooooo01ooool206Ko5Oooo`0306Kooooooooo05Goool001Woool00`1Voooo
ooooo`1Doooo0`1Voacoool00`000?ooooooo`0Moooo0P1VoaOoool00`1Vooooooooo`1Eoooo000I
oooo00<0I_ooooooool0Eoooo`80I_lJoooo00<0003oooooool06_ooo`<0I_lIoooo00<0I_oooooo
ool0EOooo`006Oooo`0306Kooooooooo05Woool206Ko6?ooo`80000Hoooo0`1Voacoool00`1Voooo
ooooo`1Eoooo000Ioooo00<0I_ooooooool0Foooo`80I_lFoooo00<0003oooooool04oooo`@0I_lO
oooo00<0I_ooooooool0EOooo`006Oooo`0306Kooooooooo05[oool2000000Coool0I_l0I_l0I_l2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`0@oooo0`1Vob?oool00`1Vooooooooo`1E
oooo000Ioooo00<0I_ooooooool0FOooo`040000oooooooo00000oooo`<0I_l2oooo00<0003ooooo
ool00oooo`040000oooooooo00001?ooo`030000oooooooo00koool206Ko9_ooo`0306Kooooooooo
05Goool001Woool00`1Vooooooooo`1Ioooo00@0003oooooool00006oooo0P1Vo`03oooo0000oooo
00Koool00`000?ooooooo`02oooo0`0000_oool306Ko:Oooo`0306Kooooooooo05Coool001Woool0
0`1Vooooooooo`1Coooo100000;oool010000?ooooooo`0000Soool206Ko00<0003oooooool00_oo
o`800005oooo00<0003oooooool02Oooo`80I_l/oooo00<0I_ooooooool0E?ooo`006Oooo`0306Ko
oooooooo05Woool010000?ooooooo`0000Soool010000?ooooooo`0000<0I_l00`000?ooooooo`04
oooo00<0003oooooool01Oooo`@0I_l^oooo00<0I_ooooooool0E?ooo`006Oooo`0306Kooooooooo
05[oool200002_ooo`800004oooo0`0000Coool010000?ooooooooooo`@0I_lboooo00<0I_oooooo
ool0E?ooo`006Oooo`0306Kooooooooo06ooool406Ko0P000080I_lfoooo00<0I_ooooooool0E?oo
o`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`006Ooo
o`0306Kooooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`006Oooo`0306Ko
oooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`006Oooo`<0000hoooo1000
03Ooool20000>?ooo`@0000koooo0`0001Goool001Woool00`1Vo`000?ooo`0hoooo00<0003ooooo
ool0>?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005ooo
o`D0000ioooo00<0003oooooool0=oooo`030000oooooooo03Ooool00`1Vo`000?ooo`0joooo1@00
01Goool0017oool400000_ooo`040000oooo06Ko0000<oooo`@00004oooo00<0003oooooool0=_oo
o`030000oooooooo03Ooool00`1Vooooo`00000joooo00@0003oooooool0000Foooo000Hoooo00<0
0000I_l00000>Oooo`040000oooooooo0000=oooo`80000hoooo00@0003oooooool0000joooo00<0
003oool000005_ooo`006Oooo`80000joooo0P0003Soool00`000?ooooooo`0goooo00<0I_l00000
0000??ooo`80000Foooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo03Ooool00`1Voooo
ooooo`1Doooo000Ioooo00<0I_ooooooool0Loooo`80000hoooo00<0I_ooooooool0E?ooo`006Ooo
o`0306Kooooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`006Oooo`0306Ko
oooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`006Oooo`0306Kooooooooo
07?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0
003oooooool02Oooo`04o`2Ioooooooo00005oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0003oooooool0>Oooo`030000oooooooo03Ooool01?l0VOooooooo`0001Ooool0
08ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o09Wooooo
ool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?oo
o`00Soooo`80001doooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOoo
ooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?oo
ooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o09Woooooool06?ooo`00Sooo
o`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2I
oooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001d
oooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo001f
oooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`1coooo00?o09Wooooo
ool06?ooo`00MOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00MOooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool00`000?ooooooo`02oooo0`0007?oool00ol0VOooooooo`0Hoooo001e
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Looo
o`03o`2Ioooooooo01Soool007Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`04oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool007Koool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001d
oooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?
oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o
09Woooooool06?ooo`00Soooo`80001doooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo
07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool0
08ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o09Wooooo
ool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?oo
o`00Soooo`80001doooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOoo
ooooo`0Hoooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Loooo`03o`2I
oooooooo01Soool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`1coooo00?o09Woooooool06?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000Loooo`03o`2Ioooooooo01Soool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo07?oool00ol0VOooooooo`0Hoooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo001loooo0P0000[oool3
00001?ooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo0P0007Coool00ol0VOoo
ooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?oo
ooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o09Woooooool06?ooo`00Sooo
o`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2I
oooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001d
oooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?
oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o
09Woooooool06?ooo`00Soooo`80001doooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo
07?oool00ol0VOooooooo`0Hoooo001foooo0P0000Coool200001Oooo`030000oooooooo00;oool2
00001Oooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo001eoooo00@0003oooooool0000:
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1coooo00?o
09Woooooool06?ooo`00MOooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo0`0007?oool00ol0VOooooooo`0Hoooo001eoooo00@0003oooooool0000;oooo00@0
003oooooooooool200001Oooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo001eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo
07?oool00ol0VOooooooo`0Hoooo001foooo0P0000Woool400000oooo`<00004oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008ooool20000M?ooo`03o`2Ioooooooo01Soool008ooool0
0`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOoo
ooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool20000M?oo
o`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Sooo
o`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2I
oooooooo01Soool008ooool20000M?ooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1c
oooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?
oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool20000M?ooo`03o`2Ioooooooo
01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Qoooo`D00003oooo00<0
003oooooool0Loooo`03o`2Ioooooooo01Soool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008Woool00`000?ooooooo`03oooo0`0007?oool00ol0VOoo
ooooo`0Hoooo0029oooo00<0003oooooool0U?ooo`00ROooo`030000oooooooo09Coool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200000ooo
o`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00_oool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02Oooo`<00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.05744, 0.0331289, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.05744, 0.0331289, 0.0127628}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{Automatic, 173}, {Automatic, -27}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 212, 6, 96, "Title"],
Cell[1942, 60, 1013, 25, 258, "Text"],
Cell[2958, 87, 120, 4, 49, "Text"],
Cell[3081, 93, 344, 6, 19, "Input",
  CellOpen->False],
Cell[3428, 101, 185, 5, 68, "Text"],
Cell[3616, 108, 81, 1, 30, "Input"],
Cell[3700, 111, 108, 1, 49, "Text"],
Cell[3811, 114, 557, 12, 19, "Input",
  CellOpen->False],
Cell[4371, 128, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4448, 132, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4526, 136, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[4924, 152, 636, 10, 110, "Input"],

Cell[CellGroupData[{
Cell[5585, 166, 23315, 932, 186, 12248, 791, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28903, 1100, 23501, 937, 186, 12302, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[52407, 2039, 23293, 936, 186, 12333, 796, "GraphicsData", "PostScript", \
"Graphics"],
Cell[75703, 2977, 23339, 935, 186, 12306, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[99045, 3914, 23202, 932, 186, 12283, 793, "GraphicsData", "PostScript", \
"Graphics"],
Cell[122250, 4848, 23401, 937, 186, 12336, 796, "GraphicsData", "PostScript", \
"Graphics"],
Cell[145654, 5787, 23276, 934, 186, 12304, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[168933, 6723, 23448, 936, 186, 12302, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[192384, 7661, 23241, 933, 186, 12302, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[215628, 8596, 23384, 937, 186, 12335, 796, "GraphicsData", "PostScript", \
"Graphics"],
Cell[239015, 9535, 23195, 934, 186, 12316, 795, "GraphicsData", "PostScript", \
"Graphics"],
Cell[262213, 10471, 23294, 936, 186, 12351, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[285510, 11409, 23180, 935, 186, 12350, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[308693, 12346, 23301, 934, 186, 12309, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[331997, 13282, 23162, 933, 186, 12316, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[355162, 14217, 23297, 937, 186, 12370, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[378462, 15156, 23071, 934, 186, 12350, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[401536, 16092, 23245, 934, 186, 12322, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[424784, 17028, 22210, 921, 186, 12320, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[446997, 17951, 22091, 921, 186, 12338, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[469091, 18874, 21622, 913, 186, 12299, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[490716, 19789, 22139, 921, 186, 12338, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[512858, 20712, 22994, 932, 186, 12334, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[535855, 21646, 23937, 945, 186, 12366, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[559795, 22593, 24206, 948, 186, 12347, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[584004, 23543, 24350, 950, 186, 12349, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[608357, 24495, 24337, 953, 186, 12413, 801, "GraphicsData", \
"PostScript", "Graphics"],
Cell[632697, 25450, 24388, 950, 186, 12351, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[657088, 26402, 24155, 945, 186, 12321, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[681246, 27349, 24293, 949, 186, 12353, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[705542, 28300, 24237, 950, 186, 12382, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[729782, 29252, 24378, 953, 186, 12418, 801, "GraphicsData", \
"PostScript", "Graphics"],
Cell[754163, 30207, 24302, 953, 186, 12431, 802, "GraphicsData", \
"PostScript", "Graphics"],
Cell[778468, 31162, 24451, 952, 186, 12382, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[802922, 32116, 24335, 952, 186, 12395, 800, "GraphicsData", \
"PostScript", "Graphics"],
Cell[827260, 33070, 24458, 954, 186, 12417, 801, "GraphicsData", \
"PostScript", "Graphics"],
Cell[851721, 34026, 24337, 953, 186, 12417, 801, "GraphicsData", \
"PostScript", "Graphics"],
Cell[876061, 34981, 24355, 950, 186, 12354, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[900419, 35933, 24260, 948, 186, 12336, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[924682, 36883, 23829, 943, 186, 12351, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[948514, 37828, 21905, 896, 186, 11699, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[970422, 38726, 23445, 930, 186, 11991, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[993870, 39658, 23840, 933, 186, 11957, 782, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1017713, 40593, 23937, 937, 186, 12005, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1041653, 41532, 23913, 940, 186, 12070, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1065569, 42474, 24035, 941, 186, 12071, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1089607, 43417, 23945, 940, 186, 12066, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1113555, 44359, 24010, 938, 186, 12005, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1137568, 45299, 23903, 939, 186, 12069, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1161474, 46240, 24020, 942, 186, 12088, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1185497, 47184, 23875, 938, 186, 12036, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1209375, 48124, 23965, 939, 186, 12037, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1233343, 49065, 23854, 936, 186, 12020, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1257200, 50003, 24006, 940, 186, 12050, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1281209, 50945, 23973, 943, 186, 12114, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1305185, 51890, 23935, 937, 186, 12020, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1329123, 52829, 23795, 938, 186, 12062, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1352921, 53769, 23816, 936, 186, 12022, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1376740, 54707, 23233, 929, 186, 12022, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1399976, 55638, 23226, 929, 186, 12040, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1423205, 56569, 22936, 926, 186, 12029, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1446144, 57497, 23399, 939, 186, 12180, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1469546, 58438, 23612, 946, 186, 12272, 802, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1493161, 59386, 24199, 955, 186, 12308, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1517363, 60343, 24389, 961, 186, 12372, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1541755, 61306, 24484, 962, 186, 12374, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1566242, 62270, 24421, 963, 186, 12400, 810, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1590666, 63235, 24505, 961, 186, 12342, 806, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1615174, 64198, 24364, 959, 186, 12335, 806, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1639541, 65159, 24545, 963, 186, 12370, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1664089, 66124, 24512, 963, 186, 12386, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1688604, 67089, 24679, 968, 186, 12444, 813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1713286, 68059, 24502, 961, 186, 12352, 807, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1737791, 69022, 24768, 972, 186, 12492, 816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1762562, 69996, 24610, 965, 186, 12395, 810, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1787175, 70963, 24778, 971, 186, 12482, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1811956, 71936, 24629, 966, 186, 12406, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1836588, 72904, 24778, 968, 186, 12421, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1861369, 73874, 24697, 969, 186, 12445, 813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1886069, 74845, 24825, 972, 186, 12476, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1910897, 75819, 24537, 963, 186, 12379, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1935437, 76784, 24916, 973, 186, 12486, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1960356, 77759, 24767, 969, 186, 12451, 813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1985126, 78730, 24914, 973, 186, 12480, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2010043, 79705, 24816, 969, 186, 12427, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2034862, 80676, 24949, 973, 186, 12483, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2059814, 81651, 24798, 969, 186, 12433, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2084615, 82622, 24883, 968, 186, 12384, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2109501, 83592, 24867, 974, 186, 12514, 817, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2134371, 84568, 24942, 974, 186, 12500, 816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2159316, 85544, 24942, 976, 186, 12545, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2184261, 86522, 24987, 973, 186, 12464, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2209251, 87497, 24896, 973, 186, 12478, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2234150, 88472, 25028, 976, 186, 12513, 817, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2259181, 89450, 24938, 973, 186, 12480, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2284122, 90425, 25011, 973, 186, 12464, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2309136, 91400, 24824, 971, 186, 12463, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2333963, 92373, 24829, 969, 186, 12428, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2358795, 93344, 24638, 968, 186, 12443, 813, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

